Class: Akeyless::AccountGeneralSettings

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/account_general_settings.rb

Overview

AccountGeneralSettings describes general settings for an account

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AccountGeneralSettings

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/akeyless/models/account_general_settings.rb', line 177

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::AccountGeneralSettings` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::AccountGeneralSettings`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_default_key_item_id')
    self. = attributes[:'account_default_key_item_id']
  end

  if attributes.key?(:'account_default_key_name')
    self. = attributes[:'account_default_key_name']
  end

  if attributes.key?(:'account_file_bytes_used')
    self. = attributes[:'account_file_bytes_used']
  end

  if attributes.key?(:'ai_insights')
    self.ai_insights = attributes[:'ai_insights']
  end

  if attributes.key?(:'allow_auto_fill')
    self.allow_auto_fill = attributes[:'allow_auto_fill']
  end

  if attributes.key?(:'allow_passkeys')
    self.allow_passkeys = attributes[:'allow_passkeys']
  end

  if attributes.key?(:'allowed_client_types')
    self.allowed_client_types = attributes[:'allowed_client_types']
  end

  if attributes.key?(:'allowed_clients_ips')
    self.allowed_clients_ips = attributes[:'allowed_clients_ips']
  end

  if attributes.key?(:'allowed_gateways_ips')
    self.allowed_gateways_ips = attributes[:'allowed_gateways_ips']
  end

  if attributes.key?(:'auth_usage_event')
    self.auth_usage_event = attributes[:'auth_usage_event']
  end

  if attributes.key?(:'certificate_expiration_events')
    self.certificate_expiration_events = attributes[:'certificate_expiration_events']
  end

  if attributes.key?(:'data_protection_section')
    self.data_protection_section = attributes[:'data_protection_section']
  end

  if attributes.key?(:'default_auth_method')
    self.default_auth_method = attributes[:'default_auth_method']
  end

  if attributes.key?(:'default_home_page')
    self.default_home_page = attributes[:'default_home_page']
  end

  if attributes.key?(:'dynamic_secret_max_ttl')
    self.dynamic_secret_max_ttl = attributes[:'dynamic_secret_max_ttl']
  end

  if attributes.key?(:'email_customization')
    self.email_customization = attributes[:'email_customization']
  end

  if attributes.key?(:'enable_request_for_access')
    self.enable_request_for_access = attributes[:'enable_request_for_access']
  end

  if attributes.key?(:'enable_search_history')
    self.enable_search_history = attributes[:'enable_search_history']
  end

  if attributes.key?(:'hide_personal_folder')
    self.hide_personal_folder = attributes[:'hide_personal_folder']
  end

  if attributes.key?(:'hide_secret_reveal_copy')
    self.hide_secret_reveal_copy = attributes[:'hide_secret_reveal_copy']
  end

  if attributes.key?(:'hide_static_password')
    self.hide_static_password = attributes[:'hide_static_password']
  end

  if attributes.key?(:'invalid_characters')
    self.invalid_characters = attributes[:'invalid_characters']
  end

  if attributes.key?(:'item_locking')
    self.item_locking = attributes[:'item_locking']
  end

  if attributes.key?(:'item_usage_event')
    self.item_usage_event = attributes[:'item_usage_event']
  end

  if attributes.key?(:'lock_default_key')
    self.lock_default_key = attributes[:'lock_default_key']
  end

  if attributes.key?(:'password_expiration_info')
    self.password_expiration_info = attributes[:'password_expiration_info']
  end

  if attributes.key?(:'password_policy')
    self.password_policy = attributes[:'password_policy']
  end

  if attributes.key?(:'password_score')
    self.password_score = attributes[:'password_score']
  end

  if attributes.key?(:'personal_folder_global_mapping')
    self.personal_folder_global_mapping = attributes[:'personal_folder_global_mapping']
  end

  if attributes.key?(:'protect_items_by_default')
    self.protect_items_by_default = attributes[:'protect_items_by_default']
  end

  if attributes.key?(:'rotation_secret_max_interval')
    self.rotation_secret_max_interval = attributes[:'rotation_secret_max_interval']
  end

  if attributes.key?(:'sharing_policy')
    self.sharing_policy = attributes[:'sharing_policy']
  end
end

Instance Attribute Details

#account_default_key_item_idObject

AccountDefaultKeyItemID is the item ID of the DFC key item configured as the default protection key



20
21
22
# File 'lib/akeyless/models/account_general_settings.rb', line 20

def 
  @account_default_key_item_id
end

#account_default_key_nameObject

AccountDefaultKeyName is the name of the DFC key item configured as the default key This is here simply for the response to include the item name in addition to the display ID so the client can properly show this to the user. It will not be saved to the DB, only the AccountDefaultKeyItemID will.



23
24
25
# File 'lib/akeyless/models/account_general_settings.rb', line 23

def 
  @account_default_key_name
end

#account_file_bytes_usedObject

AccountFileBytesUsed tracks active + pending file-item plain bytes for quota enforcement.



26
27
28
# File 'lib/akeyless/models/account_general_settings.rb', line 26

def 
  @account_file_bytes_used
end

#ai_insightsObject

Returns the value of attribute ai_insights.



28
29
30
# File 'lib/akeyless/models/account_general_settings.rb', line 28

def ai_insights
  @ai_insights
end

#allow_auto_fillObject

Returns the value of attribute allow_auto_fill.



30
31
32
# File 'lib/akeyless/models/account_general_settings.rb', line 30

def allow_auto_fill
  @allow_auto_fill
end

#allow_passkeysObject

Returns the value of attribute allow_passkeys.



32
33
34
# File 'lib/akeyless/models/account_general_settings.rb', line 32

def allow_passkeys
  @allow_passkeys
end

#allowed_client_typesObject

Returns the value of attribute allowed_client_types.



34
35
36
# File 'lib/akeyless/models/account_general_settings.rb', line 34

def allowed_client_types
  @allowed_client_types
end

#allowed_clients_ipsObject

Returns the value of attribute allowed_clients_ips.



36
37
38
# File 'lib/akeyless/models/account_general_settings.rb', line 36

def allowed_clients_ips
  @allowed_clients_ips
end

#allowed_gateways_ipsObject

Returns the value of attribute allowed_gateways_ips.



38
39
40
# File 'lib/akeyless/models/account_general_settings.rb', line 38

def allowed_gateways_ips
  @allowed_gateways_ips
end

#auth_usage_eventObject

Returns the value of attribute auth_usage_event.



40
41
42
# File 'lib/akeyless/models/account_general_settings.rb', line 40

def auth_usage_event
  @auth_usage_event
end

#certificate_expiration_eventsObject

Returns the value of attribute certificate_expiration_events.



42
43
44
# File 'lib/akeyless/models/account_general_settings.rb', line 42

def certificate_expiration_events
  @certificate_expiration_events
end

#data_protection_sectionObject

Returns the value of attribute data_protection_section.



44
45
46
# File 'lib/akeyless/models/account_general_settings.rb', line 44

def data_protection_section
  @data_protection_section
end

#default_auth_methodObject

Returns the value of attribute default_auth_method.



46
47
48
# File 'lib/akeyless/models/account_general_settings.rb', line 46

def default_auth_method
  @default_auth_method
end

#default_home_pageObject

Returns the value of attribute default_home_page.



48
49
50
# File 'lib/akeyless/models/account_general_settings.rb', line 48

def default_home_page
  @default_home_page
end

#dynamic_secret_max_ttlObject

Returns the value of attribute dynamic_secret_max_ttl.



50
51
52
# File 'lib/akeyless/models/account_general_settings.rb', line 50

def dynamic_secret_max_ttl
  @dynamic_secret_max_ttl
end

#email_customizationObject

Returns the value of attribute email_customization.



52
53
54
# File 'lib/akeyless/models/account_general_settings.rb', line 52

def email_customization
  @email_customization
end

#enable_request_for_accessObject

Returns the value of attribute enable_request_for_access.



54
55
56
# File 'lib/akeyless/models/account_general_settings.rb', line 54

def enable_request_for_access
  @enable_request_for_access
end

#enable_search_historyObject

Returns the value of attribute enable_search_history.



56
57
58
# File 'lib/akeyless/models/account_general_settings.rb', line 56

def enable_search_history
  @enable_search_history
end

#hide_personal_folderObject

Returns the value of attribute hide_personal_folder.



58
59
60
# File 'lib/akeyless/models/account_general_settings.rb', line 58

def hide_personal_folder
  @hide_personal_folder
end

#hide_secret_reveal_copyObject

Returns the value of attribute hide_secret_reveal_copy.



60
61
62
# File 'lib/akeyless/models/account_general_settings.rb', line 60

def hide_secret_reveal_copy
  @hide_secret_reveal_copy
end

#hide_static_passwordObject

Returns the value of attribute hide_static_password.



62
63
64
# File 'lib/akeyless/models/account_general_settings.rb', line 62

def hide_static_password
  @hide_static_password
end

#invalid_charactersObject

InvalidCharacters is the invalid characters for items/targets/roles/auths/notifier_forwarder naming convention



65
66
67
# File 'lib/akeyless/models/account_general_settings.rb', line 65

def invalid_characters
  @invalid_characters
end

#item_lockingObject

Returns the value of attribute item_locking.



67
68
69
# File 'lib/akeyless/models/account_general_settings.rb', line 67

def item_locking
  @item_locking
end

#item_usage_eventObject

Returns the value of attribute item_usage_event.



69
70
71
# File 'lib/akeyless/models/account_general_settings.rb', line 69

def item_usage_event
  @item_usage_event
end

#lock_default_keyObject

LockDefaultKey determines whether the configured default key can be updated by end-users on a per-request basis true - all requests use the configured default key false - every request can determine its protection key (default) nil - change nothing (every request can determine its protection key (default)) This parameter is only relevant if AccountDefaultKeyItemID is not empty



72
73
74
# File 'lib/akeyless/models/account_general_settings.rb', line 72

def lock_default_key
  @lock_default_key
end

#password_expiration_infoObject

Returns the value of attribute password_expiration_info.



74
75
76
# File 'lib/akeyless/models/account_general_settings.rb', line 74

def password_expiration_info
  @password_expiration_info
end

#password_policyObject

Returns the value of attribute password_policy.



76
77
78
# File 'lib/akeyless/models/account_general_settings.rb', line 76

def password_policy
  @password_policy
end

#password_scoreObject

Returns the value of attribute password_score.



78
79
80
# File 'lib/akeyless/models/account_general_settings.rb', line 78

def password_score
  @password_score
end

#personal_folder_global_mappingObject

Returns the value of attribute personal_folder_global_mapping.



80
81
82
# File 'lib/akeyless/models/account_general_settings.rb', line 80

def personal_folder_global_mapping
  @personal_folder_global_mapping
end

#protect_items_by_defaultObject

Returns the value of attribute protect_items_by_default.



82
83
84
# File 'lib/akeyless/models/account_general_settings.rb', line 82

def protect_items_by_default
  @protect_items_by_default
end

#rotation_secret_max_intervalObject

Returns the value of attribute rotation_secret_max_interval.



84
85
86
# File 'lib/akeyless/models/account_general_settings.rb', line 84

def rotation_secret_max_interval
  @rotation_secret_max_interval
end

#sharing_policyObject

Returns the value of attribute sharing_policy.



86
87
88
# File 'lib/akeyless/models/account_general_settings.rb', line 86

def sharing_policy
  @sharing_policy
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/akeyless/models/account_general_settings.rb', line 412

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



127
128
129
# File 'lib/akeyless/models/account_general_settings.rb', line 127

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/akeyless/models/account_general_settings.rb', line 89

def self.attribute_map
  {
    :'account_default_key_item_id' => :'account_default_key_item_id',
    :'account_default_key_name' => :'account_default_key_name',
    :'account_file_bytes_used' => :'account_file_bytes_used',
    :'ai_insights' => :'ai_insights',
    :'allow_auto_fill' => :'allow_auto_fill',
    :'allow_passkeys' => :'allow_passkeys',
    :'allowed_client_types' => :'allowed_client_types',
    :'allowed_clients_ips' => :'allowed_clients_ips',
    :'allowed_gateways_ips' => :'allowed_gateways_ips',
    :'auth_usage_event' => :'auth_usage_event',
    :'certificate_expiration_events' => :'certificate_expiration_events',
    :'data_protection_section' => :'data_protection_section',
    :'default_auth_method' => :'default_auth_method',
    :'default_home_page' => :'default_home_page',
    :'dynamic_secret_max_ttl' => :'dynamic_secret_max_ttl',
    :'email_customization' => :'email_customization',
    :'enable_request_for_access' => :'enable_request_for_access',
    :'enable_search_history' => :'enable_search_history',
    :'hide_personal_folder' => :'hide_personal_folder',
    :'hide_secret_reveal_copy' => :'hide_secret_reveal_copy',
    :'hide_static_password' => :'hide_static_password',
    :'invalid_characters' => :'invalid_characters',
    :'item_locking' => :'item_locking',
    :'item_usage_event' => :'item_usage_event',
    :'lock_default_key' => :'lock_default_key',
    :'password_expiration_info' => :'password_expiration_info',
    :'password_policy' => :'password_policy',
    :'password_score' => :'password_score',
    :'personal_folder_global_mapping' => :'personal_folder_global_mapping',
    :'protect_items_by_default' => :'protect_items_by_default',
    :'rotation_secret_max_interval' => :'rotation_secret_max_interval',
    :'sharing_policy' => :'sharing_policy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/akeyless/models/account_general_settings.rb', line 388

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



170
171
172
173
# File 'lib/akeyless/models/account_general_settings.rb', line 170

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/akeyless/models/account_general_settings.rb', line 132

def self.openapi_types
  {
    :'account_default_key_item_id' => :'Integer',
    :'account_default_key_name' => :'String',
    :'account_file_bytes_used' => :'Integer',
    :'ai_insights' => :'AiInsightsSetting',
    :'allow_auto_fill' => :'Boolean',
    :'allow_passkeys' => :'Boolean',
    :'allowed_client_types' => :'AllowedClientType',
    :'allowed_clients_ips' => :'AllowedIpSettings',
    :'allowed_gateways_ips' => :'AllowedIpSettings',
    :'auth_usage_event' => :'UsageEventSetting',
    :'certificate_expiration_events' => :'CertificateExpirationEventsSettings',
    :'data_protection_section' => :'DataProtectionSection',
    :'default_auth_method' => :'DefaultAuthMethodSettings',
    :'default_home_page' => :'DefaultHomePage',
    :'dynamic_secret_max_ttl' => :'DynamicSecretMaxTtl',
    :'email_customization' => :'EmailCustomization',
    :'enable_request_for_access' => :'Boolean',
    :'enable_search_history' => :'Boolean',
    :'hide_personal_folder' => :'Boolean',
    :'hide_secret_reveal_copy' => :'Boolean',
    :'hide_static_password' => :'Boolean',
    :'invalid_characters' => :'String',
    :'item_locking' => :'ItemLockingSetting',
    :'item_usage_event' => :'UsageEventSetting',
    :'lock_default_key' => :'Boolean',
    :'password_expiration_info' => :'PasswordExpirationInfo',
    :'password_policy' => :'PasswordPolicyInfo',
    :'password_score' => :'PasswordScoreSetting',
    :'personal_folder_global_mapping' => :'PersonalFolderGlobalMappingSettings',
    :'protect_items_by_default' => :'Boolean',
    :'rotation_secret_max_interval' => :'RotationSecretMaxInterval',
    :'sharing_policy' => :'SharingPolicyInfo'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/akeyless/models/account_general_settings.rb', line 336

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
       == o. &&
       == o. &&
      ai_insights == o.ai_insights &&
      allow_auto_fill == o.allow_auto_fill &&
      allow_passkeys == o.allow_passkeys &&
      allowed_client_types == o.allowed_client_types &&
      allowed_clients_ips == o.allowed_clients_ips &&
      allowed_gateways_ips == o.allowed_gateways_ips &&
      auth_usage_event == o.auth_usage_event &&
      certificate_expiration_events == o.certificate_expiration_events &&
      data_protection_section == o.data_protection_section &&
      default_auth_method == o.default_auth_method &&
      default_home_page == o.default_home_page &&
      dynamic_secret_max_ttl == o.dynamic_secret_max_ttl &&
      email_customization == o.email_customization &&
      enable_request_for_access == o.enable_request_for_access &&
      enable_search_history == o.enable_search_history &&
      hide_personal_folder == o.hide_personal_folder &&
      hide_secret_reveal_copy == o.hide_secret_reveal_copy &&
      hide_static_password == o.hide_static_password &&
      invalid_characters == o.invalid_characters &&
      item_locking == o.item_locking &&
      item_usage_event == o.item_usage_event &&
      lock_default_key == o.lock_default_key &&
      password_expiration_info == o.password_expiration_info &&
      password_policy == o.password_policy &&
      password_score == o.password_score &&
      personal_folder_global_mapping == o.personal_folder_global_mapping &&
      protect_items_by_default == o.protect_items_by_default &&
      rotation_secret_max_interval == o.rotation_secret_max_interval &&
      sharing_policy == o.sharing_policy
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



483
484
485
486
487
488
489
490
491
492
493
494
495
# File 'lib/akeyless/models/account_general_settings.rb', line 483

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


375
376
377
# File 'lib/akeyless/models/account_general_settings.rb', line 375

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



381
382
383
# File 'lib/akeyless/models/account_general_settings.rb', line 381

def hash
  [, , , ai_insights, allow_auto_fill, allow_passkeys, allowed_client_types, allowed_clients_ips, allowed_gateways_ips, auth_usage_event, certificate_expiration_events, data_protection_section, default_auth_method, default_home_page, dynamic_secret_max_ttl, email_customization, enable_request_for_access, enable_search_history, hide_personal_folder, hide_secret_reveal_copy, hide_static_password, invalid_characters, item_locking, item_usage_event, lock_default_key, password_expiration_info, password_policy, password_score, personal_folder_global_mapping, protect_items_by_default, rotation_secret_max_interval, sharing_policy].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



321
322
323
324
325
# File 'lib/akeyless/models/account_general_settings.rb', line 321

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



459
460
461
# File 'lib/akeyless/models/account_general_settings.rb', line 459

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/akeyless/models/account_general_settings.rb', line 465

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



453
454
455
# File 'lib/akeyless/models/account_general_settings.rb', line 453

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



329
330
331
332
# File 'lib/akeyless/models/account_general_settings.rb', line 329

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end