Class: Akeyless::AerospikeTargetDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/aerospike_target_details.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AerospikeTargetDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/akeyless/models/aerospike_target_details.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::AerospikeTargetDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::AerospikeTargetDetails`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'aerospike_admin_username')
    self.aerospike_admin_username = attributes[:'aerospike_admin_username']
  end

  if attributes.key?(:'aerospike_client_certificate')
    self.aerospike_client_certificate = attributes[:'aerospike_client_certificate']
  end

  if attributes.key?(:'aerospike_client_id')
    self.aerospike_client_id = attributes[:'aerospike_client_id']
  end

  if attributes.key?(:'aerospike_client_private_key')
    self.aerospike_client_private_key = attributes[:'aerospike_client_private_key']
  end

  if attributes.key?(:'aerospike_client_secret')
    self.aerospike_client_secret = attributes[:'aerospike_client_secret']
  end

  if attributes.key?(:'aerospike_cloud')
    self.aerospike_cloud = attributes[:'aerospike_cloud']
  end

  if attributes.key?(:'aerospike_cluster_id')
    self.aerospike_cluster_id = attributes[:'aerospike_cluster_id']
  end

  if attributes.key?(:'aerospike_db_server_name')
    self.aerospike_db_server_name = attributes[:'aerospike_db_server_name']
  end

  if attributes.key?(:'aerospike_enable_mtls')
    self.aerospike_enable_mtls = attributes[:'aerospike_enable_mtls']
  end

  if attributes.key?(:'aerospike_hostname')
    self.aerospike_hostname = attributes[:'aerospike_hostname']
  end

  if attributes.key?(:'aerospike_namespace')
    self.aerospike_namespace = attributes[:'aerospike_namespace']
  end

  if attributes.key?(:'aerospike_password')
    self.aerospike_password = attributes[:'aerospike_password']
  end

  if attributes.key?(:'aerospike_port')
    self.aerospike_port = attributes[:'aerospike_port']
  end

  if attributes.key?(:'aerospike_skip_server_name_validation')
    self.aerospike_skip_server_name_validation = attributes[:'aerospike_skip_server_name_validation']
  end

  if attributes.key?(:'aerospike_ssl_connection_certificate')
    self.aerospike_ssl_connection_certificate = attributes[:'aerospike_ssl_connection_certificate']
  end

  if attributes.key?(:'aerospike_ssl_connection_mode')
    self.aerospike_ssl_connection_mode = attributes[:'aerospike_ssl_connection_mode']
  end
end

Instance Attribute Details

#aerospike_admin_usernameObject

Returns the value of attribute aerospike_admin_username.



18
19
20
# File 'lib/akeyless/models/aerospike_target_details.rb', line 18

def aerospike_admin_username
  @aerospike_admin_username
end

#aerospike_client_certificateObject

Returns the value of attribute aerospike_client_certificate.



20
21
22
# File 'lib/akeyless/models/aerospike_target_details.rb', line 20

def aerospike_client_certificate
  @aerospike_client_certificate
end

#aerospike_client_idObject

Returns the value of attribute aerospike_client_id.



22
23
24
# File 'lib/akeyless/models/aerospike_target_details.rb', line 22

def aerospike_client_id
  @aerospike_client_id
end

#aerospike_client_private_keyObject

Returns the value of attribute aerospike_client_private_key.



24
25
26
# File 'lib/akeyless/models/aerospike_target_details.rb', line 24

def aerospike_client_private_key
  @aerospike_client_private_key
end

#aerospike_client_secretObject

Returns the value of attribute aerospike_client_secret.



26
27
28
# File 'lib/akeyless/models/aerospike_target_details.rb', line 26

def aerospike_client_secret
  @aerospike_client_secret
end

#aerospike_cloudObject

Returns the value of attribute aerospike_cloud.



28
29
30
# File 'lib/akeyless/models/aerospike_target_details.rb', line 28

def aerospike_cloud
  @aerospike_cloud
end

#aerospike_cluster_idObject

Returns the value of attribute aerospike_cluster_id.



30
31
32
# File 'lib/akeyless/models/aerospike_target_details.rb', line 30

def aerospike_cluster_id
  @aerospike_cluster_id
end

#aerospike_db_server_nameObject

Returns the value of attribute aerospike_db_server_name.



32
33
34
# File 'lib/akeyless/models/aerospike_target_details.rb', line 32

def aerospike_db_server_name
  @aerospike_db_server_name
end

#aerospike_enable_mtlsObject

Returns the value of attribute aerospike_enable_mtls.



34
35
36
# File 'lib/akeyless/models/aerospike_target_details.rb', line 34

def aerospike_enable_mtls
  @aerospike_enable_mtls
end

#aerospike_hostnameObject

Returns the value of attribute aerospike_hostname.



36
37
38
# File 'lib/akeyless/models/aerospike_target_details.rb', line 36

def aerospike_hostname
  @aerospike_hostname
end

#aerospike_namespaceObject

Returns the value of attribute aerospike_namespace.



38
39
40
# File 'lib/akeyless/models/aerospike_target_details.rb', line 38

def aerospike_namespace
  @aerospike_namespace
end

#aerospike_passwordObject

Returns the value of attribute aerospike_password.



40
41
42
# File 'lib/akeyless/models/aerospike_target_details.rb', line 40

def aerospike_password
  @aerospike_password
end

#aerospike_portObject

Returns the value of attribute aerospike_port.



42
43
44
# File 'lib/akeyless/models/aerospike_target_details.rb', line 42

def aerospike_port
  @aerospike_port
end

#aerospike_skip_server_name_validationObject

Returns the value of attribute aerospike_skip_server_name_validation.



44
45
46
# File 'lib/akeyless/models/aerospike_target_details.rb', line 44

def aerospike_skip_server_name_validation
  @aerospike_skip_server_name_validation
end

#aerospike_ssl_connection_certificateObject

Returns the value of attribute aerospike_ssl_connection_certificate.



46
47
48
# File 'lib/akeyless/models/aerospike_target_details.rb', line 46

def aerospike_ssl_connection_certificate
  @aerospike_ssl_connection_certificate
end

#aerospike_ssl_connection_modeObject

Returns the value of attribute aerospike_ssl_connection_mode.



48
49
50
# File 'lib/akeyless/models/aerospike_target_details.rb', line 48

def aerospike_ssl_connection_mode
  @aerospike_ssl_connection_mode
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/akeyless/models/aerospike_target_details.rb', line 262

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/akeyless/models/aerospike_target_details.rb', line 73

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/akeyless/models/aerospike_target_details.rb', line 51

def self.attribute_map
  {
    :'aerospike_admin_username' => :'aerospike_admin_username',
    :'aerospike_client_certificate' => :'aerospike_client_certificate',
    :'aerospike_client_id' => :'aerospike_client_id',
    :'aerospike_client_private_key' => :'aerospike_client_private_key',
    :'aerospike_client_secret' => :'aerospike_client_secret',
    :'aerospike_cloud' => :'aerospike_cloud',
    :'aerospike_cluster_id' => :'aerospike_cluster_id',
    :'aerospike_db_server_name' => :'aerospike_db_server_name',
    :'aerospike_enable_mtls' => :'aerospike_enable_mtls',
    :'aerospike_hostname' => :'aerospike_hostname',
    :'aerospike_namespace' => :'aerospike_namespace',
    :'aerospike_password' => :'aerospike_password',
    :'aerospike_port' => :'aerospike_port',
    :'aerospike_skip_server_name_validation' => :'aerospike_skip_server_name_validation',
    :'aerospike_ssl_connection_certificate' => :'aerospike_ssl_connection_certificate',
    :'aerospike_ssl_connection_mode' => :'aerospike_ssl_connection_mode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/akeyless/models/aerospike_target_details.rb', line 238

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
# File 'lib/akeyless/models/aerospike_target_details.rb', line 100

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/akeyless/models/aerospike_target_details.rb', line 78

def self.openapi_types
  {
    :'aerospike_admin_username' => :'String',
    :'aerospike_client_certificate' => :'String',
    :'aerospike_client_id' => :'String',
    :'aerospike_client_private_key' => :'String',
    :'aerospike_client_secret' => :'String',
    :'aerospike_cloud' => :'Boolean',
    :'aerospike_cluster_id' => :'String',
    :'aerospike_db_server_name' => :'String',
    :'aerospike_enable_mtls' => :'Boolean',
    :'aerospike_hostname' => :'String',
    :'aerospike_namespace' => :'String',
    :'aerospike_password' => :'String',
    :'aerospike_port' => :'String',
    :'aerospike_skip_server_name_validation' => :'String',
    :'aerospike_ssl_connection_certificate' => :'String',
    :'aerospike_ssl_connection_mode' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/akeyless/models/aerospike_target_details.rb', line 202

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      aerospike_admin_username == o.aerospike_admin_username &&
      aerospike_client_certificate == o.aerospike_client_certificate &&
      aerospike_client_id == o.aerospike_client_id &&
      aerospike_client_private_key == o.aerospike_client_private_key &&
      aerospike_client_secret == o.aerospike_client_secret &&
      aerospike_cloud == o.aerospike_cloud &&
      aerospike_cluster_id == o.aerospike_cluster_id &&
      aerospike_db_server_name == o.aerospike_db_server_name &&
      aerospike_enable_mtls == o.aerospike_enable_mtls &&
      aerospike_hostname == o.aerospike_hostname &&
      aerospike_namespace == o.aerospike_namespace &&
      aerospike_password == o.aerospike_password &&
      aerospike_port == o.aerospike_port &&
      aerospike_skip_server_name_validation == o.aerospike_skip_server_name_validation &&
      aerospike_ssl_connection_certificate == o.aerospike_ssl_connection_certificate &&
      aerospike_ssl_connection_mode == o.aerospike_ssl_connection_mode
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/akeyless/models/aerospike_target_details.rb', line 333

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


225
226
227
# File 'lib/akeyless/models/aerospike_target_details.rb', line 225

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



231
232
233
# File 'lib/akeyless/models/aerospike_target_details.rb', line 231

def hash
  [aerospike_admin_username, aerospike_client_certificate, aerospike_client_id, aerospike_client_private_key, aerospike_client_secret, aerospike_cloud, aerospike_cluster_id, aerospike_db_server_name, aerospike_enable_mtls, aerospike_hostname, aerospike_namespace, aerospike_password, aerospike_port, aerospike_skip_server_name_validation, aerospike_ssl_connection_certificate, aerospike_ssl_connection_mode].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



187
188
189
190
191
# File 'lib/akeyless/models/aerospike_target_details.rb', line 187

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



309
310
311
# File 'lib/akeyless/models/aerospike_target_details.rb', line 309

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/akeyless/models/aerospike_target_details.rb', line 315

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



303
304
305
# File 'lib/akeyless/models/aerospike_target_details.rb', line 303

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



195
196
197
198
# File 'lib/akeyless/models/aerospike_target_details.rb', line 195

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end