Class: Akeyless::AssocTargetItem

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/assoc_target_item.rb

Overview

assocTargetItem is a command that creates an association between target and item.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AssocTargetItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/akeyless/models/assoc_target_item.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::AssocTargetItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::AssocTargetItem`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  end

  if attributes.key?(:'key_operations')
    if (value = attributes[:'key_operations']).is_a?(Array)
      self.key_operations = value
    end
  end

  if attributes.key?(:'keyring_name')
    self.keyring_name = attributes[:'keyring_name']
  end

  if attributes.key?(:'kms_algorithm')
    self.kms_algorithm = attributes[:'kms_algorithm']
  end

  if attributes.key?(:'location_id')
    self.location_id = attributes[:'location_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  end

  if attributes.key?(:'purpose')
    self.purpose = attributes[:'purpose']
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'tenant_secret_type')
    self.tenant_secret_type = attributes[:'tenant_secret_type']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'vault_name')
    self.vault_name = attributes[:'vault_name']
  end
end

Instance Attribute Details

#json ⇒ Object

Set output format to JSON



20
21
22
# File 'lib/akeyless/models/assoc_target_item.rb', line 20

def json
  @json
end

#key_operations ⇒ Object

A list of allowed operations for the key (required for azure targets)



23
24
25
# File 'lib/akeyless/models/assoc_target_item.rb', line 23

def key_operations
  @key_operations
end

#keyring_name ⇒ Object

Keyring name of the GCP KMS (required for gcp targets)



26
27
28
# File 'lib/akeyless/models/assoc_target_item.rb', line 26

def keyring_name
  @keyring_name
end

#kms_algorithm ⇒ Object

Algorithm of the key in GCP KMS (required for gcp targets)



29
30
31
# File 'lib/akeyless/models/assoc_target_item.rb', line 29

def kms_algorithm
  @kms_algorithm
end

#location_id ⇒ Object

Location id of the GCP KMS (required for gcp targets)



32
33
34
# File 'lib/akeyless/models/assoc_target_item.rb', line 32

def location_id
  @location_id
end

#name ⇒ Object

The item to associate



35
36
37
# File 'lib/akeyless/models/assoc_target_item.rb', line 35

def name
  @name
end

#project_id ⇒ Object

Project id of the GCP KMS (required for gcp targets)



38
39
40
# File 'lib/akeyless/models/assoc_target_item.rb', line 38

def project_id
  @project_id
end

#purpose ⇒ Object

Purpose of the key in GCP KMS (required for gcp targets)



41
42
43
# File 'lib/akeyless/models/assoc_target_item.rb', line 41

def purpose
  @purpose
end

#target_name ⇒ Object

The target to associate



44
45
46
# File 'lib/akeyless/models/assoc_target_item.rb', line 44

def target_name
  @target_name
end

#tenant_secret_type ⇒ Object

The tenant secret type [Data/SearchIndex/Analytics] (required for salesforce targets)



47
48
49
# File 'lib/akeyless/models/assoc_target_item.rb', line 47

def tenant_secret_type
  @tenant_secret_type
end

#token ⇒ Object

Authentication token (see /auth and /configure)



50
51
52
# File 'lib/akeyless/models/assoc_target_item.rb', line 50

def token
  @token
end

#uid_token ⇒ Object

The universal identity token, Required only for universal_identity authentication



53
54
55
# File 'lib/akeyless/models/assoc_target_item.rb', line 53

def uid_token
  @uid_token
end

#vault_name ⇒ Object

Name of the vault used (required for azure targets)



56
57
58
# File 'lib/akeyless/models/assoc_target_item.rb', line 56

def vault_name
  @vault_name
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/akeyless/models/assoc_target_item.rb', line 78

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/akeyless/models/assoc_target_item.rb', line 59

def self.attribute_map
  {
    :'json' => :'json',
    :'key_operations' => :'key-operations',
    :'keyring_name' => :'keyring-name',
    :'kms_algorithm' => :'kms-algorithm',
    :'location_id' => :'location-id',
    :'name' => :'name',
    :'project_id' => :'project-id',
    :'purpose' => :'purpose',
    :'target_name' => :'target-name',
    :'tenant_secret_type' => :'tenant-secret-type',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'vault_name' => :'vault-name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



235
236
237
# File 'lib/akeyless/models/assoc_target_item.rb', line 235

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



102
103
104
105
# File 'lib/akeyless/models/assoc_target_item.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/akeyless/models/assoc_target_item.rb', line 83

def self.openapi_types
  {
    :'json' => :'Boolean',
    :'key_operations' => :'Array<String>',
    :'keyring_name' => :'String',
    :'kms_algorithm' => :'String',
    :'location_id' => :'String',
    :'name' => :'String',
    :'project_id' => :'String',
    :'purpose' => :'String',
    :'target_name' => :'String',
    :'tenant_secret_type' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'vault_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/akeyless/models/assoc_target_item.rb', line 202

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      json == o.json &&
      key_operations == o.key_operations &&
      keyring_name == o.keyring_name &&
      kms_algorithm == o.kms_algorithm &&
      location_id == o.location_id &&
      name == o.name &&
      project_id == o.project_id &&
      purpose == o.purpose &&
      target_name == o.target_name &&
      tenant_secret_type == o.tenant_secret_type &&
      token == o.token &&
      uid_token == o.uid_token &&
      vault_name == o.vault_name
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/akeyless/models/assoc_target_item.rb', line 266

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/akeyless/models/assoc_target_item.rb', line 337

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/akeyless/models/assoc_target_item.rb', line 242

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


222
223
224
# File 'lib/akeyless/models/assoc_target_item.rb', line 222

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



228
229
230
# File 'lib/akeyless/models/assoc_target_item.rb', line 228

def hash
  [json, key_operations, keyring_name, kms_algorithm, location_id, name, project_id, purpose, target_name, tenant_secret_type, token, uid_token, vault_name].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/akeyless/models/assoc_target_item.rb', line 179

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @target_name.nil?
    invalid_properties.push('invalid value for "target_name", target_name cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



313
314
315
# File 'lib/akeyless/models/assoc_target_item.rb', line 313

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/akeyless/models/assoc_target_item.rb', line 319

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



307
308
309
# File 'lib/akeyless/models/assoc_target_item.rb', line 307

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



194
195
196
197
198
# File 'lib/akeyless/models/assoc_target_item.rb', line 194

def valid?
  return false if @name.nil?
  return false if @target_name.nil?
  true
end