Class: Akeyless::Auth

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/auth.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Auth

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/akeyless/models/auth.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::Auth` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::Auth`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_id')
    self.access_id = attributes[:'access_id']
  end

  if attributes.key?(:'access_key')
    self.access_key = attributes[:'access_key']
  end

  if attributes.key?(:'access_type')
    self.access_type = attributes[:'access_type']
  else
    self.access_type = 'access_key'
  end

  if attributes.key?(:'admin_email')
    self.admin_email = attributes[:'admin_email']
  end

  if attributes.key?(:'admin_password')
    self.admin_password = attributes[:'admin_password']
  end

  if attributes.key?(:'cert_data')
    self.cert_data = attributes[:'cert_data']
  end

  if attributes.key?(:'cloud_id')
    self.cloud_id = attributes[:'cloud_id']
  end

  if attributes.key?(:'debug')
    self.debug = attributes[:'debug']
  end

  if attributes.key?(:'gcp_audience')
    self.gcp_audience = attributes[:'gcp_audience']
  end

  if attributes.key?(:'jwt')
    self.jwt = attributes[:'jwt']
  end

  if attributes.key?(:'k8s_auth_config_name')
    self.k8s_auth_config_name = attributes[:'k8s_auth_config_name']
  end

  if attributes.key?(:'k8s_service_account_token')
    self. = attributes[:'k8s_service_account_token']
  end

  if attributes.key?(:'key_data')
    self.key_data = attributes[:'key_data']
  end

  if attributes.key?(:'ldap_password')
    self.ldap_password = attributes[:'ldap_password']
  end

  if attributes.key?(:'ldap_username')
    self.ldap_username = attributes[:'ldap_username']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end
end

Instance Attribute Details

#access_idObject

Access ID



19
20
21
# File 'lib/akeyless/models/auth.rb', line 19

def access_id
  @access_id
end

#access_keyObject

Access key (relevant only for access-type=access_key)



22
23
24
# File 'lib/akeyless/models/auth.rb', line 22

def access_key
  @access_key
end

#access_typeObject

Access Type (access_key/password/saml/ldap/k8s/azure_ad/oidc/aws_iam/universal_identity/jwt/gcp/cert)



25
26
27
# File 'lib/akeyless/models/auth.rb', line 25

def access_type
  @access_type
end

#admin_emailObject

Email (relevant only for access-type=password)



28
29
30
# File 'lib/akeyless/models/auth.rb', line 28

def admin_email
  @admin_email
end

#admin_passwordObject

Password (relevant only for access-type=password)



31
32
33
# File 'lib/akeyless/models/auth.rb', line 31

def admin_password
  @admin_password
end

#cert_dataObject

Certificate data encoded in base64. Used if file was not provided. (relevant only for access-type=cert)



34
35
36
# File 'lib/akeyless/models/auth.rb', line 34

def cert_data
  @cert_data
end

#cloud_idObject

The cloud identity (relevant only for access-type=azure_ad,aws_iam,gcp)



37
38
39
# File 'lib/akeyless/models/auth.rb', line 37

def cloud_id
  @cloud_id
end

#debugObject

Returns the value of attribute debug.



39
40
41
# File 'lib/akeyless/models/auth.rb', line 39

def debug
  @debug
end

#gcp_audienceObject

GCP JWT audience



42
43
44
# File 'lib/akeyless/models/auth.rb', line 42

def gcp_audience
  @gcp_audience
end

#jwtObject

The Json Web Token (relevant only for access-type=jwt/oidc)



45
46
47
# File 'lib/akeyless/models/auth.rb', line 45

def jwt
  @jwt
end

#k8s_auth_config_nameObject

The K8S Auth config name (relevant only for access-type=k8s)



48
49
50
# File 'lib/akeyless/models/auth.rb', line 48

def k8s_auth_config_name
  @k8s_auth_config_name
end

#k8s_service_account_tokenObject

The K8S service account token. (relevant only for access-type=k8s)



51
52
53
# File 'lib/akeyless/models/auth.rb', line 51

def 
  
end

#key_dataObject

Private key data encoded in base64. Used if file was not provided.(relevant only for access-type=cert)



54
55
56
# File 'lib/akeyless/models/auth.rb', line 54

def key_data
  @key_data
end

#ldap_passwordObject

LDAP password (relevant only for access-type=ldap)



57
58
59
# File 'lib/akeyless/models/auth.rb', line 57

def ldap_password
  @ldap_password
end

#ldap_usernameObject

LDAP username (relevant only for access-type=ldap)



60
61
62
# File 'lib/akeyless/models/auth.rb', line 60

def ldap_username
  @ldap_username
end

#uid_tokenObject

The universal_identity token (relevant only for access-type=universal_identity)



63
64
65
# File 'lib/akeyless/models/auth.rb', line 63

def uid_token
  @uid_token
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/akeyless/models/auth.rb', line 88

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/akeyless/models/auth.rb', line 66

def self.attribute_map
  {
    :'access_id' => :'access-id',
    :'access_key' => :'access-key',
    :'access_type' => :'access-type',
    :'admin_email' => :'admin-email',
    :'admin_password' => :'admin-password',
    :'cert_data' => :'cert-data',
    :'cloud_id' => :'cloud-id',
    :'debug' => :'debug',
    :'gcp_audience' => :'gcp-audience',
    :'jwt' => :'jwt',
    :'k8s_auth_config_name' => :'k8s-auth-config-name',
    :'k8s_service_account_token' => :'k8s-service-account-token',
    :'key_data' => :'key-data',
    :'ldap_password' => :'ldap_password',
    :'ldap_username' => :'ldap_username',
    :'uid_token' => :'uid_token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



253
254
255
# File 'lib/akeyless/models/auth.rb', line 253

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
# File 'lib/akeyless/models/auth.rb', line 115

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/akeyless/models/auth.rb', line 93

def self.openapi_types
  {
    :'access_id' => :'String',
    :'access_key' => :'String',
    :'access_type' => :'String',
    :'admin_email' => :'String',
    :'admin_password' => :'String',
    :'cert_data' => :'String',
    :'cloud_id' => :'String',
    :'debug' => :'Boolean',
    :'gcp_audience' => :'String',
    :'jwt' => :'String',
    :'k8s_auth_config_name' => :'String',
    :'k8s_service_account_token' => :'String',
    :'key_data' => :'String',
    :'ldap_password' => :'String',
    :'ldap_username' => :'String',
    :'uid_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/akeyless/models/auth.rb', line 217

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_id == o.access_id &&
      access_key == o.access_key &&
      access_type == o.access_type &&
      admin_email == o.admin_email &&
      admin_password == o.admin_password &&
      cert_data == o.cert_data &&
      cloud_id == o.cloud_id &&
      debug == o.debug &&
      gcp_audience == o.gcp_audience &&
      jwt == o.jwt &&
      k8s_auth_config_name == o.k8s_auth_config_name &&
       == o. &&
      key_data == o.key_data &&
      ldap_password == o.ldap_password &&
      ldap_username == o.ldap_username &&
      uid_token == o.uid_token
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • type Data type

  • value Value to be deserialized

Returns:

  • Deserialized data



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/akeyless/models/auth.rb', line 284

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • Any valid value

Returns:

  • Returns the value in the form of hash



355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/akeyless/models/auth.rb', line 355

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/akeyless/models/auth.rb', line 260

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • to be compared

Returns:



240
241
242
# File 'lib/akeyless/models/auth.rb', line 240

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



246
247
248
# File 'lib/akeyless/models/auth.rb', line 246

def hash
  [access_id, access_key, access_type, admin_email, admin_password, cert_data, cloud_id, debug, gcp_audience, jwt, k8s_auth_config_name, , key_data, ldap_password, ldap_username, uid_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



204
205
206
207
# File 'lib/akeyless/models/auth.rb', line 204

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • Returns the object in the form of hash



331
332
333
# File 'lib/akeyless/models/auth.rb', line 331

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/akeyless/models/auth.rb', line 337

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



325
326
327
# File 'lib/akeyless/models/auth.rb', line 325

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



211
212
213
# File 'lib/akeyless/models/auth.rb', line 211

def valid?
  true
end