Class: Akeyless::AuthMethodAccessInfo
- Inherits:
-
Object
- Object
- Akeyless::AuthMethodAccessInfo
- Defined in:
- lib/akeyless/models/auth_method_access_info.rb
Instance Attribute Summary collapse
-
#access_expires ⇒ Object
Returns the value of attribute access_expires.
-
#access_id_alias ⇒ Object
for accounts where AccessId holds encrypted email this field will hold generated AccessId, for accounts based on regular AccessId it will be equal to accessId itself.
-
#alicloud_access_rules ⇒ Object
Returns the value of attribute alicloud_access_rules.
-
#allowed_client_type ⇒ Object
Returns the value of attribute allowed_client_type.
-
#api_key_access_rules ⇒ Object
Returns the value of attribute api_key_access_rules.
-
#audit_logs_claims ⇒ Object
Returns the value of attribute audit_logs_claims.
-
#aws_iam_access_rules ⇒ Object
Returns the value of attribute aws_iam_access_rules.
-
#azure_ad_access_rules ⇒ Object
Returns the value of attribute azure_ad_access_rules.
-
#cert_access_rules ⇒ Object
Returns the value of attribute cert_access_rules.
-
#cidr_whitelist ⇒ Object
Returns the value of attribute cidr_whitelist.
-
#email_pass_access_rules ⇒ Object
Returns the value of attribute email_pass_access_rules.
-
#enforce_client_type ⇒ Object
EnforceClientType mirrors the SaaS Auth client-type enforcement decision (GwAuthEligibilityReply.EnforceClientType) captured online, so Gateway-owned offline auth and cached-creds usage honor the same enforce flag SaaS uses (see base_access.AuthenticateClientType).
-
#force_sub_claims ⇒ Object
if true the role associated with this auth method must include sub claims.
-
#gcp_access_rules ⇒ Object
Returns the value of attribute gcp_access_rules.
-
#gw_cidr_whitelist ⇒ Object
Returns the value of attribute gw_cidr_whitelist.
-
#huawei_access_rules ⇒ Object
Returns the value of attribute huawei_access_rules.
-
#jwt_ttl ⇒ Object
Returns the value of attribute jwt_ttl.
-
#k8s_access_rules ⇒ Object
Returns the value of attribute k8s_access_rules.
-
#kerberos_access_rules ⇒ Object
Returns the value of attribute kerberos_access_rules.
-
#ldap_access_rules ⇒ Object
Returns the value of attribute ldap_access_rules.
-
#oauth2_access_rules ⇒ Object
Returns the value of attribute oauth2_access_rules.
-
#oci_access_rules ⇒ Object
Returns the value of attribute oci_access_rules.
-
#oidc_access_rules ⇒ Object
Returns the value of attribute oidc_access_rules.
-
#product_types ⇒ Object
List of product types this auth method will be in use of.
-
#rules_type ⇒ Object
Returns the value of attribute rules_type.
-
#saml_access_rules ⇒ Object
Returns the value of attribute saml_access_rules.
-
#sub_claims_delimiters ⇒ Object
Returns the value of attribute sub_claims_delimiters.
-
#uid_expiration_events ⇒ Object
Relevant only for Universal Identity auth methods: token about-to-expire notification thresholds.
-
#universal_identity_access_rules ⇒ Object
Returns the value of attribute universal_identity_access_rules.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuthMethodAccessInfo
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AuthMethodAccessInfo
Initializes the object
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 164 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::AuthMethodAccessInfo` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::AuthMethodAccessInfo`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'access_expires') self.access_expires = attributes[:'access_expires'] end if attributes.key?(:'access_id_alias') self.access_id_alias = attributes[:'access_id_alias'] end if attributes.key?(:'alicloud_access_rules') self.alicloud_access_rules = attributes[:'alicloud_access_rules'] end if attributes.key?(:'allowed_client_type') if (value = attributes[:'allowed_client_type']).is_a?(Array) self.allowed_client_type = value end end if attributes.key?(:'api_key_access_rules') self.api_key_access_rules = attributes[:'api_key_access_rules'] end if attributes.key?(:'audit_logs_claims') if (value = attributes[:'audit_logs_claims']).is_a?(Array) self.audit_logs_claims = value end end if attributes.key?(:'aws_iam_access_rules') self.aws_iam_access_rules = attributes[:'aws_iam_access_rules'] end if attributes.key?(:'azure_ad_access_rules') self.azure_ad_access_rules = attributes[:'azure_ad_access_rules'] end if attributes.key?(:'cert_access_rules') self.cert_access_rules = attributes[:'cert_access_rules'] end if attributes.key?(:'cidr_whitelist') self.cidr_whitelist = attributes[:'cidr_whitelist'] end if attributes.key?(:'email_pass_access_rules') self.email_pass_access_rules = attributes[:'email_pass_access_rules'] end if attributes.key?(:'enforce_client_type') self.enforce_client_type = attributes[:'enforce_client_type'] end if attributes.key?(:'force_sub_claims') self.force_sub_claims = attributes[:'force_sub_claims'] end if attributes.key?(:'gcp_access_rules') self.gcp_access_rules = attributes[:'gcp_access_rules'] end if attributes.key?(:'gw_cidr_whitelist') self.gw_cidr_whitelist = attributes[:'gw_cidr_whitelist'] end if attributes.key?(:'huawei_access_rules') self.huawei_access_rules = attributes[:'huawei_access_rules'] end if attributes.key?(:'jwt_ttl') self.jwt_ttl = attributes[:'jwt_ttl'] end if attributes.key?(:'k8s_access_rules') self.k8s_access_rules = attributes[:'k8s_access_rules'] end if attributes.key?(:'kerberos_access_rules') self.kerberos_access_rules = attributes[:'kerberos_access_rules'] end if attributes.key?(:'ldap_access_rules') self.ldap_access_rules = attributes[:'ldap_access_rules'] end if attributes.key?(:'oauth2_access_rules') self.oauth2_access_rules = attributes[:'oauth2_access_rules'] end if attributes.key?(:'oci_access_rules') self.oci_access_rules = attributes[:'oci_access_rules'] end if attributes.key?(:'oidc_access_rules') self.oidc_access_rules = attributes[:'oidc_access_rules'] end if attributes.key?(:'product_types') if (value = attributes[:'product_types']).is_a?(Array) self.product_types = value end end if attributes.key?(:'rules_type') self.rules_type = attributes[:'rules_type'] end if attributes.key?(:'saml_access_rules') self.saml_access_rules = attributes[:'saml_access_rules'] end if attributes.key?(:'sub_claims_delimiters') if (value = attributes[:'sub_claims_delimiters']).is_a?(Array) self.sub_claims_delimiters = value end end if attributes.key?(:'uid_expiration_events') if (value = attributes[:'uid_expiration_events']).is_a?(Array) self.uid_expiration_events = value end end if attributes.key?(:'universal_identity_access_rules') self.universal_identity_access_rules = attributes[:'universal_identity_access_rules'] end end |
Instance Attribute Details
#access_expires ⇒ Object
Returns the value of attribute access_expires.
18 19 20 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 18 def access_expires @access_expires end |
#access_id_alias ⇒ Object
for accounts where AccessId holds encrypted email this field will hold generated AccessId, for accounts based on regular AccessId it will be equal to accessId itself
21 22 23 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 21 def access_id_alias @access_id_alias end |
#alicloud_access_rules ⇒ Object
Returns the value of attribute alicloud_access_rules.
23 24 25 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 23 def alicloud_access_rules @alicloud_access_rules end |
#allowed_client_type ⇒ Object
Returns the value of attribute allowed_client_type.
25 26 27 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 25 def allowed_client_type @allowed_client_type end |
#api_key_access_rules ⇒ Object
Returns the value of attribute api_key_access_rules.
27 28 29 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 27 def api_key_access_rules @api_key_access_rules end |
#audit_logs_claims ⇒ Object
Returns the value of attribute audit_logs_claims.
29 30 31 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 29 def audit_logs_claims @audit_logs_claims end |
#aws_iam_access_rules ⇒ Object
Returns the value of attribute aws_iam_access_rules.
31 32 33 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 31 def aws_iam_access_rules @aws_iam_access_rules end |
#azure_ad_access_rules ⇒ Object
Returns the value of attribute azure_ad_access_rules.
33 34 35 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 33 def azure_ad_access_rules @azure_ad_access_rules end |
#cert_access_rules ⇒ Object
Returns the value of attribute cert_access_rules.
35 36 37 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 35 def cert_access_rules @cert_access_rules end |
#cidr_whitelist ⇒ Object
Returns the value of attribute cidr_whitelist.
37 38 39 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 37 def cidr_whitelist @cidr_whitelist end |
#email_pass_access_rules ⇒ Object
Returns the value of attribute email_pass_access_rules.
39 40 41 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 39 def email_pass_access_rules @email_pass_access_rules end |
#enforce_client_type ⇒ Object
EnforceClientType mirrors the SaaS Auth client-type enforcement decision (GwAuthEligibilityReply.EnforceClientType) captured online, so Gateway-owned offline auth and cached-creds usage honor the same enforce flag SaaS uses (see base_access.AuthenticateClientType). When false, client-type mismatches are not rejected.
42 43 44 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 42 def enforce_client_type @enforce_client_type end |
#force_sub_claims ⇒ Object
if true the role associated with this auth method must include sub claims
45 46 47 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 45 def force_sub_claims @force_sub_claims end |
#gcp_access_rules ⇒ Object
Returns the value of attribute gcp_access_rules.
47 48 49 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 47 def gcp_access_rules @gcp_access_rules end |
#gw_cidr_whitelist ⇒ Object
Returns the value of attribute gw_cidr_whitelist.
49 50 51 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 49 def gw_cidr_whitelist @gw_cidr_whitelist end |
#huawei_access_rules ⇒ Object
Returns the value of attribute huawei_access_rules.
51 52 53 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 51 def huawei_access_rules @huawei_access_rules end |
#jwt_ttl ⇒ Object
Returns the value of attribute jwt_ttl.
53 54 55 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 53 def jwt_ttl @jwt_ttl end |
#k8s_access_rules ⇒ Object
Returns the value of attribute k8s_access_rules.
55 56 57 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 55 def k8s_access_rules @k8s_access_rules end |
#kerberos_access_rules ⇒ Object
Returns the value of attribute kerberos_access_rules.
57 58 59 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 57 def kerberos_access_rules @kerberos_access_rules end |
#ldap_access_rules ⇒ Object
Returns the value of attribute ldap_access_rules.
59 60 61 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 59 def ldap_access_rules @ldap_access_rules end |
#oauth2_access_rules ⇒ Object
Returns the value of attribute oauth2_access_rules.
61 62 63 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 61 def oauth2_access_rules @oauth2_access_rules end |
#oci_access_rules ⇒ Object
Returns the value of attribute oci_access_rules.
63 64 65 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 63 def oci_access_rules @oci_access_rules end |
#oidc_access_rules ⇒ Object
Returns the value of attribute oidc_access_rules.
65 66 67 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 65 def oidc_access_rules @oidc_access_rules end |
#product_types ⇒ Object
List of product types this auth method will be in use of
68 69 70 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 68 def product_types @product_types end |
#rules_type ⇒ Object
Returns the value of attribute rules_type.
70 71 72 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 70 def rules_type @rules_type end |
#saml_access_rules ⇒ Object
Returns the value of attribute saml_access_rules.
72 73 74 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 72 def saml_access_rules @saml_access_rules end |
#sub_claims_delimiters ⇒ Object
Returns the value of attribute sub_claims_delimiters.
74 75 76 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 74 def sub_claims_delimiters @sub_claims_delimiters end |
#uid_expiration_events ⇒ Object
Relevant only for Universal Identity auth methods: token about-to-expire notification thresholds.
77 78 79 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 77 def uid_expiration_events @uid_expiration_events end |
#universal_identity_access_rules ⇒ Object
Returns the value of attribute universal_identity_access_rules.
79 80 81 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 79 def universal_identity_access_rules @universal_identity_access_rules end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 394 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
117 118 119 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 117 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 82 def self.attribute_map { :'access_expires' => :'access_expires', :'access_id_alias' => :'access_id_alias', :'alicloud_access_rules' => :'alicloud_access_rules', :'allowed_client_type' => :'allowed_client_type', :'api_key_access_rules' => :'api_key_access_rules', :'audit_logs_claims' => :'audit_logs_claims', :'aws_iam_access_rules' => :'aws_iam_access_rules', :'azure_ad_access_rules' => :'azure_ad_access_rules', :'cert_access_rules' => :'cert_access_rules', :'cidr_whitelist' => :'cidr_whitelist', :'email_pass_access_rules' => :'email_pass_access_rules', :'enforce_client_type' => :'enforce_client_type', :'force_sub_claims' => :'force_sub_claims', :'gcp_access_rules' => :'gcp_access_rules', :'gw_cidr_whitelist' => :'gw_cidr_whitelist', :'huawei_access_rules' => :'huawei_access_rules', :'jwt_ttl' => :'jwt_ttl', :'k8s_access_rules' => :'k8s_access_rules', :'kerberos_access_rules' => :'kerberos_access_rules', :'ldap_access_rules' => :'ldap_access_rules', :'oauth2_access_rules' => :'oauth2_access_rules', :'oci_access_rules' => :'oci_access_rules', :'oidc_access_rules' => :'oidc_access_rules', :'product_types' => :'product_types', :'rules_type' => :'rules_type', :'saml_access_rules' => :'saml_access_rules', :'sub_claims_delimiters' => :'sub_claims_delimiters', :'uid_expiration_events' => :'uid_expiration_events', :'universal_identity_access_rules' => :'universal_identity_access_rules' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 370 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
157 158 159 160 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 157 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 122 def self.openapi_types { :'access_expires' => :'Integer', :'access_id_alias' => :'String', :'alicloud_access_rules' => :'AliCloudAccessRules', :'allowed_client_type' => :'Array<String>', :'api_key_access_rules' => :'APIKeyAccessRules', :'audit_logs_claims' => :'Array<String>', :'aws_iam_access_rules' => :'AWSIAMAccessRules', :'azure_ad_access_rules' => :'AzureADAccessRules', :'cert_access_rules' => :'CertAccessRules', :'cidr_whitelist' => :'String', :'email_pass_access_rules' => :'EmailPassAccessRules', :'enforce_client_type' => :'Boolean', :'force_sub_claims' => :'Boolean', :'gcp_access_rules' => :'GCPAccessRules', :'gw_cidr_whitelist' => :'String', :'huawei_access_rules' => :'HuaweiAccessRules', :'jwt_ttl' => :'Integer', :'k8s_access_rules' => :'KubernetesAccessRules', :'kerberos_access_rules' => :'KerberosAccessRules', :'ldap_access_rules' => :'LDAPAccessRules', :'oauth2_access_rules' => :'OAuth2AccessRules', :'oci_access_rules' => :'OCIAccessRules', :'oidc_access_rules' => :'OIDCAccessRules', :'product_types' => :'Array<String>', :'rules_type' => :'String', :'saml_access_rules' => :'SAMLAccessRules', :'sub_claims_delimiters' => :'Array<String>', :'uid_expiration_events' => :'Array<UidExpirationEvent>', :'universal_identity_access_rules' => :'UniversalIdentityAccessRules' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 321 def ==(o) return true if self.equal?(o) self.class == o.class && access_expires == o.access_expires && access_id_alias == o.access_id_alias && alicloud_access_rules == o.alicloud_access_rules && allowed_client_type == o.allowed_client_type && api_key_access_rules == o.api_key_access_rules && audit_logs_claims == o.audit_logs_claims && aws_iam_access_rules == o.aws_iam_access_rules && azure_ad_access_rules == o.azure_ad_access_rules && cert_access_rules == o.cert_access_rules && cidr_whitelist == o.cidr_whitelist && email_pass_access_rules == o.email_pass_access_rules && enforce_client_type == o.enforce_client_type && force_sub_claims == o.force_sub_claims && gcp_access_rules == o.gcp_access_rules && gw_cidr_whitelist == o.gw_cidr_whitelist && huawei_access_rules == o.huawei_access_rules && jwt_ttl == o.jwt_ttl && k8s_access_rules == o.k8s_access_rules && kerberos_access_rules == o.kerberos_access_rules && ldap_access_rules == o.ldap_access_rules && oauth2_access_rules == o.oauth2_access_rules && oci_access_rules == o.oci_access_rules && oidc_access_rules == o.oidc_access_rules && product_types == o.product_types && rules_type == o.rules_type && saml_access_rules == o.saml_access_rules && sub_claims_delimiters == o.sub_claims_delimiters && uid_expiration_events == o.uid_expiration_events && universal_identity_access_rules == o.universal_identity_access_rules end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
465 466 467 468 469 470 471 472 473 474 475 476 477 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 465 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
357 358 359 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 357 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
363 364 365 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 363 def hash [access_expires, access_id_alias, alicloud_access_rules, allowed_client_type, api_key_access_rules, audit_logs_claims, aws_iam_access_rules, azure_ad_access_rules, cert_access_rules, cidr_whitelist, email_pass_access_rules, enforce_client_type, force_sub_claims, gcp_access_rules, gw_cidr_whitelist, huawei_access_rules, jwt_ttl, k8s_access_rules, kerberos_access_rules, ldap_access_rules, oauth2_access_rules, oci_access_rules, oidc_access_rules, product_types, rules_type, saml_access_rules, sub_claims_delimiters, uid_expiration_events, universal_identity_access_rules].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
306 307 308 309 310 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 306 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
441 442 443 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 441 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 447 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
435 436 437 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 435 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
314 315 316 317 |
# File 'lib/akeyless/models/auth_method_access_info.rb', line 314 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |