Class: Akeyless::CertificateChainInfo
- Inherits:
-
Object
- Object
- Akeyless::CertificateChainInfo
- Defined in:
- lib/akeyless/models/certificate_chain_info.rb
Instance Attribute Summary collapse
-
#auto_renew_certificate ⇒ Object
Returns the value of attribute auto_renew_certificate.
-
#certificate_chain ⇒ Object
Returns the value of attribute certificate_chain.
-
#certificate_format ⇒ Object
Returns the value of attribute certificate_format.
-
#certificate_has_private_key ⇒ Object
Returns the value of attribute certificate_has_private_key.
-
#certificate_issuer_gw_cluster_id ⇒ Object
Returns the value of attribute certificate_issuer_gw_cluster_id.
-
#certificate_issuer_gw_cluster_url ⇒ Object
Returns the value of attribute certificate_issuer_gw_cluster_url.
-
#certificate_issuer_item_id ⇒ Object
Returns the value of attribute certificate_issuer_item_id.
-
#certificate_issuer_name ⇒ Object
Returns the value of attribute certificate_issuer_name.
-
#certificate_pem ⇒ Object
Returns the value of attribute certificate_pem.
-
#certificate_status ⇒ Object
Returns the value of attribute certificate_status.
-
#common_name ⇒ Object
Returns the value of attribute common_name.
-
#csr_pem ⇒ Object
CSRPEM contains the PEM-encoded CSR for pending certificates (HTTP-01 challenge).
-
#error_message ⇒ Object
Returns the value of attribute error_message.
-
#expiration_date ⇒ Object
Returns the value of attribute expiration_date.
-
#expiration_events ⇒ Object
Returns the value of attribute expiration_events.
-
#external_ca_id ⇒ Object
Returns the value of attribute external_ca_id.
-
#issuance_status ⇒ Object
Returns the value of attribute issuance_status.
-
#leaf_certificate_pem ⇒ Object
LeafCertificatePem contains only the leaf certificate, derived from CertificatePem.
-
#not_before ⇒ Object
Returns the value of attribute not_before.
-
#renew_before_expiration_in_days ⇒ Object
Returns the value of attribute renew_before_expiration_in_days.
-
#split_certificate_chain ⇒ Object
SplitCertificateChain reflects whether this certificate was issued while its PKI Cert Issuer had split-certificate-chain enabled.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CertificateChainInfo
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CertificateChainInfo
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::CertificateChainInfo` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::CertificateChainInfo`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'auto_renew_certificate') self.auto_renew_certificate = attributes[:'auto_renew_certificate'] end if attributes.key?(:'certificate_chain') if (value = attributes[:'certificate_chain']).is_a?(Array) self.certificate_chain = value end end if attributes.key?(:'certificate_format') self.certificate_format = attributes[:'certificate_format'] end if attributes.key?(:'certificate_has_private_key') self.certificate_has_private_key = attributes[:'certificate_has_private_key'] end if attributes.key?(:'certificate_issuer_gw_cluster_id') self.certificate_issuer_gw_cluster_id = attributes[:'certificate_issuer_gw_cluster_id'] end if attributes.key?(:'certificate_issuer_gw_cluster_url') self.certificate_issuer_gw_cluster_url = attributes[:'certificate_issuer_gw_cluster_url'] end if attributes.key?(:'certificate_issuer_item_id') self.certificate_issuer_item_id = attributes[:'certificate_issuer_item_id'] end if attributes.key?(:'certificate_issuer_name') self.certificate_issuer_name = attributes[:'certificate_issuer_name'] end if attributes.key?(:'certificate_pem') self.certificate_pem = attributes[:'certificate_pem'] end if attributes.key?(:'certificate_status') self.certificate_status = attributes[:'certificate_status'] end if attributes.key?(:'common_name') self.common_name = attributes[:'common_name'] end if attributes.key?(:'csr_pem') self.csr_pem = attributes[:'csr_pem'] end if attributes.key?(:'error_message') self. = attributes[:'error_message'] end if attributes.key?(:'expiration_date') self.expiration_date = attributes[:'expiration_date'] end if attributes.key?(:'expiration_events') if (value = attributes[:'expiration_events']).is_a?(Array) self.expiration_events = value end end if attributes.key?(:'external_ca_id') self.external_ca_id = attributes[:'external_ca_id'] end if attributes.key?(:'issuance_status') self.issuance_status = attributes[:'issuance_status'] end if attributes.key?(:'leaf_certificate_pem') self.leaf_certificate_pem = attributes[:'leaf_certificate_pem'] end if attributes.key?(:'not_before') self.not_before = attributes[:'not_before'] end if attributes.key?(:'renew_before_expiration_in_days') self.renew_before_expiration_in_days = attributes[:'renew_before_expiration_in_days'] end if attributes.key?(:'split_certificate_chain') self.split_certificate_chain = attributes[:'split_certificate_chain'] end end |
Instance Attribute Details
#auto_renew_certificate ⇒ Object
Returns the value of attribute auto_renew_certificate.
18 19 20 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 18 def auto_renew_certificate @auto_renew_certificate end |
#certificate_chain ⇒ Object
Returns the value of attribute certificate_chain.
20 21 22 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 20 def certificate_chain @certificate_chain end |
#certificate_format ⇒ Object
Returns the value of attribute certificate_format.
22 23 24 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 22 def certificate_format @certificate_format end |
#certificate_has_private_key ⇒ Object
Returns the value of attribute certificate_has_private_key.
24 25 26 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 24 def certificate_has_private_key @certificate_has_private_key end |
#certificate_issuer_gw_cluster_id ⇒ Object
Returns the value of attribute certificate_issuer_gw_cluster_id.
26 27 28 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 26 def certificate_issuer_gw_cluster_id @certificate_issuer_gw_cluster_id end |
#certificate_issuer_gw_cluster_url ⇒ Object
Returns the value of attribute certificate_issuer_gw_cluster_url.
28 29 30 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 28 def certificate_issuer_gw_cluster_url @certificate_issuer_gw_cluster_url end |
#certificate_issuer_item_id ⇒ Object
Returns the value of attribute certificate_issuer_item_id.
30 31 32 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 30 def certificate_issuer_item_id @certificate_issuer_item_id end |
#certificate_issuer_name ⇒ Object
Returns the value of attribute certificate_issuer_name.
32 33 34 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 32 def certificate_issuer_name @certificate_issuer_name end |
#certificate_pem ⇒ Object
Returns the value of attribute certificate_pem.
34 35 36 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 34 def certificate_pem @certificate_pem end |
#certificate_status ⇒ Object
Returns the value of attribute certificate_status.
36 37 38 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 36 def certificate_status @certificate_status end |
#common_name ⇒ Object
Returns the value of attribute common_name.
38 39 40 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 38 def common_name @common_name end |
#csr_pem ⇒ Object
CSRPEM contains the PEM-encoded CSR for pending certificates (HTTP-01 challenge)
41 42 43 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 41 def csr_pem @csr_pem end |
#error_message ⇒ Object
Returns the value of attribute error_message.
43 44 45 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 43 def @error_message end |
#expiration_date ⇒ Object
Returns the value of attribute expiration_date.
45 46 47 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 45 def expiration_date @expiration_date end |
#expiration_events ⇒ Object
Returns the value of attribute expiration_events.
47 48 49 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 47 def expiration_events @expiration_events end |
#external_ca_id ⇒ Object
Returns the value of attribute external_ca_id.
49 50 51 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 49 def external_ca_id @external_ca_id end |
#issuance_status ⇒ Object
Returns the value of attribute issuance_status.
51 52 53 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 51 def issuance_status @issuance_status end |
#leaf_certificate_pem ⇒ Object
LeafCertificatePem contains only the leaf certificate, derived from CertificatePem. Populated only when the certificate was issued with SplitCertificateChain enabled.
54 55 56 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 54 def leaf_certificate_pem @leaf_certificate_pem end |
#not_before ⇒ Object
Returns the value of attribute not_before.
56 57 58 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 56 def not_before @not_before end |
#renew_before_expiration_in_days ⇒ Object
Returns the value of attribute renew_before_expiration_in_days.
58 59 60 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 58 def renew_before_expiration_in_days @renew_before_expiration_in_days end |
#split_certificate_chain ⇒ Object
SplitCertificateChain reflects whether this certificate was issued while its PKI Cert Issuer had split-certificate-chain enabled. When true, LeafCertificatePem is populated in addition to CertificatePem (which always holds the full chain).
61 62 63 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 61 def split_certificate_chain @split_certificate_chain end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 314 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
91 92 93 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 91 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 64 def self.attribute_map { :'auto_renew_certificate' => :'auto_renew_certificate', :'certificate_chain' => :'certificate_chain', :'certificate_format' => :'certificate_format', :'certificate_has_private_key' => :'certificate_has_private_key', :'certificate_issuer_gw_cluster_id' => :'certificate_issuer_gw_cluster_id', :'certificate_issuer_gw_cluster_url' => :'certificate_issuer_gw_cluster_url', :'certificate_issuer_item_id' => :'certificate_issuer_item_id', :'certificate_issuer_name' => :'certificate_issuer_name', :'certificate_pem' => :'certificate_pem', :'certificate_status' => :'certificate_status', :'common_name' => :'common_name', :'csr_pem' => :'csr_pem', :'error_message' => :'error_message', :'expiration_date' => :'expiration_date', :'expiration_events' => :'expiration_events', :'external_ca_id' => :'external_ca_id', :'issuance_status' => :'issuance_status', :'leaf_certificate_pem' => :'leaf_certificate_pem', :'not_before' => :'not_before', :'renew_before_expiration_in_days' => :'renew_before_expiration_in_days', :'split_certificate_chain' => :'split_certificate_chain' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 290 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
123 124 125 126 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 123 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 96 def self.openapi_types { :'auto_renew_certificate' => :'Boolean', :'certificate_chain' => :'Array<CertificateInfo>', :'certificate_format' => :'String', :'certificate_has_private_key' => :'Boolean', :'certificate_issuer_gw_cluster_id' => :'Integer', :'certificate_issuer_gw_cluster_url' => :'String', :'certificate_issuer_item_id' => :'Integer', :'certificate_issuer_name' => :'String', :'certificate_pem' => :'String', :'certificate_status' => :'String', :'common_name' => :'String', :'csr_pem' => :'String', :'error_message' => :'String', :'expiration_date' => :'Time', :'expiration_events' => :'Array<CertificateExpirationEvent>', :'external_ca_id' => :'NullString', :'issuance_status' => :'String', :'leaf_certificate_pem' => :'String', :'not_before' => :'Time', :'renew_before_expiration_in_days' => :'Integer', :'split_certificate_chain' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 249 def ==(o) return true if self.equal?(o) self.class == o.class && auto_renew_certificate == o.auto_renew_certificate && certificate_chain == o.certificate_chain && certificate_format == o.certificate_format && certificate_has_private_key == o.certificate_has_private_key && certificate_issuer_gw_cluster_id == o.certificate_issuer_gw_cluster_id && certificate_issuer_gw_cluster_url == o.certificate_issuer_gw_cluster_url && certificate_issuer_item_id == o.certificate_issuer_item_id && certificate_issuer_name == o.certificate_issuer_name && certificate_pem == o.certificate_pem && certificate_status == o.certificate_status && common_name == o.common_name && csr_pem == o.csr_pem && == o. && expiration_date == o.expiration_date && expiration_events == o.expiration_events && external_ca_id == o.external_ca_id && issuance_status == o.issuance_status && leaf_certificate_pem == o.leaf_certificate_pem && not_before == o.not_before && renew_before_expiration_in_days == o.renew_before_expiration_in_days && split_certificate_chain == o.split_certificate_chain end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 385 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
277 278 279 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 277 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
283 284 285 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 283 def hash [auto_renew_certificate, certificate_chain, certificate_format, certificate_has_private_key, certificate_issuer_gw_cluster_id, certificate_issuer_gw_cluster_url, certificate_issuer_item_id, certificate_issuer_name, certificate_pem, certificate_status, common_name, csr_pem, , expiration_date, expiration_events, external_ca_id, issuance_status, leaf_certificate_pem, not_before, renew_before_expiration_in_days, split_certificate_chain].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
234 235 236 237 238 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 234 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
361 362 363 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 361 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 367 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
355 356 357 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 355 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
242 243 244 245 |
# File 'lib/akeyless/models/certificate_chain_info.rb', line 242 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |