Class: Akeyless::CertificateDiscovery
- Inherits:
-
Object
- Object
- Akeyless::CertificateDiscovery
- Defined in:
- lib/akeyless/models/certificate_discovery.rb
Overview
CertificateDiscovery is a command that discovery certificates
Instance Attribute Summary collapse
-
#debug ⇒ Object
Debug mode.
-
#expiration_event_in ⇒ Object
How many days before the expiration of the certificate would you like to be notified.
-
#hosts ⇒ Object
A comma separated list of IPs, CIDR ranges, or DNS names to discovery.
-
#json ⇒ Object
Set output format to JSON.
-
#port_ranges ⇒ Object
A comma separated list of port ranges Examples: "80,443" or "80,443,8080-8090" or "443".
-
#protection_key ⇒ Object
The name of the key that protects the certificate value.
-
#target_location ⇒ Object
The folder where the results will be saved.
-
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`).
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CertificateDiscovery
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CertificateDiscovery
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::CertificateDiscovery` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::CertificateDiscovery`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'debug') self.debug = attributes[:'debug'] else self.debug = false end if attributes.key?(:'expiration_event_in') if (value = attributes[:'expiration_event_in']).is_a?(Array) self.expiration_event_in = value end end if attributes.key?(:'hosts') self.hosts = attributes[:'hosts'] else self.hosts = nil end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'port_ranges') self.port_ranges = attributes[:'port_ranges'] else self.port_ranges = '443' end if attributes.key?(:'protection_key') self.protection_key = attributes[:'protection_key'] end if attributes.key?(:'target_location') self.target_location = attributes[:'target_location'] else self.target_location = nil end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end end |
Instance Attribute Details
#debug ⇒ Object
Debug mode
20 21 22 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 20 def debug @debug end |
#expiration_event_in ⇒ Object
How many days before the expiration of the certificate would you like to be notified.
23 24 25 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 23 def expiration_event_in @expiration_event_in end |
#hosts ⇒ Object
A comma separated list of IPs, CIDR ranges, or DNS names to discovery
26 27 28 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 26 def hosts @hosts end |
#json ⇒ Object
Set output format to JSON
29 30 31 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 29 def json @json end |
#port_ranges ⇒ Object
A comma separated list of port ranges Examples: "80,443" or "80,443,8080-8090" or "443"
32 33 34 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 32 def port_ranges @port_ranges end |
#protection_key ⇒ Object
The name of the key that protects the certificate value
35 36 37 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 35 def protection_key @protection_key end |
#target_location ⇒ Object
The folder where the results will be saved
38 39 40 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 38 def target_location @target_location end |
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`)
41 42 43 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 41 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
44 45 46 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 44 def uid_token @uid_token end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 231 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 62 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 47 def self.attribute_map { :'debug' => :'debug', :'expiration_event_in' => :'expiration-event-in', :'hosts' => :'hosts', :'json' => :'json', :'port_ranges' => :'port-ranges', :'protection_key' => :'protection-key', :'target_location' => :'target-location', :'token' => :'token', :'uid_token' => :'uid-token' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 207 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 67 def self.openapi_types { :'debug' => :'Boolean', :'expiration_event_in' => :'Array<String>', :'hosts' => :'String', :'json' => :'Boolean', :'port_ranges' => :'String', :'protection_key' => :'String', :'target_location' => :'String', :'token' => :'String', :'uid_token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 178 def ==(o) return true if self.equal?(o) self.class == o.class && debug == o.debug && expiration_event_in == o.expiration_event_in && hosts == o.hosts && json == o.json && port_ranges == o.port_ranges && protection_key == o.protection_key && target_location == o.target_location && token == o.token && uid_token == o.uid_token end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 302 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
194 195 196 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 194 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
200 201 202 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 200 def hash [debug, expiration_event_in, hosts, json, port_ranges, protection_key, target_location, token, uid_token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 153 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @hosts.nil? invalid_properties.push('invalid value for "hosts", hosts cannot be nil.') end if @target_location.nil? invalid_properties.push('invalid value for "target_location", target_location cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
278 279 280 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 278 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 284 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
272 273 274 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 272 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
169 170 171 172 173 174 |
# File 'lib/akeyless/models/certificate_discovery.rb', line 169 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @hosts.nil? return false if @target_location.nil? true end |