Class: Akeyless::Connect

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/connect.rb

Overview

Connect is a command that performs secure remote access

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Connect

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/akeyless/models/connect.rb', line 123

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::Connect` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::Connect`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'helper')
    self.helper = attributes[:'helper']
  end

  if attributes.key?(:'rc_file_override')
    self.rc_file_override = attributes[:'rc_file_override']
  end

  if attributes.key?(:'bastion_ctrl_path')
    self.bastion_ctrl_path = attributes[:'bastion_ctrl_path']
  end

  if attributes.key?(:'bastion_ctrl_port')
    self.bastion_ctrl_port = attributes[:'bastion_ctrl_port']
  else
    self.bastion_ctrl_port = '9900'
  end

  if attributes.key?(:'bastion_ctrl_proto')
    self.bastion_ctrl_proto = attributes[:'bastion_ctrl_proto']
  else
    self.bastion_ctrl_proto = 'http'
  end

  if attributes.key?(:'bastion_ctrl_subdomain')
    self.bastion_ctrl_subdomain = attributes[:'bastion_ctrl_subdomain']
  end

  if attributes.key?(:'cert_issuer_name')
    self.cert_issuer_name = attributes[:'cert_issuer_name']
  end

  if attributes.key?(:'identity_file')
    self.identity_file = attributes[:'identity_file']
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'ssh_extra_args')
    self.ssh_extra_args = attributes[:'ssh_extra_args']
  end

  if attributes.key?(:'ssh_legacy_signing_alg')
    self.ssh_legacy_signing_alg = attributes[:'ssh_legacy_signing_alg']
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'via_bastion')
    self.via_bastion = attributes[:'via_bastion']
  end
end

Instance Attribute Details

#bastion_ctrl_pathObject

The Bastion API path



25
26
27
# File 'lib/akeyless/models/connect.rb', line 25

def bastion_ctrl_path
  @bastion_ctrl_path
end

#bastion_ctrl_portObject

The Bastion API Port



28
29
30
# File 'lib/akeyless/models/connect.rb', line 28

def bastion_ctrl_port
  @bastion_ctrl_port
end

#bastion_ctrl_protoObject

The Bastion API protocol



31
32
33
# File 'lib/akeyless/models/connect.rb', line 31

def bastion_ctrl_proto
  @bastion_ctrl_proto
end

#bastion_ctrl_subdomainObject

The Bastion API prefix



34
35
36
# File 'lib/akeyless/models/connect.rb', line 34

def bastion_ctrl_subdomain
  @bastion_ctrl_subdomain
end

#cert_issuer_nameObject

The Akeyless certificate issuer name



37
38
39
# File 'lib/akeyless/models/connect.rb', line 37

def cert_issuer_name
  @cert_issuer_name
end

#helperObject

Returns the value of attribute helper.



19
20
21
# File 'lib/akeyless/models/connect.rb', line 19

def helper
  @helper
end

#identity_fileObject

The file from which the identity (private key) for public key authentication is read



40
41
42
# File 'lib/akeyless/models/connect.rb', line 40

def identity_file
  @identity_file
end

#jsonObject

Set output format to JSON



43
44
45
# File 'lib/akeyless/models/connect.rb', line 43

def json
  @json
end

#nameObject

The Secret name (for database and AWS producers - producer name)



46
47
48
# File 'lib/akeyless/models/connect.rb', line 46

def name
  @name
end

#rc_file_overrideObject

used to override .akeyless-connect.rc in tests



22
23
24
# File 'lib/akeyless/models/connect.rb', line 22

def rc_file_override
  @rc_file_override
end

#ssh_extra_argsObject

The Use to add offical SSH arguments (except -i)



49
50
51
# File 'lib/akeyless/models/connect.rb', line 49

def ssh_extra_args
  @ssh_extra_args
end

#ssh_legacy_signing_algObject

Set this option to output legacy ('[email protected]') signing algorithm name in the ssh certificate.



52
53
54
# File 'lib/akeyless/models/connect.rb', line 52

def ssh_legacy_signing_alg
  @ssh_legacy_signing_alg
end

#targetObject

The target



55
56
57
# File 'lib/akeyless/models/connect.rb', line 55

def target
  @target
end

#tokenObject

Authentication token (see /auth and /configure)



58
59
60
# File 'lib/akeyless/models/connect.rb', line 58

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



61
62
63
# File 'lib/akeyless/models/connect.rb', line 61

def uid_token
  @uid_token
end

#via_bastionObject

The jump box server



64
65
66
# File 'lib/akeyless/models/connect.rb', line 64

def via_bastion
  @via_bastion
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/akeyless/models/connect.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/akeyless/models/connect.rb', line 67

def self.attribute_map
  {
    :'helper' => :'Helper',
    :'rc_file_override' => :'RcFileOverride',
    :'bastion_ctrl_path' => :'bastion-ctrl-path',
    :'bastion_ctrl_port' => :'bastion-ctrl-port',
    :'bastion_ctrl_proto' => :'bastion-ctrl-proto',
    :'bastion_ctrl_subdomain' => :'bastion-ctrl-subdomain',
    :'cert_issuer_name' => :'cert-issuer-name',
    :'identity_file' => :'identity-file',
    :'json' => :'json',
    :'name' => :'name',
    :'ssh_extra_args' => :'ssh-extra-args',
    :'ssh_legacy_signing_alg' => :'ssh-legacy-signing-alg',
    :'target' => :'target',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'via_bastion' => :'via-bastion'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



256
257
258
# File 'lib/akeyless/models/connect.rb', line 256

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



116
117
118
119
# File 'lib/akeyless/models/connect.rb', line 116

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/akeyless/models/connect.rb', line 94

def self.openapi_types
  {
    :'helper' => :'Object',
    :'rc_file_override' => :'String',
    :'bastion_ctrl_path' => :'String',
    :'bastion_ctrl_port' => :'String',
    :'bastion_ctrl_proto' => :'String',
    :'bastion_ctrl_subdomain' => :'String',
    :'cert_issuer_name' => :'String',
    :'identity_file' => :'String',
    :'json' => :'Boolean',
    :'name' => :'String',
    :'ssh_extra_args' => :'String',
    :'ssh_legacy_signing_alg' => :'Boolean',
    :'target' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'via_bastion' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/akeyless/models/connect.rb', line 220

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      helper == o.helper &&
      rc_file_override == o.rc_file_override &&
      bastion_ctrl_path == o.bastion_ctrl_path &&
      bastion_ctrl_port == o.bastion_ctrl_port &&
      bastion_ctrl_proto == o.bastion_ctrl_proto &&
      bastion_ctrl_subdomain == o.bastion_ctrl_subdomain &&
      cert_issuer_name == o.cert_issuer_name &&
      identity_file == o.identity_file &&
      json == o.json &&
      name == o.name &&
      ssh_extra_args == o.ssh_extra_args &&
      ssh_legacy_signing_alg == o.ssh_legacy_signing_alg &&
      target == o.target &&
      token == o.token &&
      uid_token == o.uid_token &&
      via_bastion == o.via_bastion
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/akeyless/models/connect.rb', line 287

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/akeyless/models/connect.rb', line 358

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/akeyless/models/connect.rb', line 263

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


243
244
245
# File 'lib/akeyless/models/connect.rb', line 243

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



249
250
251
# File 'lib/akeyless/models/connect.rb', line 249

def hash
  [helper, rc_file_override, bastion_ctrl_path, bastion_ctrl_port, bastion_ctrl_proto, bastion_ctrl_subdomain, cert_issuer_name, identity_file, json, name, ssh_extra_args, ssh_legacy_signing_alg, target, token, uid_token, via_bastion].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



207
208
209
210
# File 'lib/akeyless/models/connect.rb', line 207

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



334
335
336
# File 'lib/akeyless/models/connect.rb', line 334

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/akeyless/models/connect.rb', line 340

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



328
329
330
# File 'lib/akeyless/models/connect.rb', line 328

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



214
215
216
# File 'lib/akeyless/models/connect.rb', line 214

def valid?
  true
end