Class: Akeyless::CreateAzureTarget

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/create_azure_target.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateAzureTarget

Initializes the object



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/akeyless/models/create_azure_target.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::CreateAzureTarget` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::CreateAzureTarget`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'client_secret')
    self.client_secret = attributes[:'client_secret']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'use_gw_cloud_identity')
    self.use_gw_cloud_identity = attributes[:'use_gw_cloud_identity']
  end
end

Instance Attribute Details

#client_idObject

Returns the value of attribute client_id.



18
19
20
# File 'lib/akeyless/models/create_azure_target.rb', line 18

def client_id
  @client_id
end

#client_secretObject

Returns the value of attribute client_secret.



20
21
22
# File 'lib/akeyless/models/create_azure_target.rb', line 20

def client_secret
  @client_secret
end

#commentObject

Comment about the target



23
24
25
# File 'lib/akeyless/models/create_azure_target.rb', line 23

def comment
  @comment
end

#keyObject

The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)



26
27
28
# File 'lib/akeyless/models/create_azure_target.rb', line 26

def key
  @key
end

#nameObject

Target name



29
30
31
# File 'lib/akeyless/models/create_azure_target.rb', line 29

def name
  @name
end

#tenant_idObject

Returns the value of attribute tenant_id.



31
32
33
# File 'lib/akeyless/models/create_azure_target.rb', line 31

def tenant_id
  @tenant_id
end

#tokenObject

Authentication token (see /auth and /configure)



34
35
36
# File 'lib/akeyless/models/create_azure_target.rb', line 34

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



37
38
39
# File 'lib/akeyless/models/create_azure_target.rb', line 37

def uid_token
  @uid_token
end

#use_gw_cloud_identityObject

Returns the value of attribute use_gw_cloud_identity.



39
40
41
# File 'lib/akeyless/models/create_azure_target.rb', line 39

def use_gw_cloud_identity
  @use_gw_cloud_identity
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/akeyless/models/create_azure_target.rb', line 57

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/akeyless/models/create_azure_target.rb', line 42

def self.attribute_map
  {
    :'client_id' => :'client-id',
    :'client_secret' => :'client-secret',
    :'comment' => :'comment',
    :'key' => :'key',
    :'name' => :'name',
    :'tenant_id' => :'tenant-id',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'use_gw_cloud_identity' => :'use-gw-cloud-identity'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



183
184
185
# File 'lib/akeyless/models/create_azure_target.rb', line 183

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/akeyless/models/create_azure_target.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/akeyless/models/create_azure_target.rb', line 62

def self.openapi_types
  {
    :'client_id' => :'String',
    :'client_secret' => :'String',
    :'comment' => :'String',
    :'key' => :'String',
    :'name' => :'String',
    :'tenant_id' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'use_gw_cloud_identity' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/akeyless/models/create_azure_target.rb', line 154

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      client_id == o.client_id &&
      client_secret == o.client_secret &&
      comment == o.comment &&
      key == o.key &&
      name == o.name &&
      tenant_id == o.tenant_id &&
      token == o.token &&
      uid_token == o.uid_token &&
      use_gw_cloud_identity == o.use_gw_cloud_identity
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/akeyless/models/create_azure_target.rb', line 214

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/akeyless/models/create_azure_target.rb', line 285

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/akeyless/models/create_azure_target.rb', line 190

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


170
171
172
# File 'lib/akeyless/models/create_azure_target.rb', line 170

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



176
177
178
# File 'lib/akeyless/models/create_azure_target.rb', line 176

def hash
  [client_id, client_secret, comment, key, name, tenant_id, token, uid_token, use_gw_cloud_identity].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



136
137
138
139
140
141
142
143
# File 'lib/akeyless/models/create_azure_target.rb', line 136

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



261
262
263
# File 'lib/akeyless/models/create_azure_target.rb', line 261

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/akeyless/models/create_azure_target.rb', line 267

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



255
256
257
# File 'lib/akeyless/models/create_azure_target.rb', line 255

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



147
148
149
150
# File 'lib/akeyless/models/create_azure_target.rb', line 147

def valid?
  return false if @name.nil?
  true
end