Class: Akeyless::CreateClassicKey

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/create_classic_key.rb

Overview

CreateClassicKey is a command that creates classic key

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateClassicKey

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/akeyless/models/create_classic_key.rb', line 134

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::CreateClassicKey` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::CreateClassicKey`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'alg')
    self.alg = attributes[:'alg']
  end

  if attributes.key?(:'cert_file_data')
    self.cert_file_data = attributes[:'cert_file_data']
  end

  if attributes.key?(:'key_data')
    self.key_data = attributes[:'key_data']
  end

  if attributes.key?(:'key_operations')
    if (value = attributes[:'key_operations']).is_a?(Array)
      self.key_operations = value
    end
  end

  if attributes.key?(:'keyring_name')
    self.keyring_name = attributes[:'keyring_name']
  end

  if attributes.key?(:'kms_algorithm')
    self.kms_algorithm = attributes[:'kms_algorithm']
  end

  if attributes.key?(:'location_id')
    self.location_id = attributes[:'location_id']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  end

  if attributes.key?(:'protection_key_name')
    self.protection_key_name = attributes[:'protection_key_name']
  end

  if attributes.key?(:'purpose')
    self.purpose = attributes[:'purpose']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'tenant_secret_type')
    self.tenant_secret_type = attributes[:'tenant_secret_type']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'vault_name')
    self.vault_name = attributes[:'vault_name']
  end
end

Instance Attribute Details

#algObject

Classic Key type; options: [AES128GCM, AES256GCM, AES128SIV, AES256SIV, RSA1024, RSA2048, RSA3072, RSA4096, EC256, EC384]



20
21
22
# File 'lib/akeyless/models/create_classic_key.rb', line 20

def alg
  @alg
end

#cert_file_dataObject

Certificate in a PEM format.



23
24
25
# File 'lib/akeyless/models/create_classic_key.rb', line 23

def cert_file_data
  @cert_file_data
end

#key_dataObject

Base64-encoded classic key value



26
27
28
# File 'lib/akeyless/models/create_classic_key.rb', line 26

def key_data
  @key_data
end

#key_operationsObject

A list of allowed operations for the key (required for azure targets)



29
30
31
# File 'lib/akeyless/models/create_classic_key.rb', line 29

def key_operations
  @key_operations
end

#keyring_nameObject

Keyring name of the GCP KMS (required for gcp targets)



32
33
34
# File 'lib/akeyless/models/create_classic_key.rb', line 32

def keyring_name
  @keyring_name
end

#kms_algorithmObject

Algorithm of the key in GCP KMS (required for gcp targets)



35
36
37
# File 'lib/akeyless/models/create_classic_key.rb', line 35

def kms_algorithm
  @kms_algorithm
end

#location_idObject

Location id of the GCP KMS (required for gcp targets)



38
39
40
# File 'lib/akeyless/models/create_classic_key.rb', line 38

def location_id
  @location_id
end

#metadataObject

Metadata about the classic key



41
42
43
# File 'lib/akeyless/models/create_classic_key.rb', line 41

def 
  @metadata
end

#nameObject

ClassicKey name



44
45
46
# File 'lib/akeyless/models/create_classic_key.rb', line 44

def name
  @name
end

#project_idObject

Project id of the GCP KMS (required for gcp targets)



47
48
49
# File 'lib/akeyless/models/create_classic_key.rb', line 47

def project_id
  @project_id
end

#protection_key_nameObject

The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)



50
51
52
# File 'lib/akeyless/models/create_classic_key.rb', line 50

def protection_key_name
  @protection_key_name
end

#purposeObject

Purpose of the key in GCP KMS (required for gcp targets)



53
54
55
# File 'lib/akeyless/models/create_classic_key.rb', line 53

def purpose
  @purpose
end

#tagsObject

List of the tags attached to this classic key



56
57
58
# File 'lib/akeyless/models/create_classic_key.rb', line 56

def tags
  @tags
end

#target_nameObject

Target name



59
60
61
# File 'lib/akeyless/models/create_classic_key.rb', line 59

def target_name
  @target_name
end

#tenant_secret_typeObject

The tenant secret type [Data/SearchIndex/Analytics] (required for salesforce targets)



62
63
64
# File 'lib/akeyless/models/create_classic_key.rb', line 62

def tenant_secret_type
  @tenant_secret_type
end

#tokenObject

Authentication token (see /auth and /configure)



65
66
67
# File 'lib/akeyless/models/create_classic_key.rb', line 65

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



68
69
70
# File 'lib/akeyless/models/create_classic_key.rb', line 68

def uid_token
  @uid_token
end

#vault_nameObject

Name of the vault used (required for azure targets)



71
72
73
# File 'lib/akeyless/models/create_classic_key.rb', line 71

def vault_name
  @vault_name
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/akeyless/models/create_classic_key.rb', line 98

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/akeyless/models/create_classic_key.rb', line 74

def self.attribute_map
  {
    :'alg' => :'alg',
    :'cert_file_data' => :'cert-file-data',
    :'key_data' => :'key-data',
    :'key_operations' => :'key-operations',
    :'keyring_name' => :'keyring-name',
    :'kms_algorithm' => :'kms-algorithm',
    :'location_id' => :'location-id',
    :'metadata' => :'metadata',
    :'name' => :'name',
    :'project_id' => :'project-id',
    :'protection_key_name' => :'protection-key-name',
    :'purpose' => :'purpose',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'tenant_secret_type' => :'tenant-secret-type',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'vault_name' => :'vault-name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



287
288
289
# File 'lib/akeyless/models/create_classic_key.rb', line 287

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



127
128
129
130
# File 'lib/akeyless/models/create_classic_key.rb', line 127

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/akeyless/models/create_classic_key.rb', line 103

def self.openapi_types
  {
    :'alg' => :'String',
    :'cert_file_data' => :'String',
    :'key_data' => :'String',
    :'key_operations' => :'Array<String>',
    :'keyring_name' => :'String',
    :'kms_algorithm' => :'String',
    :'location_id' => :'String',
    :'metadata' => :'String',
    :'name' => :'String',
    :'project_id' => :'String',
    :'protection_key_name' => :'String',
    :'purpose' => :'String',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'tenant_secret_type' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'vault_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/akeyless/models/create_classic_key.rb', line 249

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      alg == o.alg &&
      cert_file_data == o.cert_file_data &&
      key_data == o.key_data &&
      key_operations == o.key_operations &&
      keyring_name == o.keyring_name &&
      kms_algorithm == o.kms_algorithm &&
      location_id == o.location_id &&
       == o. &&
      name == o.name &&
      project_id == o.project_id &&
      protection_key_name == o.protection_key_name &&
      purpose == o.purpose &&
      tags == o.tags &&
      target_name == o.target_name &&
      tenant_secret_type == o.tenant_secret_type &&
      token == o.token &&
      uid_token == o.uid_token &&
      vault_name == o.vault_name
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/akeyless/models/create_classic_key.rb', line 318

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'lib/akeyless/models/create_classic_key.rb', line 389

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/akeyless/models/create_classic_key.rb', line 294

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


274
275
276
# File 'lib/akeyless/models/create_classic_key.rb', line 274

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



280
281
282
# File 'lib/akeyless/models/create_classic_key.rb', line 280

def hash
  [alg, cert_file_data, key_data, key_operations, keyring_name, kms_algorithm, location_id, , name, project_id, protection_key_name, purpose, tags, target_name, tenant_secret_type, token, uid_token, vault_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/akeyless/models/create_classic_key.rb', line 226

def list_invalid_properties
  invalid_properties = Array.new
  if @alg.nil?
    invalid_properties.push('invalid value for "alg", alg cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



365
366
367
# File 'lib/akeyless/models/create_classic_key.rb', line 365

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/akeyless/models/create_classic_key.rb', line 371

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



359
360
361
# File 'lib/akeyless/models/create_classic_key.rb', line 359

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



241
242
243
244
245
# File 'lib/akeyless/models/create_classic_key.rb', line 241

def valid?
  return false if @alg.nil?
  return false if @name.nil?
  true
end