Class: Akeyless::CreateDFCKey

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/create_dfc_key.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateDFCKey

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/akeyless/models/create_dfc_key.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::CreateDFCKey` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::CreateDFCKey`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'alg')
    self.alg = attributes[:'alg']
  end

  if attributes.key?(:'customer_frg_id')
    self.customer_frg_id = attributes[:'customer_frg_id']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'split_level')
    self.split_level = attributes[:'split_level']
  else
    self.split_level = 2
  end

  if attributes.key?(:'tag')
    if (value = attributes[:'tag']).is_a?(Array)
      self.tag = value
    end
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end
end

Instance Attribute Details

#alg ⇒ Object

DFCKey type; options: [AES128GCM, AES256GCM, AES128SIV, AES256SIV, RSA1024, RSA2048, RSA3072, RSA4096]



19
20
21
# File 'lib/akeyless/models/create_dfc_key.rb', line 19

def alg
  @alg
end

#customer_frg_id ⇒ Object

The customer fragment ID that will be used to create the DFC key (if empty, the key will be created independently of a customer fragment)



22
23
24
# File 'lib/akeyless/models/create_dfc_key.rb', line 22

def customer_frg_id
  @customer_frg_id
end

#delete_protection ⇒ Object

Protection from accidental deletion of this item



25
26
27
# File 'lib/akeyless/models/create_dfc_key.rb', line 25

def delete_protection
  @delete_protection
end

#metadata ⇒ Object

Metadata about the DFC key



28
29
30
# File 'lib/akeyless/models/create_dfc_key.rb', line 28

def 
  @metadata
end

#name ⇒ Object

DFCKey name



31
32
33
# File 'lib/akeyless/models/create_dfc_key.rb', line 31

def name
  @name
end

#split_level ⇒ Object

The number of fragments that the item will be split into (not includes customer fragment)



34
35
36
# File 'lib/akeyless/models/create_dfc_key.rb', line 34

def split_level
  @split_level
end

#tag ⇒ Object

List of the tags attached to this DFC key



37
38
39
# File 'lib/akeyless/models/create_dfc_key.rb', line 37

def tag
  @tag
end

#token ⇒ Object

Authentication token (see /auth and /configure)



40
41
42
# File 'lib/akeyless/models/create_dfc_key.rb', line 40

def token
  @token
end

#uid_token ⇒ Object

The universal identity token, Required only for universal_identity authentication



43
44
45
# File 'lib/akeyless/models/create_dfc_key.rb', line 43

def uid_token
  @uid_token
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/akeyless/models/create_dfc_key.rb', line 61

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/akeyless/models/create_dfc_key.rb', line 46

def self.attribute_map
  {
    :'alg' => :'alg',
    :'customer_frg_id' => :'customer-frg-id',
    :'delete_protection' => :'delete_protection',
    :'metadata' => :'metadata',
    :'name' => :'name',
    :'split_level' => :'split-level',
    :'tag' => :'tag',
    :'token' => :'token',
    :'uid_token' => :'uid-token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



196
197
198
# File 'lib/akeyless/models/create_dfc_key.rb', line 196

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



81
82
83
84
# File 'lib/akeyless/models/create_dfc_key.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/akeyless/models/create_dfc_key.rb', line 66

def self.openapi_types
  {
    :'alg' => :'String',
    :'customer_frg_id' => :'String',
    :'delete_protection' => :'String',
    :'metadata' => :'String',
    :'name' => :'String',
    :'split_level' => :'Integer',
    :'tag' => :'Array<String>',
    :'token' => :'String',
    :'uid_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/akeyless/models/create_dfc_key.rb', line 167

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      alg == o.alg &&
      customer_frg_id == o.customer_frg_id &&
      delete_protection == o.delete_protection &&
       == o. &&
      name == o.name &&
      split_level == o.split_level &&
      tag == o.tag &&
      token == o.token &&
      uid_token == o.uid_token
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/akeyless/models/create_dfc_key.rb', line 227

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/akeyless/models/create_dfc_key.rb', line 298

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/akeyless/models/create_dfc_key.rb', line 203

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


183
184
185
# File 'lib/akeyless/models/create_dfc_key.rb', line 183

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



189
190
191
# File 'lib/akeyless/models/create_dfc_key.rb', line 189

def hash
  [alg, customer_frg_id, delete_protection, , name, split_level, tag, token, uid_token].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/akeyless/models/create_dfc_key.rb', line 144

def list_invalid_properties
  invalid_properties = Array.new
  if @alg.nil?
    invalid_properties.push('invalid value for "alg", alg cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



274
275
276
# File 'lib/akeyless/models/create_dfc_key.rb', line 274

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/akeyless/models/create_dfc_key.rb', line 280

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



268
269
270
# File 'lib/akeyless/models/create_dfc_key.rb', line 268

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



159
160
161
162
163
# File 'lib/akeyless/models/create_dfc_key.rb', line 159

def valid?
  return false if @alg.nil?
  return false if @name.nil?
  true
end