Class: Akeyless::CreateEventForwarder

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/create_event_forwarder.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateEventForwarder

Initializes the object



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/akeyless/models/create_event_forwarder.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::CreateEventForwarder` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::CreateEventForwarder`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'admin_name')
    self.admin_name = attributes[:'admin_name']
  end

  if attributes.key?(:'admin_pwd')
    self.admin_pwd = attributes[:'admin_pwd']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'email_to')
    self.email_to = attributes[:'email_to']
  end

  if attributes.key?(:'event_source_locations')
    if (value = attributes[:'event_source_locations']).is_a?(Array)
      self.event_source_locations = value
    end
  else
    self.event_source_locations = nil
  end

  if attributes.key?(:'event_source_type')
    self.event_source_type = attributes[:'event_source_type']
  else
    self.event_source_type = 'item'
  end

  if attributes.key?(:'event_types')
    if (value = attributes[:'event_types']).is_a?(Array)
      self.event_types = value
    end
  end

  if attributes.key?(:'every')
    self.every = attributes[:'every']
  end

  if attributes.key?(:'forwarder_type')
    self.forwarder_type = attributes[:'forwarder_type']
  else
    self.forwarder_type = nil
  end

  if attributes.key?(:'host')
    self.host = attributes[:'host']
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'runner_type')
    self.runner_type = attributes[:'runner_type']
  else
    self.runner_type = nil
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end
end

Instance Attribute Details

#admin_nameObject

Workstation Admin Name



19
20
21
# File 'lib/akeyless/models/create_event_forwarder.rb', line 19

def admin_name
  @admin_name
end

#admin_pwdObject

Workstation Admin password



22
23
24
# File 'lib/akeyless/models/create_event_forwarder.rb', line 22

def admin_pwd
  @admin_pwd
end

#commentObject

Deprecated - use description



25
26
27
# File 'lib/akeyless/models/create_event_forwarder.rb', line 25

def comment
  @comment
end

#descriptionObject

Description of the object



28
29
30
# File 'lib/akeyless/models/create_event_forwarder.rb', line 28

def description
  @description
end

#email_toObject

A comma seperated list of email addresses to send event to (relevant only for "email" Event Forwarder)



31
32
33
# File 'lib/akeyless/models/create_event_forwarder.rb', line 31

def email_to
  @email_to
end

#event_source_locationsObject

Event sources



34
35
36
# File 'lib/akeyless/models/create_event_forwarder.rb', line 34

def event_source_locations
  @event_source_locations
end

#event_source_typeObject

Event Source type [item, target, auth_method]



37
38
39
# File 'lib/akeyless/models/create_event_forwarder.rb', line 37

def event_source_type
  @event_source_type
end

#event_typesObject

List of event types to notify about [request-access, certificate-pending-expiration, certificate-expired, auth-method-pending-expiration, auth-method-expired, rotated-secret-success, rotated-secret-failure, dynamic-secret-failure, multi-auth-failure, uid-rotation-failure]



40
41
42
# File 'lib/akeyless/models/create_event_forwarder.rb', line 40

def event_types
  @event_types
end

#everyObject

Rate of periodic runner repetition in hours



43
44
45
# File 'lib/akeyless/models/create_event_forwarder.rb', line 43

def every
  @every
end

#forwarder_typeObject

Returns the value of attribute forwarder_type.



45
46
47
# File 'lib/akeyless/models/create_event_forwarder.rb', line 45

def forwarder_type
  @forwarder_type
end

#hostObject

Workstation Host



48
49
50
# File 'lib/akeyless/models/create_event_forwarder.rb', line 48

def host
  @host
end

#jsonObject

Set output format to JSON



51
52
53
# File 'lib/akeyless/models/create_event_forwarder.rb', line 51

def json
  @json
end

#keyObject

The name of a key that used to encrypt the EventForwarder secret value (if empty, the account default protectionKey key will be used)



54
55
56
# File 'lib/akeyless/models/create_event_forwarder.rb', line 54

def key
  @key
end

#nameObject

EventForwarder name



57
58
59
# File 'lib/akeyless/models/create_event_forwarder.rb', line 57

def name
  @name
end

#runner_typeObject

Returns the value of attribute runner_type.



59
60
61
# File 'lib/akeyless/models/create_event_forwarder.rb', line 59

def runner_type
  @runner_type
end

#tokenObject

Authentication token (see /auth and /configure)



62
63
64
# File 'lib/akeyless/models/create_event_forwarder.rb', line 62

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



65
66
67
# File 'lib/akeyless/models/create_event_forwarder.rb', line 65

def uid_token
  @uid_token
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/akeyless/models/create_event_forwarder.rb', line 322

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/akeyless/models/create_event_forwarder.rb', line 91

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/akeyless/models/create_event_forwarder.rb', line 68

def self.attribute_map
  {
    :'admin_name' => :'admin-name',
    :'admin_pwd' => :'admin-pwd',
    :'comment' => :'comment',
    :'description' => :'description',
    :'email_to' => :'email-to',
    :'event_source_locations' => :'event-source-locations',
    :'event_source_type' => :'event-source-type',
    :'event_types' => :'event-types',
    :'every' => :'every',
    :'forwarder_type' => :'forwarder-type',
    :'host' => :'host',
    :'json' => :'json',
    :'key' => :'key',
    :'name' => :'name',
    :'runner_type' => :'runner-type',
    :'token' => :'token',
    :'uid_token' => :'uid-token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/akeyless/models/create_event_forwarder.rb', line 298

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



119
120
121
122
# File 'lib/akeyless/models/create_event_forwarder.rb', line 119

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/akeyless/models/create_event_forwarder.rb', line 96

def self.openapi_types
  {
    :'admin_name' => :'String',
    :'admin_pwd' => :'String',
    :'comment' => :'String',
    :'description' => :'String',
    :'email_to' => :'String',
    :'event_source_locations' => :'Array<String>',
    :'event_source_type' => :'String',
    :'event_types' => :'Array<String>',
    :'every' => :'String',
    :'forwarder_type' => :'String',
    :'host' => :'String',
    :'json' => :'Boolean',
    :'key' => :'String',
    :'name' => :'String',
    :'runner_type' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/akeyless/models/create_event_forwarder.rb', line 261

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      admin_name == o.admin_name &&
      admin_pwd == o.admin_pwd &&
      comment == o.comment &&
      description == o.description &&
      email_to == o.email_to &&
      event_source_locations == o.event_source_locations &&
      event_source_type == o.event_source_type &&
      event_types == o.event_types &&
      every == o.every &&
      forwarder_type == o.forwarder_type &&
      host == o.host &&
      json == o.json &&
      key == o.key &&
      name == o.name &&
      runner_type == o.runner_type &&
      token == o.token &&
      uid_token == o.uid_token
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/akeyless/models/create_event_forwarder.rb', line 393

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


285
286
287
# File 'lib/akeyless/models/create_event_forwarder.rb', line 285

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



291
292
293
# File 'lib/akeyless/models/create_event_forwarder.rb', line 291

def hash
  [admin_name, admin_pwd, comment, description, email_to, event_source_locations, event_source_type, event_types, every, forwarder_type, host, json, key, name, runner_type, token, uid_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/akeyless/models/create_event_forwarder.rb', line 226

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @event_source_locations.nil?
    invalid_properties.push('invalid value for "event_source_locations", event_source_locations cannot be nil.')
  end

  if @forwarder_type.nil?
    invalid_properties.push('invalid value for "forwarder_type", forwarder_type cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @runner_type.nil?
    invalid_properties.push('invalid value for "runner_type", runner_type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



369
370
371
# File 'lib/akeyless/models/create_event_forwarder.rb', line 369

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/akeyless/models/create_event_forwarder.rb', line 375

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



363
364
365
# File 'lib/akeyless/models/create_event_forwarder.rb', line 363

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



250
251
252
253
254
255
256
257
# File 'lib/akeyless/models/create_event_forwarder.rb', line 250

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @event_source_locations.nil?
  return false if @forwarder_type.nil?
  return false if @name.nil?
  return false if @runner_type.nil?
  true
end