Class: Akeyless::CreatePKICertIssuer

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/create_pki_cert_issuer.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreatePKICertIssuer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 168

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::CreatePKICertIssuer` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::CreatePKICertIssuer`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'allow_any_name')
    self.allow_any_name = attributes[:'allow_any_name']
  end

  if attributes.key?(:'allow_subdomains')
    self.allow_subdomains = attributes[:'allow_subdomains']
  end

  if attributes.key?(:'allowed_domains')
    self.allowed_domains = attributes[:'allowed_domains']
  end

  if attributes.key?(:'allowed_uri_sans')
    self.allowed_uri_sans = attributes[:'allowed_uri_sans']
  end

  if attributes.key?(:'client_flag')
    self.client_flag = attributes[:'client_flag']
  end

  if attributes.key?(:'code_signing_flag')
    self.code_signing_flag = attributes[:'code_signing_flag']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'key_usage')
    self.key_usage = attributes[:'key_usage']
  else
    self.key_usage = 'DigitalSignature,KeyAgreement,KeyEncipherment'
  end

  if attributes.key?(:'locality')
    self.locality = attributes[:'locality']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'not_enforce_hostnames')
    self.not_enforce_hostnames = attributes[:'not_enforce_hostnames']
  end

  if attributes.key?(:'not_require_cn')
    self.not_require_cn = attributes[:'not_require_cn']
  end

  if attributes.key?(:'organizational_units')
    self.organizational_units = attributes[:'organizational_units']
  end

  if attributes.key?(:'organizations')
    self.organizations = attributes[:'organizations']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'province')
    self.province = attributes[:'province']
  end

  if attributes.key?(:'server_flag')
    self.server_flag = attributes[:'server_flag']
  end

  if attributes.key?(:'signer_key_name')
    self.signer_key_name = attributes[:'signer_key_name']
  end

  if attributes.key?(:'street_address')
    self.street_address = attributes[:'street_address']
  end

  if attributes.key?(:'tag')
    if (value = attributes[:'tag']).is_a?(Array)
      self.tag = value
    end
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'ttl')
    self.ttl = attributes[:'ttl']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end
end

Instance Attribute Details

#allow_any_name ⇒ Object

If set, clients can request certificates for any CN



19
20
21
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 19

def allow_any_name
  @allow_any_name
end

#allow_subdomains ⇒ Object

If set, clients can request certificates for subdomains and wildcard subdomains of the allowed domains



22
23
24
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 22

def allow_subdomains
  @allow_subdomains
end

#allowed_domains ⇒ Object

A list of the allowed domains that clients can request to be included in the certificate (in a comma-delimited list)



25
26
27
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 25

def allowed_domains
  @allowed_domains
end

#allowed_uri_sans ⇒ Object

A list of the allowed URIs that clients can request to be included in the certificate as part of the URI Subject Alternative Names (in a comma-delimited list)



28
29
30
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 28

def allowed_uri_sans
  @allowed_uri_sans
end

#client_flag ⇒ Object

If set, certificates will be flagged for client auth use



31
32
33
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 31

def client_flag
  @client_flag
end

#code_signing_flag ⇒ Object

If set, certificates will be flagged for code signing use



34
35
36
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 34

def code_signing_flag
  @code_signing_flag
end

#country ⇒ Object

A comma-separated list of the country that will be set in the issued certificate



37
38
39
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 37

def country
  @country
end

#delete_protection ⇒ Object

Protection from accidental deletion of this item



40
41
42
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 40

def delete_protection
  @delete_protection
end

#key_usage ⇒ Object

key-usage



43
44
45
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 43

def key_usage
  @key_usage
end

#locality ⇒ Object

A comma-separated list of the locality that will be set in the issued certificate



46
47
48
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 46

def locality
  @locality
end

#metadata ⇒ Object

A metadata about the issuer



49
50
51
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 49

def 
  
end

#name ⇒ Object

PKI certificate issuer name



52
53
54
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 52

def name
  @name
end

#not_enforce_hostnames ⇒ Object

If set, any names are allowed for CN and SANs in the certificate and not only a valid host name



55
56
57
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 55

def not_enforce_hostnames
  @not_enforce_hostnames
end

#not_require_cn ⇒ Object

If set, clients can request certificates without a CN



58
59
60
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 58

def not_require_cn
  @not_require_cn
end

#organizational_units ⇒ Object

A comma-separated list of organizational units (OU) that will be set in the issued certificate



61
62
63
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 61

def organizational_units
  @organizational_units
end

#organizations ⇒ Object

A comma-separated list of organizations (O) that will be set in the issued certificate



64
65
66
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 64

def organizations
  @organizations
end

#postal_code ⇒ Object

A comma-separated list of the postal code that will be set in the issued certificate



67
68
69
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 67

def postal_code
  @postal_code
end

#province ⇒ Object

A comma-separated list of the province that will be set in the issued certificate



70
71
72
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 70

def province
  @province
end

#server_flag ⇒ Object

If set, certificates will be flagged for server auth use



73
74
75
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 73

def server_flag
  @server_flag
end

#signer_key_name ⇒ Object

A key to sign the certificate with



76
77
78
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 76

def signer_key_name
  @signer_key_name
end

#street_address ⇒ Object

A comma-separated list of the street address that will be set in the issued certificate



79
80
81
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 79

def street_address
  @street_address
end

#tag ⇒ Object

List of the tags attached to this key



82
83
84
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 82

def tag
  @tag
end

#token ⇒ Object

Authentication token (see /auth and /configure)



85
86
87
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 85

def token
  @token
end

#ttl ⇒ Object

he requested Time To Live for the certificate, in seconds



88
89
90
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 88

def ttl
  @ttl
end

#uid_token ⇒ Object

The universal identity token, Required only for universal_identity authentication



91
92
93
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 91

def uid_token
  @uid_token
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



125
126
127
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 125

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 94

def self.attribute_map
  {
    :'allow_any_name' => :'allow-any-name',
    :'allow_subdomains' => :'allow-subdomains',
    :'allowed_domains' => :'allowed-domains',
    :'allowed_uri_sans' => :'allowed-uri-sans',
    :'client_flag' => :'client-flag',
    :'code_signing_flag' => :'code-signing-flag',
    :'country' => :'country',
    :'delete_protection' => :'delete_protection',
    :'key_usage' => :'key-usage',
    :'locality' => :'locality',
    :'metadata' => :'metadata',
    :'name' => :'name',
    :'not_enforce_hostnames' => :'not-enforce-hostnames',
    :'not_require_cn' => :'not-require-cn',
    :'organizational_units' => :'organizational-units',
    :'organizations' => :'organizations',
    :'postal_code' => :'postal-code',
    :'province' => :'province',
    :'server_flag' => :'server-flag',
    :'signer_key_name' => :'signer-key-name',
    :'street_address' => :'street-address',
    :'tag' => :'tag',
    :'token' => :'token',
    :'ttl' => :'ttl',
    :'uid_token' => :'uid-token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



361
362
363
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 361

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



161
162
163
164
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 161

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 130

def self.openapi_types
  {
    :'allow_any_name' => :'Boolean',
    :'allow_subdomains' => :'Boolean',
    :'allowed_domains' => :'String',
    :'allowed_uri_sans' => :'String',
    :'client_flag' => :'Boolean',
    :'code_signing_flag' => :'Boolean',
    :'country' => :'String',
    :'delete_protection' => :'String',
    :'key_usage' => :'String',
    :'locality' => :'String',
    :'metadata' => :'String',
    :'name' => :'String',
    :'not_enforce_hostnames' => :'Boolean',
    :'not_require_cn' => :'Boolean',
    :'organizational_units' => :'String',
    :'organizations' => :'String',
    :'postal_code' => :'String',
    :'province' => :'String',
    :'server_flag' => :'Boolean',
    :'signer_key_name' => :'String',
    :'street_address' => :'String',
    :'tag' => :'Array<String>',
    :'token' => :'String',
    :'ttl' => :'Integer',
    :'uid_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 316

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      allow_any_name == o.allow_any_name &&
      allow_subdomains == o.allow_subdomains &&
      allowed_domains == o.allowed_domains &&
      allowed_uri_sans == o.allowed_uri_sans &&
      client_flag == o.client_flag &&
      code_signing_flag == o.code_signing_flag &&
      country == o.country &&
      delete_protection == o.delete_protection &&
      key_usage == o.key_usage &&
      locality == o.locality &&
       == o. &&
      name == o.name &&
      not_enforce_hostnames == o.not_enforce_hostnames &&
      not_require_cn == o.not_require_cn &&
      organizational_units == o.organizational_units &&
      organizations == o.organizations &&
      postal_code == o.postal_code &&
      province == o.province &&
      server_flag == o.server_flag &&
      signer_key_name == o.signer_key_name &&
      street_address == o.street_address &&
      tag == o.tag &&
      token == o.token &&
      ttl == o.ttl &&
      uid_token == o.uid_token
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 392

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



463
464
465
466
467
468
469
470
471
472
473
474
475
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 463

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 368

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


348
349
350
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 348

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



354
355
356
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 354

def hash
  [allow_any_name, allow_subdomains, allowed_domains, allowed_uri_sans, client_flag, code_signing_flag, country, delete_protection, key_usage, locality, , name, not_enforce_hostnames, not_require_cn, organizational_units, organizations, postal_code, province, server_flag, signer_key_name, street_address, tag, token, ttl, uid_token].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 288

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @signer_key_name.nil?
    invalid_properties.push('invalid value for "signer_key_name", signer_key_name cannot be nil.')
  end

  if @ttl.nil?
    invalid_properties.push('invalid value for "ttl", ttl cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



439
440
441
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 439

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 445

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



433
434
435
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 433

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



307
308
309
310
311
312
# File 'lib/akeyless/models/create_pki_cert_issuer.rb', line 307

def valid?
  return false if @name.nil?
  return false if @signer_key_name.nil?
  return false if @ttl.nil?
  true
end