Class: Akeyless::CreateRotatedSecret

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/create_rotated_secret.rb

Overview

createRotatedSecret is a command that creates a rotated secret [Deprecated: Use rotated-secret-create commands]

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateRotatedSecret

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
# File 'lib/akeyless/models/create_rotated_secret.rb', line 342

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::CreateRotatedSecret` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::CreateRotatedSecret`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'provider_type')
    self.provider_type = attributes[:'provider_type']
  end

  if attributes.key?(:'api_id')
    self.api_id = attributes[:'api_id']
  end

  if attributes.key?(:'api_key')
    self.api_key = attributes[:'api_key']
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  end

  if attributes.key?(:'authentication_credentials')
    self.authentication_credentials = attributes[:'authentication_credentials']
  else
    self.authentication_credentials = 'use-user-creds'
  end

  if attributes.key?(:'auto_rotate')
    self.auto_rotate = attributes[:'auto_rotate']
  end

  if attributes.key?(:'aws_region')
    self.aws_region = attributes[:'aws_region']
  else
    self.aws_region = 'us-east-2'
  end

  if attributes.key?(:'custom_payload')
    self.custom_payload = attributes[:'custom_payload']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'gcp_key')
    self.gcp_key = attributes[:'gcp_key']
  end

  if attributes.key?(:'gcp_service_account_email')
    self. = attributes[:'gcp_service_account_email']
  end

  if attributes.key?(:'gcp_service_account_key_id')
    self. = attributes[:'gcp_service_account_key_id']
  end

  if attributes.key?(:'grace_rotation')
    self.grace_rotation = attributes[:'grace_rotation']
  end

  if attributes.key?(:'host_provider')
    self.host_provider = attributes[:'host_provider']
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'lock_during_sra_session')
    self.lock_during_sra_session = attributes[:'lock_during_sra_session']
  end

  if attributes.key?(:'lock_on_read')
    self.lock_on_read = attributes[:'lock_on_read']
  end

  if attributes.key?(:'lock_ttl')
    self.lock_ttl = attributes[:'lock_ttl']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'password_length')
    self.password_length = attributes[:'password_length']
  end

  if attributes.key?(:'rotate_after_disconnect')
    self.rotate_after_disconnect = attributes[:'rotate_after_disconnect']
  end

  if attributes.key?(:'rotate_on_unlock')
    self.rotate_on_unlock = attributes[:'rotate_on_unlock']
  end

  if attributes.key?(:'rotated_password')
    self.rotated_password = attributes[:'rotated_password']
  end

  if attributes.key?(:'rotated_username')
    self.rotated_username = attributes[:'rotated_username']
  end

  if attributes.key?(:'rotation_hour')
    self.rotation_hour = attributes[:'rotation_hour']
  end

  if attributes.key?(:'rotation_interval')
    self.rotation_interval = attributes[:'rotation_interval']
  end

  if attributes.key?(:'rotator_creds_type')
    self.rotator_creds_type = attributes[:'rotator_creds_type']
  end

  if attributes.key?(:'rotator_custom_cmd')
    self.rotator_custom_cmd = attributes[:'rotator_custom_cmd']
  end

  if attributes.key?(:'rotator_type')
    self.rotator_type = attributes[:'rotator_type']
  else
    self.rotator_type = nil
  end

  if attributes.key?(:'same_password')
    self.same_password = attributes[:'same_password']
  end

  if attributes.key?(:'secure_access_allow_external_user')
    self.secure_access_allow_external_user = attributes[:'secure_access_allow_external_user']
  else
    self.secure_access_allow_external_user = false
  end

  if attributes.key?(:'secure_access_aws_account_id')
    self. = attributes[:'secure_access_aws_account_id']
  end

  if attributes.key?(:'secure_access_aws_native_cli')
    self.secure_access_aws_native_cli = attributes[:'secure_access_aws_native_cli']
  end

  if attributes.key?(:'secure_access_bastion_issuer')
    self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer']
  end

  if attributes.key?(:'secure_access_certificate_issuer')
    self.secure_access_certificate_issuer = attributes[:'secure_access_certificate_issuer']
  end

  if attributes.key?(:'secure_access_db_name')
    self.secure_access_db_name = attributes[:'secure_access_db_name']
  end

  if attributes.key?(:'secure_access_db_schema')
    self.secure_access_db_schema = attributes[:'secure_access_db_schema']
  end

  if attributes.key?(:'secure_access_disable_concurrent_connections')
    self.secure_access_disable_concurrent_connections = attributes[:'secure_access_disable_concurrent_connections']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_enforce_hosts_restriction')
    self.secure_access_enforce_hosts_restriction = attributes[:'secure_access_enforce_hosts_restriction']
  end

  if attributes.key?(:'secure_access_host')
    if (value = attributes[:'secure_access_host']).is_a?(Array)
      self.secure_access_host = value
    end
  end

  if attributes.key?(:'secure_access_rdp_domain')
    self.secure_access_rdp_domain = attributes[:'secure_access_rdp_domain']
  end

  if attributes.key?(:'secure_access_rdp_user')
    self.secure_access_rdp_user = attributes[:'secure_access_rdp_user']
  end

  if attributes.key?(:'secure_access_url')
    self.secure_access_url = attributes[:'secure_access_url']
  end

  if attributes.key?(:'secure_access_web')
    self.secure_access_web = attributes[:'secure_access_web']
  else
    self.secure_access_web = false
  end

  if attributes.key?(:'secure_access_web_browsing')
    self.secure_access_web_browsing = attributes[:'secure_access_web_browsing']
  else
    self.secure_access_web_browsing = false
  end

  if attributes.key?(:'secure_access_web_proxy')
    self.secure_access_web_proxy = attributes[:'secure_access_web_proxy']
  else
    self.secure_access_web_proxy = false
  end

  if attributes.key?(:'ssh_password')
    self.ssh_password = attributes[:'ssh_password']
  end

  if attributes.key?(:'ssh_username')
    self.ssh_username = attributes[:'ssh_username']
  end

  if attributes.key?(:'storage_account_key_name')
    self. = attributes[:'storage_account_key_name']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target')
    if (value = attributes[:'target']).is_a?(Array)
      self.target = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  else
    self.target_name = nil
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'user_attribute')
    self.user_attribute = attributes[:'user_attribute']
  else
    self.user_attribute = 'cn'
  end

  if attributes.key?(:'user_dn')
    self.user_dn = attributes[:'user_dn']
  end
end

Instance Attribute Details

#api_idObject

API ID to rotate (relevant only for rotator-type=api-key)



22
23
24
# File 'lib/akeyless/models/create_rotated_secret.rb', line 22

def api_id
  @api_id
end

#api_keyObject

API key to rotate (relevant only for rotator-type=api-key)



25
26
27
# File 'lib/akeyless/models/create_rotated_secret.rb', line 25

def api_key
  @api_key
end

#application_idObject

ApplicationId (used in azure)



28
29
30
# File 'lib/akeyless/models/create_rotated_secret.rb', line 28

def application_id
  @application_id
end

#authentication_credentialsObject

The credentials to connect with use-user-creds/use-target-creds



31
32
33
# File 'lib/akeyless/models/create_rotated_secret.rb', line 31

def authentication_credentials
  @authentication_credentials
end

#auto_rotateObject

Whether to automatically rotate every --rotation-interval days, or disable existing automatic rotation [true/false]



34
35
36
# File 'lib/akeyless/models/create_rotated_secret.rb', line 34

def auto_rotate
  @auto_rotate
end

#aws_regionObject

Aws Region (relevant only for aws)



37
38
39
# File 'lib/akeyless/models/create_rotated_secret.rb', line 37

def aws_region
  @aws_region
end

#custom_payloadObject

Secret payload to be sent with rotation request (relevant only for rotator-type=custom)



40
41
42
# File 'lib/akeyless/models/create_rotated_secret.rb', line 40

def custom_payload
  @custom_payload
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



43
44
45
# File 'lib/akeyless/models/create_rotated_secret.rb', line 43

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



46
47
48
# File 'lib/akeyless/models/create_rotated_secret.rb', line 46

def description
  @description
end

#gcp_keyObject

Base64-encoded service account private key text



49
50
51
# File 'lib/akeyless/models/create_rotated_secret.rb', line 49

def gcp_key
  @gcp_key
end

#gcp_service_account_emailObject

The email of the gcp service account to rotate



52
53
54
# File 'lib/akeyless/models/create_rotated_secret.rb', line 52

def 
  @gcp_service_account_email
end

#gcp_service_account_key_idObject

The key id of the gcp service account to rotate



55
56
57
# File 'lib/akeyless/models/create_rotated_secret.rb', line 55

def 
  @gcp_service_account_key_id
end

#grace_rotationObject

Create a new access key without deleting the old key from AWS for backup (relevant only for AWS) [true/false]



58
59
60
# File 'lib/akeyless/models/create_rotated_secret.rb', line 58

def grace_rotation
  @grace_rotation
end

#host_providerObject

Host provider type [explicit/target], Default Host provider is explicit, Relevant only for SRA items.



61
62
63
# File 'lib/akeyless/models/create_rotated_secret.rb', line 61

def host_provider
  @host_provider
end

#jsonObject

Set output format to JSON



64
65
66
# File 'lib/akeyless/models/create_rotated_secret.rb', line 64

def json
  @json
end

#keyObject

The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)



67
68
69
# File 'lib/akeyless/models/create_rotated_secret.rb', line 67

def key
  @key
end

#lock_during_sra_sessionObject

Lock this secret for read/update while an SRA session is active



70
71
72
# File 'lib/akeyless/models/create_rotated_secret.rb', line 70

def lock_during_sra_session
  @lock_during_sra_session
end

#lock_on_readObject

Lock this secret after each successful value read



73
74
75
# File 'lib/akeyless/models/create_rotated_secret.rb', line 73

def lock_on_read
  @lock_on_read
end

#lock_ttlObject

Lock TTL in minutes



76
77
78
# File 'lib/akeyless/models/create_rotated_secret.rb', line 76

def lock_ttl
  @lock_ttl
end

#metadataObject

Deprecated - use description



79
80
81
# File 'lib/akeyless/models/create_rotated_secret.rb', line 79

def 
  @metadata
end

#nameObject

Secret name



82
83
84
# File 'lib/akeyless/models/create_rotated_secret.rb', line 82

def name
  @name
end

#password_lengthObject

The length of the password to be generated



85
86
87
# File 'lib/akeyless/models/create_rotated_secret.rb', line 85

def password_length
  @password_length
end

#provider_typeObject

Returns the value of attribute provider_type.



19
20
21
# File 'lib/akeyless/models/create_rotated_secret.rb', line 19

def provider_type
  @provider_type
end

#rotate_after_disconnectObject

StringOrBool accepts JSON strings, booleans, and numbers for backward compatibility with older SDK versions that send boolean values for rotate-after-disconnect.



88
89
90
# File 'lib/akeyless/models/create_rotated_secret.rb', line 88

def rotate_after_disconnect
  @rotate_after_disconnect
end

#rotate_on_unlockObject

Rotate this secret after it is unlocked



91
92
93
# File 'lib/akeyless/models/create_rotated_secret.rb', line 91

def rotate_on_unlock
  @rotate_on_unlock
end

#rotated_passwordObject

rotated-username password (relevant only for rotator-type=password)



94
95
96
# File 'lib/akeyless/models/create_rotated_secret.rb', line 94

def rotated_password
  @rotated_password
end

#rotated_usernameObject

username to be rotated, if selected use-self-creds at rotator-creds-type, this username will try to rotate it's own password, if use-target-creds is selected, target credentials will be use to rotate the rotated-password (relevant only for rotator-type=password)



97
98
99
# File 'lib/akeyless/models/create_rotated_secret.rb', line 97

def rotated_username
  @rotated_username
end

#rotation_hourObject

The Hour of the rotation in UTC. Default rotation-hour is 14:00



100
101
102
# File 'lib/akeyless/models/create_rotated_secret.rb', line 100

def rotation_hour
  @rotation_hour
end

#rotation_intervalObject

The number of days to wait between every automatic key rotation (1-365)



103
104
105
# File 'lib/akeyless/models/create_rotated_secret.rb', line 103

def rotation_interval
  @rotation_interval
end

#rotator_creds_typeObject

Returns the value of attribute rotator_creds_type.



105
106
107
# File 'lib/akeyless/models/create_rotated_secret.rb', line 105

def rotator_creds_type
  @rotator_creds_type
end

#rotator_custom_cmdObject

Custom rotation command (relevant only for ssh target)



108
109
110
# File 'lib/akeyless/models/create_rotated_secret.rb', line 108

def rotator_custom_cmd
  @rotator_custom_cmd
end

#rotator_typeObject

Rotator Type



111
112
113
# File 'lib/akeyless/models/create_rotated_secret.rb', line 111

def rotator_type
  @rotator_type
end

#same_passwordObject

Rotate same password for each host from the Linked Target (relevant only for Linked Target)



114
115
116
# File 'lib/akeyless/models/create_rotated_secret.rb', line 114

def same_password
  @same_password
end

#secure_access_allow_external_userObject

Allow providing external user for a domain users (relevant only for rdp)



117
118
119
# File 'lib/akeyless/models/create_rotated_secret.rb', line 117

def secure_access_allow_external_user
  @secure_access_allow_external_user
end

#secure_access_aws_account_idObject

The AWS account id (relevant only for aws)



120
121
122
# File 'lib/akeyless/models/create_rotated_secret.rb', line 120

def 
  @secure_access_aws_account_id
end

#secure_access_aws_native_cliObject

The AWS native cli



123
124
125
# File 'lib/akeyless/models/create_rotated_secret.rb', line 123

def secure_access_aws_native_cli
  @secure_access_aws_native_cli
end

#secure_access_bastion_issuerObject

Deprecated. use secure-access-certificate-issuer



126
127
128
# File 'lib/akeyless/models/create_rotated_secret.rb', line 126

def secure_access_bastion_issuer
  @secure_access_bastion_issuer
end

#secure_access_certificate_issuerObject

Path to the SSH Certificate Issuer for your Akeyless Secure Access



129
130
131
# File 'lib/akeyless/models/create_rotated_secret.rb', line 129

def secure_access_certificate_issuer
  @secure_access_certificate_issuer
end

#secure_access_db_nameObject

The DB name (relevant only for DB Dynamic-Secret)



132
133
134
# File 'lib/akeyless/models/create_rotated_secret.rb', line 132

def secure_access_db_name
  @secure_access_db_name
end

#secure_access_db_schemaObject

The db schema (relevant only for mssql or postgresql)



135
136
137
# File 'lib/akeyless/models/create_rotated_secret.rb', line 135

def secure_access_db_schema
  @secure_access_db_schema
end

#secure_access_disable_concurrent_connectionsObject

Enable this flag to prevent simultaneous use of the same secret



138
139
140
# File 'lib/akeyless/models/create_rotated_secret.rb', line 138

def secure_access_disable_concurrent_connections
  @secure_access_disable_concurrent_connections
end

#secure_access_enableObject

Enable/Disable secure remote access [true/false]



141
142
143
# File 'lib/akeyless/models/create_rotated_secret.rb', line 141

def secure_access_enable
  @secure_access_enable
end

#secure_access_enforce_hosts_restrictionObject

Enforce connections only to allowed SRA hosts



144
145
146
# File 'lib/akeyless/models/create_rotated_secret.rb', line 144

def secure_access_enforce_hosts_restriction
  @secure_access_enforce_hosts_restriction
end

#secure_access_hostObject

Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)



147
148
149
# File 'lib/akeyless/models/create_rotated_secret.rb', line 147

def secure_access_host
  @secure_access_host
end

#secure_access_rdp_domainObject

Required when the Dynamic Secret is used for a domain user (relevant only for RDP Dynamic-Secret)



150
151
152
# File 'lib/akeyless/models/create_rotated_secret.rb', line 150

def secure_access_rdp_domain
  @secure_access_rdp_domain
end

#secure_access_rdp_userObject

Override the RDP Domain username (relevant only for rdp)



153
154
155
# File 'lib/akeyless/models/create_rotated_secret.rb', line 153

def secure_access_rdp_user
  @secure_access_rdp_user
end

#secure_access_urlObject

Destination URL to inject secrets



156
157
158
# File 'lib/akeyless/models/create_rotated_secret.rb', line 156

def secure_access_url
  @secure_access_url
end

#secure_access_webObject

Enable Web Secure Remote Access



159
160
161
# File 'lib/akeyless/models/create_rotated_secret.rb', line 159

def secure_access_web
  @secure_access_web
end

#secure_access_web_browsingObject

Secure browser viaAkeyless's Secure Remote Access (SRA) (relevant only for aws or azure)



162
163
164
# File 'lib/akeyless/models/create_rotated_secret.rb', line 162

def secure_access_web_browsing
  @secure_access_web_browsing
end

#secure_access_web_proxyObject

Web-Proxy via Akeyless's Secure Remote Access (SRA) (relevant only for aws or azure)



165
166
167
# File 'lib/akeyless/models/create_rotated_secret.rb', line 165

def secure_access_web_proxy
  @secure_access_web_proxy
end

#ssh_passwordObject

Deprecated: use RotatedPassword



168
169
170
# File 'lib/akeyless/models/create_rotated_secret.rb', line 168

def ssh_password
  @ssh_password
end

#ssh_usernameObject

Deprecated: use RotatedUser



171
172
173
# File 'lib/akeyless/models/create_rotated_secret.rb', line 171

def ssh_username
  @ssh_username
end

#storage_account_key_nameObject

The name of the storage account key to rotate [key1/key2/kerb1/kerb2] (relevat to azure-storage-account)



174
175
176
# File 'lib/akeyless/models/create_rotated_secret.rb', line 174

def 
  @storage_account_key_name
end

#tagsObject

Add tags attached to this object



177
178
179
# File 'lib/akeyless/models/create_rotated_secret.rb', line 177

def tags
  @tags
end

#targetObject

A list of targets to be associated with an SRA item, To specify multiple targets use argument multiple times



180
181
182
# File 'lib/akeyless/models/create_rotated_secret.rb', line 180

def target
  @target
end

#target_nameObject

Target name



183
184
185
# File 'lib/akeyless/models/create_rotated_secret.rb', line 183

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



186
187
188
# File 'lib/akeyless/models/create_rotated_secret.rb', line 186

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



189
190
191
# File 'lib/akeyless/models/create_rotated_secret.rb', line 189

def uid_token
  @uid_token
end

#user_attributeObject

LDAP User Attribute, Default value "cn"



192
193
194
# File 'lib/akeyless/models/create_rotated_secret.rb', line 192

def user_attribute
  @user_attribute
end

#user_dnObject

LDAP User Base DN



195
196
197
# File 'lib/akeyless/models/create_rotated_secret.rb', line 195

def user_dn
  @user_dn
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
# File 'lib/akeyless/models/create_rotated_secret.rb', line 760

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



264
265
266
# File 'lib/akeyless/models/create_rotated_secret.rb', line 264

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/akeyless/models/create_rotated_secret.rb', line 198

def self.attribute_map
  {
    :'provider_type' => :'ProviderType',
    :'api_id' => :'api-id',
    :'api_key' => :'api-key',
    :'application_id' => :'application-id',
    :'authentication_credentials' => :'authentication-credentials',
    :'auto_rotate' => :'auto-rotate',
    :'aws_region' => :'aws-region',
    :'custom_payload' => :'custom-payload',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'gcp_key' => :'gcp-key',
    :'gcp_service_account_email' => :'gcp-service-account-email',
    :'gcp_service_account_key_id' => :'gcp-service-account-key-id',
    :'grace_rotation' => :'grace-rotation',
    :'host_provider' => :'host-provider',
    :'json' => :'json',
    :'key' => :'key',
    :'lock_during_sra_session' => :'lock-during-sra-session',
    :'lock_on_read' => :'lock-on-read',
    :'lock_ttl' => :'lock-ttl',
    :'metadata' => :'metadata',
    :'name' => :'name',
    :'password_length' => :'password-length',
    :'rotate_after_disconnect' => :'rotate-after-disconnect',
    :'rotate_on_unlock' => :'rotate-on-unlock',
    :'rotated_password' => :'rotated-password',
    :'rotated_username' => :'rotated-username',
    :'rotation_hour' => :'rotation-hour',
    :'rotation_interval' => :'rotation-interval',
    :'rotator_creds_type' => :'rotator-creds-type',
    :'rotator_custom_cmd' => :'rotator-custom-cmd',
    :'rotator_type' => :'rotator-type',
    :'same_password' => :'same-password',
    :'secure_access_allow_external_user' => :'secure-access-allow-external-user',
    :'secure_access_aws_account_id' => :'secure-access-aws-account-id',
    :'secure_access_aws_native_cli' => :'secure-access-aws-native-cli',
    :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer',
    :'secure_access_certificate_issuer' => :'secure-access-certificate-issuer',
    :'secure_access_db_name' => :'secure-access-db-name',
    :'secure_access_db_schema' => :'secure-access-db-schema',
    :'secure_access_disable_concurrent_connections' => :'secure-access-disable-concurrent-connections',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_enforce_hosts_restriction' => :'secure-access-enforce-hosts-restriction',
    :'secure_access_host' => :'secure-access-host',
    :'secure_access_rdp_domain' => :'secure-access-rdp-domain',
    :'secure_access_rdp_user' => :'secure-access-rdp-user',
    :'secure_access_url' => :'secure-access-url',
    :'secure_access_web' => :'secure-access-web',
    :'secure_access_web_browsing' => :'secure-access-web-browsing',
    :'secure_access_web_proxy' => :'secure-access-web-proxy',
    :'ssh_password' => :'ssh-password',
    :'ssh_username' => :'ssh-username',
    :'storage_account_key_name' => :'storage-account-key-name',
    :'tags' => :'tags',
    :'target' => :'target',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'user_attribute' => :'user-attribute',
    :'user_dn' => :'user-dn'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
# File 'lib/akeyless/models/create_rotated_secret.rb', line 736

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



335
336
337
338
# File 'lib/akeyless/models/create_rotated_secret.rb', line 335

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/akeyless/models/create_rotated_secret.rb', line 269

def self.openapi_types
  {
    :'provider_type' => :'String',
    :'api_id' => :'String',
    :'api_key' => :'String',
    :'application_id' => :'String',
    :'authentication_credentials' => :'String',
    :'auto_rotate' => :'String',
    :'aws_region' => :'String',
    :'custom_payload' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'gcp_key' => :'String',
    :'gcp_service_account_email' => :'String',
    :'gcp_service_account_key_id' => :'String',
    :'grace_rotation' => :'String',
    :'host_provider' => :'String',
    :'json' => :'Boolean',
    :'key' => :'String',
    :'lock_during_sra_session' => :'String',
    :'lock_on_read' => :'String',
    :'lock_ttl' => :'String',
    :'metadata' => :'String',
    :'name' => :'String',
    :'password_length' => :'String',
    :'rotate_after_disconnect' => :'String',
    :'rotate_on_unlock' => :'String',
    :'rotated_password' => :'String',
    :'rotated_username' => :'String',
    :'rotation_hour' => :'Integer',
    :'rotation_interval' => :'String',
    :'rotator_creds_type' => :'String',
    :'rotator_custom_cmd' => :'String',
    :'rotator_type' => :'String',
    :'same_password' => :'String',
    :'secure_access_allow_external_user' => :'Boolean',
    :'secure_access_aws_account_id' => :'String',
    :'secure_access_aws_native_cli' => :'Boolean',
    :'secure_access_bastion_issuer' => :'String',
    :'secure_access_certificate_issuer' => :'String',
    :'secure_access_db_name' => :'String',
    :'secure_access_db_schema' => :'String',
    :'secure_access_disable_concurrent_connections' => :'Boolean',
    :'secure_access_enable' => :'String',
    :'secure_access_enforce_hosts_restriction' => :'Boolean',
    :'secure_access_host' => :'Array<String>',
    :'secure_access_rdp_domain' => :'String',
    :'secure_access_rdp_user' => :'String',
    :'secure_access_url' => :'String',
    :'secure_access_web' => :'Boolean',
    :'secure_access_web_browsing' => :'Boolean',
    :'secure_access_web_proxy' => :'Boolean',
    :'ssh_password' => :'String',
    :'ssh_username' => :'String',
    :'storage_account_key_name' => :'String',
    :'tags' => :'Array<String>',
    :'target' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'user_attribute' => :'String',
    :'user_dn' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
# File 'lib/akeyless/models/create_rotated_secret.rb', line 656

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      provider_type == o.provider_type &&
      api_id == o.api_id &&
      api_key == o.api_key &&
      application_id == o.application_id &&
      authentication_credentials == o.authentication_credentials &&
      auto_rotate == o.auto_rotate &&
      aws_region == o.aws_region &&
      custom_payload == o.custom_payload &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      gcp_key == o.gcp_key &&
       == o. &&
       == o. &&
      grace_rotation == o.grace_rotation &&
      host_provider == o.host_provider &&
      json == o.json &&
      key == o.key &&
      lock_during_sra_session == o.lock_during_sra_session &&
      lock_on_read == o.lock_on_read &&
      lock_ttl == o.lock_ttl &&
       == o. &&
      name == o.name &&
      password_length == o.password_length &&
      rotate_after_disconnect == o.rotate_after_disconnect &&
      rotate_on_unlock == o.rotate_on_unlock &&
      rotated_password == o.rotated_password &&
      rotated_username == o.rotated_username &&
      rotation_hour == o.rotation_hour &&
      rotation_interval == o.rotation_interval &&
      rotator_creds_type == o.rotator_creds_type &&
      rotator_custom_cmd == o.rotator_custom_cmd &&
      rotator_type == o.rotator_type &&
      same_password == o.same_password &&
      secure_access_allow_external_user == o.secure_access_allow_external_user &&
       == o. &&
      secure_access_aws_native_cli == o.secure_access_aws_native_cli &&
      secure_access_bastion_issuer == o.secure_access_bastion_issuer &&
      secure_access_certificate_issuer == o.secure_access_certificate_issuer &&
      secure_access_db_name == o.secure_access_db_name &&
      secure_access_db_schema == o.secure_access_db_schema &&
      secure_access_disable_concurrent_connections == o.secure_access_disable_concurrent_connections &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_enforce_hosts_restriction == o.secure_access_enforce_hosts_restriction &&
      secure_access_host == o.secure_access_host &&
      secure_access_rdp_domain == o.secure_access_rdp_domain &&
      secure_access_rdp_user == o.secure_access_rdp_user &&
      secure_access_url == o.secure_access_url &&
      secure_access_web == o.secure_access_web &&
      secure_access_web_browsing == o.secure_access_web_browsing &&
      secure_access_web_proxy == o.secure_access_web_proxy &&
      ssh_password == o.ssh_password &&
      ssh_username == o.ssh_username &&
       == o. &&
      tags == o.tags &&
      target == o.target &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      user_attribute == o.user_attribute &&
      user_dn == o.user_dn
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



831
832
833
834
835
836
837
838
839
840
841
842
843
# File 'lib/akeyless/models/create_rotated_secret.rb', line 831

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


723
724
725
# File 'lib/akeyless/models/create_rotated_secret.rb', line 723

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



729
730
731
# File 'lib/akeyless/models/create_rotated_secret.rb', line 729

def hash
  [provider_type, api_id, api_key, application_id, authentication_credentials, auto_rotate, aws_region, custom_payload, delete_protection, description, gcp_key, , , grace_rotation, host_provider, json, key, lock_during_sra_session, lock_on_read, lock_ttl, , name, password_length, rotate_after_disconnect, rotate_on_unlock, rotated_password, rotated_username, rotation_hour, rotation_interval, rotator_creds_type, rotator_custom_cmd, rotator_type, same_password, secure_access_allow_external_user, , secure_access_aws_native_cli, secure_access_bastion_issuer, secure_access_certificate_issuer, secure_access_db_name, secure_access_db_schema, secure_access_disable_concurrent_connections, secure_access_enable, secure_access_enforce_hosts_restriction, secure_access_host, secure_access_rdp_domain, secure_access_rdp_user, secure_access_url, secure_access_web, secure_access_web_browsing, secure_access_web_proxy, ssh_password, ssh_username, , tags, target, target_name, token, uid_token, user_attribute, user_dn].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
# File 'lib/akeyless/models/create_rotated_secret.rb', line 626

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @rotator_type.nil?
    invalid_properties.push('invalid value for "rotator_type", rotator_type cannot be nil.')
  end

  if @target_name.nil?
    invalid_properties.push('invalid value for "target_name", target_name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



807
808
809
# File 'lib/akeyless/models/create_rotated_secret.rb', line 807

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'lib/akeyless/models/create_rotated_secret.rb', line 813

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



801
802
803
# File 'lib/akeyless/models/create_rotated_secret.rb', line 801

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



646
647
648
649
650
651
652
# File 'lib/akeyless/models/create_rotated_secret.rb', line 646

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @rotator_type.nil?
  return false if @target_name.nil?
  true
end