Class: Akeyless::CreateSSHCertIssuer
- Inherits:
-
Object
- Object
- Akeyless::CreateSSHCertIssuer
- Defined in:
- lib/akeyless/models/create_ssh_cert_issuer.rb
Instance Attribute Summary collapse
-
#allowed_users ⇒ Object
Users allowed to fetch the certificate, e.g root,ubuntu.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this item.
-
#extensions ⇒ Object
Signed certificates with extensions, e.g permit-port-forwarding=\"\".
-
#metadata ⇒ Object
A metadata about the issuer.
-
#name ⇒ Object
SSH certificate issuer name.
-
#principals ⇒ Object
Signed certificates with principal, e.g example_role1,example_role2.
-
#secure_access_bastion_api ⇒ Object
Returns the value of attribute secure_access_bastion_api.
-
#secure_access_bastion_ssh ⇒ Object
Returns the value of attribute secure_access_bastion_ssh.
-
#secure_access_enable ⇒ Object
Returns the value of attribute secure_access_enable.
-
#secure_access_host ⇒ Object
Returns the value of attribute secure_access_host.
-
#secure_access_ssh_creds_user ⇒ Object
Returns the value of attribute secure_access_ssh_creds_user.
-
#secure_access_use_internal_bastion ⇒ Object
Returns the value of attribute secure_access_use_internal_bastion.
-
#signer_key_name ⇒ Object
A key to sign the certificate with.
-
#tag ⇒ Object
List of the tags attached to this key.
-
#token ⇒ Object
Authentication token (see
/authand/configure). -
#ttl ⇒ Object
he requested Time To Live for the certificate, in seconds.
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSSHCertIssuer
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSSHCertIssuer
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::CreateSSHCertIssuer` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::CreateSSHCertIssuer`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'allowed_users') self.allowed_users = attributes[:'allowed_users'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'extensions') if (value = attributes[:'extensions']).is_a?(Hash) self.extensions = value end end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'principals') self.principals = attributes[:'principals'] end if attributes.key?(:'secure_access_bastion_api') self.secure_access_bastion_api = attributes[:'secure_access_bastion_api'] end if attributes.key?(:'secure_access_bastion_ssh') self.secure_access_bastion_ssh = attributes[:'secure_access_bastion_ssh'] end if attributes.key?(:'secure_access_enable') self.secure_access_enable = attributes[:'secure_access_enable'] end if attributes.key?(:'secure_access_host') if (value = attributes[:'secure_access_host']).is_a?(Array) self.secure_access_host = value end end if attributes.key?(:'secure_access_ssh_creds_user') self.secure_access_ssh_creds_user = attributes[:'secure_access_ssh_creds_user'] end if attributes.key?(:'secure_access_use_internal_bastion') self.secure_access_use_internal_bastion = attributes[:'secure_access_use_internal_bastion'] end if attributes.key?(:'signer_key_name') self.signer_key_name = attributes[:'signer_key_name'] end if attributes.key?(:'tag') if (value = attributes[:'tag']).is_a?(Array) self.tag = value end end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'ttl') self.ttl = attributes[:'ttl'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end end |
Instance Attribute Details
#allowed_users ⇒ Object
Users allowed to fetch the certificate, e.g root,ubuntu
19 20 21 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 19 def allowed_users @allowed_users end |
#delete_protection ⇒ Object
Protection from accidental deletion of this item
22 23 24 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 22 def delete_protection @delete_protection end |
#extensions ⇒ Object
Signed certificates with extensions, e.g permit-port-forwarding=\"\"
25 26 27 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 25 def extensions @extensions end |
#metadata ⇒ Object
A metadata about the issuer
28 29 30 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 28 def @metadata end |
#name ⇒ Object
SSH certificate issuer name
31 32 33 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 31 def name @name end |
#principals ⇒ Object
Signed certificates with principal, e.g example_role1,example_role2
34 35 36 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 34 def principals @principals end |
#secure_access_bastion_api ⇒ Object
Returns the value of attribute secure_access_bastion_api.
36 37 38 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 36 def secure_access_bastion_api @secure_access_bastion_api end |
#secure_access_bastion_ssh ⇒ Object
Returns the value of attribute secure_access_bastion_ssh.
38 39 40 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 38 def secure_access_bastion_ssh @secure_access_bastion_ssh end |
#secure_access_enable ⇒ Object
Returns the value of attribute secure_access_enable.
40 41 42 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 40 def secure_access_enable @secure_access_enable end |
#secure_access_host ⇒ Object
Returns the value of attribute secure_access_host.
42 43 44 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 42 def secure_access_host @secure_access_host end |
#secure_access_ssh_creds_user ⇒ Object
Returns the value of attribute secure_access_ssh_creds_user.
44 45 46 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 44 def secure_access_ssh_creds_user @secure_access_ssh_creds_user end |
#secure_access_use_internal_bastion ⇒ Object
Returns the value of attribute secure_access_use_internal_bastion.
46 47 48 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 46 def secure_access_use_internal_bastion @secure_access_use_internal_bastion end |
#signer_key_name ⇒ Object
A key to sign the certificate with
49 50 51 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 49 def signer_key_name @signer_key_name end |
#tag ⇒ Object
List of the tags attached to this key
52 53 54 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 52 def tag @tag end |
#token ⇒ Object
Authentication token (see /auth and /configure)
55 56 57 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 55 def token @token end |
#ttl ⇒ Object
he requested Time To Live for the certificate, in seconds
58 59 60 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 58 def ttl @ttl end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
61 62 63 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 61 def uid_token @uid_token end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
87 88 89 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 87 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 64 def self.attribute_map { :'allowed_users' => :'allowed-users', :'delete_protection' => :'delete_protection', :'extensions' => :'extensions', :'metadata' => :'metadata', :'name' => :'name', :'principals' => :'principals', :'secure_access_bastion_api' => :'secure-access-bastion-api', :'secure_access_bastion_ssh' => :'secure-access-bastion-ssh', :'secure_access_enable' => :'secure-access-enable', :'secure_access_host' => :'secure-access-host', :'secure_access_ssh_creds_user' => :'secure-access-ssh-creds-user', :'secure_access_use_internal_bastion' => :'secure-access-use-internal-bastion', :'signer_key_name' => :'signer-key-name', :'tag' => :'tag', :'token' => :'token', :'ttl' => :'ttl', :'uid_token' => :'uid-token' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
282 283 284 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 282 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
115 116 117 118 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 115 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 92 def self.openapi_types { :'allowed_users' => :'String', :'delete_protection' => :'String', :'extensions' => :'Hash<String, String>', :'metadata' => :'String', :'name' => :'String', :'principals' => :'String', :'secure_access_bastion_api' => :'String', :'secure_access_bastion_ssh' => :'String', :'secure_access_enable' => :'String', :'secure_access_host' => :'Array<String>', :'secure_access_ssh_creds_user' => :'String', :'secure_access_use_internal_bastion' => :'Boolean', :'signer_key_name' => :'String', :'tag' => :'Array<String>', :'token' => :'String', :'ttl' => :'Integer', :'uid_token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 245 def ==(o) return true if self.equal?(o) self.class == o.class && allowed_users == o.allowed_users && delete_protection == o.delete_protection && extensions == o.extensions && == o. && name == o.name && principals == o.principals && secure_access_bastion_api == o.secure_access_bastion_api && secure_access_bastion_ssh == o.secure_access_bastion_ssh && secure_access_enable == o.secure_access_enable && secure_access_host == o.secure_access_host && secure_access_ssh_creds_user == o.secure_access_ssh_creds_user && secure_access_use_internal_bastion == o.secure_access_use_internal_bastion && signer_key_name == o.signer_key_name && tag == o.tag && token == o.token && ttl == o.ttl && uid_token == o.uid_token end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 313 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 384 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 289 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
269 270 271 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 269 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
275 276 277 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 275 def hash [allowed_users, delete_protection, extensions, , name, principals, secure_access_bastion_api, secure_access_bastion_ssh, secure_access_enable, secure_access_host, secure_access_ssh_creds_user, secure_access_use_internal_bastion, signer_key_name, tag, token, ttl, uid_token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 212 def list_invalid_properties invalid_properties = Array.new if @allowed_users.nil? invalid_properties.push('invalid value for "allowed_users", allowed_users cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @signer_key_name.nil? invalid_properties.push('invalid value for "signer_key_name", signer_key_name cannot be nil.') end if @ttl.nil? invalid_properties.push('invalid value for "ttl", ttl cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
360 361 362 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 360 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 366 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
354 355 356 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 354 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
235 236 237 238 239 240 241 |
# File 'lib/akeyless/models/create_ssh_cert_issuer.rb', line 235 def valid? return false if @allowed_users.nil? return false if @name.nil? return false if @signer_key_name.nil? return false if @ttl.nil? true end |