Class: Akeyless::CreateSSHTarget

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/create_ssh_target.rb

Overview

createSSHTarget is a command that creates a new target. [Deprecated: Use target-create-ssh command]

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateSSHTarget

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/akeyless/models/create_ssh_target.rb', line 129

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::CreateSSHTarget` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::CreateSSHTarget`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'host')
    self.host = attributes[:'host']
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'lock_on_read')
    self.lock_on_read = attributes[:'lock_on_read']
  end

  if attributes.key?(:'lock_ttl')
    self.lock_ttl = attributes[:'lock_ttl']
  end

  if attributes.key?(:'max_versions')
    self.max_versions = attributes[:'max_versions']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'port')
    self.port = attributes[:'port']
  else
    self.port = '22'
  end

  if attributes.key?(:'private_key')
    self.private_key = attributes[:'private_key']
  end

  if attributes.key?(:'private_key_password')
    self.private_key_password = attributes[:'private_key_password']
  end

  if attributes.key?(:'rotate_on_unlock')
    self.rotate_on_unlock = attributes[:'rotate_on_unlock']
  end

  if attributes.key?(:'ssh_password')
    self.ssh_password = attributes[:'ssh_password']
  end

  if attributes.key?(:'ssh_username')
    self.ssh_username = attributes[:'ssh_username']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end
end

Instance Attribute Details

#commentObject

Deprecated - use description



20
21
22
# File 'lib/akeyless/models/create_ssh_target.rb', line 20

def comment
  @comment
end

#descriptionObject

Description of the object



23
24
25
# File 'lib/akeyless/models/create_ssh_target.rb', line 23

def description
  @description
end

#hostObject

SSH host name



26
27
28
# File 'lib/akeyless/models/create_ssh_target.rb', line 26

def host
  @host
end

#jsonObject

Set output format to JSON



29
30
31
# File 'lib/akeyless/models/create_ssh_target.rb', line 29

def json
  @json
end

#keyObject

The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)



32
33
34
# File 'lib/akeyless/models/create_ssh_target.rb', line 32

def key
  @key
end

#lock_on_readObject

Lock this secret after each successful value read



35
36
37
# File 'lib/akeyless/models/create_ssh_target.rb', line 35

def lock_on_read
  @lock_on_read
end

#lock_ttlObject

Lock TTL in minutes



38
39
40
# File 'lib/akeyless/models/create_ssh_target.rb', line 38

def lock_ttl
  @lock_ttl
end

#max_versionsObject

Set the maximum number of versions, limited by the account settings defaults.



41
42
43
# File 'lib/akeyless/models/create_ssh_target.rb', line 41

def max_versions
  @max_versions
end

#nameObject

Target name



44
45
46
# File 'lib/akeyless/models/create_ssh_target.rb', line 44

def name
  @name
end

#portObject

SSH port



47
48
49
# File 'lib/akeyless/models/create_ssh_target.rb', line 47

def port
  @port
end

#private_keyObject

SSH private key



50
51
52
# File 'lib/akeyless/models/create_ssh_target.rb', line 50

def private_key
  @private_key
end

#private_key_passwordObject

SSH private key password



53
54
55
# File 'lib/akeyless/models/create_ssh_target.rb', line 53

def private_key_password
  @private_key_password
end

#rotate_on_unlockObject

Rotate this secret after it is unlocked



56
57
58
# File 'lib/akeyless/models/create_ssh_target.rb', line 56

def rotate_on_unlock
  @rotate_on_unlock
end

#ssh_passwordObject

SSH password to rotate



59
60
61
# File 'lib/akeyless/models/create_ssh_target.rb', line 59

def ssh_password
  @ssh_password
end

#ssh_usernameObject

SSH username



62
63
64
# File 'lib/akeyless/models/create_ssh_target.rb', line 62

def ssh_username
  @ssh_username
end

#tokenObject

Authentication token (see /auth and /configure)



65
66
67
# File 'lib/akeyless/models/create_ssh_target.rb', line 65

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



68
69
70
# File 'lib/akeyless/models/create_ssh_target.rb', line 68

def uid_token
  @uid_token
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/akeyless/models/create_ssh_target.rb', line 300

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



94
95
96
# File 'lib/akeyless/models/create_ssh_target.rb', line 94

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/akeyless/models/create_ssh_target.rb', line 71

def self.attribute_map
  {
    :'comment' => :'comment',
    :'description' => :'description',
    :'host' => :'host',
    :'json' => :'json',
    :'key' => :'key',
    :'lock_on_read' => :'lock-on-read',
    :'lock_ttl' => :'lock-ttl',
    :'max_versions' => :'max-versions',
    :'name' => :'name',
    :'port' => :'port',
    :'private_key' => :'private-key',
    :'private_key_password' => :'private-key-password',
    :'rotate_on_unlock' => :'rotate-on-unlock',
    :'ssh_password' => :'ssh-password',
    :'ssh_username' => :'ssh-username',
    :'token' => :'token',
    :'uid_token' => :'uid-token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/akeyless/models/create_ssh_target.rb', line 276

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



122
123
124
125
# File 'lib/akeyless/models/create_ssh_target.rb', line 122

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/akeyless/models/create_ssh_target.rb', line 99

def self.openapi_types
  {
    :'comment' => :'String',
    :'description' => :'String',
    :'host' => :'String',
    :'json' => :'Boolean',
    :'key' => :'String',
    :'lock_on_read' => :'String',
    :'lock_ttl' => :'String',
    :'max_versions' => :'String',
    :'name' => :'String',
    :'port' => :'String',
    :'private_key' => :'String',
    :'private_key_password' => :'String',
    :'rotate_on_unlock' => :'String',
    :'ssh_password' => :'String',
    :'ssh_username' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/akeyless/models/create_ssh_target.rb', line 239

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      comment == o.comment &&
      description == o.description &&
      host == o.host &&
      json == o.json &&
      key == o.key &&
      lock_on_read == o.lock_on_read &&
      lock_ttl == o.lock_ttl &&
      max_versions == o.max_versions &&
      name == o.name &&
      port == o.port &&
      private_key == o.private_key &&
      private_key_password == o.private_key_password &&
      rotate_on_unlock == o.rotate_on_unlock &&
      ssh_password == o.ssh_password &&
      ssh_username == o.ssh_username &&
      token == o.token &&
      uid_token == o.uid_token
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/akeyless/models/create_ssh_target.rb', line 371

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


263
264
265
# File 'lib/akeyless/models/create_ssh_target.rb', line 263

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



269
270
271
# File 'lib/akeyless/models/create_ssh_target.rb', line 269

def hash
  [comment, description, host, json, key, lock_on_read, lock_ttl, max_versions, name, port, private_key, private_key_password, rotate_on_unlock, ssh_password, ssh_username, token, uid_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



219
220
221
222
223
224
225
226
227
# File 'lib/akeyless/models/create_ssh_target.rb', line 219

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



347
348
349
# File 'lib/akeyless/models/create_ssh_target.rb', line 347

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/akeyless/models/create_ssh_target.rb', line 353

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



341
342
343
# File 'lib/akeyless/models/create_ssh_target.rb', line 341

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



231
232
233
234
235
# File 'lib/akeyless/models/create_ssh_target.rb', line 231

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end