Class: Akeyless::DbTargetDetails
- Inherits:
-
Object
- Object
- Akeyless::DbTargetDetails
- Defined in:
- lib/akeyless/models/db_target_details.rb
Overview
DbTargetDetails
Instance Attribute Summary collapse
-
#client_certificate ⇒ Object
(Optional) ClientCertificate defines the client certificate for mutual TLS.
-
#client_key_passphrase ⇒ Object
(Optional) ClientKeyPassphrase defines the passphrase for the client private key.
-
#client_private_key ⇒ Object
(Optional) ClientPrivateKey defines the client private key for mutual TLS.
-
#cloud_service_provider ⇒ Object
Returns the value of attribute cloud_service_provider.
-
#cluster_mode ⇒ Object
Returns the value of attribute cluster_mode.
-
#connection_type ⇒ Object
Returns the value of attribute connection_type.
-
#db_client_id ⇒ Object
Returns the value of attribute db_client_id.
-
#db_client_secret ⇒ Object
Returns the value of attribute db_client_secret.
-
#db_host_name ⇒ Object
Returns the value of attribute db_host_name.
-
#db_name ⇒ Object
Returns the value of attribute db_name.
-
#db_port ⇒ Object
Returns the value of attribute db_port.
-
#db_private_key ⇒ Object
(Optional) Private Key in PEM format.
-
#db_private_key_passphrase ⇒ Object
Returns the value of attribute db_private_key_passphrase.
-
#db_pwd ⇒ Object
Returns the value of attribute db_pwd.
-
#db_server_certificates ⇒ Object
(Optional) DBServerCertificates defines the set of root certificate authorities that clients use when verifying server certificates.
-
#db_server_name ⇒ Object
(Optional) ServerName is used to verify the hostname on the returned certificates unless InsecureSkipVerify is given.
-
#db_tenant_id ⇒ Object
Returns the value of attribute db_tenant_id.
-
#db_user_name ⇒ Object
Returns the value of attribute db_user_name.
-
#enable_mtls ⇒ Object
(Optional) EnableMTLS defines if mutual TLS will be used to connect to DB.
-
#oracle_wallet_details ⇒ Object
Returns the value of attribute oracle_wallet_details.
-
#sf_account ⇒ Object
Returns the value of attribute sf_account.
-
#ssl_connection_certificate ⇒ Object
(Optional) SSLConnectionCertificate defines the certificate for SSL connection.
-
#ssl_connection_mode ⇒ Object
(Optional) SSLConnectionMode defines if SSL mode will be used to connect to DB.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DbTargetDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DbTargetDetails
Initializes the object
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/akeyless/models/db_target_details.rb', line 145 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DbTargetDetails` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DbTargetDetails`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'client_certificate') self.client_certificate = attributes[:'client_certificate'] end if attributes.key?(:'client_key_passphrase') self.client_key_passphrase = attributes[:'client_key_passphrase'] end if attributes.key?(:'client_private_key') self.client_private_key = attributes[:'client_private_key'] end if attributes.key?(:'cloud_service_provider') self.cloud_service_provider = attributes[:'cloud_service_provider'] end if attributes.key?(:'cluster_mode') self.cluster_mode = attributes[:'cluster_mode'] end if attributes.key?(:'connection_type') self.connection_type = attributes[:'connection_type'] end if attributes.key?(:'db_client_id') self.db_client_id = attributes[:'db_client_id'] end if attributes.key?(:'db_client_secret') self.db_client_secret = attributes[:'db_client_secret'] end if attributes.key?(:'db_host_name') self.db_host_name = attributes[:'db_host_name'] end if attributes.key?(:'db_name') self.db_name = attributes[:'db_name'] end if attributes.key?(:'db_port') self.db_port = attributes[:'db_port'] end if attributes.key?(:'db_private_key') self.db_private_key = attributes[:'db_private_key'] end if attributes.key?(:'db_private_key_passphrase') self.db_private_key_passphrase = attributes[:'db_private_key_passphrase'] end if attributes.key?(:'db_pwd') self.db_pwd = attributes[:'db_pwd'] end if attributes.key?(:'db_server_certificates') self.db_server_certificates = attributes[:'db_server_certificates'] end if attributes.key?(:'db_server_name') self.db_server_name = attributes[:'db_server_name'] end if attributes.key?(:'db_tenant_id') self.db_tenant_id = attributes[:'db_tenant_id'] end if attributes.key?(:'db_user_name') self.db_user_name = attributes[:'db_user_name'] end if attributes.key?(:'enable_mtls') self.enable_mtls = attributes[:'enable_mtls'] end if attributes.key?(:'oracle_wallet_details') self.oracle_wallet_details = attributes[:'oracle_wallet_details'] end if attributes.key?(:'sf_account') self.sf_account = attributes[:'sf_account'] end if attributes.key?(:'ssl_connection_certificate') self.ssl_connection_certificate = attributes[:'ssl_connection_certificate'] end if attributes.key?(:'ssl_connection_mode') self.ssl_connection_mode = attributes[:'ssl_connection_mode'] end end |
Instance Attribute Details
#client_certificate ⇒ Object
(Optional) ClientCertificate defines the client certificate for mutual TLS. Must be base64 certificate loaded by UI using file loader field
20 21 22 |
# File 'lib/akeyless/models/db_target_details.rb', line 20 def client_certificate @client_certificate end |
#client_key_passphrase ⇒ Object
(Optional) ClientKeyPassphrase defines the passphrase for the client private key
23 24 25 |
# File 'lib/akeyless/models/db_target_details.rb', line 23 def client_key_passphrase @client_key_passphrase end |
#client_private_key ⇒ Object
(Optional) ClientPrivateKey defines the client private key for mutual TLS. Must be base64 private key loaded by UI using file loader field
26 27 28 |
# File 'lib/akeyless/models/db_target_details.rb', line 26 def client_private_key @client_private_key end |
#cloud_service_provider ⇒ Object
Returns the value of attribute cloud_service_provider.
28 29 30 |
# File 'lib/akeyless/models/db_target_details.rb', line 28 def cloud_service_provider @cloud_service_provider end |
#cluster_mode ⇒ Object
Returns the value of attribute cluster_mode.
30 31 32 |
# File 'lib/akeyless/models/db_target_details.rb', line 30 def cluster_mode @cluster_mode end |
#connection_type ⇒ Object
Returns the value of attribute connection_type.
32 33 34 |
# File 'lib/akeyless/models/db_target_details.rb', line 32 def connection_type @connection_type end |
#db_client_id ⇒ Object
Returns the value of attribute db_client_id.
34 35 36 |
# File 'lib/akeyless/models/db_target_details.rb', line 34 def db_client_id @db_client_id end |
#db_client_secret ⇒ Object
Returns the value of attribute db_client_secret.
36 37 38 |
# File 'lib/akeyless/models/db_target_details.rb', line 36 def db_client_secret @db_client_secret end |
#db_host_name ⇒ Object
Returns the value of attribute db_host_name.
38 39 40 |
# File 'lib/akeyless/models/db_target_details.rb', line 38 def db_host_name @db_host_name end |
#db_name ⇒ Object
Returns the value of attribute db_name.
40 41 42 |
# File 'lib/akeyless/models/db_target_details.rb', line 40 def db_name @db_name end |
#db_port ⇒ Object
Returns the value of attribute db_port.
42 43 44 |
# File 'lib/akeyless/models/db_target_details.rb', line 42 def db_port @db_port end |
#db_private_key ⇒ Object
(Optional) Private Key in PEM format
45 46 47 |
# File 'lib/akeyless/models/db_target_details.rb', line 45 def db_private_key @db_private_key end |
#db_private_key_passphrase ⇒ Object
Returns the value of attribute db_private_key_passphrase.
47 48 49 |
# File 'lib/akeyless/models/db_target_details.rb', line 47 def db_private_key_passphrase @db_private_key_passphrase end |
#db_pwd ⇒ Object
Returns the value of attribute db_pwd.
49 50 51 |
# File 'lib/akeyless/models/db_target_details.rb', line 49 def db_pwd @db_pwd end |
#db_server_certificates ⇒ Object
(Optional) DBServerCertificates defines the set of root certificate authorities that clients use when verifying server certificates. If DBServerCertificates is empty, TLS uses the host’s root CA set.
52 53 54 |
# File 'lib/akeyless/models/db_target_details.rb', line 52 def db_server_certificates @db_server_certificates end |
#db_server_name ⇒ Object
(Optional) ServerName is used to verify the hostname on the returned certificates unless InsecureSkipVerify is given. It is also included in the client’s handshake to support virtual hosting unless it is an IP address.
55 56 57 |
# File 'lib/akeyless/models/db_target_details.rb', line 55 def db_server_name @db_server_name end |
#db_tenant_id ⇒ Object
Returns the value of attribute db_tenant_id.
57 58 59 |
# File 'lib/akeyless/models/db_target_details.rb', line 57 def db_tenant_id @db_tenant_id end |
#db_user_name ⇒ Object
Returns the value of attribute db_user_name.
59 60 61 |
# File 'lib/akeyless/models/db_target_details.rb', line 59 def db_user_name @db_user_name end |
#enable_mtls ⇒ Object
(Optional) EnableMTLS defines if mutual TLS will be used to connect to DB
62 63 64 |
# File 'lib/akeyless/models/db_target_details.rb', line 62 def enable_mtls @enable_mtls end |
#oracle_wallet_details ⇒ Object
Returns the value of attribute oracle_wallet_details.
64 65 66 |
# File 'lib/akeyless/models/db_target_details.rb', line 64 def oracle_wallet_details @oracle_wallet_details end |
#sf_account ⇒ Object
Returns the value of attribute sf_account.
66 67 68 |
# File 'lib/akeyless/models/db_target_details.rb', line 66 def sf_account @sf_account end |
#ssl_connection_certificate ⇒ Object
(Optional) SSLConnectionCertificate defines the certificate for SSL connection. Must be base64 certificate loaded by UI using file loader field
69 70 71 |
# File 'lib/akeyless/models/db_target_details.rb', line 69 def ssl_connection_certificate @ssl_connection_certificate end |
#ssl_connection_mode ⇒ Object
(Optional) SSLConnectionMode defines if SSL mode will be used to connect to DB
72 73 74 |
# File 'lib/akeyless/models/db_target_details.rb', line 72 def ssl_connection_mode @ssl_connection_mode end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/akeyless/models/db_target_details.rb', line 335 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
104 105 106 |
# File 'lib/akeyless/models/db_target_details.rb', line 104 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/akeyless/models/db_target_details.rb', line 75 def self.attribute_map { :'client_certificate' => :'client_certificate', :'client_key_passphrase' => :'client_key_passphrase', :'client_private_key' => :'client_private_key', :'cloud_service_provider' => :'cloud_service_provider', :'cluster_mode' => :'cluster_mode', :'connection_type' => :'connection_type', :'db_client_id' => :'db_client_id', :'db_client_secret' => :'db_client_secret', :'db_host_name' => :'db_host_name', :'db_name' => :'db_name', :'db_port' => :'db_port', :'db_private_key' => :'db_private_key', :'db_private_key_passphrase' => :'db_private_key_passphrase', :'db_pwd' => :'db_pwd', :'db_server_certificates' => :'db_server_certificates', :'db_server_name' => :'db_server_name', :'db_tenant_id' => :'db_tenant_id', :'db_user_name' => :'db_user_name', :'enable_mtls' => :'enable_mtls', :'oracle_wallet_details' => :'oracle_wallet_details', :'sf_account' => :'sf_account', :'ssl_connection_certificate' => :'ssl_connection_certificate', :'ssl_connection_mode' => :'ssl_connection_mode' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/akeyless/models/db_target_details.rb', line 311 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
138 139 140 141 |
# File 'lib/akeyless/models/db_target_details.rb', line 138 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/akeyless/models/db_target_details.rb', line 109 def self.openapi_types { :'client_certificate' => :'String', :'client_key_passphrase' => :'String', :'client_private_key' => :'String', :'cloud_service_provider' => :'String', :'cluster_mode' => :'Boolean', :'connection_type' => :'String', :'db_client_id' => :'String', :'db_client_secret' => :'String', :'db_host_name' => :'String', :'db_name' => :'String', :'db_port' => :'String', :'db_private_key' => :'String', :'db_private_key_passphrase' => :'String', :'db_pwd' => :'String', :'db_server_certificates' => :'String', :'db_server_name' => :'String', :'db_tenant_id' => :'String', :'db_user_name' => :'String', :'enable_mtls' => :'Boolean', :'oracle_wallet_details' => :'WalletDetails', :'sf_account' => :'String', :'ssl_connection_certificate' => :'String', :'ssl_connection_mode' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/akeyless/models/db_target_details.rb', line 268 def ==(o) return true if self.equal?(o) self.class == o.class && client_certificate == o.client_certificate && client_key_passphrase == o.client_key_passphrase && client_private_key == o.client_private_key && cloud_service_provider == o.cloud_service_provider && cluster_mode == o.cluster_mode && connection_type == o.connection_type && db_client_id == o.db_client_id && db_client_secret == o.db_client_secret && db_host_name == o.db_host_name && db_name == o.db_name && db_port == o.db_port && db_private_key == o.db_private_key && db_private_key_passphrase == o.db_private_key_passphrase && db_pwd == o.db_pwd && db_server_certificates == o.db_server_certificates && db_server_name == o.db_server_name && db_tenant_id == o.db_tenant_id && db_user_name == o.db_user_name && enable_mtls == o.enable_mtls && oracle_wallet_details == o.oracle_wallet_details && sf_account == o.sf_account && ssl_connection_certificate == o.ssl_connection_certificate && ssl_connection_mode == o.ssl_connection_mode end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/akeyless/models/db_target_details.rb', line 406 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
298 299 300 |
# File 'lib/akeyless/models/db_target_details.rb', line 298 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
304 305 306 |
# File 'lib/akeyless/models/db_target_details.rb', line 304 def hash [client_certificate, client_key_passphrase, client_private_key, cloud_service_provider, cluster_mode, connection_type, db_client_id, db_client_secret, db_host_name, db_name, db_port, db_private_key, db_private_key_passphrase, db_pwd, db_server_certificates, db_server_name, db_tenant_id, db_user_name, enable_mtls, oracle_wallet_details, sf_account, ssl_connection_certificate, ssl_connection_mode].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
253 254 255 256 257 |
# File 'lib/akeyless/models/db_target_details.rb', line 253 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
382 383 384 |
# File 'lib/akeyless/models/db_target_details.rb', line 382 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/akeyless/models/db_target_details.rb', line 388 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
376 377 378 |
# File 'lib/akeyless/models/db_target_details.rb', line 376 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
261 262 263 264 |
# File 'lib/akeyless/models/db_target_details.rb', line 261 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |