Class: Akeyless::DynamicSecretCreateGcp

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/dynamic_secret_create_gcp.rb

Overview

dynamicSecretCreateGcp is a command that creates a GCP dynamic secret

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DynamicSecretCreateGcp

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 202

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DynamicSecretCreateGcp` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DynamicSecretCreateGcp`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_type')
    self.access_type = attributes[:'access_type']
  end

  if attributes.key?(:'ara_enabled')
    self.ara_enabled = attributes[:'ara_enabled']
  end

  if attributes.key?(:'custom_username_template')
    self.custom_username_template = attributes[:'custom_username_template']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'fixed_user_claim_keyname')
    self.fixed_user_claim_keyname = attributes[:'fixed_user_claim_keyname']
  else
    self.fixed_user_claim_keyname = 'ext_email'
  end

  if attributes.key?(:'gcp_cred_type')
    self.gcp_cred_type = attributes[:'gcp_cred_type']
  end

  if attributes.key?(:'gcp_key')
    self.gcp_key = attributes[:'gcp_key']
  end

  if attributes.key?(:'gcp_key_algo')
    self.gcp_key_algo = attributes[:'gcp_key_algo']
  end

  if attributes.key?(:'gcp_project_id')
    self.gcp_project_id = attributes[:'gcp_project_id']
  end

  if attributes.key?(:'gcp_sa_email')
    self.gcp_sa_email = attributes[:'gcp_sa_email']
  end

  if attributes.key?(:'gcp_token_scopes')
    self.gcp_token_scopes = attributes[:'gcp_token_scopes']
  end

  if attributes.key?(:'input_rule')
    if (value = attributes[:'input_rule']).is_a?(Array)
      self.input_rule = value
    end
  end

  if attributes.key?(:'item_custom_fields')
    if (value = attributes[:'item_custom_fields']).is_a?(Hash)
      self.item_custom_fields = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'output_rule')
    if (value = attributes[:'output_rule']).is_a?(Array)
      self.output_rule = value
    end
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'role_binding')
    self.role_binding = attributes[:'role_binding']
  end

  if attributes.key?(:'role_names')
    self.role_names = attributes[:'role_names']
  end

  if attributes.key?(:'secure_access_delay')
    self.secure_access_delay = attributes[:'secure_access_delay']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_url')
    self.secure_access_url = attributes[:'secure_access_url']
  end

  if attributes.key?(:'secure_access_web_browsing')
    self.secure_access_web_browsing = attributes[:'secure_access_web_browsing']
  else
    self.secure_access_web_browsing = false
  end

  if attributes.key?(:'secure_access_web_proxy')
    self.secure_access_web_proxy = attributes[:'secure_access_web_proxy']
  else
    self.secure_access_web_proxy = false
  end

  if attributes.key?(:'service_account_type')
    self. = attributes[:'service_account_type']
  else
    self. = 'fixed'
  end

  if attributes.key?(:'skip_dry_run')
    self.skip_dry_run = attributes[:'skip_dry_run']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '60m'
  end
end

Instance Attribute Details

#access_typeObject

Returns the value of attribute access_type.



19
20
21
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 19

def access_type
  @access_type
end

#ara_enabledObject

Enable or disable Agentic Runtime Authority rule enforcement for this item. Mirrors commands.AgenticRulesParams.AraEnabled.



22
23
24
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 22

def ara_enabled
  @ara_enabled
end

#custom_username_templateObject

Customize how temporary usernames are generated using go template



25
26
27
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 25

def custom_username_template
  @custom_username_template
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



28
29
30
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 28

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



31
32
33
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 31

def description
  @description
end

#fixed_user_claim_keynameObject

For externally provided users, denotes the key-name of IdP claim to extract the username from (Relevant only when --access-type=external)



34
35
36
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 34

def fixed_user_claim_keyname
  @fixed_user_claim_keyname
end

#gcp_cred_typeObject

Returns the value of attribute gcp_cred_type.



36
37
38
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 36

def gcp_cred_type
  @gcp_cred_type
end

#gcp_keyObject

Base64-encoded service account private key text



39
40
41
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 39

def gcp_key
  @gcp_key
end

#gcp_key_algoObject

Service account key algorithm, e.g. KEY_ALG_RSA_1024 (Relevant only when --access-type=sa and --gcp-cred-type=key)



42
43
44
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 42

def gcp_key_algo
  @gcp_key_algo
end

#gcp_project_idObject

GCP Project ID override for dynamic secret operations



45
46
47
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 45

def gcp_project_id
  @gcp_project_id
end

#gcp_sa_emailObject

The email of the fixed service account to generate keys or tokens for (Relevant only when --access-type=sa and --service-account-type=fixed)



48
49
50
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 48

def gcp_sa_email
  @gcp_sa_email
end

#gcp_token_scopesObject

Access token scopes list, e.g. scope1,scope2 (Relevant only when --access-type=sa; required when --gcp-cred-type=token)



51
52
53
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 51

def gcp_token_scopes
  @gcp_token_scopes
end

#input_ruleObject

Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).



54
55
56
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 54

def input_rule
  @input_rule
end

#item_custom_fieldsObject

Additional custom fields to associate with the item



57
58
59
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 57

def item_custom_fields
  @item_custom_fields
end

#jsonObject

Set output format to JSON



60
61
62
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 60

def json
  @json
end

#nameObject

Dynamic secret name



63
64
65
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 63

def name
  @name
end

#output_ruleObject

Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)



66
67
68
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 66

def output_rule
  @output_rule
end

#producer_encryption_key_nameObject

Dynamic producer encryption key



69
70
71
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 69

def producer_encryption_key_name
  @producer_encryption_key_name
end

#role_bindingObject

Role binding definitions in JSON format (Relevant only when --access-type=sa and --service-account-type=dynamic)



72
73
74
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 72

def role_binding
  @role_binding
end

#role_namesObject

Comma-separated list of GCP roles to assign to the user (Relevant only when --access-type=external)



75
76
77
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 75

def role_names
  @role_names
end

#secure_access_delayObject

The delay duration, in seconds, to wait after generating just-in-time credentials. Accepted range: 0-120 seconds



78
79
80
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 78

def secure_access_delay
  @secure_access_delay
end

#secure_access_enableObject

Enable/Disable secure remote access [true/false]



81
82
83
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 81

def secure_access_enable
  @secure_access_enable
end

#secure_access_urlObject

Destination URL to inject secrets



84
85
86
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 84

def secure_access_url
  @secure_access_url
end

#secure_access_web_browsingObject

Secure browser via Akeyless's Secure Remote Access (SRA)



87
88
89
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 87

def secure_access_web_browsing
  @secure_access_web_browsing
end

#secure_access_web_proxyObject

Web-Proxy via Akeyless's Secure Remote Access (SRA)



90
91
92
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 90

def secure_access_web_proxy
  @secure_access_web_proxy
end

#service_account_typeObject

The type of the GCP service account. Options [fixed, dynamic] (Relevant only when --access-type=sa)



93
94
95
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 93

def 
  @service_account_type
end

#skip_dry_runObject

If set, dry-run will be skipped



96
97
98
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 96

def skip_dry_run
  @skip_dry_run
end

#tagsObject

Add tags attached to this object



99
100
101
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 99

def tags
  @tags
end

#target_nameObject

Target name



102
103
104
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 102

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



105
106
107
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 105

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



108
109
110
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 108

def uid_token
  @uid_token
end

#user_ttlObject

User TTL



111
112
113
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 111

def user_ttl
  @user_ttl
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 464

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



152
153
154
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 152

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 114

def self.attribute_map
  {
    :'access_type' => :'access-type',
    :'ara_enabled' => :'ara-enabled',
    :'custom_username_template' => :'custom-username-template',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'fixed_user_claim_keyname' => :'fixed-user-claim-keyname',
    :'gcp_cred_type' => :'gcp-cred-type',
    :'gcp_key' => :'gcp-key',
    :'gcp_key_algo' => :'gcp-key-algo',
    :'gcp_project_id' => :'gcp-project-id',
    :'gcp_sa_email' => :'gcp-sa-email',
    :'gcp_token_scopes' => :'gcp-token-scopes',
    :'input_rule' => :'input-rule',
    :'item_custom_fields' => :'item-custom-fields',
    :'json' => :'json',
    :'name' => :'name',
    :'output_rule' => :'output-rule',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'role_binding' => :'role-binding',
    :'role_names' => :'role-names',
    :'secure_access_delay' => :'secure-access-delay',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_url' => :'secure-access-url',
    :'secure_access_web_browsing' => :'secure-access-web-browsing',
    :'secure_access_web_proxy' => :'secure-access-web-proxy',
    :'service_account_type' => :'service-account-type',
    :'skip_dry_run' => :'skip_dry_run',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'user_ttl' => :'user-ttl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 440

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



195
196
197
198
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 195

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 157

def self.openapi_types
  {
    :'access_type' => :'String',
    :'ara_enabled' => :'Boolean',
    :'custom_username_template' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'fixed_user_claim_keyname' => :'String',
    :'gcp_cred_type' => :'String',
    :'gcp_key' => :'String',
    :'gcp_key_algo' => :'String',
    :'gcp_project_id' => :'String',
    :'gcp_sa_email' => :'String',
    :'gcp_token_scopes' => :'String',
    :'input_rule' => :'Array<String>',
    :'item_custom_fields' => :'Hash<String, String>',
    :'json' => :'Boolean',
    :'name' => :'String',
    :'output_rule' => :'Array<String>',
    :'producer_encryption_key_name' => :'String',
    :'role_binding' => :'String',
    :'role_names' => :'String',
    :'secure_access_delay' => :'Integer',
    :'secure_access_enable' => :'String',
    :'secure_access_url' => :'String',
    :'secure_access_web_browsing' => :'Boolean',
    :'secure_access_web_proxy' => :'Boolean',
    :'service_account_type' => :'String',
    :'skip_dry_run' => :'String',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'user_ttl' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 388

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_type == o.access_type &&
      ara_enabled == o.ara_enabled &&
      custom_username_template == o.custom_username_template &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      fixed_user_claim_keyname == o.fixed_user_claim_keyname &&
      gcp_cred_type == o.gcp_cred_type &&
      gcp_key == o.gcp_key &&
      gcp_key_algo == o.gcp_key_algo &&
      gcp_project_id == o.gcp_project_id &&
      gcp_sa_email == o.gcp_sa_email &&
      gcp_token_scopes == o.gcp_token_scopes &&
      input_rule == o.input_rule &&
      item_custom_fields == o.item_custom_fields &&
      json == o.json &&
      name == o.name &&
      output_rule == o.output_rule &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      role_binding == o.role_binding &&
      role_names == o.role_names &&
      secure_access_delay == o.secure_access_delay &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_url == o.secure_access_url &&
      secure_access_web_browsing == o.secure_access_web_browsing &&
      secure_access_web_proxy == o.secure_access_web_proxy &&
       == o. &&
      skip_dry_run == o.skip_dry_run &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      user_ttl == o.user_ttl
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 535

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


427
428
429
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 427

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



433
434
435
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 433

def hash
  [access_type, ara_enabled, custom_username_template, delete_protection, description, fixed_user_claim_keyname, gcp_cred_type, gcp_key, gcp_key_algo, gcp_project_id, gcp_sa_email, gcp_token_scopes, input_rule, item_custom_fields, json, name, output_rule, producer_encryption_key_name, role_binding, role_names, secure_access_delay, secure_access_enable, secure_access_url, secure_access_web_browsing, secure_access_web_proxy, , skip_dry_run, tags, target_name, token, uid_token, user_ttl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



368
369
370
371
372
373
374
375
376
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 368

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



511
512
513
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 511

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



517
518
519
520
521
522
523
524
525
526
527
528
529
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 517

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



505
506
507
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 505

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



380
381
382
383
384
# File 'lib/akeyless/models/dynamic_secret_create_gcp.rb', line 380

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end