Class: Akeyless::DynamicSecretCreateLdap

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/dynamic_secret_create_ldap.rb

Overview

dynamicSecretCreateLdap is a command that creates ldap dynamic secret

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DynamicSecretCreateLdap

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 262

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DynamicSecretCreateLdap` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DynamicSecretCreateLdap`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'provider_type')
    self.provider_type = attributes[:'provider_type']
  end

  if attributes.key?(:'ara_enabled')
    self.ara_enabled = attributes[:'ara_enabled']
  end

  if attributes.key?(:'bind_dn')
    self.bind_dn = attributes[:'bind_dn']
  end

  if attributes.key?(:'bind_dn_password')
    self.bind_dn_password = attributes[:'bind_dn_password']
  end

  if attributes.key?(:'custom_username_template')
    self.custom_username_template = attributes[:'custom_username_template']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'enable_agentic_runtime_authority')
    self.enable_agentic_runtime_authority = attributes[:'enable_agentic_runtime_authority']
  end

  if attributes.key?(:'enable_ai_quorum')
    self.enable_ai_quorum = attributes[:'enable_ai_quorum']
  end

  if attributes.key?(:'external_username')
    self.external_username = attributes[:'external_username']
  else
    self.external_username = 'false'
  end

  if attributes.key?(:'fixed_user_claim_keyname')
    self.fixed_user_claim_keyname = attributes[:'fixed_user_claim_keyname']
  else
    self.fixed_user_claim_keyname = 'ext_username'
  end

  if attributes.key?(:'group_dn')
    self.group_dn = attributes[:'group_dn']
  end

  if attributes.key?(:'host_provider')
    self.host_provider = attributes[:'host_provider']
  end

  if attributes.key?(:'input_rule')
    if (value = attributes[:'input_rule']).is_a?(Array)
      self.input_rule = value
    end
  end

  if attributes.key?(:'item_custom_fields')
    if (value = attributes[:'item_custom_fields']).is_a?(Hash)
      self.item_custom_fields = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'ldap_ca_cert')
    self.ldap_ca_cert = attributes[:'ldap_ca_cert']
  end

  if attributes.key?(:'ldap_url')
    self.ldap_url = attributes[:'ldap_url']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'output_rule')
    if (value = attributes[:'output_rule']).is_a?(Array)
      self.output_rule = value
    end
  end

  if attributes.key?(:'password_length')
    self.password_length = attributes[:'password_length']
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'secure_access_bastion_issuer')
    self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer']
  end

  if attributes.key?(:'secure_access_certificate_issuer')
    self.secure_access_certificate_issuer = attributes[:'secure_access_certificate_issuer']
  end

  if attributes.key?(:'secure_access_delay')
    self.secure_access_delay = attributes[:'secure_access_delay']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_enforce_hosts_restriction')
    self.secure_access_enforce_hosts_restriction = attributes[:'secure_access_enforce_hosts_restriction']
  end

  if attributes.key?(:'secure_access_host')
    if (value = attributes[:'secure_access_host']).is_a?(Array)
      self.secure_access_host = value
    end
  end

  if attributes.key?(:'secure_access_rd_gateway_server')
    self.secure_access_rd_gateway_server = attributes[:'secure_access_rd_gateway_server']
  end

  if attributes.key?(:'secure_access_rdp_domain')
    self.secure_access_rdp_domain = attributes[:'secure_access_rdp_domain']
  end

  if attributes.key?(:'skip_dry_run')
    self.skip_dry_run = attributes[:'skip_dry_run']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target')
    if (value = attributes[:'target']).is_a?(Array)
      self.target = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'token_expiration')
    self.token_expiration = attributes[:'token_expiration']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'use_capital_letters')
    self.use_capital_letters = attributes[:'use_capital_letters']
  end

  if attributes.key?(:'use_lower_letters')
    self.use_lower_letters = attributes[:'use_lower_letters']
  end

  if attributes.key?(:'use_numbers')
    self.use_numbers = attributes[:'use_numbers']
  end

  if attributes.key?(:'use_special_characters')
    self.use_special_characters = attributes[:'use_special_characters']
  end

  if attributes.key?(:'user_attribute')
    self.user_attribute = attributes[:'user_attribute']
  end

  if attributes.key?(:'user_dn')
    self.user_dn = attributes[:'user_dn']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '60m'
  end
end

Instance Attribute Details

#ara_enabledObject

Enable or disable Agentic Runtime Authority rule enforcement for this item. Mirrors commands.AgenticRulesParams.AraEnabled.



22
23
24
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 22

def ara_enabled
  @ara_enabled
end

#bind_dnObject

Bind DN



25
26
27
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 25

def bind_dn
  @bind_dn
end

#bind_dn_passwordObject

Bind DN Password



28
29
30
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 28

def bind_dn_password
  @bind_dn_password
end

#custom_username_templateObject

Customize how temporary usernames are generated using go template



31
32
33
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 31

def custom_username_template
  @custom_username_template
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



34
35
36
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 34

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



37
38
39
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 37

def description
  @description
end

#enable_agentic_runtime_authorityObject

EnableAra is the documented spelling of AraEnabled; --ara-enabled shipped first and stays as an undocumented alias.



40
41
42
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 40

def enable_agentic_runtime_authority
  @enable_agentic_runtime_authority
end

#enable_ai_quorumObject

Turns on AI Quorum checks for this item.



43
44
45
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 43

def enable_ai_quorum
  @enable_ai_quorum
end

#external_usernameObject

Externally provided username [true/false]



46
47
48
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 46

def external_username
  @external_username
end

#fixed_user_claim_keynameObject

For externally provided users, denotes the key-name of IdP claim to extract the username from (relevant only for external-username=true)



49
50
51
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 49

def fixed_user_claim_keyname
  @fixed_user_claim_keyname
end

#group_dnObject

Group DN which the temporary user should be added



52
53
54
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 52

def group_dn
  @group_dn
end

#host_providerObject

Host provider type [explicit/target], Default Host provider is explicit, Relevant only for SRA items.



55
56
57
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 55

def host_provider
  @host_provider
end

#input_ruleObject

Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).



58
59
60
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 58

def input_rule
  @input_rule
end

#item_custom_fieldsObject

Additional custom fields to associate with the item



61
62
63
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 61

def item_custom_fields
  @item_custom_fields
end

#jsonObject

Set output format to JSON



64
65
66
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 64

def json
  @json
end

#ldap_ca_certObject

CA Certificate File Content



67
68
69
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 67

def ldap_ca_cert
  @ldap_ca_cert
end

#ldap_urlObject

LDAP Server URL



70
71
72
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 70

def ldap_url
  @ldap_url
end

#nameObject

Dynamic secret name



73
74
75
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 73

def name
  @name
end

#output_ruleObject

Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)



76
77
78
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 76

def output_rule
  @output_rule
end

#password_lengthObject

The length of the password to be generated



79
80
81
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 79

def password_length
  @password_length
end

#producer_encryption_key_nameObject

Dynamic producer encryption key



82
83
84
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 82

def producer_encryption_key_name
  @producer_encryption_key_name
end

#provider_typeObject

Returns the value of attribute provider_type.



19
20
21
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 19

def provider_type
  @provider_type
end

#secure_access_bastion_issuerObject

Deprecated. use secure-access-certificate-issuer



85
86
87
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 85

def secure_access_bastion_issuer
  @secure_access_bastion_issuer
end

#secure_access_certificate_issuerObject

Path to the SSH Certificate Issuer for your Akeyless Secure Access



88
89
90
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 88

def secure_access_certificate_issuer
  @secure_access_certificate_issuer
end

#secure_access_delayObject

The delay duration, in seconds, to wait after generating just-in-time credentials. Accepted range: 0-120 seconds



91
92
93
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 91

def secure_access_delay
  @secure_access_delay
end

#secure_access_enableObject

Enable/Disable secure remote access [true/false]



94
95
96
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 94

def secure_access_enable
  @secure_access_enable
end

#secure_access_enforce_hosts_restrictionObject

Enforce connections only to allowed SRA hosts



97
98
99
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 97

def secure_access_enforce_hosts_restriction
  @secure_access_enforce_hosts_restriction
end

#secure_access_hostObject

Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)



100
101
102
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 100

def secure_access_host
  @secure_access_host
end

#secure_access_rd_gateway_serverObject

RD Gateway server



103
104
105
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 103

def secure_access_rd_gateway_server
  @secure_access_rd_gateway_server
end

#secure_access_rdp_domainObject

Required when the Dynamic Secret is used for a domain user



106
107
108
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 106

def secure_access_rdp_domain
  @secure_access_rdp_domain
end

#skip_dry_runObject

If set, dry-run will be skipped [true/false]



109
110
111
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 109

def skip_dry_run
  @skip_dry_run
end

#tagsObject

Add tags attached to this object



112
113
114
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 112

def tags
  @tags
end

#targetObject

A list of targets to be associated with an SRA item, To specify multiple targets use argument multiple times



115
116
117
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 115

def target
  @target
end

#target_nameObject

Target name



118
119
120
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 118

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



121
122
123
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 121

def token
  @token
end

#token_expirationObject

Token expiration



124
125
126
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 124

def token_expiration
  @token_expiration
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



127
128
129
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 127

def uid_token
  @uid_token
end

#use_capital_lettersObject

Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). [true/false]



130
131
132
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 130

def use_capital_letters
  @use_capital_letters
end

#use_lower_lettersObject

Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). [true/false]



133
134
135
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 133

def use_lower_letters
  @use_lower_letters
end

#use_numbersObject

Specifies whether the generated temporary password must contain at least one numeric character (0 to 9). [true/false]



136
137
138
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 136

def use_numbers
  @use_numbers
end

#use_special_charactersObject

Returns the value of attribute use_special_characters.



138
139
140
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 138

def use_special_characters
  @use_special_characters
end

#user_attributeObject

User Attribute



141
142
143
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 141

def user_attribute
  @user_attribute
end

#user_dnObject

User DN



144
145
146
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 144

def user_dn
  @user_dn
end

#user_ttlObject

User TTL



147
148
149
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 147

def user_ttl
  @user_ttl
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 584

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



200
201
202
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 200

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 150

def self.attribute_map
  {
    :'provider_type' => :'ProviderType',
    :'ara_enabled' => :'ara-enabled',
    :'bind_dn' => :'bind-dn',
    :'bind_dn_password' => :'bind-dn-password',
    :'custom_username_template' => :'custom-username-template',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'enable_agentic_runtime_authority' => :'enable-agentic-runtime-authority',
    :'enable_ai_quorum' => :'enable-ai-quorum',
    :'external_username' => :'external-username',
    :'fixed_user_claim_keyname' => :'fixed-user-claim-keyname',
    :'group_dn' => :'group-dn',
    :'host_provider' => :'host-provider',
    :'input_rule' => :'input-rule',
    :'item_custom_fields' => :'item-custom-fields',
    :'json' => :'json',
    :'ldap_ca_cert' => :'ldap-ca-cert',
    :'ldap_url' => :'ldap-url',
    :'name' => :'name',
    :'output_rule' => :'output-rule',
    :'password_length' => :'password-length',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer',
    :'secure_access_certificate_issuer' => :'secure-access-certificate-issuer',
    :'secure_access_delay' => :'secure-access-delay',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_enforce_hosts_restriction' => :'secure-access-enforce-hosts-restriction',
    :'secure_access_host' => :'secure-access-host',
    :'secure_access_rd_gateway_server' => :'secure-access-rd-gateway-server',
    :'secure_access_rdp_domain' => :'secure-access-rdp-domain',
    :'skip_dry_run' => :'skip-dry-run',
    :'tags' => :'tags',
    :'target' => :'target',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'token_expiration' => :'token-expiration',
    :'uid_token' => :'uid-token',
    :'use_capital_letters' => :'use-capital-letters',
    :'use_lower_letters' => :'use-lower-letters',
    :'use_numbers' => :'use-numbers',
    :'use_special_characters' => :'use-special-characters',
    :'user_attribute' => :'user-attribute',
    :'user_dn' => :'user-dn',
    :'user_ttl' => :'user-ttl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 560

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



255
256
257
258
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 255

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 205

def self.openapi_types
  {
    :'provider_type' => :'String',
    :'ara_enabled' => :'Boolean',
    :'bind_dn' => :'String',
    :'bind_dn_password' => :'String',
    :'custom_username_template' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'enable_agentic_runtime_authority' => :'Boolean',
    :'enable_ai_quorum' => :'Boolean',
    :'external_username' => :'String',
    :'fixed_user_claim_keyname' => :'String',
    :'group_dn' => :'String',
    :'host_provider' => :'String',
    :'input_rule' => :'Array<String>',
    :'item_custom_fields' => :'Hash<String, String>',
    :'json' => :'Boolean',
    :'ldap_ca_cert' => :'String',
    :'ldap_url' => :'String',
    :'name' => :'String',
    :'output_rule' => :'Array<String>',
    :'password_length' => :'String',
    :'producer_encryption_key_name' => :'String',
    :'secure_access_bastion_issuer' => :'String',
    :'secure_access_certificate_issuer' => :'String',
    :'secure_access_delay' => :'Integer',
    :'secure_access_enable' => :'String',
    :'secure_access_enforce_hosts_restriction' => :'Boolean',
    :'secure_access_host' => :'Array<String>',
    :'secure_access_rd_gateway_server' => :'String',
    :'secure_access_rdp_domain' => :'String',
    :'skip_dry_run' => :'Boolean',
    :'tags' => :'Array<String>',
    :'target' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'token_expiration' => :'String',
    :'uid_token' => :'String',
    :'use_capital_letters' => :'String',
    :'use_lower_letters' => :'String',
    :'use_numbers' => :'String',
    :'use_special_characters' => :'String',
    :'user_attribute' => :'String',
    :'user_dn' => :'String',
    :'user_ttl' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 496

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      provider_type == o.provider_type &&
      ara_enabled == o.ara_enabled &&
      bind_dn == o.bind_dn &&
      bind_dn_password == o.bind_dn_password &&
      custom_username_template == o.custom_username_template &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      enable_agentic_runtime_authority == o.enable_agentic_runtime_authority &&
      enable_ai_quorum == o.enable_ai_quorum &&
      external_username == o.external_username &&
      fixed_user_claim_keyname == o.fixed_user_claim_keyname &&
      group_dn == o.group_dn &&
      host_provider == o.host_provider &&
      input_rule == o.input_rule &&
      item_custom_fields == o.item_custom_fields &&
      json == o.json &&
      ldap_ca_cert == o.ldap_ca_cert &&
      ldap_url == o.ldap_url &&
      name == o.name &&
      output_rule == o.output_rule &&
      password_length == o.password_length &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      secure_access_bastion_issuer == o.secure_access_bastion_issuer &&
      secure_access_certificate_issuer == o.secure_access_certificate_issuer &&
      secure_access_delay == o.secure_access_delay &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_enforce_hosts_restriction == o.secure_access_enforce_hosts_restriction &&
      secure_access_host == o.secure_access_host &&
      secure_access_rd_gateway_server == o.secure_access_rd_gateway_server &&
      secure_access_rdp_domain == o.secure_access_rdp_domain &&
      skip_dry_run == o.skip_dry_run &&
      tags == o.tags &&
      target == o.target &&
      target_name == o.target_name &&
      token == o.token &&
      token_expiration == o.token_expiration &&
      uid_token == o.uid_token &&
      use_capital_letters == o.use_capital_letters &&
      use_lower_letters == o.use_lower_letters &&
      use_numbers == o.use_numbers &&
      use_special_characters == o.use_special_characters &&
      user_attribute == o.user_attribute &&
      user_dn == o.user_dn &&
      user_ttl == o.user_ttl
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



655
656
657
658
659
660
661
662
663
664
665
666
667
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 655

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


547
548
549
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 547

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



553
554
555
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 553

def hash
  [provider_type, ara_enabled, bind_dn, bind_dn_password, custom_username_template, delete_protection, description, enable_agentic_runtime_authority, enable_ai_quorum, external_username, fixed_user_claim_keyname, group_dn, host_provider, input_rule, item_custom_fields, json, ldap_ca_cert, ldap_url, name, output_rule, password_length, producer_encryption_key_name, secure_access_bastion_issuer, secure_access_certificate_issuer, secure_access_delay, secure_access_enable, secure_access_enforce_hosts_restriction, secure_access_host, secure_access_rd_gateway_server, secure_access_rdp_domain, skip_dry_run, tags, target, target_name, token, token_expiration, uid_token, use_capital_letters, use_lower_letters, use_numbers, use_special_characters, user_attribute, user_dn, user_ttl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



476
477
478
479
480
481
482
483
484
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 476

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



631
632
633
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 631

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



637
638
639
640
641
642
643
644
645
646
647
648
649
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 637

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



625
626
627
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 625

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



488
489
490
491
492
# File 'lib/akeyless/models/dynamic_secret_create_ldap.rb', line 488

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end