Class: Akeyless::DynamicSecretTmpCredsUpdate
- Inherits:
-
Object
- Object
- Akeyless::DynamicSecretTmpCredsUpdate
- Defined in:
- lib/akeyless/models/dynamic_secret_tmp_creds_update.rb
Overview
dynamicSecretTmpCredsUpdate is a command that updates dynamic secret temp creds
Instance Attribute Summary collapse
-
#ara_enabled ⇒ Object
Enable or disable Agentic Runtime Authority rule enforcement for this item.
-
#host ⇒ Object
Host.
-
#input_rule ⇒ Object
Agentic input rule in name=...,rule=...
-
#json ⇒ Object
Set output format to JSON.
-
#name ⇒ Object
Dynamic secret name.
-
#new_ttl_min ⇒ Object
New TTL in Minutes.
-
#output_rule ⇒ Object
Agentic output rule in name=...,rule=...
-
#skip_dry_run ⇒ Object
If set, dry-run will be skipped.
-
#tmp_creds_id ⇒ Object
Tmp Creds ID.
-
#token ⇒ Object
Authentication token (see
/authand/configure). -
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DynamicSecretTmpCredsUpdate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DynamicSecretTmpCredsUpdate
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DynamicSecretTmpCredsUpdate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DynamicSecretTmpCredsUpdate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ara_enabled') self.ara_enabled = attributes[:'ara_enabled'] end if attributes.key?(:'host') self.host = attributes[:'host'] else self.host = nil end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'new_ttl_min') self.new_ttl_min = attributes[:'new_ttl_min'] else self.new_ttl_min = nil end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'skip_dry_run') self.skip_dry_run = attributes[:'skip_dry_run'] end if attributes.key?(:'tmp_creds_id') self.tmp_creds_id = attributes[:'tmp_creds_id'] else self.tmp_creds_id = nil end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end end |
Instance Attribute Details
#ara_enabled ⇒ Object
Enable or disable Agentic Runtime Authority rule enforcement for this item. Mirrors commands.AgenticRulesParams.AraEnabled.
20 21 22 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 20 def ara_enabled @ara_enabled end |
#host ⇒ Object
Host
23 24 25 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 23 def host @host end |
#input_rule ⇒ Object
Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).
26 27 28 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 26 def input_rule @input_rule end |
#json ⇒ Object
Set output format to JSON
29 30 31 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 29 def json @json end |
#name ⇒ Object
Dynamic secret name
32 33 34 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 32 def name @name end |
#new_ttl_min ⇒ Object
New TTL in Minutes
35 36 37 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 35 def new_ttl_min @new_ttl_min end |
#output_rule ⇒ Object
Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)
38 39 40 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 38 def output_rule @output_rule end |
#skip_dry_run ⇒ Object
If set, dry-run will be skipped
41 42 43 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 41 def skip_dry_run @skip_dry_run end |
#tmp_creds_id ⇒ Object
Tmp Creds ID
44 45 46 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 44 def tmp_creds_id @tmp_creds_id end |
#token ⇒ Object
Authentication token (see /auth and /configure)
47 48 49 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 47 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
50 51 52 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 50 def uid_token @uid_token end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 263 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 70 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 53 def self.attribute_map { :'ara_enabled' => :'ara-enabled', :'host' => :'host', :'input_rule' => :'input-rule', :'json' => :'json', :'name' => :'name', :'new_ttl_min' => :'new-ttl-min', :'output_rule' => :'output-rule', :'skip_dry_run' => :'skip_dry_run', :'tmp_creds_id' => :'tmp-creds-id', :'token' => :'token', :'uid_token' => :'uid-token' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 239 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 92 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 75 def self.openapi_types { :'ara_enabled' => :'Boolean', :'host' => :'String', :'input_rule' => :'Array<String>', :'json' => :'Boolean', :'name' => :'String', :'new_ttl_min' => :'Integer', :'output_rule' => :'Array<String>', :'skip_dry_run' => :'String', :'tmp_creds_id' => :'String', :'token' => :'String', :'uid_token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 208 def ==(o) return true if self.equal?(o) self.class == o.class && ara_enabled == o.ara_enabled && host == o.host && input_rule == o.input_rule && json == o.json && name == o.name && new_ttl_min == o.new_ttl_min && output_rule == o.output_rule && skip_dry_run == o.skip_dry_run && tmp_creds_id == o.tmp_creds_id && token == o.token && uid_token == o.uid_token end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 334 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
226 227 228 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 226 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
232 233 234 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 232 def hash [ara_enabled, host, input_rule, json, name, new_ttl_min, output_rule, skip_dry_run, tmp_creds_id, token, uid_token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 173 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @host.nil? invalid_properties.push('invalid value for "host", host cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @new_ttl_min.nil? invalid_properties.push('invalid value for "new_ttl_min", new_ttl_min cannot be nil.') end if @tmp_creds_id.nil? invalid_properties.push('invalid value for "tmp_creds_id", tmp_creds_id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
310 311 312 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 310 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 316 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
304 305 306 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 304 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
197 198 199 200 201 202 203 204 |
# File 'lib/akeyless/models/dynamic_secret_tmp_creds_update.rb', line 197 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @host.nil? return false if @name.nil? return false if @new_ttl_min.nil? return false if @tmp_creds_id.nil? true end |