Class: Akeyless::DynamicSecretUpdateAzure

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/dynamic_secret_update_azure.rb

Overview

dynamicSecretUpdateAzure is a command that updates azure dynamic secret

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DynamicSecretUpdateAzure

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 248

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DynamicSecretUpdateAzure` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DynamicSecretUpdateAzure`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'app_obj_id')
    self.app_obj_id = attributes[:'app_obj_id']
  end

  if attributes.key?(:'ara_enabled')
    self.ara_enabled = attributes[:'ara_enabled']
  end

  if attributes.key?(:'azure_administrative_unit')
    self.azure_administrative_unit = attributes[:'azure_administrative_unit']
  end

  if attributes.key?(:'azure_client_id')
    self.azure_client_id = attributes[:'azure_client_id']
  end

  if attributes.key?(:'azure_client_secret')
    self.azure_client_secret = attributes[:'azure_client_secret']
  end

  if attributes.key?(:'azure_tenant_id')
    self.azure_tenant_id = attributes[:'azure_tenant_id']
  end

  if attributes.key?(:'custom_username_template')
    self.custom_username_template = attributes[:'custom_username_template']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'enable_agentic_runtime_authority')
    self.enable_agentic_runtime_authority = attributes[:'enable_agentic_runtime_authority']
  end

  if attributes.key?(:'enable_ai_quorum')
    self.enable_ai_quorum = attributes[:'enable_ai_quorum']
  end

  if attributes.key?(:'fixed_user_claim_keyname')
    self.fixed_user_claim_keyname = attributes[:'fixed_user_claim_keyname']
  else
    self.fixed_user_claim_keyname = 'false'
  end

  if attributes.key?(:'fixed_user_only')
    self.fixed_user_only = attributes[:'fixed_user_only']
  else
    self.fixed_user_only = false
  end

  if attributes.key?(:'input_rule')
    if (value = attributes[:'input_rule']).is_a?(Array)
      self.input_rule = value
    end
  end

  if attributes.key?(:'item_custom_fields')
    if (value = attributes[:'item_custom_fields']).is_a?(Hash)
      self.item_custom_fields = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'output_rule')
    if (value = attributes[:'output_rule']).is_a?(Array)
      self.output_rule = value
    end
  end

  if attributes.key?(:'password_length')
    self.password_length = attributes[:'password_length']
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_url')
    self.secure_access_url = attributes[:'secure_access_url']
  end

  if attributes.key?(:'secure_access_web')
    self.secure_access_web = attributes[:'secure_access_web']
  else
    self.secure_access_web = true
  end

  if attributes.key?(:'secure_access_web_browsing')
    self.secure_access_web_browsing = attributes[:'secure_access_web_browsing']
  else
    self.secure_access_web_browsing = false
  end

  if attributes.key?(:'secure_access_web_proxy')
    self.secure_access_web_proxy = attributes[:'secure_access_web_proxy']
  else
    self.secure_access_web_proxy = false
  end

  if attributes.key?(:'skip_dry_run')
    self.skip_dry_run = attributes[:'skip_dry_run']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'use_capital_letters')
    self.use_capital_letters = attributes[:'use_capital_letters']
  end

  if attributes.key?(:'use_lower_letters')
    self.use_lower_letters = attributes[:'use_lower_letters']
  end

  if attributes.key?(:'use_numbers')
    self.use_numbers = attributes[:'use_numbers']
  end

  if attributes.key?(:'use_special_characters')
    self.use_special_characters = attributes[:'use_special_characters']
  end

  if attributes.key?(:'user_group_obj_id')
    self.user_group_obj_id = attributes[:'user_group_obj_id']
  end

  if attributes.key?(:'user_portal_access')
    self.user_portal_access = attributes[:'user_portal_access']
  else
    self.user_portal_access = false
  end

  if attributes.key?(:'user_principal_name')
    self.user_principal_name = attributes[:'user_principal_name']
  end

  if attributes.key?(:'user_programmatic_access')
    self.user_programmatic_access = attributes[:'user_programmatic_access']
  else
    self.user_programmatic_access = false
  end

  if attributes.key?(:'user_role_template_id')
    self.user_role_template_id = attributes[:'user_role_template_id']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '60m'
  end
end

Instance Attribute Details

#app_obj_id ⇒ Object

Azure App Object Id



20
21
22
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 20

def app_obj_id
  @app_obj_id
end

#ara_enabled ⇒ Object

Enable or disable Agentic Runtime Authority rule enforcement for this item. Mirrors commands.AgenticRulesParams.AraEnabled.



23
24
25
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 23

def ara_enabled
  @ara_enabled
end

#azure_administrative_unit ⇒ Object

Azure AD administrative unit (relevant only when azure-user-portal-access=true)



26
27
28
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 26

def azure_administrative_unit
  @azure_administrative_unit
end

#azure_client_id ⇒ Object

Azure Client ID



29
30
31
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 29

def azure_client_id
  @azure_client_id
end

#azure_client_secret ⇒ Object

Azure Client Secret



32
33
34
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 32

def azure_client_secret
  @azure_client_secret
end

#azure_tenant_id ⇒ Object

Azure Tenant ID



35
36
37
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 35

def azure_tenant_id
  @azure_tenant_id
end

#custom_username_template ⇒ Object

Customize how temporary usernames are generated using go template



38
39
40
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 38

def custom_username_template
  @custom_username_template
end

#delete_protection ⇒ Object

Protection from accidental deletion of this object [true/false]



41
42
43
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 41

def delete_protection
  @delete_protection
end

#description ⇒ Object

Description of the object



44
45
46
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 44

def description
  @description
end

#enable_agentic_runtime_authority ⇒ Object

EnableAra is the documented spelling of AraEnabled; --ara-enabled shipped first and stays as an undocumented alias.



47
48
49
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 47

def enable_agentic_runtime_authority
  @enable_agentic_runtime_authority
end

#enable_ai_quorum ⇒ Object

Turns on AI Quorum checks for this item.



50
51
52
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 50

def enable_ai_quorum
  @enable_ai_quorum
end

#fixed_user_claim_keyname ⇒ Object

FixedUserClaimKeyname



53
54
55
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 53

def fixed_user_claim_keyname
  @fixed_user_claim_keyname
end

#fixed_user_only ⇒ Object

Fixed user



56
57
58
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 56

def fixed_user_only
  @fixed_user_only
end

#input_rule ⇒ Object

Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).



59
60
61
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 59

def input_rule
  @input_rule
end

#item_custom_fields ⇒ Object

Additional custom fields to associate with the item



62
63
64
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 62

def item_custom_fields
  @item_custom_fields
end

#json ⇒ Object

Set output format to JSON



65
66
67
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 65

def json
  @json
end

#name ⇒ Object

Dynamic secret name



68
69
70
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 68

def name
  @name
end

#new_name ⇒ Object

Dynamic secret name



71
72
73
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 71

def new_name
  @new_name
end

#output_rule ⇒ Object

Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)



74
75
76
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 74

def output_rule
  @output_rule
end

#password_length ⇒ Object

The length of the password to be generated



77
78
79
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 77

def password_length
  @password_length
end

#producer_encryption_key_name ⇒ Object

Dynamic secret encryption key



80
81
82
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 80

def producer_encryption_key_name
  @producer_encryption_key_name
end

#secure_access_enable ⇒ Object

Enable/Disable secure remote access [true/false]



83
84
85
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 83

def secure_access_enable
  @secure_access_enable
end

#secure_access_url ⇒ Object

Destination URL to inject secrets



86
87
88
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 86

def secure_access_url
  @secure_access_url
end

#secure_access_web ⇒ Object

Enable Web Secure Remote Access



89
90
91
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 89

def secure_access_web
  @secure_access_web
end

#secure_access_web_browsing ⇒ Object

Secure browser via Akeyless's Secure Remote Access (SRA)



92
93
94
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 92

def secure_access_web_browsing
  @secure_access_web_browsing
end

#secure_access_web_proxy ⇒ Object

Web-Proxy via Akeyless's Secure Remote Access (SRA)



95
96
97
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 95

def secure_access_web_proxy
  @secure_access_web_proxy
end

#skip_dry_run ⇒ Object

If set, dry-run will be skipped [true/false]



98
99
100
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 98

def skip_dry_run
  @skip_dry_run
end

#tags ⇒ Object

Add tags attached to this object



101
102
103
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 101

def tags
  @tags
end

#target_name ⇒ Object

Target name



104
105
106
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 104

def target_name
  @target_name
end

#token ⇒ Object

Authentication token (see /auth and /configure)



107
108
109
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 107

def token
  @token
end

#uid_token ⇒ Object

The universal identity token, Required only for universal_identity authentication



110
111
112
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 110

def uid_token
  @uid_token
end

#use_capital_letters ⇒ Object

Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). [true/false]



113
114
115
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 113

def use_capital_letters
  @use_capital_letters
end

#use_lower_letters ⇒ Object

Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). [true/false]



116
117
118
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 116

def use_lower_letters
  @use_lower_letters
end

#use_numbers ⇒ Object

Specifies whether the generated temporary password must contain at least one numeric character (0 to 9). [true/false]



119
120
121
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 119

def use_numbers
  @use_numbers
end

#use_special_characters ⇒ Object

Returns the value of attribute use_special_characters.



121
122
123
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 121

def use_special_characters
  @use_special_characters
end

#user_group_obj_id ⇒ Object

User Group Object Id



124
125
126
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 124

def user_group_obj_id
  @user_group_obj_id
end

#user_portal_access ⇒ Object

Azure User portal access



127
128
129
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 127

def user_portal_access
  @user_portal_access
end

#user_principal_name ⇒ Object

User Principal Name



130
131
132
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 130

def user_principal_name
  @user_principal_name
end

#user_programmatic_access ⇒ Object

Azure User programmatic access



133
134
135
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 133

def user_programmatic_access
  @user_programmatic_access
end

#user_role_template_id ⇒ Object

User Role Template Id



136
137
138
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 136

def user_role_template_id
  @user_role_template_id
end

#user_ttl ⇒ Object

User TTL



139
140
141
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 139

def user_ttl
  @user_ttl
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 561

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



189
190
191
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 189

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 142

def self.attribute_map
  {
    :'app_obj_id' => :'app-obj-id',
    :'ara_enabled' => :'ara-enabled',
    :'azure_administrative_unit' => :'azure-administrative-unit',
    :'azure_client_id' => :'azure-client-id',
    :'azure_client_secret' => :'azure-client-secret',
    :'azure_tenant_id' => :'azure-tenant-id',
    :'custom_username_template' => :'custom-username-template',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'enable_agentic_runtime_authority' => :'enable-agentic-runtime-authority',
    :'enable_ai_quorum' => :'enable-ai-quorum',
    :'fixed_user_claim_keyname' => :'fixed-user-claim-keyname',
    :'fixed_user_only' => :'fixed-user-only',
    :'input_rule' => :'input-rule',
    :'item_custom_fields' => :'item-custom-fields',
    :'json' => :'json',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'output_rule' => :'output-rule',
    :'password_length' => :'password-length',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_url' => :'secure-access-url',
    :'secure_access_web' => :'secure-access-web',
    :'secure_access_web_browsing' => :'secure-access-web-browsing',
    :'secure_access_web_proxy' => :'secure-access-web-proxy',
    :'skip_dry_run' => :'skip-dry-run',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'use_capital_letters' => :'use-capital-letters',
    :'use_lower_letters' => :'use-lower-letters',
    :'use_numbers' => :'use-numbers',
    :'use_special_characters' => :'use-special-characters',
    :'user_group_obj_id' => :'user-group-obj-id',
    :'user_portal_access' => :'user-portal-access',
    :'user_principal_name' => :'user-principal-name',
    :'user_programmatic_access' => :'user-programmatic-access',
    :'user_role_template_id' => :'user-role-template-id',
    :'user_ttl' => :'user-ttl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 537

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



241
242
243
244
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 241

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 194

def self.openapi_types
  {
    :'app_obj_id' => :'String',
    :'ara_enabled' => :'Boolean',
    :'azure_administrative_unit' => :'String',
    :'azure_client_id' => :'String',
    :'azure_client_secret' => :'String',
    :'azure_tenant_id' => :'String',
    :'custom_username_template' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'enable_agentic_runtime_authority' => :'Boolean',
    :'enable_ai_quorum' => :'Boolean',
    :'fixed_user_claim_keyname' => :'String',
    :'fixed_user_only' => :'Boolean',
    :'input_rule' => :'Array<String>',
    :'item_custom_fields' => :'Hash<String, String>',
    :'json' => :'Boolean',
    :'name' => :'String',
    :'new_name' => :'String',
    :'output_rule' => :'Array<String>',
    :'password_length' => :'String',
    :'producer_encryption_key_name' => :'String',
    :'secure_access_enable' => :'String',
    :'secure_access_url' => :'String',
    :'secure_access_web' => :'Boolean',
    :'secure_access_web_browsing' => :'Boolean',
    :'secure_access_web_proxy' => :'Boolean',
    :'skip_dry_run' => :'Boolean',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'use_capital_letters' => :'String',
    :'use_lower_letters' => :'String',
    :'use_numbers' => :'String',
    :'use_special_characters' => :'String',
    :'user_group_obj_id' => :'String',
    :'user_portal_access' => :'Boolean',
    :'user_principal_name' => :'String',
    :'user_programmatic_access' => :'Boolean',
    :'user_role_template_id' => :'String',
    :'user_ttl' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 476

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      app_obj_id == o.app_obj_id &&
      ara_enabled == o.ara_enabled &&
      azure_administrative_unit == o.azure_administrative_unit &&
      azure_client_id == o.azure_client_id &&
      azure_client_secret == o.azure_client_secret &&
      azure_tenant_id == o.azure_tenant_id &&
      custom_username_template == o.custom_username_template &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      enable_agentic_runtime_authority == o.enable_agentic_runtime_authority &&
      enable_ai_quorum == o.enable_ai_quorum &&
      fixed_user_claim_keyname == o.fixed_user_claim_keyname &&
      fixed_user_only == o.fixed_user_only &&
      input_rule == o.input_rule &&
      item_custom_fields == o.item_custom_fields &&
      json == o.json &&
      name == o.name &&
      new_name == o.new_name &&
      output_rule == o.output_rule &&
      password_length == o.password_length &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_url == o.secure_access_url &&
      secure_access_web == o.secure_access_web &&
      secure_access_web_browsing == o.secure_access_web_browsing &&
      secure_access_web_proxy == o.secure_access_web_proxy &&
      skip_dry_run == o.skip_dry_run &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      use_capital_letters == o.use_capital_letters &&
      use_lower_letters == o.use_lower_letters &&
      use_numbers == o.use_numbers &&
      use_special_characters == o.use_special_characters &&
      user_group_obj_id == o.user_group_obj_id &&
      user_portal_access == o.user_portal_access &&
      user_principal_name == o.user_principal_name &&
      user_programmatic_access == o.user_programmatic_access &&
      user_role_template_id == o.user_role_template_id &&
      user_ttl == o.user_ttl
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



632
633
634
635
636
637
638
639
640
641
642
643
644
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 632

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


524
525
526
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 524

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



530
531
532
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 530

def hash
  [app_obj_id, ara_enabled, azure_administrative_unit, azure_client_id, azure_client_secret, azure_tenant_id, custom_username_template, delete_protection, description, enable_agentic_runtime_authority, enable_ai_quorum, fixed_user_claim_keyname, fixed_user_only, input_rule, item_custom_fields, json, name, new_name, output_rule, password_length, producer_encryption_key_name, secure_access_enable, secure_access_url, secure_access_web, secure_access_web_browsing, secure_access_web_proxy, skip_dry_run, tags, target_name, token, uid_token, use_capital_letters, use_lower_letters, use_numbers, use_special_characters, user_group_obj_id, user_portal_access, user_principal_name, user_programmatic_access, user_role_template_id, user_ttl].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



456
457
458
459
460
461
462
463
464
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 456

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



608
609
610
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 608

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 614

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



602
603
604
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 602

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



468
469
470
471
472
# File 'lib/akeyless/models/dynamic_secret_update_azure.rb', line 468

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end