Class: Akeyless::DynamicSecretUpdateCustom
- Inherits:
-
Object
- Object
- Akeyless::DynamicSecretUpdateCustom
- Defined in:
- lib/akeyless/models/dynamic_secret_update_custom.rb
Instance Attribute Summary collapse
-
#admin_rotation_interval_days ⇒ Object
Define rotation interval in days.
-
#ara_enabled ⇒ Object
Enable or disable Agentic Runtime Authority rule enforcement for this item.
-
#create_sync_url ⇒ Object
URL of an endpoint that implements /sync/create method, for example https://webhook.example.com/sync/create.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#description ⇒ Object
Description of the object.
-
#enable_admin_rotation ⇒ Object
Should admin credentials be rotated.
-
#enable_agentic_runtime_authority ⇒ Object
EnableAra is the documented spelling of AraEnabled; --ara-enabled shipped first and stays as an undocumented alias.
-
#enable_ai_quorum ⇒ Object
Turns on AI Quorum checks for this item.
-
#input_rule ⇒ Object
Agentic input rule in name=...,rule=...
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#name ⇒ Object
Dynamic secret name.
-
#new_name ⇒ Object
Dynamic secret name.
-
#output_rule ⇒ Object
Agentic output rule in name=...,rule=...
-
#payload ⇒ Object
Secret payload to be sent with each create/revoke webhook request.
-
#producer_encryption_key_name ⇒ Object
Dynamic producer encryption key.
-
#revoke_sync_url ⇒ Object
URL of an endpoint that implements /sync/revoke method, for example https://webhook.example.com/sync/revoke.
-
#rotate_sync_url ⇒ Object
URL of an endpoint that implements /sync/rotate method, for example https://webhook.example.com/sync/rotate.
-
#skip_dry_run ⇒ Object
If set, dry-run will be skipped [true/false].
-
#tags ⇒ Object
Add tags attached to this object.
-
#timeout_sec ⇒ Object
Maximum allowed time in seconds for the webhook to return the results.
-
#token ⇒ Object
Authentication token (see
/authand/configure). -
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#user_ttl ⇒ Object
User TTL.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DynamicSecretUpdateCustom
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DynamicSecretUpdateCustom
Initializes the object
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 163 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DynamicSecretUpdateCustom` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DynamicSecretUpdateCustom`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'admin_rotation_interval_days') self.admin_rotation_interval_days = attributes[:'admin_rotation_interval_days'] end if attributes.key?(:'ara_enabled') self.ara_enabled = attributes[:'ara_enabled'] end if attributes.key?(:'create_sync_url') self.create_sync_url = attributes[:'create_sync_url'] else self.create_sync_url = nil end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'enable_admin_rotation') self.enable_admin_rotation = attributes[:'enable_admin_rotation'] else self.enable_admin_rotation = false end if attributes.key?(:'enable_agentic_runtime_authority') self. = attributes[:'enable_agentic_runtime_authority'] end if attributes.key?(:'enable_ai_quorum') self.enable_ai_quorum = attributes[:'enable_ai_quorum'] end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'new_name') self.new_name = attributes[:'new_name'] end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'payload') self.payload = attributes[:'payload'] end if attributes.key?(:'producer_encryption_key_name') self.producer_encryption_key_name = attributes[:'producer_encryption_key_name'] end if attributes.key?(:'revoke_sync_url') self.revoke_sync_url = attributes[:'revoke_sync_url'] else self.revoke_sync_url = nil end if attributes.key?(:'rotate_sync_url') self.rotate_sync_url = attributes[:'rotate_sync_url'] end if attributes.key?(:'skip_dry_run') self.skip_dry_run = attributes[:'skip_dry_run'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'timeout_sec') self.timeout_sec = attributes[:'timeout_sec'] else self.timeout_sec = 60 end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'user_ttl') self.user_ttl = attributes[:'user_ttl'] else self.user_ttl = '60m' end end |
Instance Attribute Details
#admin_rotation_interval_days ⇒ Object
Define rotation interval in days
19 20 21 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 19 def admin_rotation_interval_days @admin_rotation_interval_days end |
#ara_enabled ⇒ Object
Enable or disable Agentic Runtime Authority rule enforcement for this item. Mirrors commands.AgenticRulesParams.AraEnabled.
22 23 24 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 22 def ara_enabled @ara_enabled end |
#create_sync_url ⇒ Object
URL of an endpoint that implements /sync/create method, for example https://webhook.example.com/sync/create
25 26 27 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 25 def create_sync_url @create_sync_url end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
28 29 30 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 28 def delete_protection @delete_protection end |
#description ⇒ Object
Description of the object
31 32 33 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 31 def description @description end |
#enable_admin_rotation ⇒ Object
Should admin credentials be rotated
34 35 36 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 34 def enable_admin_rotation @enable_admin_rotation end |
#enable_agentic_runtime_authority ⇒ Object
EnableAra is the documented spelling of AraEnabled; --ara-enabled shipped first and stays as an undocumented alias.
37 38 39 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 37 def @enable_agentic_runtime_authority end |
#enable_ai_quorum ⇒ Object
Turns on AI Quorum checks for this item.
40 41 42 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 40 def enable_ai_quorum @enable_ai_quorum end |
#input_rule ⇒ Object
Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).
43 44 45 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 43 def input_rule @input_rule end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
46 47 48 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 46 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
49 50 51 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 49 def json @json end |
#name ⇒ Object
Dynamic secret name
52 53 54 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 52 def name @name end |
#new_name ⇒ Object
Dynamic secret name
55 56 57 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 55 def new_name @new_name end |
#output_rule ⇒ Object
Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)
58 59 60 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 58 def output_rule @output_rule end |
#payload ⇒ Object
Secret payload to be sent with each create/revoke webhook request
61 62 63 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 61 def payload @payload end |
#producer_encryption_key_name ⇒ Object
Dynamic producer encryption key
64 65 66 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 64 def producer_encryption_key_name @producer_encryption_key_name end |
#revoke_sync_url ⇒ Object
URL of an endpoint that implements /sync/revoke method, for example https://webhook.example.com/sync/revoke
67 68 69 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 67 def revoke_sync_url @revoke_sync_url end |
#rotate_sync_url ⇒ Object
URL of an endpoint that implements /sync/rotate method, for example https://webhook.example.com/sync/rotate
70 71 72 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 70 def rotate_sync_url @rotate_sync_url end |
#skip_dry_run ⇒ Object
If set, dry-run will be skipped [true/false]
73 74 75 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 73 def skip_dry_run @skip_dry_run end |
#tags ⇒ Object
Add tags attached to this object
76 77 78 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 76 def @tags end |
#timeout_sec ⇒ Object
Maximum allowed time in seconds for the webhook to return the results
79 80 81 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 79 def timeout_sec @timeout_sec end |
#token ⇒ Object
Authentication token (see /auth and /configure)
82 83 84 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 82 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
85 86 87 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 85 def uid_token @uid_token end |
#user_ttl ⇒ Object
User TTL
88 89 90 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 88 def user_ttl @user_ttl end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 395 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
121 122 123 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 121 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 91 def self.attribute_map { :'admin_rotation_interval_days' => :'admin-rotation-interval-days', :'ara_enabled' => :'ara-enabled', :'create_sync_url' => :'create-sync-url', :'delete_protection' => :'delete_protection', :'description' => :'description', :'enable_admin_rotation' => :'enable-admin-rotation', :'enable_agentic_runtime_authority' => :'enable-agentic-runtime-authority', :'enable_ai_quorum' => :'enable-ai-quorum', :'input_rule' => :'input-rule', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'name' => :'name', :'new_name' => :'new-name', :'output_rule' => :'output-rule', :'payload' => :'payload', :'producer_encryption_key_name' => :'producer-encryption-key-name', :'revoke_sync_url' => :'revoke-sync-url', :'rotate_sync_url' => :'rotate-sync-url', :'skip_dry_run' => :'skip-dry-run', :'tags' => :'tags', :'timeout_sec' => :'timeout-sec', :'token' => :'token', :'uid_token' => :'uid-token', :'user_ttl' => :'user-ttl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 371 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
156 157 158 159 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 156 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 126 def self.openapi_types { :'admin_rotation_interval_days' => :'Integer', :'ara_enabled' => :'Boolean', :'create_sync_url' => :'String', :'delete_protection' => :'String', :'description' => :'String', :'enable_admin_rotation' => :'Boolean', :'enable_agentic_runtime_authority' => :'Boolean', :'enable_ai_quorum' => :'Boolean', :'input_rule' => :'Array<String>', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'name' => :'String', :'new_name' => :'String', :'output_rule' => :'Array<String>', :'payload' => :'String', :'producer_encryption_key_name' => :'String', :'revoke_sync_url' => :'String', :'rotate_sync_url' => :'String', :'skip_dry_run' => :'Boolean', :'tags' => :'Array<String>', :'timeout_sec' => :'Integer', :'token' => :'String', :'uid_token' => :'String', :'user_ttl' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 327 def ==(o) return true if self.equal?(o) self.class == o.class && admin_rotation_interval_days == o.admin_rotation_interval_days && ara_enabled == o.ara_enabled && create_sync_url == o.create_sync_url && delete_protection == o.delete_protection && description == o.description && enable_admin_rotation == o.enable_admin_rotation && == o. && enable_ai_quorum == o.enable_ai_quorum && input_rule == o.input_rule && item_custom_fields == o.item_custom_fields && json == o.json && name == o.name && new_name == o.new_name && output_rule == o.output_rule && payload == o.payload && producer_encryption_key_name == o.producer_encryption_key_name && revoke_sync_url == o.revoke_sync_url && rotate_sync_url == o.rotate_sync_url && skip_dry_run == o.skip_dry_run && == o. && timeout_sec == o.timeout_sec && token == o.token && uid_token == o.uid_token && user_ttl == o.user_ttl end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
466 467 468 469 470 471 472 473 474 475 476 477 478 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 466 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
358 359 360 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 358 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
364 365 366 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 364 def hash [admin_rotation_interval_days, ara_enabled, create_sync_url, delete_protection, description, enable_admin_rotation, , enable_ai_quorum, input_rule, item_custom_fields, json, name, new_name, output_rule, payload, producer_encryption_key_name, revoke_sync_url, rotate_sync_url, skip_dry_run, , timeout_sec, token, uid_token, user_ttl].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 297 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @create_sync_url.nil? invalid_properties.push('invalid value for "create_sync_url", create_sync_url cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @revoke_sync_url.nil? invalid_properties.push('invalid value for "revoke_sync_url", revoke_sync_url cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
442 443 444 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 442 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 448 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
436 437 438 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 436 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
317 318 319 320 321 322 323 |
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 317 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @create_sync_url.nil? return false if @name.nil? return false if @revoke_sync_url.nil? true end |