Class: Akeyless::DynamicSecretUpdateGitlab
- Inherits:
-
Object
- Object
- Akeyless::DynamicSecretUpdateGitlab
- Defined in:
- lib/akeyless/models/dynamic_secret_update_gitlab.rb
Overview
dynamicSecretUpdateGitlab is a command that updates gitlab dynamic secret
Instance Attribute Summary collapse
-
#ara_enabled ⇒ Object
Enable or disable Agentic Runtime Authority rule enforcement for this item.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#description ⇒ Object
Description of the object.
-
#enable_agentic_runtime_authority ⇒ Object
EnableAra is the documented spelling of AraEnabled; --ara-enabled shipped first and stays as an undocumented alias.
-
#enable_ai_quorum ⇒ Object
Turns on AI Quorum checks for this item.
-
#gitlab_access_token ⇒ Object
Gitlab access token.
-
#gitlab_access_type ⇒ Object
Gitlab access token type [project,group].
-
#gitlab_certificate ⇒ Object
Gitlab tls certificate (base64 encoded).
-
#gitlab_role ⇒ Object
Gitlab role.
-
#gitlab_token_scopes ⇒ Object
Comma-separated list of access token scopes to grant.
-
#gitlab_url ⇒ Object
Gitlab base url.
-
#group_name ⇒ Object
Gitlab group name, required for access-type=group.
-
#input_rule ⇒ Object
Agentic input rule in name=...,rule=...
-
#installation_organization ⇒ Object
Gitlab project name, required for access-type=project.
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#name ⇒ Object
Dynamic secret name.
-
#new_name ⇒ Object
Dynamic secret name.
-
#output_rule ⇒ Object
Agentic output rule in name=...,rule=...
-
#skip_dry_run ⇒ Object
If set, dry-run will be skipped [true/false].
-
#tags ⇒ Object
Add tags attached to this object.
-
#target_name ⇒ Object
Target name.
-
#token ⇒ Object
Authentication token (see
/authand/configure). -
#ttl ⇒ Object
Access Token TTL.
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DynamicSecretUpdateGitlab
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DynamicSecretUpdateGitlab
Initializes the object
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 169 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DynamicSecretUpdateGitlab` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DynamicSecretUpdateGitlab`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ara_enabled') self.ara_enabled = attributes[:'ara_enabled'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'enable_agentic_runtime_authority') self. = attributes[:'enable_agentic_runtime_authority'] end if attributes.key?(:'enable_ai_quorum') self.enable_ai_quorum = attributes[:'enable_ai_quorum'] end if attributes.key?(:'gitlab_access_token') self.gitlab_access_token = attributes[:'gitlab_access_token'] end if attributes.key?(:'gitlab_access_type') self.gitlab_access_type = attributes[:'gitlab_access_type'] else self.gitlab_access_type = nil end if attributes.key?(:'gitlab_certificate') self.gitlab_certificate = attributes[:'gitlab_certificate'] end if attributes.key?(:'gitlab_role') self.gitlab_role = attributes[:'gitlab_role'] end if attributes.key?(:'gitlab_token_scopes') self.gitlab_token_scopes = attributes[:'gitlab_token_scopes'] else self.gitlab_token_scopes = nil end if attributes.key?(:'gitlab_url') self.gitlab_url = attributes[:'gitlab_url'] else self.gitlab_url = 'https://gitlab.com/' end if attributes.key?(:'group_name') self.group_name = attributes[:'group_name'] end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'installation_organization') self.installation_organization = attributes[:'installation_organization'] end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'new_name') self.new_name = attributes[:'new_name'] end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'skip_dry_run') self.skip_dry_run = attributes[:'skip_dry_run'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'target_name') self.target_name = attributes[:'target_name'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'ttl') self.ttl = attributes[:'ttl'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end end |
Instance Attribute Details
#ara_enabled ⇒ Object
Enable or disable Agentic Runtime Authority rule enforcement for this item. Mirrors commands.AgenticRulesParams.AraEnabled.
20 21 22 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 20 def ara_enabled @ara_enabled end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
23 24 25 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 23 def delete_protection @delete_protection end |
#description ⇒ Object
Description of the object
26 27 28 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 26 def description @description end |
#enable_agentic_runtime_authority ⇒ Object
EnableAra is the documented spelling of AraEnabled; --ara-enabled shipped first and stays as an undocumented alias.
29 30 31 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 29 def @enable_agentic_runtime_authority end |
#enable_ai_quorum ⇒ Object
Turns on AI Quorum checks for this item.
32 33 34 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 32 def enable_ai_quorum @enable_ai_quorum end |
#gitlab_access_token ⇒ Object
Gitlab access token
35 36 37 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 35 def gitlab_access_token @gitlab_access_token end |
#gitlab_access_type ⇒ Object
Gitlab access token type [project,group]
38 39 40 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 38 def gitlab_access_type @gitlab_access_type end |
#gitlab_certificate ⇒ Object
Gitlab tls certificate (base64 encoded)
41 42 43 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 41 def gitlab_certificate @gitlab_certificate end |
#gitlab_role ⇒ Object
Gitlab role
44 45 46 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 44 def gitlab_role @gitlab_role end |
#gitlab_token_scopes ⇒ Object
Comma-separated list of access token scopes to grant
47 48 49 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 47 def gitlab_token_scopes @gitlab_token_scopes end |
#gitlab_url ⇒ Object
Gitlab base url
50 51 52 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 50 def gitlab_url @gitlab_url end |
#group_name ⇒ Object
Gitlab group name, required for access-type=group
53 54 55 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 53 def group_name @group_name end |
#input_rule ⇒ Object
Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).
56 57 58 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 56 def input_rule @input_rule end |
#installation_organization ⇒ Object
Gitlab project name, required for access-type=project
59 60 61 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 59 def installation_organization @installation_organization end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
62 63 64 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 62 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
65 66 67 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 65 def json @json end |
#name ⇒ Object
Dynamic secret name
68 69 70 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 68 def name @name end |
#new_name ⇒ Object
Dynamic secret name
71 72 73 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 71 def new_name @new_name end |
#output_rule ⇒ Object
Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)
74 75 76 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 74 def output_rule @output_rule end |
#skip_dry_run ⇒ Object
If set, dry-run will be skipped [true/false]
77 78 79 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 77 def skip_dry_run @skip_dry_run end |
#tags ⇒ Object
Add tags attached to this object
80 81 82 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 80 def @tags end |
#target_name ⇒ Object
Target name
83 84 85 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 83 def target_name @target_name end |
#token ⇒ Object
Authentication token (see /auth and /configure)
86 87 88 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 86 def token @token end |
#ttl ⇒ Object
Access Token TTL
89 90 91 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 89 def ttl @ttl end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
92 93 94 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 92 def uid_token @uid_token end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 402 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
126 127 128 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 126 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 95 def self.attribute_map { :'ara_enabled' => :'ara-enabled', :'delete_protection' => :'delete_protection', :'description' => :'description', :'enable_agentic_runtime_authority' => :'enable-agentic-runtime-authority', :'enable_ai_quorum' => :'enable-ai-quorum', :'gitlab_access_token' => :'gitlab-access-token', :'gitlab_access_type' => :'gitlab-access-type', :'gitlab_certificate' => :'gitlab-certificate', :'gitlab_role' => :'gitlab-role', :'gitlab_token_scopes' => :'gitlab-token-scopes', :'gitlab_url' => :'gitlab-url', :'group_name' => :'group-name', :'input_rule' => :'input-rule', :'installation_organization' => :'installation-organization', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'name' => :'name', :'new_name' => :'new-name', :'output_rule' => :'output-rule', :'skip_dry_run' => :'skip-dry-run', :'tags' => :'tags', :'target_name' => :'target-name', :'token' => :'token', :'ttl' => :'ttl', :'uid_token' => :'uid-token' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 378 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
162 163 164 165 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 162 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 131 def self.openapi_types { :'ara_enabled' => :'Boolean', :'delete_protection' => :'String', :'description' => :'String', :'enable_agentic_runtime_authority' => :'Boolean', :'enable_ai_quorum' => :'Boolean', :'gitlab_access_token' => :'String', :'gitlab_access_type' => :'String', :'gitlab_certificate' => :'String', :'gitlab_role' => :'String', :'gitlab_token_scopes' => :'String', :'gitlab_url' => :'String', :'group_name' => :'String', :'input_rule' => :'Array<String>', :'installation_organization' => :'String', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'name' => :'String', :'new_name' => :'String', :'output_rule' => :'Array<String>', :'skip_dry_run' => :'Boolean', :'tags' => :'Array<String>', :'target_name' => :'String', :'token' => :'String', :'ttl' => :'String', :'uid_token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 333 def ==(o) return true if self.equal?(o) self.class == o.class && ara_enabled == o.ara_enabled && delete_protection == o.delete_protection && description == o.description && == o. && enable_ai_quorum == o.enable_ai_quorum && gitlab_access_token == o.gitlab_access_token && gitlab_access_type == o.gitlab_access_type && gitlab_certificate == o.gitlab_certificate && gitlab_role == o.gitlab_role && gitlab_token_scopes == o.gitlab_token_scopes && gitlab_url == o.gitlab_url && group_name == o.group_name && input_rule == o.input_rule && installation_organization == o.installation_organization && item_custom_fields == o.item_custom_fields && json == o.json && name == o.name && new_name == o.new_name && output_rule == o.output_rule && skip_dry_run == o.skip_dry_run && == o. && target_name == o.target_name && token == o.token && ttl == o.ttl && uid_token == o.uid_token end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
473 474 475 476 477 478 479 480 481 482 483 484 485 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 473 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
365 366 367 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 365 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
371 372 373 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 371 def hash [ara_enabled, delete_protection, description, , enable_ai_quorum, gitlab_access_token, gitlab_access_type, gitlab_certificate, gitlab_role, gitlab_token_scopes, gitlab_url, group_name, input_rule, installation_organization, item_custom_fields, json, name, new_name, output_rule, skip_dry_run, , target_name, token, ttl, uid_token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 303 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @gitlab_access_type.nil? invalid_properties.push('invalid value for "gitlab_access_type", gitlab_access_type cannot be nil.') end if @gitlab_token_scopes.nil? invalid_properties.push('invalid value for "gitlab_token_scopes", gitlab_token_scopes cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
449 450 451 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 449 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 455 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
443 444 445 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 443 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
323 324 325 326 327 328 329 |
# File 'lib/akeyless/models/dynamic_secret_update_gitlab.rb', line 323 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @gitlab_access_type.nil? return false if @gitlab_token_scopes.nil? return false if @name.nil? true end |