Class: Akeyless::DynamicSecretUpdateGoogleWorkspace

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/dynamic_secret_update_google_workspace.rb

Overview

dynamicSecretUpdateGoogleWorkspace is a command that updates a Google Workspace dynamic secret

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DynamicSecretUpdateGoogleWorkspace

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 191

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DynamicSecretUpdateGoogleWorkspace` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DynamicSecretUpdateGoogleWorkspace`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_mode')
    self.access_mode = attributes[:'access_mode']
  else
    self.access_mode = nil
  end

  if attributes.key?(:'admin_email')
    self.admin_email = attributes[:'admin_email']
  else
    self.admin_email = nil
  end

  if attributes.key?(:'ara_enabled')
    self.ara_enabled = attributes[:'ara_enabled']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'fixed_user_claim_keyname')
    self.fixed_user_claim_keyname = attributes[:'fixed_user_claim_keyname']
  else
    self.fixed_user_claim_keyname = 'ext_email'
  end

  if attributes.key?(:'gcp_key')
    self.gcp_key = attributes[:'gcp_key']
  end

  if attributes.key?(:'group_email')
    self.group_email = attributes[:'group_email']
  end

  if attributes.key?(:'group_role')
    self.group_role = attributes[:'group_role']
  end

  if attributes.key?(:'input_rule')
    if (value = attributes[:'input_rule']).is_a?(Array)
      self.input_rule = value
    end
  end

  if attributes.key?(:'item_custom_fields')
    if (value = attributes[:'item_custom_fields']).is_a?(Hash)
      self.item_custom_fields = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'output_rule')
    if (value = attributes[:'output_rule']).is_a?(Array)
      self.output_rule = value
    end
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'role_name')
    self.role_name = attributes[:'role_name']
  end

  if attributes.key?(:'role_scope')
    self.role_scope = attributes[:'role_scope']
  end

  if attributes.key?(:'secure_access_delay')
    self.secure_access_delay = attributes[:'secure_access_delay']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_url')
    self.secure_access_url = attributes[:'secure_access_url']
  end

  if attributes.key?(:'secure_access_web')
    self.secure_access_web = attributes[:'secure_access_web']
  else
    self.secure_access_web = true
  end

  if attributes.key?(:'secure_access_web_browsing')
    self.secure_access_web_browsing = attributes[:'secure_access_web_browsing']
  else
    self.secure_access_web_browsing = false
  end

  if attributes.key?(:'secure_access_web_proxy')
    self.secure_access_web_proxy = attributes[:'secure_access_web_proxy']
  else
    self.secure_access_web_proxy = false
  end

  if attributes.key?(:'skip_dry_run')
    self.skip_dry_run = attributes[:'skip_dry_run']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '60m'
  end
end

Instance Attribute Details

#access_modeObject

Returns the value of attribute access_mode.



19
20
21
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 19

def access_mode
  @access_mode
end

#admin_emailObject

Admin user email



22
23
24
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 22

def admin_email
  @admin_email
end

#ara_enabledObject

Enable or disable Agentic Runtime Authority rule enforcement for this item. Mirrors commands.AgenticRulesParams.AraEnabled.



25
26
27
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 25

def ara_enabled
  @ara_enabled
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



28
29
30
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 28

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



31
32
33
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 31

def description
  @description
end

#fixed_user_claim_keynameObject

For externally provided users, denotes the key-name of IdP claim to extract the username from



34
35
36
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 34

def fixed_user_claim_keyname
  @fixed_user_claim_keyname
end

#gcp_keyObject

Base64-encoded service account private key text



37
38
39
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 37

def gcp_key
  @gcp_key
end

#group_emailObject

A group email, relevant only for group access-mode



40
41
42
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 40

def group_email
  @group_email
end

#group_roleObject

Returns the value of attribute group_role.



42
43
44
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 42

def group_role
  @group_role
end

#input_ruleObject

Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).



45
46
47
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 45

def input_rule
  @input_rule
end

#item_custom_fieldsObject

Additional custom fields to associate with the item



48
49
50
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 48

def item_custom_fields
  @item_custom_fields
end

#jsonObject

Set output format to JSON



51
52
53
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 51

def json
  @json
end

#nameObject

Dynamic secret name



54
55
56
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 54

def name
  @name
end

#new_nameObject

Dynamic secret name



57
58
59
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 57

def new_name
  @new_name
end

#output_ruleObject

Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)



60
61
62
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 60

def output_rule
  @output_rule
end

#producer_encryption_key_nameObject

Dynamic producer encryption key



63
64
65
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 63

def producer_encryption_key_name
  @producer_encryption_key_name
end

#role_nameObject

Name of the admin role to assign to the user, relevant only for role access-mode



66
67
68
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 66

def role_name
  @role_name
end

#role_scopeObject

Returns the value of attribute role_scope.



68
69
70
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 68

def role_scope
  @role_scope
end

#secure_access_delayObject

The delay duration, in seconds, to wait after generating just-in-time credentials. Accepted range: 0-120 seconds



71
72
73
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 71

def secure_access_delay
  @secure_access_delay
end

#secure_access_enableObject

Enable/Disable secure remote access [true/false]



74
75
76
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 74

def secure_access_enable
  @secure_access_enable
end

#secure_access_urlObject

Destination URL to inject secrets



77
78
79
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 77

def secure_access_url
  @secure_access_url
end

#secure_access_webObject

Enable Web Secure Remote Access



80
81
82
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 80

def secure_access_web
  @secure_access_web
end

#secure_access_web_browsingObject

Secure browser via Akeyless's Secure Remote Access (SRA)



83
84
85
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 83

def secure_access_web_browsing
  @secure_access_web_browsing
end

#secure_access_web_proxyObject

Web-Proxy via Akeyless's Secure Remote Access (SRA)



86
87
88
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 86

def secure_access_web_proxy
  @secure_access_web_proxy
end

#skip_dry_runObject

If set, dry-run will be skipped



89
90
91
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 89

def skip_dry_run
  @skip_dry_run
end

#tagsObject

Add tags attached to this object



92
93
94
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 92

def tags
  @tags
end

#target_nameObject

Name of existing target to use in dynamic secret creation



95
96
97
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 95

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



98
99
100
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 98

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



101
102
103
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 101

def uid_token
  @uid_token
end

#user_ttlObject

User TTL



104
105
106
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 104

def user_ttl
  @user_ttl
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 457

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



143
144
145
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 143

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 107

def self.attribute_map
  {
    :'access_mode' => :'access-mode',
    :'admin_email' => :'admin-email',
    :'ara_enabled' => :'ara-enabled',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'fixed_user_claim_keyname' => :'fixed-user-claim-keyname',
    :'gcp_key' => :'gcp-key',
    :'group_email' => :'group-email',
    :'group_role' => :'group-role',
    :'input_rule' => :'input-rule',
    :'item_custom_fields' => :'item-custom-fields',
    :'json' => :'json',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'output_rule' => :'output-rule',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'role_name' => :'role-name',
    :'role_scope' => :'role-scope',
    :'secure_access_delay' => :'secure-access-delay',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_url' => :'secure-access-url',
    :'secure_access_web' => :'secure-access-web',
    :'secure_access_web_browsing' => :'secure-access-web-browsing',
    :'secure_access_web_proxy' => :'secure-access-web-proxy',
    :'skip_dry_run' => :'skip_dry_run',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'user_ttl' => :'user-ttl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 433

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



184
185
186
187
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 184

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 148

def self.openapi_types
  {
    :'access_mode' => :'String',
    :'admin_email' => :'String',
    :'ara_enabled' => :'Boolean',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'fixed_user_claim_keyname' => :'String',
    :'gcp_key' => :'String',
    :'group_email' => :'String',
    :'group_role' => :'String',
    :'input_rule' => :'Array<String>',
    :'item_custom_fields' => :'Hash<String, String>',
    :'json' => :'Boolean',
    :'name' => :'String',
    :'new_name' => :'String',
    :'output_rule' => :'Array<String>',
    :'producer_encryption_key_name' => :'String',
    :'role_name' => :'String',
    :'role_scope' => :'String',
    :'secure_access_delay' => :'Integer',
    :'secure_access_enable' => :'String',
    :'secure_access_url' => :'String',
    :'secure_access_web' => :'Boolean',
    :'secure_access_web_browsing' => :'Boolean',
    :'secure_access_web_proxy' => :'Boolean',
    :'skip_dry_run' => :'String',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'user_ttl' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 383

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_mode == o.access_mode &&
      admin_email == o.admin_email &&
      ara_enabled == o.ara_enabled &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      fixed_user_claim_keyname == o.fixed_user_claim_keyname &&
      gcp_key == o.gcp_key &&
      group_email == o.group_email &&
      group_role == o.group_role &&
      input_rule == o.input_rule &&
      item_custom_fields == o.item_custom_fields &&
      json == o.json &&
      name == o.name &&
      new_name == o.new_name &&
      output_rule == o.output_rule &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      role_name == o.role_name &&
      role_scope == o.role_scope &&
      secure_access_delay == o.secure_access_delay &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_url == o.secure_access_url &&
      secure_access_web == o.secure_access_web &&
      secure_access_web_browsing == o.secure_access_web_browsing &&
      secure_access_web_proxy == o.secure_access_web_proxy &&
      skip_dry_run == o.skip_dry_run &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      user_ttl == o.user_ttl
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



528
529
530
531
532
533
534
535
536
537
538
539
540
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 528

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


420
421
422
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 420

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



426
427
428
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 426

def hash
  [access_mode, admin_email, ara_enabled, delete_protection, description, fixed_user_claim_keyname, gcp_key, group_email, group_role, input_rule, item_custom_fields, json, name, new_name, output_rule, producer_encryption_key_name, role_name, role_scope, secure_access_delay, secure_access_enable, secure_access_url, secure_access_web, secure_access_web_browsing, secure_access_web_proxy, skip_dry_run, tags, target_name, token, uid_token, user_ttl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 353

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @access_mode.nil?
    invalid_properties.push('invalid value for "access_mode", access_mode cannot be nil.')
  end

  if @admin_email.nil?
    invalid_properties.push('invalid value for "admin_email", admin_email cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



504
505
506
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 504

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



510
511
512
513
514
515
516
517
518
519
520
521
522
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 510

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



498
499
500
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 498

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



373
374
375
376
377
378
379
# File 'lib/akeyless/models/dynamic_secret_update_google_workspace.rb', line 373

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @access_mode.nil?
  return false if @admin_email.nil?
  return false if @name.nil?
  true
end