Class: Akeyless::DynamicSecretUpdateRedis
- Inherits:
-
Object
- Object
- Akeyless::DynamicSecretUpdateRedis
- Defined in:
- lib/akeyless/models/dynamic_secret_update_redis.rb
Overview
dynamicSecretUpdateRedis is a command that updates redis dynamic secret
Instance Attribute Summary collapse
-
#acl_rules ⇒ Object
A JSON array list of redis ACL rules to attach to the created user.
-
#custom_username_template ⇒ Object
Customize how temporary usernames are generated using go template.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#description ⇒ Object
Description of the object.
-
#host ⇒ Object
Redis Host.
-
#input_rule ⇒ Object
Agentic input rule in name=…,rule=…
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#name ⇒ Object
Dynamic secret name.
-
#new_name ⇒ Object
Dynamic secret name.
-
#output_rule ⇒ Object
Agentic output rule in name=…,rule=…
-
#password ⇒ Object
Redis Password.
-
#password_length ⇒ Object
The length of the password to be generated.
-
#port ⇒ Object
Redis Port.
-
#producer_encryption_key_name ⇒ Object
Dynamic producer encryption key.
-
#ssl ⇒ Object
Enable/Disable SSL [true/false].
-
#ssl_certificate ⇒ Object
SSL CA certificate in base64 encoding generated from a trusted Certificate Authority (CA).
-
#tags ⇒ Object
Add tags attached to this object.
-
#target_name ⇒ Object
Target name.
-
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`).
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#user_ttl ⇒ Object
User TTL.
-
#username ⇒ Object
Redis Username.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DynamicSecretUpdateRedis
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DynamicSecretUpdateRedis
Initializes the object
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 159 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DynamicSecretUpdateRedis` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DynamicSecretUpdateRedis`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'acl_rules') self.acl_rules = attributes[:'acl_rules'] end if attributes.key?(:'custom_username_template') self.custom_username_template = attributes[:'custom_username_template'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'host') self.host = attributes[:'host'] else self.host = '127.0.0.1' end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'new_name') self.new_name = attributes[:'new_name'] end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'password') self.password = attributes[:'password'] end if attributes.key?(:'password_length') self.password_length = attributes[:'password_length'] end if attributes.key?(:'port') self.port = attributes[:'port'] else self.port = '6379' end if attributes.key?(:'producer_encryption_key_name') self.producer_encryption_key_name = attributes[:'producer_encryption_key_name'] end if attributes.key?(:'ssl') self.ssl = attributes[:'ssl'] else self.ssl = false end if attributes.key?(:'ssl_certificate') self.ssl_certificate = attributes[:'ssl_certificate'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'target_name') self.target_name = attributes[:'target_name'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'user_ttl') self.user_ttl = attributes[:'user_ttl'] else self.user_ttl = '60m' end if attributes.key?(:'username') self.username = attributes[:'username'] end end |
Instance Attribute Details
#acl_rules ⇒ Object
A JSON array list of redis ACL rules to attach to the created user. For available rules see the ACL CAT command redis.io/commands/acl-cat By default the user will have permissions to read all keys ‘["~*", "+@read"]’
20 21 22 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 20 def acl_rules @acl_rules end |
#custom_username_template ⇒ Object
Customize how temporary usernames are generated using go template
23 24 25 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 23 def custom_username_template @custom_username_template end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
26 27 28 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 26 def delete_protection @delete_protection end |
#description ⇒ Object
Description of the object
29 30 31 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 29 def description @description end |
#host ⇒ Object
Redis Host
32 33 34 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 32 def host @host end |
#input_rule ⇒ Object
Agentic input rule in name=…,rule=… format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).
35 36 37 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 35 def input_rule @input_rule end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
38 39 40 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 38 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
41 42 43 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 41 def json @json end |
#name ⇒ Object
Dynamic secret name
44 45 46 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 44 def name @name end |
#new_name ⇒ Object
Dynamic secret name
47 48 49 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 47 def new_name @new_name end |
#output_rule ⇒ Object
Agentic output rule in name=…,rule=… format (e.g. name=rule1,rule=Mask secrets)
50 51 52 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 50 def output_rule @output_rule end |
#password ⇒ Object
Redis Password
53 54 55 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 53 def password @password end |
#password_length ⇒ Object
The length of the password to be generated
56 57 58 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 56 def password_length @password_length end |
#port ⇒ Object
Redis Port
59 60 61 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 59 def port @port end |
#producer_encryption_key_name ⇒ Object
Dynamic producer encryption key
62 63 64 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 62 def producer_encryption_key_name @producer_encryption_key_name end |
#ssl ⇒ Object
Enable/Disable SSL [true/false]
65 66 67 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 65 def ssl @ssl end |
#ssl_certificate ⇒ Object
SSL CA certificate in base64 encoding generated from a trusted Certificate Authority (CA)
68 69 70 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 68 def ssl_certificate @ssl_certificate end |
#tags ⇒ Object
Add tags attached to this object
71 72 73 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 71 def @tags end |
#target_name ⇒ Object
Target name
74 75 76 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 74 def target_name @target_name end |
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`)
77 78 79 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 77 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
80 81 82 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 80 def uid_token @uid_token end |
#user_ttl ⇒ Object
User TTL
83 84 85 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 83 def user_ttl @user_ttl end |
#username ⇒ Object
Redis Username
86 87 88 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 86 def username @username end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 374 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
118 119 120 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 118 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 89 def self.attribute_map { :'acl_rules' => :'acl-rules', :'custom_username_template' => :'custom-username-template', :'delete_protection' => :'delete_protection', :'description' => :'description', :'host' => :'host', :'input_rule' => :'input-rule', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'name' => :'name', :'new_name' => :'new-name', :'output_rule' => :'output-rule', :'password' => :'password', :'password_length' => :'password-length', :'port' => :'port', :'producer_encryption_key_name' => :'producer-encryption-key-name', :'ssl' => :'ssl', :'ssl_certificate' => :'ssl-certificate', :'tags' => :'tags', :'target_name' => :'target-name', :'token' => :'token', :'uid_token' => :'uid-token', :'user_ttl' => :'user-ttl', :'username' => :'username' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 350 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
152 153 154 155 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 152 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 123 def self.openapi_types { :'acl_rules' => :'String', :'custom_username_template' => :'String', :'delete_protection' => :'String', :'description' => :'String', :'host' => :'String', :'input_rule' => :'Array<String>', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'name' => :'String', :'new_name' => :'String', :'output_rule' => :'Array<String>', :'password' => :'String', :'password_length' => :'String', :'port' => :'String', :'producer_encryption_key_name' => :'String', :'ssl' => :'Boolean', :'ssl_certificate' => :'String', :'tags' => :'Array<String>', :'target_name' => :'String', :'token' => :'String', :'uid_token' => :'String', :'user_ttl' => :'String', :'username' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 307 def ==(o) return true if self.equal?(o) self.class == o.class && acl_rules == o.acl_rules && custom_username_template == o.custom_username_template && delete_protection == o.delete_protection && description == o.description && host == o.host && input_rule == o.input_rule && item_custom_fields == o.item_custom_fields && json == o.json && name == o.name && new_name == o.new_name && output_rule == o.output_rule && password == o.password && password_length == o.password_length && port == o.port && producer_encryption_key_name == o.producer_encryption_key_name && ssl == o.ssl && ssl_certificate == o.ssl_certificate && == o. && target_name == o.target_name && token == o.token && uid_token == o.uid_token && user_ttl == o.user_ttl && username == o.username end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
445 446 447 448 449 450 451 452 453 454 455 456 457 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 445 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
337 338 339 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 337 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
343 344 345 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 343 def hash [acl_rules, custom_username_template, delete_protection, description, host, input_rule, item_custom_fields, json, name, new_name, output_rule, password, password_length, port, producer_encryption_key_name, ssl, ssl_certificate, , target_name, token, uid_token, user_ttl, username].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
287 288 289 290 291 292 293 294 295 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 287 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
421 422 423 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 421 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
427 428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 427 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
415 416 417 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 415 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
299 300 301 302 303 |
# File 'lib/akeyless/models/dynamic_secret_update_redis.rb', line 299 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |