Class: Akeyless::DynamicSecretUpdateRedshift

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/dynamic_secret_update_redshift.rb

Overview

dynamicSecretUpdateRedshift is a command that updates redshift dynamic secret

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DynamicSecretUpdateRedshift

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 198

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DynamicSecretUpdateRedshift` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DynamicSecretUpdateRedshift`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ara_enabled')
    self.ara_enabled = attributes[:'ara_enabled']
  end

  if attributes.key?(:'creation_statements')
    self.creation_statements = attributes[:'creation_statements']
  end

  if attributes.key?(:'custom_username_template')
    self.custom_username_template = attributes[:'custom_username_template']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'input_rule')
    if (value = attributes[:'input_rule']).is_a?(Array)
      self.input_rule = value
    end
  end

  if attributes.key?(:'item_custom_fields')
    if (value = attributes[:'item_custom_fields']).is_a?(Hash)
      self.item_custom_fields = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'output_rule')
    if (value = attributes[:'output_rule']).is_a?(Array)
      self.output_rule = value
    end
  end

  if attributes.key?(:'password_length')
    self.password_length = attributes[:'password_length']
  end

  if attributes.key?(:'producer_encryption_key')
    self.producer_encryption_key = attributes[:'producer_encryption_key']
  end

  if attributes.key?(:'redshift_db_name')
    self.redshift_db_name = attributes[:'redshift_db_name']
  end

  if attributes.key?(:'redshift_host')
    self.redshift_host = attributes[:'redshift_host']
  else
    self.redshift_host = '127.0.0.1'
  end

  if attributes.key?(:'redshift_password')
    self.redshift_password = attributes[:'redshift_password']
  end

  if attributes.key?(:'redshift_port')
    self.redshift_port = attributes[:'redshift_port']
  else
    self.redshift_port = '5439'
  end

  if attributes.key?(:'redshift_username')
    self.redshift_username = attributes[:'redshift_username']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_host')
    if (value = attributes[:'secure_access_host']).is_a?(Array)
      self.secure_access_host = value
    end
  end

  if attributes.key?(:'skip_dry_run')
    self.skip_dry_run = attributes[:'skip_dry_run']
  end

  if attributes.key?(:'ssl')
    self.ssl = attributes[:'ssl']
  else
    self.ssl = false
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'use_capital_letters')
    self.use_capital_letters = attributes[:'use_capital_letters']
  end

  if attributes.key?(:'use_lower_letters')
    self.use_lower_letters = attributes[:'use_lower_letters']
  end

  if attributes.key?(:'use_numbers')
    self.use_numbers = attributes[:'use_numbers']
  end

  if attributes.key?(:'use_special_characters')
    self.use_special_characters = attributes[:'use_special_characters']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '60m'
  end
end

Instance Attribute Details

#ara_enabledObject

Enable or disable Agentic Runtime Authority rule enforcement for this item. Mirrors commands.AgenticRulesParams.AraEnabled.



20
21
22
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 20

def ara_enabled
  @ara_enabled
end

#creation_statementsObject

Redshift Creation statements



23
24
25
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 23

def creation_statements
  @creation_statements
end

#custom_username_templateObject

Customize how temporary usernames are generated using go template



26
27
28
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 26

def custom_username_template
  @custom_username_template
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



29
30
31
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 29

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



32
33
34
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 32

def description
  @description
end

#input_ruleObject

Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).



35
36
37
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 35

def input_rule
  @input_rule
end

#item_custom_fieldsObject

Additional custom fields to associate with the item



38
39
40
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 38

def item_custom_fields
  @item_custom_fields
end

#jsonObject

Set output format to JSON



41
42
43
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 41

def json
  @json
end

#nameObject

Dynamic secret name



44
45
46
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 44

def name
  @name
end

#new_nameObject

Dynamic secret name



47
48
49
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 47

def new_name
  @new_name
end

#output_ruleObject

Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)



50
51
52
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 50

def output_rule
  @output_rule
end

#password_lengthObject

The length of the password to be generated



53
54
55
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 53

def password_length
  @password_length
end

#producer_encryption_keyObject

Dynamic producer encryption key



56
57
58
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 56

def producer_encryption_key
  @producer_encryption_key
end

#redshift_db_nameObject

Redshift DB Name



59
60
61
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 59

def redshift_db_name
  @redshift_db_name
end

#redshift_hostObject

Redshift Host



62
63
64
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 62

def redshift_host
  @redshift_host
end

#redshift_passwordObject

Redshift Password



65
66
67
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 65

def redshift_password
  @redshift_password
end

#redshift_portObject

Redshift Port



68
69
70
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 68

def redshift_port
  @redshift_port
end

#redshift_usernameObject

Redshift Username



71
72
73
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 71

def redshift_username
  @redshift_username
end

#secure_access_enableObject

Enable/Disable secure remote access [true/false]



74
75
76
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 74

def secure_access_enable
  @secure_access_enable
end

#secure_access_hostObject

Target DB servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts)



77
78
79
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 77

def secure_access_host
  @secure_access_host
end

#skip_dry_runObject

If set, dry-run will be skipped



80
81
82
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 80

def skip_dry_run
  @skip_dry_run
end

#sslObject

Enable/Disable SSL [true/false]



83
84
85
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 83

def ssl
  @ssl
end

#tagsObject

Add tags attached to this object



86
87
88
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 86

def tags
  @tags
end

#target_nameObject

Target name



89
90
91
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 89

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



92
93
94
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 92

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



95
96
97
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 95

def uid_token
  @uid_token
end

#use_capital_lettersObject

Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). [true/false]



98
99
100
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 98

def use_capital_letters
  @use_capital_letters
end

#use_lower_lettersObject

Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). [true/false]



101
102
103
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 101

def use_lower_letters
  @use_lower_letters
end

#use_numbersObject

Specifies whether the generated temporary password must contain at least one numeric character (0 to 9). [true/false]



104
105
106
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 104

def use_numbers
  @use_numbers
end

#use_special_charactersObject

Returns the value of attribute use_special_characters.



106
107
108
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 106

def use_special_characters
  @use_special_characters
end

#user_ttlObject

User TTL



109
110
111
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 109

def user_ttl
  @user_ttl
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 455

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



149
150
151
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 149

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 112

def self.attribute_map
  {
    :'ara_enabled' => :'ara-enabled',
    :'creation_statements' => :'creation-statements',
    :'custom_username_template' => :'custom-username-template',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'input_rule' => :'input-rule',
    :'item_custom_fields' => :'item-custom-fields',
    :'json' => :'json',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'output_rule' => :'output-rule',
    :'password_length' => :'password-length',
    :'producer_encryption_key' => :'producer-encryption-key',
    :'redshift_db_name' => :'redshift-db-name',
    :'redshift_host' => :'redshift-host',
    :'redshift_password' => :'redshift-password',
    :'redshift_port' => :'redshift-port',
    :'redshift_username' => :'redshift-username',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_host' => :'secure-access-host',
    :'skip_dry_run' => :'skip_dry_run',
    :'ssl' => :'ssl',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'use_capital_letters' => :'use-capital-letters',
    :'use_lower_letters' => :'use-lower-letters',
    :'use_numbers' => :'use-numbers',
    :'use_special_characters' => :'use-special-characters',
    :'user_ttl' => :'user-ttl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 431

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



191
192
193
194
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 191

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 154

def self.openapi_types
  {
    :'ara_enabled' => :'Boolean',
    :'creation_statements' => :'String',
    :'custom_username_template' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'input_rule' => :'Array<String>',
    :'item_custom_fields' => :'Hash<String, String>',
    :'json' => :'Boolean',
    :'name' => :'String',
    :'new_name' => :'String',
    :'output_rule' => :'Array<String>',
    :'password_length' => :'String',
    :'producer_encryption_key' => :'String',
    :'redshift_db_name' => :'String',
    :'redshift_host' => :'String',
    :'redshift_password' => :'String',
    :'redshift_port' => :'String',
    :'redshift_username' => :'String',
    :'secure_access_enable' => :'String',
    :'secure_access_host' => :'Array<String>',
    :'skip_dry_run' => :'String',
    :'ssl' => :'Boolean',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'use_capital_letters' => :'String',
    :'use_lower_letters' => :'String',
    :'use_numbers' => :'String',
    :'use_special_characters' => :'String',
    :'user_ttl' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 380

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ara_enabled == o.ara_enabled &&
      creation_statements == o.creation_statements &&
      custom_username_template == o.custom_username_template &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      input_rule == o.input_rule &&
      item_custom_fields == o.item_custom_fields &&
      json == o.json &&
      name == o.name &&
      new_name == o.new_name &&
      output_rule == o.output_rule &&
      password_length == o.password_length &&
      producer_encryption_key == o.producer_encryption_key &&
      redshift_db_name == o.redshift_db_name &&
      redshift_host == o.redshift_host &&
      redshift_password == o.redshift_password &&
      redshift_port == o.redshift_port &&
      redshift_username == o.redshift_username &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_host == o.secure_access_host &&
      skip_dry_run == o.skip_dry_run &&
      ssl == o.ssl &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      use_capital_letters == o.use_capital_letters &&
      use_lower_letters == o.use_lower_letters &&
      use_numbers == o.use_numbers &&
      use_special_characters == o.use_special_characters &&
      user_ttl == o.user_ttl
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



526
527
528
529
530
531
532
533
534
535
536
537
538
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 526

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


418
419
420
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 418

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



424
425
426
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 424

def hash
  [ara_enabled, creation_statements, custom_username_template, delete_protection, description, input_rule, item_custom_fields, json, name, new_name, output_rule, password_length, producer_encryption_key, redshift_db_name, redshift_host, redshift_password, redshift_port, redshift_username, secure_access_enable, secure_access_host, skip_dry_run, ssl, tags, target_name, token, uid_token, use_capital_letters, use_lower_letters, use_numbers, use_special_characters, user_ttl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



360
361
362
363
364
365
366
367
368
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 360

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



502
503
504
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 502

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



508
509
510
511
512
513
514
515
516
517
518
519
520
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 508

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



496
497
498
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 496

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



372
373
374
375
376
# File 'lib/akeyless/models/dynamic_secret_update_redshift.rb', line 372

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end