Class: Akeyless::DynamicSecretUpdateSnowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/dynamic_secret_update_snowflake.rb

Overview

GatewayUpdateProducerSnowflakeCmd is a command that updates a Snowflake dynamic secret

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DynamicSecretUpdateSnowflake

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 187

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DynamicSecretUpdateSnowflake` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DynamicSecretUpdateSnowflake`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account')
    self. = attributes[:'account']
  end

  if attributes.key?(:'account_password')
    self. = attributes[:'account_password']
  end

  if attributes.key?(:'account_username')
    self. = attributes[:'account_username']
  end

  if attributes.key?(:'auth_mode')
    self.auth_mode = attributes[:'auth_mode']
  else
    self.auth_mode = 'password'
  end

  if attributes.key?(:'custom_username_template')
    self.custom_username_template = attributes[:'custom_username_template']
  end

  if attributes.key?(:'db_name')
    self.db_name = attributes[:'db_name']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'input_rule')
    if (value = attributes[:'input_rule']).is_a?(Array)
      self.input_rule = value
    end
  end

  if attributes.key?(:'item_custom_fields')
    if (value = attributes[:'item_custom_fields']).is_a?(Hash)
      self.item_custom_fields = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'key_algo')
    self.key_algo = attributes[:'key_algo']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'output_rule')
    if (value = attributes[:'output_rule']).is_a?(Array)
      self.output_rule = value
    end
  end

  if attributes.key?(:'password_length')
    self.password_length = attributes[:'password_length']
  end

  if attributes.key?(:'private_key')
    self.private_key = attributes[:'private_key']
  end

  if attributes.key?(:'private_key_passphrase')
    self.private_key_passphrase = attributes[:'private_key_passphrase']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'use_capital_letters')
    self.use_capital_letters = attributes[:'use_capital_letters']
  end

  if attributes.key?(:'use_lower_letters')
    self.use_lower_letters = attributes[:'use_lower_letters']
  end

  if attributes.key?(:'use_numbers')
    self.use_numbers = attributes[:'use_numbers']
  end

  if attributes.key?(:'use_special_characters')
    self.use_special_characters = attributes[:'use_special_characters']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '24h'
  end

  if attributes.key?(:'warehouse')
    self.warehouse = attributes[:'warehouse']
  end
end

Instance Attribute Details

#accountObject

Account name



20
21
22
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 20

def 
  @account
end

#account_passwordObject

Database Password



23
24
25
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 23

def 
  @account_password
end

#account_usernameObject

Database Username



26
27
28
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 26

def 
  @account_username
end

#auth_modeObject

The authentication mode for the temporary user [password/key]



29
30
31
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 29

def auth_mode
  @auth_mode
end

#custom_username_templateObject

Customize how temporary usernames are generated using go template



32
33
34
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 32

def custom_username_template
  @custom_username_template
end

#db_nameObject

Database name



35
36
37
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 35

def db_name
  @db_name
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



38
39
40
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 38

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



41
42
43
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 41

def description
  @description
end

#input_ruleObject

Agentic input rule in name=…,rule=… format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).



44
45
46
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 44

def input_rule
  @input_rule
end

#item_custom_fieldsObject

Additional custom fields to associate with the item



47
48
49
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 47

def item_custom_fields
  @item_custom_fields
end

#jsonObject

Set output format to JSON



50
51
52
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 50

def json
  @json
end

#key_algoObject

Returns the value of attribute key_algo.



52
53
54
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 52

def key_algo
  @key_algo
end

#nameObject

Dynamic secret name



55
56
57
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 55

def name
  @name
end

#new_nameObject

Dynamic secret name



58
59
60
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 58

def new_name
  @new_name
end

#output_ruleObject

Agentic output rule in name=…,rule=… format (e.g. name=rule1,rule=Mask secrets)



61
62
63
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 61

def output_rule
  @output_rule
end

#password_lengthObject

The length of the password to be generated



64
65
66
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 64

def password_length
  @password_length
end

#private_keyObject

RSA Private key (base64 encoded)



67
68
69
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 67

def private_key
  @private_key
end

#private_key_passphraseObject

The Private key passphrase



70
71
72
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 70

def private_key_passphrase
  @private_key_passphrase
end

#roleObject

User role



73
74
75
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 73

def role
  @role
end

#tagsObject

Add tags attached to this object



76
77
78
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 76

def tags
  @tags
end

#target_nameObject

Target name



79
80
81
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 79

def target_name
  @target_name
end

#tokenObject

Authentication token (see ‘/auth` and `/configure`)



82
83
84
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 82

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



85
86
87
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 85

def uid_token
  @uid_token
end

#use_capital_lettersObject

Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). [true/false]



88
89
90
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 88

def use_capital_letters
  @use_capital_letters
end

#use_lower_lettersObject

Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). [true/false]



91
92
93
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 91

def use_lower_letters
  @use_lower_letters
end

#use_numbersObject

Specifies whether the generated temporary password must contain at least one numeric character (0 to 9). [true/false]



94
95
96
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 94

def use_numbers
  @use_numbers
end

#use_special_charactersObject

Returns the value of attribute use_special_characters.



96
97
98
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 96

def use_special_characters
  @use_special_characters
end

#user_ttlObject

User TTL



99
100
101
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 99

def user_ttl
  @user_ttl
end

#warehouseObject

Warehouse name



102
103
104
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 102

def warehouse
  @warehouse
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 428

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



140
141
142
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 140

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 105

def self.attribute_map
  {
    :'account' => :'account',
    :'account_password' => :'account-password',
    :'account_username' => :'account-username',
    :'auth_mode' => :'auth-mode',
    :'custom_username_template' => :'custom-username-template',
    :'db_name' => :'db-name',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'input_rule' => :'input-rule',
    :'item_custom_fields' => :'item-custom-fields',
    :'json' => :'json',
    :'key_algo' => :'key-algo',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'output_rule' => :'output-rule',
    :'password_length' => :'password-length',
    :'private_key' => :'private-key',
    :'private_key_passphrase' => :'private-key-passphrase',
    :'role' => :'role',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'use_capital_letters' => :'use-capital-letters',
    :'use_lower_letters' => :'use-lower-letters',
    :'use_numbers' => :'use-numbers',
    :'use_special_characters' => :'use-special-characters',
    :'user_ttl' => :'user-ttl',
    :'warehouse' => :'warehouse'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 404

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



180
181
182
183
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 180

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 145

def self.openapi_types
  {
    :'account' => :'String',
    :'account_password' => :'String',
    :'account_username' => :'String',
    :'auth_mode' => :'String',
    :'custom_username_template' => :'String',
    :'db_name' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'input_rule' => :'Array<String>',
    :'item_custom_fields' => :'Hash<String, String>',
    :'json' => :'Boolean',
    :'key_algo' => :'String',
    :'name' => :'String',
    :'new_name' => :'String',
    :'output_rule' => :'Array<String>',
    :'password_length' => :'String',
    :'private_key' => :'String',
    :'private_key_passphrase' => :'String',
    :'role' => :'String',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'use_capital_letters' => :'String',
    :'use_lower_letters' => :'String',
    :'use_numbers' => :'String',
    :'use_special_characters' => :'String',
    :'user_ttl' => :'String',
    :'warehouse' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 355

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
       == o. &&
       == o. &&
      auth_mode == o.auth_mode &&
      custom_username_template == o.custom_username_template &&
      db_name == o.db_name &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      input_rule == o.input_rule &&
      item_custom_fields == o.item_custom_fields &&
      json == o.json &&
      key_algo == o.key_algo &&
      name == o.name &&
      new_name == o.new_name &&
      output_rule == o.output_rule &&
      password_length == o.password_length &&
      private_key == o.private_key &&
      private_key_passphrase == o.private_key_passphrase &&
      role == o.role &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      use_capital_letters == o.use_capital_letters &&
      use_lower_letters == o.use_lower_letters &&
      use_numbers == o.use_numbers &&
      use_special_characters == o.use_special_characters &&
      user_ttl == o.user_ttl &&
      warehouse == o.warehouse
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



499
500
501
502
503
504
505
506
507
508
509
510
511
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 499

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


391
392
393
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 391

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



397
398
399
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 397

def hash
  [, , , auth_mode, custom_username_template, db_name, delete_protection, description, input_rule, item_custom_fields, json, key_algo, name, new_name, output_rule, password_length, private_key, private_key_passphrase, role, tags, target_name, token, uid_token, use_capital_letters, use_lower_letters, use_numbers, use_special_characters, user_ttl, warehouse].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



335
336
337
338
339
340
341
342
343
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 335

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



475
476
477
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 475

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 481

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



469
470
471
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 469

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



347
348
349
350
351
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 347

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end