Class: Akeyless::DynamicSecretUpdateVenafi

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/dynamic_secret_update_venafi.rb

Overview

dynamicSecretUpdateVenafi is a command that updates a Venafi dynamic secret to dynamically update certificates generated by Venafi or have Akeyless generated certificates using PKI be monitored by Venafi

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DynamicSecretUpdateVenafi

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 204

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DynamicSecretUpdateVenafi` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DynamicSecretUpdateVenafi`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'admin_rotation_interval_days')
    self.admin_rotation_interval_days = attributes[:'admin_rotation_interval_days']
  else
    self.admin_rotation_interval_days = 0
  end

  if attributes.key?(:'allow_subdomains')
    self.allow_subdomains = attributes[:'allow_subdomains']
  end

  if attributes.key?(:'allowed_domains')
    if (value = attributes[:'allowed_domains']).is_a?(Array)
      self.allowed_domains = value
    end
  end

  if attributes.key?(:'ara_enabled')
    self.ara_enabled = attributes[:'ara_enabled']
  end

  if attributes.key?(:'auto_generated_folder')
    self.auto_generated_folder = attributes[:'auto_generated_folder']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'enable_admin_rotation')
    self.enable_admin_rotation = attributes[:'enable_admin_rotation']
  else
    self.enable_admin_rotation = false
  end

  if attributes.key?(:'input_rule')
    if (value = attributes[:'input_rule']).is_a?(Array)
      self.input_rule = value
    end
  end

  if attributes.key?(:'item_custom_fields')
    if (value = attributes[:'item_custom_fields']).is_a?(Hash)
      self.item_custom_fields = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'output_rule')
    if (value = attributes[:'output_rule']).is_a?(Array)
      self.output_rule = value
    end
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'root_first_in_chain')
    self.root_first_in_chain = attributes[:'root_first_in_chain']
  end

  if attributes.key?(:'sign_using_akeyless_pki')
    self.sign_using_akeyless_pki = attributes[:'sign_using_akeyless_pki']
  end

  if attributes.key?(:'signer_key_name')
    self.signer_key_name = attributes[:'signer_key_name']
  end

  if attributes.key?(:'skip_dry_run')
    self.skip_dry_run = attributes[:'skip_dry_run']
  end

  if attributes.key?(:'store_private_key')
    self.store_private_key = attributes[:'store_private_key']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '2160h'
  end

  if attributes.key?(:'venafi_access_token')
    self.venafi_access_token = attributes[:'venafi_access_token']
  end

  if attributes.key?(:'venafi_api_key')
    self.venafi_api_key = attributes[:'venafi_api_key']
  end

  if attributes.key?(:'venafi_baseurl')
    self.venafi_baseurl = attributes[:'venafi_baseurl']
  end

  if attributes.key?(:'venafi_client_id')
    self.venafi_client_id = attributes[:'venafi_client_id']
  else
    self.venafi_client_id = 'akeyless'
  end

  if attributes.key?(:'venafi_refresh_token')
    self.venafi_refresh_token = attributes[:'venafi_refresh_token']
  end

  if attributes.key?(:'venafi_use_tpp')
    self.venafi_use_tpp = attributes[:'venafi_use_tpp']
  end

  if attributes.key?(:'venafi_zone')
    self.venafi_zone = attributes[:'venafi_zone']
  end
end

Instance Attribute Details

#admin_rotation_interval_daysObject

Admin credentials rotation interval (days)



20
21
22
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 20

def admin_rotation_interval_days
  @admin_rotation_interval_days
end

#allow_subdomainsObject

Allow subdomains



23
24
25
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 23

def allow_subdomains
  @allow_subdomains
end

#allowed_domainsObject

Allowed domains



26
27
28
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 26

def allowed_domains
  @allowed_domains
end

#ara_enabledObject

Enable or disable Agentic Runtime Authority rule enforcement for this item. Mirrors commands.AgenticRulesParams.AraEnabled.



29
30
31
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 29

def ara_enabled
  @ara_enabled
end

#auto_generated_folderObject

Auto generated folder



32
33
34
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 32

def auto_generated_folder
  @auto_generated_folder
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



35
36
37
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 35

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



38
39
40
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 38

def description
  @description
end

#enable_admin_rotationObject

Automatic admin credentials rotation



41
42
43
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 41

def enable_admin_rotation
  @enable_admin_rotation
end

#input_ruleObject

Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).



44
45
46
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 44

def input_rule
  @input_rule
end

#item_custom_fieldsObject

Additional custom fields to associate with the item



47
48
49
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 47

def item_custom_fields
  @item_custom_fields
end

#jsonObject

Set output format to JSON



50
51
52
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 50

def json
  @json
end

#nameObject

Dynamic secret name



53
54
55
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 53

def name
  @name
end

#new_nameObject

Dynamic secret name



56
57
58
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 56

def new_name
  @new_name
end

#output_ruleObject

Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)



59
60
61
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 59

def output_rule
  @output_rule
end

#producer_encryption_key_nameObject

Dynamic producer encryption key



62
63
64
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 62

def producer_encryption_key_name
  @producer_encryption_key_name
end

#root_first_in_chainObject

Root first in chain



65
66
67
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 65

def root_first_in_chain
  @root_first_in_chain
end

#sign_using_akeyless_pkiObject

Use Akeyless PKI issuer or Venafi issuer



68
69
70
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 68

def sign_using_akeyless_pki
  @sign_using_akeyless_pki
end

#signer_key_nameObject

Signer key name



71
72
73
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 71

def signer_key_name
  @signer_key_name
end

#skip_dry_runObject

If set, dry-run will be skipped



74
75
76
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 74

def skip_dry_run
  @skip_dry_run
end

#store_private_keyObject

Store private key



77
78
79
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 77

def store_private_key
  @store_private_key
end

#tagsObject

Add tags attached to this object



80
81
82
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 80

def tags
  @tags
end

#target_nameObject

Target name



83
84
85
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 83

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



86
87
88
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 86

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



89
90
91
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 89

def uid_token
  @uid_token
end

#user_ttlObject

User TTL in time.Duration format (2160h / 129600m / etc...). When using sign-using-akeyless-pki certificates created will have this validity period, otherwise the user-ttl is taken from the Validity Period field of the Zone's' Issuing Template. When using cert-manager it is advised to have a TTL of above 60 days (1440h). For more information - https://cert-manager.io/docs/usage/certificate/



92
93
94
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 92

def user_ttl
  @user_ttl
end

#venafi_access_tokenObject

Venafi Access Token to use to access the TPP environment (Relevant when using TPP)



95
96
97
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 95

def venafi_access_token
  @venafi_access_token
end

#venafi_api_keyObject

Venafi API key



98
99
100
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 98

def venafi_api_key
  @venafi_api_key
end

#venafi_baseurlObject

Venafi Baseurl



101
102
103
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 101

def venafi_baseurl
  @venafi_baseurl
end

#venafi_client_idObject

Venafi Client ID that was used when the access token was generated



104
105
106
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 104

def venafi_client_id
  @venafi_client_id
end

#venafi_refresh_tokenObject

Venafi Refresh Token to use when the Access Token is expired (Relevant when using TPP)



107
108
109
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 107

def venafi_refresh_token
  @venafi_refresh_token
end

#venafi_use_tppObject

Venafi using TPP



110
111
112
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 110

def venafi_use_tpp
  @venafi_use_tpp
end

#venafi_zoneObject

Venafi Zone



113
114
115
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 113

def venafi_zone
  @venafi_zone
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 466

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



154
155
156
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 154

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 116

def self.attribute_map
  {
    :'admin_rotation_interval_days' => :'admin-rotation-interval-days',
    :'allow_subdomains' => :'allow-subdomains',
    :'allowed_domains' => :'allowed-domains',
    :'ara_enabled' => :'ara-enabled',
    :'auto_generated_folder' => :'auto-generated-folder',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'enable_admin_rotation' => :'enable-admin-rotation',
    :'input_rule' => :'input-rule',
    :'item_custom_fields' => :'item-custom-fields',
    :'json' => :'json',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'output_rule' => :'output-rule',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'root_first_in_chain' => :'root-first-in-chain',
    :'sign_using_akeyless_pki' => :'sign-using-akeyless-pki',
    :'signer_key_name' => :'signer-key-name',
    :'skip_dry_run' => :'skip_dry_run',
    :'store_private_key' => :'store-private-key',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'user_ttl' => :'user-ttl',
    :'venafi_access_token' => :'venafi-access-token',
    :'venafi_api_key' => :'venafi-api-key',
    :'venafi_baseurl' => :'venafi-baseurl',
    :'venafi_client_id' => :'venafi-client-id',
    :'venafi_refresh_token' => :'venafi-refresh-token',
    :'venafi_use_tpp' => :'venafi-use-tpp',
    :'venafi_zone' => :'venafi-zone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 442

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



197
198
199
200
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 197

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 159

def self.openapi_types
  {
    :'admin_rotation_interval_days' => :'Integer',
    :'allow_subdomains' => :'Boolean',
    :'allowed_domains' => :'Array<String>',
    :'ara_enabled' => :'Boolean',
    :'auto_generated_folder' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'enable_admin_rotation' => :'Boolean',
    :'input_rule' => :'Array<String>',
    :'item_custom_fields' => :'Hash<String, String>',
    :'json' => :'Boolean',
    :'name' => :'String',
    :'new_name' => :'String',
    :'output_rule' => :'Array<String>',
    :'producer_encryption_key_name' => :'String',
    :'root_first_in_chain' => :'Boolean',
    :'sign_using_akeyless_pki' => :'Boolean',
    :'signer_key_name' => :'String',
    :'skip_dry_run' => :'String',
    :'store_private_key' => :'Boolean',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'user_ttl' => :'String',
    :'venafi_access_token' => :'String',
    :'venafi_api_key' => :'String',
    :'venafi_baseurl' => :'String',
    :'venafi_client_id' => :'String',
    :'venafi_refresh_token' => :'String',
    :'venafi_use_tpp' => :'Boolean',
    :'venafi_zone' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 390

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      admin_rotation_interval_days == o.admin_rotation_interval_days &&
      allow_subdomains == o.allow_subdomains &&
      allowed_domains == o.allowed_domains &&
      ara_enabled == o.ara_enabled &&
      auto_generated_folder == o.auto_generated_folder &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      enable_admin_rotation == o.enable_admin_rotation &&
      input_rule == o.input_rule &&
      item_custom_fields == o.item_custom_fields &&
      json == o.json &&
      name == o.name &&
      new_name == o.new_name &&
      output_rule == o.output_rule &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      root_first_in_chain == o.root_first_in_chain &&
      sign_using_akeyless_pki == o.sign_using_akeyless_pki &&
      signer_key_name == o.signer_key_name &&
      skip_dry_run == o.skip_dry_run &&
      store_private_key == o.store_private_key &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      user_ttl == o.user_ttl &&
      venafi_access_token == o.venafi_access_token &&
      venafi_api_key == o.venafi_api_key &&
      venafi_baseurl == o.venafi_baseurl &&
      venafi_client_id == o.venafi_client_id &&
      venafi_refresh_token == o.venafi_refresh_token &&
      venafi_use_tpp == o.venafi_use_tpp &&
      venafi_zone == o.venafi_zone
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



537
538
539
540
541
542
543
544
545
546
547
548
549
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 537

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


429
430
431
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 429

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



435
436
437
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 435

def hash
  [admin_rotation_interval_days, allow_subdomains, allowed_domains, ara_enabled, auto_generated_folder, delete_protection, description, enable_admin_rotation, input_rule, item_custom_fields, json, name, new_name, output_rule, producer_encryption_key_name, root_first_in_chain, sign_using_akeyless_pki, signer_key_name, skip_dry_run, store_private_key, tags, target_name, token, uid_token, user_ttl, venafi_access_token, venafi_api_key, venafi_baseurl, venafi_client_id, venafi_refresh_token, venafi_use_tpp, venafi_zone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



370
371
372
373
374
375
376
377
378
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 370

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



513
514
515
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 513

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



519
520
521
522
523
524
525
526
527
528
529
530
531
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 519

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



507
508
509
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 507

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



382
383
384
385
386
# File 'lib/akeyless/models/dynamic_secret_update_venafi.rb', line 382

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end