Class: Akeyless::GatewayCreateK8SAuthConfig

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/gateway_create_k8_s_auth_config.rb

Overview

gatewayCreateK8SAuth is a command that creates k8s auth config

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GatewayCreateK8SAuthConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayCreateK8SAuthConfig` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayCreateK8SAuthConfig`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_id')
    self.access_id = attributes[:'access_id']
  end

  if attributes.key?(:'cluster_api_type')
    self.cluster_api_type = attributes[:'cluster_api_type']
  else
    self.cluster_api_type = 'native_k8s'
  end

  if attributes.key?(:'config_encryption_key_name')
    self.config_encryption_key_name = attributes[:'config_encryption_key_name']
  end

  if attributes.key?(:'k8s_ca_cert')
    self.k8s_ca_cert = attributes[:'k8s_ca_cert']
  end

  if attributes.key?(:'k8s_host')
    self.k8s_host = attributes[:'k8s_host']
  end

  if attributes.key?(:'k8s_issuer')
    self.k8s_issuer = attributes[:'k8s_issuer']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'rancher_api_key')
    self.rancher_api_key = attributes[:'rancher_api_key']
  end

  if attributes.key?(:'rancher_cluster_id')
    self.rancher_cluster_id = attributes[:'rancher_cluster_id']
  end

  if attributes.key?(:'signing_key')
    self.signing_key = attributes[:'signing_key']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'token_exp')
    self.token_exp = attributes[:'token_exp']
  else
    self.token_exp = 300
  end

  if attributes.key?(:'token_reviewer_jwt')
    self.token_reviewer_jwt = attributes[:'token_reviewer_jwt']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end
end

Instance Attribute Details

#access_id ⇒ Object

The access ID of the Kubernetes auth method



20
21
22
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 20

def access_id
  @access_id
end

#cluster_api_type ⇒ Object

Cluster access type. options: [native_k8s, rancher]



23
24
25
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 23

def cluster_api_type
  @cluster_api_type
end

#config_encryption_key_name ⇒ Object

Config encryption key



26
27
28
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 26

def config_encryption_key_name
  @config_encryption_key_name
end

#k8s_ca_cert ⇒ Object

The CA Certificate (base64 encoded) to use to call into the kubernetes API server



29
30
31
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 29

def k8s_ca_cert
  @k8s_ca_cert
end

#k8s_host ⇒ Object

The URL of the kubernetes API server



32
33
34
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 32

def k8s_host
  @k8s_host
end

#k8s_issuer ⇒ Object

The Kubernetes JWT issuer name. If not set, kubernetes/serviceaccount will use as an issuer.



35
36
37
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 35

def k8s_issuer
  @k8s_issuer
end

#name ⇒ Object

K8S Auth config name



38
39
40
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 38

def name
  @name
end

#rancher_api_key ⇒ Object

The api key used to access the TokenReview API to validate other JWTs (relevant for "rancher" only)



41
42
43
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 41

def rancher_api_key
  @rancher_api_key
end

#rancher_cluster_id ⇒ Object

The cluster id as define in rancher (relevant for "rancher" only)



44
45
46
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 44

def rancher_cluster_id
  @rancher_cluster_id
end

#signing_key ⇒ Object

The private key (base64 encoded) associated with the public key defined in the Kubernetes auth



47
48
49
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 47

def signing_key
  @signing_key
end

#token ⇒ Object

Authentication token (see /auth and /configure)



50
51
52
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 50

def token
  @token
end

#token_exp ⇒ Object

Time in seconds of expiration of the Akeyless Kube Auth Method token



53
54
55
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 53

def token_exp
  @token_exp
end

#token_reviewer_jwt ⇒ Object

A Kubernetes service account JWT used to access the TokenReview API to validate other JWTs (relevant for "native_k8s" only). If not set, the JWT submitted in the authentication process will be used to access the Kubernetes TokenReview API.



56
57
58
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 56

def token_reviewer_jwt
  @token_reviewer_jwt
end

#uid_token ⇒ Object

The universal identity token, Required only for universal_identity authentication



59
60
61
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 59

def uid_token
  @uid_token
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 82

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 62

def self.attribute_map
  {
    :'access_id' => :'access-id',
    :'cluster_api_type' => :'cluster-api-type',
    :'config_encryption_key_name' => :'config-encryption-key-name',
    :'k8s_ca_cert' => :'k8s-ca-cert',
    :'k8s_host' => :'k8s-host',
    :'k8s_issuer' => :'k8s-issuer',
    :'name' => :'name',
    :'rancher_api_key' => :'rancher-api-key',
    :'rancher_cluster_id' => :'rancher-cluster-id',
    :'signing_key' => :'signing-key',
    :'token' => :'token',
    :'token_exp' => :'token-exp',
    :'token_reviewer_jwt' => :'token-reviewer-jwt',
    :'uid_token' => :'uid-token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



257
258
259
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 257

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



107
108
109
110
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 107

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 87

def self.openapi_types
  {
    :'access_id' => :'String',
    :'cluster_api_type' => :'String',
    :'config_encryption_key_name' => :'String',
    :'k8s_ca_cert' => :'String',
    :'k8s_host' => :'String',
    :'k8s_issuer' => :'String',
    :'name' => :'String',
    :'rancher_api_key' => :'String',
    :'rancher_cluster_id' => :'String',
    :'signing_key' => :'String',
    :'token' => :'String',
    :'token_exp' => :'Integer',
    :'token_reviewer_jwt' => :'String',
    :'uid_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 223

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_id == o.access_id &&
      cluster_api_type == o.cluster_api_type &&
      config_encryption_key_name == o.config_encryption_key_name &&
      k8s_ca_cert == o.k8s_ca_cert &&
      k8s_host == o.k8s_host &&
      k8s_issuer == o.k8s_issuer &&
      name == o.name &&
      rancher_api_key == o.rancher_api_key &&
      rancher_cluster_id == o.rancher_cluster_id &&
      signing_key == o.signing_key &&
      token == o.token &&
      token_exp == o.token_exp &&
      token_reviewer_jwt == o.token_reviewer_jwt &&
      uid_token == o.uid_token
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 288

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 359

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 264

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


244
245
246
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 244

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



250
251
252
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 250

def hash
  [access_id, cluster_api_type, config_encryption_key_name, k8s_ca_cert, k8s_host, k8s_issuer, name, rancher_api_key, rancher_cluster_id, signing_key, token, token_exp, token_reviewer_jwt, uid_token].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 190

def list_invalid_properties
  invalid_properties = Array.new
  if @access_id.nil?
    invalid_properties.push('invalid value for "access_id", access_id cannot be nil.')
  end

  if @k8s_host.nil?
    invalid_properties.push('invalid value for "k8s_host", k8s_host cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @signing_key.nil?
    invalid_properties.push('invalid value for "signing_key", signing_key cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



335
336
337
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 335

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 341

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



329
330
331
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 329

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



213
214
215
216
217
218
219
# File 'lib/akeyless/models/gateway_create_k8_s_auth_config.rb', line 213

def valid?
  return false if @access_id.nil?
  return false if @k8s_host.nil?
  return false if @name.nil?
  return false if @signing_key.nil?
  true
end