Class: Akeyless::GatewayCreateProducerAws

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/gateway_create_producer_aws.rb

Overview

gatewayCreateProducerAws is a command that creates aws producer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GatewayCreateProducerAws

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 161

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayCreateProducerAws` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayCreateProducerAws`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_mode')
    self.access_mode = attributes[:'access_mode']
  end

  if attributes.key?(:'admin_rotation_interval_days')
    self.admin_rotation_interval_days = attributes[:'admin_rotation_interval_days']
  else
    self.admin_rotation_interval_days = 0
  end

  if attributes.key?(:'aws_access_key_id')
    self.aws_access_key_id = attributes[:'aws_access_key_id']
  end

  if attributes.key?(:'aws_access_secret_key')
    self.aws_access_secret_key = attributes[:'aws_access_secret_key']
  end

  if attributes.key?(:'aws_role_arns')
    self.aws_role_arns = attributes[:'aws_role_arns']
  end

  if attributes.key?(:'aws_user_console_access')
    self.aws_user_console_access = attributes[:'aws_user_console_access']
  else
    self.aws_user_console_access = false
  end

  if attributes.key?(:'aws_user_groups')
    self.aws_user_groups = attributes[:'aws_user_groups']
  end

  if attributes.key?(:'aws_user_policies')
    self.aws_user_policies = attributes[:'aws_user_policies']
  end

  if attributes.key?(:'aws_user_programmatic_access')
    self.aws_user_programmatic_access = attributes[:'aws_user_programmatic_access']
  else
    self.aws_user_programmatic_access = true
  end

  if attributes.key?(:'enable_admin_rotation')
    self.enable_admin_rotation = attributes[:'enable_admin_rotation']
  else
    self.enable_admin_rotation = false
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'region')
    self.region = attributes[:'region']
  else
    self.region = 'us-east-2'
  end

  if attributes.key?(:'secure_access_aws_account_id')
    self. = attributes[:'secure_access_aws_account_id']
  end

  if attributes.key?(:'secure_access_aws_native_cli')
    self.secure_access_aws_native_cli = attributes[:'secure_access_aws_native_cli']
  end

  if attributes.key?(:'secure_access_bastion_issuer')
    self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_web')
    self.secure_access_web = attributes[:'secure_access_web']
  end

  if attributes.key?(:'secure_access_web_browsing')
    self.secure_access_web_browsing = attributes[:'secure_access_web_browsing']
  end

  if attributes.key?(:'secure_access_web_proxy')
    self.secure_access_web_proxy = attributes[:'secure_access_web_proxy']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '60m'
  end
end

Instance Attribute Details

#access_modeObject

Returns the value of attribute access_mode.



19
20
21
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 19

def access_mode
  @access_mode
end

#admin_rotation_interval_daysObject

Admin credentials rotation interval (days)



22
23
24
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 22

def admin_rotation_interval_days
  @admin_rotation_interval_days
end

#aws_access_key_idObject

Access Key ID



25
26
27
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 25

def aws_access_key_id
  @aws_access_key_id
end

#aws_access_secret_keyObject

Secret Access Key



28
29
30
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 28

def aws_access_secret_key
  @aws_access_secret_key
end

#aws_role_arnsObject

AWS Role ARNs to be used in the Assume Role operation (relevant only for assume_role mode)



31
32
33
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 31

def aws_role_arns
  @aws_role_arns
end

#aws_user_console_accessObject

AWS User console access



34
35
36
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 34

def aws_user_console_access
  @aws_user_console_access
end

#aws_user_groupsObject

AWS User groups



37
38
39
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 37

def aws_user_groups
  @aws_user_groups
end

#aws_user_policiesObject

AWS User policies



40
41
42
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 40

def aws_user_policies
  @aws_user_policies
end

#aws_user_programmatic_accessObject

AWS User programmatic access



43
44
45
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 43

def aws_user_programmatic_access
  @aws_user_programmatic_access
end

#enable_admin_rotationObject

Automatic admin credentials rotation



46
47
48
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 46

def enable_admin_rotation
  @enable_admin_rotation
end

#nameObject

Producer name



49
50
51
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 49

def name
  @name
end

#producer_encryption_key_nameObject

Dynamic producer encryption key



52
53
54
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 52

def producer_encryption_key_name
  @producer_encryption_key_name
end

#regionObject

Region



55
56
57
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 55

def region
  @region
end

#secure_access_aws_account_idObject

Returns the value of attribute secure_access_aws_account_id.



57
58
59
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 57

def 
  
end

#secure_access_aws_native_cliObject

Returns the value of attribute secure_access_aws_native_cli.



59
60
61
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 59

def secure_access_aws_native_cli
  @secure_access_aws_native_cli
end

#secure_access_bastion_issuerObject

Returns the value of attribute secure_access_bastion_issuer.



61
62
63
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 61

def secure_access_bastion_issuer
  @secure_access_bastion_issuer
end

#secure_access_enableObject

Returns the value of attribute secure_access_enable.



63
64
65
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 63

def secure_access_enable
  @secure_access_enable
end

#secure_access_webObject

Returns the value of attribute secure_access_web.



65
66
67
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 65

def secure_access_web
  @secure_access_web
end

#secure_access_web_browsingObject

Returns the value of attribute secure_access_web_browsing.



67
68
69
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 67

def secure_access_web_browsing
  @secure_access_web_browsing
end

#secure_access_web_proxyObject

Returns the value of attribute secure_access_web_proxy.



69
70
71
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 69

def secure_access_web_proxy
  @secure_access_web_proxy
end

#tagsObject

List of the tags attached to this secret



72
73
74
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 72

def tags
  @tags
end

#target_nameObject

Target name



75
76
77
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 75

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



78
79
80
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 78

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



81
82
83
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 81

def uid_token
  @uid_token
end

#user_ttlObject

User TTL



84
85
86
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 84

def user_ttl
  @user_ttl
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



118
119
120
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 118

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 87

def self.attribute_map
  {
    :'access_mode' => :'access-mode',
    :'admin_rotation_interval_days' => :'admin-rotation-interval-days',
    :'aws_access_key_id' => :'aws-access-key-id',
    :'aws_access_secret_key' => :'aws-access-secret-key',
    :'aws_role_arns' => :'aws-role-arns',
    :'aws_user_console_access' => :'aws-user-console-access',
    :'aws_user_groups' => :'aws-user-groups',
    :'aws_user_policies' => :'aws-user-policies',
    :'aws_user_programmatic_access' => :'aws-user-programmatic-access',
    :'enable_admin_rotation' => :'enable-admin-rotation',
    :'name' => :'name',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'region' => :'region',
    :'secure_access_aws_account_id' => :'secure-access-aws-account-id',
    :'secure_access_aws_native_cli' => :'secure-access-aws-native-cli',
    :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_web' => :'secure-access-web',
    :'secure_access_web_browsing' => :'secure-access-web-browsing',
    :'secure_access_web_proxy' => :'secure-access-web-proxy',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'user_ttl' => :'user-ttl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



354
355
356
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 354

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



154
155
156
157
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 154

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 123

def self.openapi_types
  {
    :'access_mode' => :'String',
    :'admin_rotation_interval_days' => :'Integer',
    :'aws_access_key_id' => :'String',
    :'aws_access_secret_key' => :'String',
    :'aws_role_arns' => :'String',
    :'aws_user_console_access' => :'Boolean',
    :'aws_user_groups' => :'String',
    :'aws_user_policies' => :'String',
    :'aws_user_programmatic_access' => :'Boolean',
    :'enable_admin_rotation' => :'Boolean',
    :'name' => :'String',
    :'producer_encryption_key_name' => :'String',
    :'region' => :'String',
    :'secure_access_aws_account_id' => :'String',
    :'secure_access_aws_native_cli' => :'Boolean',
    :'secure_access_bastion_issuer' => :'String',
    :'secure_access_enable' => :'String',
    :'secure_access_web' => :'Boolean',
    :'secure_access_web_browsing' => :'Boolean',
    :'secure_access_web_proxy' => :'Boolean',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'user_ttl' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 309

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_mode == o.access_mode &&
      admin_rotation_interval_days == o.admin_rotation_interval_days &&
      aws_access_key_id == o.aws_access_key_id &&
      aws_access_secret_key == o.aws_access_secret_key &&
      aws_role_arns == o.aws_role_arns &&
      aws_user_console_access == o.aws_user_console_access &&
      aws_user_groups == o.aws_user_groups &&
      aws_user_policies == o.aws_user_policies &&
      aws_user_programmatic_access == o.aws_user_programmatic_access &&
      enable_admin_rotation == o.enable_admin_rotation &&
      name == o.name &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      region == o.region &&
       == o. &&
      secure_access_aws_native_cli == o.secure_access_aws_native_cli &&
      secure_access_bastion_issuer == o.secure_access_bastion_issuer &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_web == o.secure_access_web &&
      secure_access_web_browsing == o.secure_access_web_browsing &&
      secure_access_web_proxy == o.secure_access_web_proxy &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      user_ttl == o.user_ttl
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • type Data type

  • value Value to be deserialized

Returns:

  • Deserialized data



385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 385

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • Any valid value

Returns:

  • Returns the value in the form of hash



456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 456

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 361

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


341
342
343
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 341

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



347
348
349
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 347

def hash
  [access_mode, admin_rotation_interval_days, aws_access_key_id, aws_access_secret_key, aws_role_arns, aws_user_console_access, aws_user_groups, aws_user_policies, aws_user_programmatic_access, enable_admin_rotation, name, producer_encryption_key_name, region, , secure_access_aws_native_cli, secure_access_bastion_issuer, secure_access_enable, secure_access_web, secure_access_web_browsing, secure_access_web_proxy, tags, target_name, token, uid_token, user_ttl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



291
292
293
294
295
296
297
298
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 291

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • Returns the object in the form of hash



432
433
434
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 432

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 438

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



426
427
428
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 426

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



302
303
304
305
# File 'lib/akeyless/models/gateway_create_producer_aws.rb', line 302

def valid?
  return false if @name.nil?
  true
end