Class: Akeyless::GatewayCreateProducerCassandra
- Inherits:
-
Object
- Object
- Akeyless::GatewayCreateProducerCassandra
- Defined in:
- lib/akeyless/models/gateway_create_producer_cassandra.rb
Overview
gatewayCreateProducerCassandra is a command that creates a Cassandra producer [Deprecated: Use dynamic-secret-create-cassandra command]
Instance Attribute Summary collapse
-
#cassandra_creation_statements ⇒ Object
Cassandra creation statements.
-
#cassandra_hosts ⇒ Object
Cassandra hosts IP or addresses, comma separated.
-
#cassandra_password ⇒ Object
Cassandra superuser password.
-
#cassandra_port ⇒ Object
Cassandra port.
-
#cassandra_username ⇒ Object
Cassandra superuser username.
-
#custom_username_template ⇒ Object
Customize how temporary usernames are generated using go template.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#input_rule ⇒ Object
Agentic input rule in name=…,rule=…
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#name ⇒ Object
Dynamic secret name.
-
#output_rule ⇒ Object
Agentic output rule in name=…,rule=…
-
#password_length ⇒ Object
The length of the password to be generated.
-
#producer_encryption_key_name ⇒ Object
Dynamic producer encryption key.
-
#ssl ⇒ Object
Enable/Disable SSL [true/false].
-
#ssl_certificate ⇒ Object
SSL CA certificate in base64 encoding generated from a trusted Certificate Authority (CA).
-
#tags ⇒ Object
Add tags attached to this object.
-
#target_name ⇒ Object
Target name.
-
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`).
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#use_capital_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z).
-
#use_lower_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z).
-
#use_numbers ⇒ Object
Specifies whether the generated temporary password must contain at least one numeric character (0 to 9).
-
#use_special_characters ⇒ Object
Returns the value of attribute use_special_characters.
-
#user_ttl ⇒ Object
User TTL.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GatewayCreateProducerCassandra
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ GatewayCreateProducerCassandra
Initializes the object
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 168 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayCreateProducerCassandra` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayCreateProducerCassandra`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'cassandra_creation_statements') self.cassandra_creation_statements = attributes[:'cassandra_creation_statements'] end if attributes.key?(:'cassandra_hosts') self.cassandra_hosts = attributes[:'cassandra_hosts'] end if attributes.key?(:'cassandra_password') self.cassandra_password = attributes[:'cassandra_password'] end if attributes.key?(:'cassandra_port') self.cassandra_port = attributes[:'cassandra_port'] else self.cassandra_port = '9042' end if attributes.key?(:'cassandra_username') self.cassandra_username = attributes[:'cassandra_username'] end if attributes.key?(:'custom_username_template') self.custom_username_template = attributes[:'custom_username_template'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'password_length') self.password_length = attributes[:'password_length'] end if attributes.key?(:'producer_encryption_key_name') self.producer_encryption_key_name = attributes[:'producer_encryption_key_name'] end if attributes.key?(:'ssl') self.ssl = attributes[:'ssl'] else self.ssl = false end if attributes.key?(:'ssl_certificate') self.ssl_certificate = attributes[:'ssl_certificate'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'target_name') self.target_name = attributes[:'target_name'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'use_capital_letters') self.use_capital_letters = attributes[:'use_capital_letters'] end if attributes.key?(:'use_lower_letters') self.use_lower_letters = attributes[:'use_lower_letters'] end if attributes.key?(:'use_numbers') self.use_numbers = attributes[:'use_numbers'] end if attributes.key?(:'use_special_characters') self.use_special_characters = attributes[:'use_special_characters'] end if attributes.key?(:'user_ttl') self.user_ttl = attributes[:'user_ttl'] else self.user_ttl = '60m' end end |
Instance Attribute Details
#cassandra_creation_statements ⇒ Object
Cassandra creation statements
20 21 22 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 20 def cassandra_creation_statements @cassandra_creation_statements end |
#cassandra_hosts ⇒ Object
Cassandra hosts IP or addresses, comma separated
23 24 25 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 23 def cassandra_hosts @cassandra_hosts end |
#cassandra_password ⇒ Object
Cassandra superuser password
26 27 28 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 26 def cassandra_password @cassandra_password end |
#cassandra_port ⇒ Object
Cassandra port
29 30 31 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 29 def cassandra_port @cassandra_port end |
#cassandra_username ⇒ Object
Cassandra superuser username
32 33 34 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 32 def cassandra_username @cassandra_username end |
#custom_username_template ⇒ Object
Customize how temporary usernames are generated using go template
35 36 37 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 35 def custom_username_template @custom_username_template end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
38 39 40 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 38 def delete_protection @delete_protection end |
#input_rule ⇒ Object
Agentic input rule in name=…,rule=… format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).
41 42 43 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 41 def input_rule @input_rule end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
44 45 46 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 44 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
47 48 49 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 47 def json @json end |
#name ⇒ Object
Dynamic secret name
50 51 52 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 50 def name @name end |
#output_rule ⇒ Object
Agentic output rule in name=…,rule=… format (e.g. name=rule1,rule=Mask secrets)
53 54 55 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 53 def output_rule @output_rule end |
#password_length ⇒ Object
The length of the password to be generated
56 57 58 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 56 def password_length @password_length end |
#producer_encryption_key_name ⇒ Object
Dynamic producer encryption key
59 60 61 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 59 def producer_encryption_key_name @producer_encryption_key_name end |
#ssl ⇒ Object
Enable/Disable SSL [true/false]
62 63 64 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 62 def ssl @ssl end |
#ssl_certificate ⇒ Object
SSL CA certificate in base64 encoding generated from a trusted Certificate Authority (CA)
65 66 67 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 65 def ssl_certificate @ssl_certificate end |
#tags ⇒ Object
Add tags attached to this object
68 69 70 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 68 def @tags end |
#target_name ⇒ Object
Target name
71 72 73 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 71 def target_name @target_name end |
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`)
74 75 76 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 74 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
77 78 79 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 77 def uid_token @uid_token end |
#use_capital_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). [true/false]
80 81 82 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 80 def use_capital_letters @use_capital_letters end |
#use_lower_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). [true/false]
83 84 85 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 83 def use_lower_letters @use_lower_letters end |
#use_numbers ⇒ Object
Specifies whether the generated temporary password must contain at least one numeric character (0 to 9). [true/false]
86 87 88 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 86 def use_numbers @use_numbers end |
#use_special_characters ⇒ Object
Returns the value of attribute use_special_characters.
88 89 90 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 88 def use_special_characters @use_special_characters end |
#user_ttl ⇒ Object
User TTL
91 92 93 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 91 def user_ttl @user_ttl end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 391 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
125 126 127 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 125 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 94 def self.attribute_map { :'cassandra_creation_statements' => :'cassandra-creation-statements', :'cassandra_hosts' => :'cassandra-hosts', :'cassandra_password' => :'cassandra-password', :'cassandra_port' => :'cassandra-port', :'cassandra_username' => :'cassandra-username', :'custom_username_template' => :'custom-username-template', :'delete_protection' => :'delete_protection', :'input_rule' => :'input-rule', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'name' => :'name', :'output_rule' => :'output-rule', :'password_length' => :'password-length', :'producer_encryption_key_name' => :'producer-encryption-key-name', :'ssl' => :'ssl', :'ssl_certificate' => :'ssl-certificate', :'tags' => :'tags', :'target_name' => :'target-name', :'token' => :'token', :'uid_token' => :'uid-token', :'use_capital_letters' => :'use-capital-letters', :'use_lower_letters' => :'use-lower-letters', :'use_numbers' => :'use-numbers', :'use_special_characters' => :'use-special-characters', :'user_ttl' => :'user-ttl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 367 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
161 162 163 164 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 161 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 130 def self.openapi_types { :'cassandra_creation_statements' => :'String', :'cassandra_hosts' => :'String', :'cassandra_password' => :'String', :'cassandra_port' => :'String', :'cassandra_username' => :'String', :'custom_username_template' => :'String', :'delete_protection' => :'String', :'input_rule' => :'Array<String>', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'name' => :'String', :'output_rule' => :'Array<String>', :'password_length' => :'String', :'producer_encryption_key_name' => :'String', :'ssl' => :'Boolean', :'ssl_certificate' => :'String', :'tags' => :'Array<String>', :'target_name' => :'String', :'token' => :'String', :'uid_token' => :'String', :'use_capital_letters' => :'String', :'use_lower_letters' => :'String', :'use_numbers' => :'String', :'use_special_characters' => :'String', :'user_ttl' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 322 def ==(o) return true if self.equal?(o) self.class == o.class && cassandra_creation_statements == o.cassandra_creation_statements && cassandra_hosts == o.cassandra_hosts && cassandra_password == o.cassandra_password && cassandra_port == o.cassandra_port && cassandra_username == o.cassandra_username && custom_username_template == o.custom_username_template && delete_protection == o.delete_protection && input_rule == o.input_rule && item_custom_fields == o.item_custom_fields && json == o.json && name == o.name && output_rule == o.output_rule && password_length == o.password_length && producer_encryption_key_name == o.producer_encryption_key_name && ssl == o.ssl && ssl_certificate == o.ssl_certificate && == o. && target_name == o.target_name && token == o.token && uid_token == o.uid_token && use_capital_letters == o.use_capital_letters && use_lower_letters == o.use_lower_letters && use_numbers == o.use_numbers && use_special_characters == o.use_special_characters && user_ttl == o.user_ttl end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
462 463 464 465 466 467 468 469 470 471 472 473 474 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 462 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
354 355 356 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 354 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
360 361 362 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 360 def hash [cassandra_creation_statements, cassandra_hosts, cassandra_password, cassandra_port, cassandra_username, custom_username_template, delete_protection, input_rule, item_custom_fields, json, name, output_rule, password_length, producer_encryption_key_name, ssl, ssl_certificate, , target_name, token, uid_token, use_capital_letters, use_lower_letters, use_numbers, use_special_characters, user_ttl].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
302 303 304 305 306 307 308 309 310 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 302 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
438 439 440 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 438 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
444 445 446 447 448 449 450 451 452 453 454 455 456 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 444 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
432 433 434 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 432 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
314 315 316 317 318 |
# File 'lib/akeyless/models/gateway_create_producer_cassandra.rb', line 314 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |