Class: Akeyless::GatewayCreateProducerCustom
- Inherits:
-
Object
- Object
- Akeyless::GatewayCreateProducerCustom
- Defined in:
- lib/akeyless/models/gateway_create_producer_custom.rb
Overview
gatewayCreateProducerCustom is a command that creates a custom producer. [Deprecated: Use dynamic-secret-create-custom command]
Instance Attribute Summary collapse
-
#admin_rotation_interval_days ⇒ Object
Define rotation interval in days.
-
#create_sync_url ⇒ Object
URL of an endpoint that implements /sync/create method, for example webhook.example.com/sync/create.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#enable_admin_rotation ⇒ Object
Should admin credentials be rotated.
-
#input_rule ⇒ Object
Agentic input rule in name=…,rule=…
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#name ⇒ Object
Dynamic secret name.
-
#output_rule ⇒ Object
Agentic output rule in name=…,rule=…
-
#payload ⇒ Object
Secret payload to be sent with each create/revoke webhook request.
-
#producer_encryption_key_name ⇒ Object
Dynamic producer encryption key.
-
#revoke_sync_url ⇒ Object
URL of an endpoint that implements /sync/revoke method, for example webhook.example.com/sync/revoke.
-
#rotate_sync_url ⇒ Object
URL of an endpoint that implements /sync/rotate method, for example webhook.example.com/sync/rotate.
-
#tags ⇒ Object
Add tags attached to this object.
-
#timeout_sec ⇒ Object
Maximum allowed time in seconds for the webhook to return the results.
-
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`).
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#user_ttl ⇒ Object
User TTL.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GatewayCreateProducerCustom
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ GatewayCreateProducerCustom
Initializes the object
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 134 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayCreateProducerCustom` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayCreateProducerCustom`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'admin_rotation_interval_days') self.admin_rotation_interval_days = attributes[:'admin_rotation_interval_days'] end if attributes.key?(:'create_sync_url') self.create_sync_url = attributes[:'create_sync_url'] else self.create_sync_url = nil end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'enable_admin_rotation') self.enable_admin_rotation = attributes[:'enable_admin_rotation'] else self.enable_admin_rotation = false end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'payload') self.payload = attributes[:'payload'] end if attributes.key?(:'producer_encryption_key_name') self.producer_encryption_key_name = attributes[:'producer_encryption_key_name'] end if attributes.key?(:'revoke_sync_url') self.revoke_sync_url = attributes[:'revoke_sync_url'] else self.revoke_sync_url = nil end if attributes.key?(:'rotate_sync_url') self.rotate_sync_url = attributes[:'rotate_sync_url'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'timeout_sec') self.timeout_sec = attributes[:'timeout_sec'] else self.timeout_sec = 60 end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'user_ttl') self.user_ttl = attributes[:'user_ttl'] else self.user_ttl = '60m' end end |
Instance Attribute Details
#admin_rotation_interval_days ⇒ Object
Define rotation interval in days
20 21 22 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 20 def admin_rotation_interval_days @admin_rotation_interval_days end |
#create_sync_url ⇒ Object
URL of an endpoint that implements /sync/create method, for example webhook.example.com/sync/create
23 24 25 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 23 def create_sync_url @create_sync_url end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
26 27 28 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 26 def delete_protection @delete_protection end |
#enable_admin_rotation ⇒ Object
Should admin credentials be rotated
29 30 31 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 29 def enable_admin_rotation @enable_admin_rotation end |
#input_rule ⇒ Object
Agentic input rule in name=…,rule=… format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).
32 33 34 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 32 def input_rule @input_rule end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
35 36 37 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 35 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
38 39 40 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 38 def json @json end |
#name ⇒ Object
Dynamic secret name
41 42 43 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 41 def name @name end |
#output_rule ⇒ Object
Agentic output rule in name=…,rule=… format (e.g. name=rule1,rule=Mask secrets)
44 45 46 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 44 def output_rule @output_rule end |
#payload ⇒ Object
Secret payload to be sent with each create/revoke webhook request
47 48 49 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 47 def payload @payload end |
#producer_encryption_key_name ⇒ Object
Dynamic producer encryption key
50 51 52 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 50 def producer_encryption_key_name @producer_encryption_key_name end |
#revoke_sync_url ⇒ Object
URL of an endpoint that implements /sync/revoke method, for example webhook.example.com/sync/revoke
53 54 55 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 53 def revoke_sync_url @revoke_sync_url end |
#rotate_sync_url ⇒ Object
URL of an endpoint that implements /sync/rotate method, for example webhook.example.com/sync/rotate
56 57 58 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 56 def rotate_sync_url @rotate_sync_url end |
#tags ⇒ Object
Add tags attached to this object
59 60 61 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 59 def @tags end |
#timeout_sec ⇒ Object
Maximum allowed time in seconds for the webhook to return the results
62 63 64 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 62 def timeout_sec @timeout_sec end |
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`)
65 66 67 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 65 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
68 69 70 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 68 def uid_token @uid_token end |
#user_ttl ⇒ Object
User TTL
71 72 73 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 71 def user_ttl @user_ttl end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 336 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
98 99 100 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 98 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 74 def self.attribute_map { :'admin_rotation_interval_days' => :'admin-rotation-interval-days', :'create_sync_url' => :'create-sync-url', :'delete_protection' => :'delete_protection', :'enable_admin_rotation' => :'enable-admin-rotation', :'input_rule' => :'input-rule', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'name' => :'name', :'output_rule' => :'output-rule', :'payload' => :'payload', :'producer_encryption_key_name' => :'producer-encryption-key-name', :'revoke_sync_url' => :'revoke-sync-url', :'rotate_sync_url' => :'rotate-sync-url', :'tags' => :'tags', :'timeout_sec' => :'timeout-sec', :'token' => :'token', :'uid_token' => :'uid-token', :'user_ttl' => :'user-ttl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 312 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
127 128 129 130 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 127 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 103 def self.openapi_types { :'admin_rotation_interval_days' => :'Integer', :'create_sync_url' => :'String', :'delete_protection' => :'String', :'enable_admin_rotation' => :'Boolean', :'input_rule' => :'Array<String>', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'name' => :'String', :'output_rule' => :'Array<String>', :'payload' => :'String', :'producer_encryption_key_name' => :'String', :'revoke_sync_url' => :'String', :'rotate_sync_url' => :'String', :'tags' => :'Array<String>', :'timeout_sec' => :'Integer', :'token' => :'String', :'uid_token' => :'String', :'user_ttl' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 274 def ==(o) return true if self.equal?(o) self.class == o.class && admin_rotation_interval_days == o.admin_rotation_interval_days && create_sync_url == o.create_sync_url && delete_protection == o.delete_protection && enable_admin_rotation == o.enable_admin_rotation && input_rule == o.input_rule && item_custom_fields == o.item_custom_fields && json == o.json && name == o.name && output_rule == o.output_rule && payload == o.payload && producer_encryption_key_name == o.producer_encryption_key_name && revoke_sync_url == o.revoke_sync_url && rotate_sync_url == o.rotate_sync_url && == o. && timeout_sec == o.timeout_sec && token == o.token && uid_token == o.uid_token && user_ttl == o.user_ttl end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 407 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
299 300 301 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 299 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
305 306 307 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 305 def hash [admin_rotation_interval_days, create_sync_url, delete_protection, enable_admin_rotation, input_rule, item_custom_fields, json, name, output_rule, payload, producer_encryption_key_name, revoke_sync_url, rotate_sync_url, , timeout_sec, token, uid_token, user_ttl].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 244 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @create_sync_url.nil? invalid_properties.push('invalid value for "create_sync_url", create_sync_url cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @revoke_sync_url.nil? invalid_properties.push('invalid value for "revoke_sync_url", revoke_sync_url cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
383 384 385 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 383 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 389 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
377 378 379 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 377 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
264 265 266 267 268 269 270 |
# File 'lib/akeyless/models/gateway_create_producer_custom.rb', line 264 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @create_sync_url.nil? return false if @name.nil? return false if @revoke_sync_url.nil? true end |