Class: Akeyless::GatewayCreateProducerGcp

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/gateway_create_producer_gcp.rb

Overview

gatewayCreateProducerGcp is a command that creates a GCP producer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GatewayCreateProducerGcp

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayCreateProducerGcp` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayCreateProducerGcp`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'gcp_cred_type')
    self.gcp_cred_type = attributes[:'gcp_cred_type']
  end

  if attributes.key?(:'gcp_key')
    self.gcp_key = attributes[:'gcp_key']
  end

  if attributes.key?(:'gcp_key_algo')
    self.gcp_key_algo = attributes[:'gcp_key_algo']
  end

  if attributes.key?(:'gcp_sa_email')
    self.gcp_sa_email = attributes[:'gcp_sa_email']
  end

  if attributes.key?(:'gcp_token_scopes')
    self.gcp_token_scopes = attributes[:'gcp_token_scopes']
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '60m'
  end
end

Instance Attribute Details

#delete_protection ⇒ Object

Protection from accidental deletion of this item



20
21
22
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 20

def delete_protection
  @delete_protection
end

#gcp_cred_type ⇒ Object

Returns the value of attribute gcp_cred_type.



22
23
24
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 22

def gcp_cred_type
  @gcp_cred_type
end

#gcp_key ⇒ Object

Base64-encoded service account private key text



25
26
27
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 25

def gcp_key
  @gcp_key
end

#gcp_key_algo ⇒ Object

Service account key algorithm, e.g. KEY_ALG_RSA_1024



28
29
30
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 28

def gcp_key_algo
  @gcp_key_algo
end

#gcp_sa_email ⇒ Object

GCP service account email



31
32
33
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 31

def gcp_sa_email
  @gcp_sa_email
end

#gcp_token_scopes ⇒ Object

Access token scopes list, e.g. scope1,scope2



34
35
36
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 34

def gcp_token_scopes
  @gcp_token_scopes
end

#json ⇒ Object

Set output format to JSON



37
38
39
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 37

def json
  @json
end

#name ⇒ Object

Producer name



40
41
42
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 40

def name
  @name
end

#producer_encryption_key_name ⇒ Object

Dynamic producer encryption key



43
44
45
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 43

def producer_encryption_key_name
  @producer_encryption_key_name
end

#tags ⇒ Object

List of the tags attached to this secret



46
47
48
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 46

def tags
  @tags
end

#target_name ⇒ Object

Target name



49
50
51
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 49

def target_name
  @target_name
end

#token ⇒ Object

Authentication token (see /auth and /configure)



52
53
54
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 52

def token
  @token
end

#uid_token ⇒ Object

The universal identity token, Required only for universal_identity authentication



55
56
57
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 55

def uid_token
  @uid_token
end

#user_ttl ⇒ Object

User TTL



58
59
60
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 58

def user_ttl
  @user_ttl
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 81

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 61

def self.attribute_map
  {
    :'delete_protection' => :'delete_protection',
    :'gcp_cred_type' => :'gcp-cred-type',
    :'gcp_key' => :'gcp-key',
    :'gcp_key_algo' => :'gcp-key-algo',
    :'gcp_sa_email' => :'gcp-sa-email',
    :'gcp_token_scopes' => :'gcp-token-scopes',
    :'json' => :'json',
    :'name' => :'name',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'user_ttl' => :'user-ttl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



241
242
243
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 241

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



106
107
108
109
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 106

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 86

def self.openapi_types
  {
    :'delete_protection' => :'String',
    :'gcp_cred_type' => :'String',
    :'gcp_key' => :'String',
    :'gcp_key_algo' => :'String',
    :'gcp_sa_email' => :'String',
    :'gcp_token_scopes' => :'String',
    :'json' => :'Boolean',
    :'name' => :'String',
    :'producer_encryption_key_name' => :'String',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'user_ttl' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 207

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      delete_protection == o.delete_protection &&
      gcp_cred_type == o.gcp_cred_type &&
      gcp_key == o.gcp_key &&
      gcp_key_algo == o.gcp_key_algo &&
      gcp_sa_email == o.gcp_sa_email &&
      gcp_token_scopes == o.gcp_token_scopes &&
      json == o.json &&
      name == o.name &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      user_ttl == o.user_ttl
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 272

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 343

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 248

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


228
229
230
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 228

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



234
235
236
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 234

def hash
  [delete_protection, gcp_cred_type, gcp_key, gcp_key_algo, gcp_sa_email, gcp_token_scopes, json, name, producer_encryption_key_name, tags, target_name, token, uid_token, user_ttl].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



189
190
191
192
193
194
195
196
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 189

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



319
320
321
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 319

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 325

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



313
314
315
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 313

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



200
201
202
203
# File 'lib/akeyless/models/gateway_create_producer_gcp.rb', line 200

def valid?
  return false if @name.nil?
  true
end