Class: Akeyless::GatewayCreateProducerGke

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/gateway_create_producer_gke.rb

Overview

gatewayCreateProducerGke is a command that creates gke producer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GatewayCreateProducerGke

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayCreateProducerGke` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayCreateProducerGke`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'gke_account_key')
    self. = attributes[:'gke_account_key']
  end

  if attributes.key?(:'gke_cluster_cert')
    self.gke_cluster_cert = attributes[:'gke_cluster_cert']
  end

  if attributes.key?(:'gke_cluster_endpoint')
    self.gke_cluster_endpoint = attributes[:'gke_cluster_endpoint']
  end

  if attributes.key?(:'gke_cluster_name')
    self.gke_cluster_name = attributes[:'gke_cluster_name']
  end

  if attributes.key?(:'gke_service_account_email')
    self. = attributes[:'gke_service_account_email']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'secure_access_allow_port_forwading')
    self.secure_access_allow_port_forwading = attributes[:'secure_access_allow_port_forwading']
  end

  if attributes.key?(:'secure_access_bastion_issuer')
    self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer']
  end

  if attributes.key?(:'secure_access_cluster_endpoint')
    self.secure_access_cluster_endpoint = attributes[:'secure_access_cluster_endpoint']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_web')
    self.secure_access_web = attributes[:'secure_access_web']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '60m'
  end
end

Instance Attribute Details

#gke_account_keyObject

GKE Service Account key file path



20
21
22
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 20

def 
  
end

#gke_cluster_certObject

GKE cluster CA certificate



23
24
25
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 23

def gke_cluster_cert
  @gke_cluster_cert
end

#gke_cluster_endpointObject

GKE cluster URL endpoint



26
27
28
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 26

def gke_cluster_endpoint
  @gke_cluster_endpoint
end

#gke_cluster_nameObject

GKE cluster name



29
30
31
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 29

def gke_cluster_name
  @gke_cluster_name
end

#gke_service_account_emailObject

GKE service account email



32
33
34
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 32

def 
  
end

#nameObject

Producer name



35
36
37
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 35

def name
  @name
end

#producer_encryption_key_nameObject

Dynamic producer encryption key



38
39
40
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 38

def producer_encryption_key_name
  @producer_encryption_key_name
end

#secure_access_allow_port_forwadingObject

Returns the value of attribute secure_access_allow_port_forwading.



40
41
42
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 40

def secure_access_allow_port_forwading
  @secure_access_allow_port_forwading
end

#secure_access_bastion_issuerObject

Returns the value of attribute secure_access_bastion_issuer.



42
43
44
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 42

def secure_access_bastion_issuer
  @secure_access_bastion_issuer
end

#secure_access_cluster_endpointObject

Returns the value of attribute secure_access_cluster_endpoint.



44
45
46
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 44

def secure_access_cluster_endpoint
  @secure_access_cluster_endpoint
end

#secure_access_enableObject

Returns the value of attribute secure_access_enable.



46
47
48
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 46

def secure_access_enable
  @secure_access_enable
end

#secure_access_webObject

Returns the value of attribute secure_access_web.



48
49
50
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 48

def secure_access_web
  @secure_access_web
end

#tagsObject

List of the tags attached to this secret



51
52
53
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 51

def tags
  @tags
end

#target_nameObject

Target name



54
55
56
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 54

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



57
58
59
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 57

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



60
61
62
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 60

def uid_token
  @uid_token
end

#user_ttlObject

User TTL



63
64
65
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 63

def user_ttl
  @user_ttl
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 66

def self.attribute_map
  {
    :'gke_account_key' => :'gke-account-key',
    :'gke_cluster_cert' => :'gke-cluster-cert',
    :'gke_cluster_endpoint' => :'gke-cluster-endpoint',
    :'gke_cluster_name' => :'gke-cluster-name',
    :'gke_service_account_email' => :'gke-service-account-email',
    :'name' => :'name',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'secure_access_allow_port_forwading' => :'secure-access-allow-port-forwading',
    :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer',
    :'secure_access_cluster_endpoint' => :'secure-access-cluster-endpoint',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_web' => :'secure-access-web',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'user_ttl' => :'user-ttl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



267
268
269
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 267

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



117
118
119
120
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 117

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 94

def self.openapi_types
  {
    :'gke_account_key' => :'String',
    :'gke_cluster_cert' => :'String',
    :'gke_cluster_endpoint' => :'String',
    :'gke_cluster_name' => :'String',
    :'gke_service_account_email' => :'String',
    :'name' => :'String',
    :'producer_encryption_key_name' => :'String',
    :'secure_access_allow_port_forwading' => :'Boolean',
    :'secure_access_bastion_issuer' => :'String',
    :'secure_access_cluster_endpoint' => :'String',
    :'secure_access_enable' => :'String',
    :'secure_access_web' => :'Boolean',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'user_ttl' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 230

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      gke_cluster_cert == o.gke_cluster_cert &&
      gke_cluster_endpoint == o.gke_cluster_endpoint &&
      gke_cluster_name == o.gke_cluster_name &&
       == o. &&
      name == o.name &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      secure_access_allow_port_forwading == o.secure_access_allow_port_forwading &&
      secure_access_bastion_issuer == o.secure_access_bastion_issuer &&
      secure_access_cluster_endpoint == o.secure_access_cluster_endpoint &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_web == o.secure_access_web &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      user_ttl == o.user_ttl
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 298

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 369

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 274

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


254
255
256
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 254

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



260
261
262
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 260

def hash
  [, gke_cluster_cert, gke_cluster_endpoint, gke_cluster_name, , name, producer_encryption_key_name, secure_access_allow_port_forwading, secure_access_bastion_issuer, secure_access_cluster_endpoint, secure_access_enable, secure_access_web, tags, target_name, token, uid_token, user_ttl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



212
213
214
215
216
217
218
219
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 212

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



345
346
347
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 345

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 351

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



339
340
341
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 339

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



223
224
225
226
# File 'lib/akeyless/models/gateway_create_producer_gke.rb', line 223

def valid?
  return false if @name.nil?
  true
end