Class: Akeyless::GatewayCreateProducerMongo

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/gateway_create_producer_mongo.rb

Overview

gatewayCreateProducerMongo is a command that creates either mongodb producer or mongodb atlas producer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GatewayCreateProducerMongo

Initializes the object



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 155

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayCreateProducerMongo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayCreateProducerMongo`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'mongodb_atlas_api_private_key')
    self.mongodb_atlas_api_private_key = attributes[:'mongodb_atlas_api_private_key']
  end

  if attributes.key?(:'mongodb_atlas_api_public_key')
    self.mongodb_atlas_api_public_key = attributes[:'mongodb_atlas_api_public_key']
  end

  if attributes.key?(:'mongodb_atlas_project_id')
    self.mongodb_atlas_project_id = attributes[:'mongodb_atlas_project_id']
  end

  if attributes.key?(:'mongodb_custom_data')
    self.mongodb_custom_data = attributes[:'mongodb_custom_data']
  end

  if attributes.key?(:'mongodb_default_auth_db')
    self.mongodb_default_auth_db = attributes[:'mongodb_default_auth_db']
  end

  if attributes.key?(:'mongodb_host_port')
    self.mongodb_host_port = attributes[:'mongodb_host_port']
  end

  if attributes.key?(:'mongodb_name')
    self.mongodb_name = attributes[:'mongodb_name']
  end

  if attributes.key?(:'mongodb_password')
    self.mongodb_password = attributes[:'mongodb_password']
  end

  if attributes.key?(:'mongodb_roles')
    self.mongodb_roles = attributes[:'mongodb_roles']
  else
    self.mongodb_roles = '[]'
  end

  if attributes.key?(:'mongodb_server_uri')
    self.mongodb_server_uri = attributes[:'mongodb_server_uri']
  end

  if attributes.key?(:'mongodb_uri_options')
    self.mongodb_uri_options = attributes[:'mongodb_uri_options']
  end

  if attributes.key?(:'mongodb_username')
    self.mongodb_username = attributes[:'mongodb_username']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'secure_access_bastion_issuer')
    self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_host')
    if (value = attributes[:'secure_access_host']).is_a?(Array)
      self.secure_access_host = value
    end
  end

  if attributes.key?(:'secure_access_web')
    self.secure_access_web = attributes[:'secure_access_web']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '60m'
  end
end

Instance Attribute Details

#mongodb_atlas_api_private_keyObject

MongoDB Atlas private key



20
21
22
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 20

def mongodb_atlas_api_private_key
  @mongodb_atlas_api_private_key
end

#mongodb_atlas_api_public_keyObject

MongoDB Atlas public key



23
24
25
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 23

def mongodb_atlas_api_public_key
  @mongodb_atlas_api_public_key
end

#mongodb_atlas_project_idObject

MongoDB Atlas project ID



26
27
28
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 26

def mongodb_atlas_project_id
  @mongodb_atlas_project_id
end

#mongodb_custom_dataObject

MongoDB custom data



29
30
31
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 29

def mongodb_custom_data
  @mongodb_custom_data
end

#mongodb_default_auth_dbObject

MongoDB server default authentication database



32
33
34
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 32

def mongodb_default_auth_db
  @mongodb_default_auth_db
end

#mongodb_host_portObject

MongoDB server host and port



35
36
37
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 35

def mongodb_host_port
  @mongodb_host_port
end

#mongodb_nameObject

MongoDB Name



38
39
40
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 38

def mongodb_name
  @mongodb_name
end

#mongodb_passwordObject

MongoDB server password. You will prompted to provide a password if it will not appear in CLI parameters



41
42
43
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 41

def mongodb_password
  @mongodb_password
end

#mongodb_rolesObject

MongoDB Roles



44
45
46
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 44

def mongodb_roles
  @mongodb_roles
end

#mongodb_server_uriObject

MongoDB server URI



47
48
49
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 47

def mongodb_server_uri
  @mongodb_server_uri
end

#mongodb_uri_optionsObject

MongoDB server URI options



50
51
52
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 50

def mongodb_uri_options
  @mongodb_uri_options
end

#mongodb_usernameObject

MongoDB server username



53
54
55
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 53

def mongodb_username
  @mongodb_username
end

#nameObject

Producer name



56
57
58
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 56

def name
  @name
end

#producer_encryption_key_nameObject

Encrypt producer with following key



59
60
61
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 59

def producer_encryption_key_name
  @producer_encryption_key_name
end

#secure_access_bastion_issuerObject

Returns the value of attribute secure_access_bastion_issuer.



61
62
63
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 61

def secure_access_bastion_issuer
  @secure_access_bastion_issuer
end

#secure_access_enableObject

Returns the value of attribute secure_access_enable.



63
64
65
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 63

def secure_access_enable
  @secure_access_enable
end

#secure_access_hostObject

Returns the value of attribute secure_access_host.



65
66
67
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 65

def secure_access_host
  @secure_access_host
end

#secure_access_webObject

Returns the value of attribute secure_access_web.



67
68
69
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 67

def secure_access_web
  @secure_access_web
end

#tagsObject

List of the tags attached to this secret



70
71
72
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 70

def tags
  @tags
end

#target_nameObject

Target name



73
74
75
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 73

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



76
77
78
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 76

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



79
80
81
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 79

def uid_token
  @uid_token
end

#user_ttlObject

User TTL



82
83
84
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 82

def user_ttl
  @user_ttl
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



114
115
116
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 114

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 85

def self.attribute_map
  {
    :'mongodb_atlas_api_private_key' => :'mongodb-atlas-api-private-key',
    :'mongodb_atlas_api_public_key' => :'mongodb-atlas-api-public-key',
    :'mongodb_atlas_project_id' => :'mongodb-atlas-project-id',
    :'mongodb_custom_data' => :'mongodb-custom-data',
    :'mongodb_default_auth_db' => :'mongodb-default-auth-db',
    :'mongodb_host_port' => :'mongodb-host-port',
    :'mongodb_name' => :'mongodb-name',
    :'mongodb_password' => :'mongodb-password',
    :'mongodb_roles' => :'mongodb-roles',
    :'mongodb_server_uri' => :'mongodb-server-uri',
    :'mongodb_uri_options' => :'mongodb-uri-options',
    :'mongodb_username' => :'mongodb-username',
    :'name' => :'name',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_host' => :'secure-access-host',
    :'secure_access_web' => :'secure-access-web',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'user_ttl' => :'user-ttl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



332
333
334
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 332

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



148
149
150
151
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 148

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 119

def self.openapi_types
  {
    :'mongodb_atlas_api_private_key' => :'String',
    :'mongodb_atlas_api_public_key' => :'String',
    :'mongodb_atlas_project_id' => :'String',
    :'mongodb_custom_data' => :'String',
    :'mongodb_default_auth_db' => :'String',
    :'mongodb_host_port' => :'String',
    :'mongodb_name' => :'String',
    :'mongodb_password' => :'String',
    :'mongodb_roles' => :'String',
    :'mongodb_server_uri' => :'String',
    :'mongodb_uri_options' => :'String',
    :'mongodb_username' => :'String',
    :'name' => :'String',
    :'producer_encryption_key_name' => :'String',
    :'secure_access_bastion_issuer' => :'String',
    :'secure_access_enable' => :'String',
    :'secure_access_host' => :'Array<String>',
    :'secure_access_web' => :'Boolean',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'user_ttl' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 289

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      mongodb_atlas_api_private_key == o.mongodb_atlas_api_private_key &&
      mongodb_atlas_api_public_key == o.mongodb_atlas_api_public_key &&
      mongodb_atlas_project_id == o.mongodb_atlas_project_id &&
      mongodb_custom_data == o.mongodb_custom_data &&
      mongodb_default_auth_db == o.mongodb_default_auth_db &&
      mongodb_host_port == o.mongodb_host_port &&
      mongodb_name == o.mongodb_name &&
      mongodb_password == o.mongodb_password &&
      mongodb_roles == o.mongodb_roles &&
      mongodb_server_uri == o.mongodb_server_uri &&
      mongodb_uri_options == o.mongodb_uri_options &&
      mongodb_username == o.mongodb_username &&
      name == o.name &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      secure_access_bastion_issuer == o.secure_access_bastion_issuer &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_host == o.secure_access_host &&
      secure_access_web == o.secure_access_web &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      user_ttl == o.user_ttl
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 363

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



434
435
436
437
438
439
440
441
442
443
444
445
446
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 434

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 339

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


319
320
321
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 319

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



325
326
327
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 325

def hash
  [mongodb_atlas_api_private_key, mongodb_atlas_api_public_key, mongodb_atlas_project_id, mongodb_custom_data, mongodb_default_auth_db, mongodb_host_port, mongodb_name, mongodb_password, mongodb_roles, mongodb_server_uri, mongodb_uri_options, mongodb_username, name, producer_encryption_key_name, secure_access_bastion_issuer, secure_access_enable, secure_access_host, secure_access_web, tags, target_name, token, uid_token, user_ttl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



271
272
273
274
275
276
277
278
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 271

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



410
411
412
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 410

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 416

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



404
405
406
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 404

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



282
283
284
285
# File 'lib/akeyless/models/gateway_create_producer_mongo.rb', line 282

def valid?
  return false if @name.nil?
  true
end