Class: Akeyless::GatewayRevokeTmpUsers
- Inherits:
-
Object
- Object
- Akeyless::GatewayRevokeTmpUsers
- Defined in:
- lib/akeyless/models/gateway_revoke_tmp_users.rb
Overview
gatewayRevokeTmpUsers is a command that revoke producer tmp user [Deprecated: Use dynamic-secret-tmp-creds-delete command]
Instance Attribute Summary collapse
-
#host ⇒ Object
Host.
-
#input_rule ⇒ Object
Agentic input rule in name=…,rule=…
-
#json ⇒ Object
Set output format to JSON.
-
#name ⇒ Object
Dynamic secret name.
-
#output_rule ⇒ Object
Agentic output rule in name=…,rule=…
-
#revoke_all ⇒ Object
Revoke All Temp Creds.
-
#soft_delete ⇒ Object
Soft Delete.
-
#tmp_creds_id ⇒ Object
Tmp Creds ID.
-
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`).
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GatewayRevokeTmpUsers
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ GatewayRevokeTmpUsers
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayRevokeTmpUsers` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayRevokeTmpUsers`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'host') self.host = attributes[:'host'] end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'revoke_all') self.revoke_all = attributes[:'revoke_all'] end if attributes.key?(:'soft_delete') self.soft_delete = attributes[:'soft_delete'] end if attributes.key?(:'tmp_creds_id') self.tmp_creds_id = attributes[:'tmp_creds_id'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end end |
Instance Attribute Details
#host ⇒ Object
Host
20 21 22 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 20 def host @host end |
#input_rule ⇒ Object
Agentic input rule in name=…,rule=… format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).
23 24 25 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 23 def input_rule @input_rule end |
#json ⇒ Object
Set output format to JSON
26 27 28 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 26 def json @json end |
#name ⇒ Object
Dynamic secret name
29 30 31 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 29 def name @name end |
#output_rule ⇒ Object
Agentic output rule in name=…,rule=… format (e.g. name=rule1,rule=Mask secrets)
32 33 34 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 32 def output_rule @output_rule end |
#revoke_all ⇒ Object
Revoke All Temp Creds
35 36 37 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 35 def revoke_all @revoke_all end |
#soft_delete ⇒ Object
Soft Delete
38 39 40 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 38 def soft_delete @soft_delete end |
#tmp_creds_id ⇒ Object
Tmp Creds ID
41 42 43 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 41 def tmp_creds_id @tmp_creds_id end |
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`)
44 45 46 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 44 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
47 48 49 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 47 def uid_token @uid_token end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 232 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 66 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 50 def self.attribute_map { :'host' => :'host', :'input_rule' => :'input-rule', :'json' => :'json', :'name' => :'name', :'output_rule' => :'output-rule', :'revoke_all' => :'revoke-all', :'soft_delete' => :'soft-delete', :'tmp_creds_id' => :'tmp-creds-id', :'token' => :'token', :'uid_token' => :'uid-token' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 208 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 71 def self.openapi_types { :'host' => :'String', :'input_rule' => :'Array<String>', :'json' => :'Boolean', :'name' => :'String', :'output_rule' => :'Array<String>', :'revoke_all' => :'Boolean', :'soft_delete' => :'Boolean', :'tmp_creds_id' => :'String', :'token' => :'String', :'uid_token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 178 def ==(o) return true if self.equal?(o) self.class == o.class && host == o.host && input_rule == o.input_rule && json == o.json && name == o.name && output_rule == o.output_rule && revoke_all == o.revoke_all && soft_delete == o.soft_delete && tmp_creds_id == o.tmp_creds_id && token == o.token && uid_token == o.uid_token end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 303 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
195 196 197 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 195 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
201 202 203 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 201 def hash [host, input_rule, json, name, output_rule, revoke_all, soft_delete, tmp_creds_id, token, uid_token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
158 159 160 161 162 163 164 165 166 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 158 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
279 280 281 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 279 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 285 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
273 274 275 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 273 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
170 171 172 173 174 |
# File 'lib/akeyless/models/gateway_revoke_tmp_users.rb', line 170 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |