Class: Akeyless::GatewayUpdateMigration

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/gateway_update_migration.rb

Overview

gatewayUpdateMigration is a command that update migration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GatewayUpdateMigration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
# File 'lib/akeyless/models/gateway_update_migration.rb', line 305

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayUpdateMigration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayUpdateMigration`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_1password_email')
    self._1password_email = attributes[:'_1password_email']
  end

  if attributes.key?(:'_1password_password')
    self._1password_password = attributes[:'_1password_password']
  end

  if attributes.key?(:'_1password_secret_key')
    self._1password_secret_key = attributes[:'_1password_secret_key']
  end

  if attributes.key?(:'_1password_url')
    self._1password_url = attributes[:'_1password_url']
  end

  if attributes.key?(:'_1password_vaults')
    if (value = attributes[:'_1password_vaults']).is_a?(Array)
      self._1password_vaults = value
    end
  end

  if attributes.key?(:'ad_auto_rotate_boolean')
    self.ad_auto_rotate_boolean = attributes[:'ad_auto_rotate_boolean']
  end

  if attributes.key?(:'ad_discover_local_users_boolean')
    self.ad_discover_local_users_boolean = attributes[:'ad_discover_local_users_boolean']
  end

  if attributes.key?(:'ad_local_users_ignore_list')
    if (value = attributes[:'ad_local_users_ignore_list']).is_a?(Hash)
      self.ad_local_users_ignore_list = value
    end
  end

  if attributes.key?(:'ad_sra_enable_rdp_boolean')
    self.ad_sra_enable_rdp_boolean = attributes[:'ad_sra_enable_rdp_boolean']
  end

  if attributes.key?(:'ad_auto_rotate')
    self.ad_auto_rotate = attributes[:'ad_auto_rotate']
  end

  if attributes.key?(:'ad_computer_base_dn')
    self.ad_computer_base_dn = attributes[:'ad_computer_base_dn']
  end

  if attributes.key?(:'ad_discover_local_users')
    self.ad_discover_local_users = attributes[:'ad_discover_local_users']
  end

  if attributes.key?(:'ad_domain_name')
    self.ad_domain_name = attributes[:'ad_domain_name']
  end

  if attributes.key?(:'ad_domain_users_path_template')
    self.ad_domain_users_path_template = attributes[:'ad_domain_users_path_template']
  end

  if attributes.key?(:'ad_local_users_ignore')
    self.ad_local_users_ignore = attributes[:'ad_local_users_ignore']
  end

  if attributes.key?(:'ad_local_users_path_template')
    self.ad_local_users_path_template = attributes[:'ad_local_users_path_template']
  end

  if attributes.key?(:'ad_rotation_hour')
    self.ad_rotation_hour = attributes[:'ad_rotation_hour']
  end

  if attributes.key?(:'ad_rotation_interval')
    self.ad_rotation_interval = attributes[:'ad_rotation_interval']
  end

  if attributes.key?(:'ad_sra_enable_rdp')
    self.ad_sra_enable_rdp = attributes[:'ad_sra_enable_rdp']
  end

  if attributes.key?(:'ad_target_name')
    self.ad_target_name = attributes[:'ad_target_name']
  end

  if attributes.key?(:'ad_targets_path_template')
    self.ad_targets_path_template = attributes[:'ad_targets_path_template']
  end

  if attributes.key?(:'ad_user_base_dn')
    self.ad_user_base_dn = attributes[:'ad_user_base_dn']
  end

  if attributes.key?(:'ad_user_groups')
    self.ad_user_groups = attributes[:'ad_user_groups']
  end

  if attributes.key?(:'as_ssh_port')
    self.as_ssh_port = attributes[:'as_ssh_port']
  end

  if attributes.key?(:'aws_key')
    self.aws_key = attributes[:'aws_key']
  end

  if attributes.key?(:'aws_key_id')
    self.aws_key_id = attributes[:'aws_key_id']
  end

  if attributes.key?(:'aws_region')
    self.aws_region = attributes[:'aws_region']
  end

  if attributes.key?(:'azure_client_id')
    self.azure_client_id = attributes[:'azure_client_id']
  end

  if attributes.key?(:'azure_kv_name')
    self.azure_kv_name = attributes[:'azure_kv_name']
  end

  if attributes.key?(:'azure_secret')
    self.azure_secret = attributes[:'azure_secret']
  end

  if attributes.key?(:'azure_tenant_id')
    self.azure_tenant_id = attributes[:'azure_tenant_id']
  end

  if attributes.key?(:'gcp_key')
    self.gcp_key = attributes[:'gcp_key']
  end

  if attributes.key?(:'hashi_json')
    self.hashi_json = attributes[:'hashi_json']
  end

  if attributes.key?(:'hashi_ns')
    if (value = attributes[:'hashi_ns']).is_a?(Array)
      self.hashi_ns = value
    end
  end

  if attributes.key?(:'hashi_token')
    self.hashi_token = attributes[:'hashi_token']
  end

  if attributes.key?(:'hashi_url')
    self.hashi_url = attributes[:'hashi_url']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  end

  if attributes.key?(:'k8s_ca_certificate')
    if (value = attributes[:'k8s_ca_certificate']).is_a?(Array)
      self.k8s_ca_certificate = value
    end
  end

  if attributes.key?(:'k8s_client_certificate')
    if (value = attributes[:'k8s_client_certificate']).is_a?(Array)
      self.k8s_client_certificate = value
    end
  end

  if attributes.key?(:'k8s_client_key')
    if (value = attributes[:'k8s_client_key']).is_a?(Array)
      self.k8s_client_key = value
    end
  end

  if attributes.key?(:'k8s_namespace')
    self.k8s_namespace = attributes[:'k8s_namespace']
  end

  if attributes.key?(:'k8s_password')
    self.k8s_password = attributes[:'k8s_password']
  end

  if attributes.key?(:'k8s_skip_system')
    self.k8s_skip_system = attributes[:'k8s_skip_system']
  end

  if attributes.key?(:'k8s_token')
    self.k8s_token = attributes[:'k8s_token']
  end

  if attributes.key?(:'k8s_url')
    self.k8s_url = attributes[:'k8s_url']
  end

  if attributes.key?(:'k8s_username')
    self.k8s_username = attributes[:'k8s_username']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'protection_key')
    self.protection_key = attributes[:'protection_key']
  end

  if attributes.key?(:'target_location')
    self.target_location = attributes[:'target_location']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end
end

Instance Attribute Details

#_1password_email ⇒ Object

1Password user email to connect to the API



20
21
22
# File 'lib/akeyless/models/gateway_update_migration.rb', line 20

def _1password_email
  @_1password_email
end

#_1password_password ⇒ Object

1Password user password to connect to the API



23
24
25
# File 'lib/akeyless/models/gateway_update_migration.rb', line 23

def _1password_password
  @_1password_password
end

#_1password_secret_key ⇒ Object

1Password user secret key to connect to the API



26
27
28
# File 'lib/akeyless/models/gateway_update_migration.rb', line 26

def _1password_secret_key
  @_1password_secret_key
end

#_1password_url ⇒ Object

1Password api container url



29
30
31
# File 'lib/akeyless/models/gateway_update_migration.rb', line 29

def _1password_url
  @_1password_url
end

#_1password_vaults ⇒ Object

1Password list of vault to get the items from



32
33
34
# File 'lib/akeyless/models/gateway_update_migration.rb', line 32

def _1password_vaults
  @_1password_vaults
end

#ad_auto_rotate ⇒ Object

Enable/Disable automatic/recurrent rotation for migrated secrets. Default is false: only manual rotation is allowed for migrated secrets. If set to true, this command should be combined with --ad-rotation-interval and --ad-rotation-hour parameters (Relevant only for Active Directory migration)



43
44
45
# File 'lib/akeyless/models/gateway_update_migration.rb', line 43

def ad_auto_rotate
  @ad_auto_rotate
end

#ad_auto_rotate_boolean ⇒ Object

Returns the value of attribute ad_auto_rotate_boolean.



34
35
36
# File 'lib/akeyless/models/gateway_update_migration.rb', line 34

def ad_auto_rotate_boolean
  @ad_auto_rotate_boolean
end

#ad_computer_base_dn ⇒ Object

Distinguished Name of Computer objects (servers) to search in Active Directory e.g.: CN=Computers,DC=example,DC=com (Relevant only for Active Directory migration)



46
47
48
# File 'lib/akeyless/models/gateway_update_migration.rb', line 46

def ad_computer_base_dn
  @ad_computer_base_dn
end

#ad_discover_local_users ⇒ Object

Enable/Disable discovery of local users from each domain server and migrate them as SSH Rotated Secrets. Default is false: only domain users will be migrated. Discovery of local users might require further installation of SSH on the servers, based on the supplied computer base DN. This will be implemented automatically as part of the migration process (Relevant only for Active Directory migration)



49
50
51
# File 'lib/akeyless/models/gateway_update_migration.rb', line 49

def ad_discover_local_users
  @ad_discover_local_users
end

#ad_discover_local_users_boolean ⇒ Object

Returns the value of attribute ad_discover_local_users_boolean.



36
37
38
# File 'lib/akeyless/models/gateway_update_migration.rb', line 36

def ad_discover_local_users_boolean
  @ad_discover_local_users_boolean
end

#ad_domain_name ⇒ Object

Active Directory Domain Name (Relevant only for Active Directory migration)



52
53
54
# File 'lib/akeyless/models/gateway_update_migration.rb', line 52

def ad_domain_name
  @ad_domain_name
end

#ad_domain_users_path_template ⇒ Object

Path location template for migrating domain users as Rotated Secrets e.g.: .../DomainUsers/{USERNAME} (Relevant only for Active Directory migration)



55
56
57
# File 'lib/akeyless/models/gateway_update_migration.rb', line 55

def ad_domain_users_path_template
  @ad_domain_users_path_template
end

#ad_local_users_ignore ⇒ Object

Comma-separated list of Local Users which should not be migrated (Relevant only for Active Directory migration)



58
59
60
# File 'lib/akeyless/models/gateway_update_migration.rb', line 58

def ad_local_users_ignore
  @ad_local_users_ignore
end

#ad_local_users_ignore_list ⇒ Object

Returns the value of attribute ad_local_users_ignore_list.



38
39
40
# File 'lib/akeyless/models/gateway_update_migration.rb', line 38

def ad_local_users_ignore_list
  @ad_local_users_ignore_list
end

#ad_local_users_path_template ⇒ Object

Path location template for migrating domain users as Rotated Secrets e.g.: .../LocalUsers/{COMPUTER_NAME}/{USERNAME} (Relevant only for Active Directory migration)



61
62
63
# File 'lib/akeyless/models/gateway_update_migration.rb', line 61

def ad_local_users_path_template
  @ad_local_users_path_template
end

#ad_rotation_hour ⇒ Object

The hour of the scheduled rotation in UTC (Relevant only for Active Directory migration)



64
65
66
# File 'lib/akeyless/models/gateway_update_migration.rb', line 64

def ad_rotation_hour
  @ad_rotation_hour
end

#ad_rotation_interval ⇒ Object

The number of days to wait between every automatic rotation [1-365] (Relevant only for Active Directory migration)



67
68
69
# File 'lib/akeyless/models/gateway_update_migration.rb', line 67

def ad_rotation_interval
  @ad_rotation_interval
end

#ad_sra_enable_rdp ⇒ Object

Enable/Disable RDP Secure Remote Access for the migrated local users rotated secrets. Default is false: rotated secrets will not be created with SRA (Relevant only for Active Directory migration)



70
71
72
# File 'lib/akeyless/models/gateway_update_migration.rb', line 70

def ad_sra_enable_rdp
  @ad_sra_enable_rdp
end

#ad_sra_enable_rdp_boolean ⇒ Object

Returns the value of attribute ad_sra_enable_rdp_boolean.



40
41
42
# File 'lib/akeyless/models/gateway_update_migration.rb', line 40

def ad_sra_enable_rdp_boolean
  @ad_sra_enable_rdp_boolean
end

#ad_target_name ⇒ Object

Active Directory LDAP Target Name. Server type should be Active Directory (Relevant only for Active Directory migration)



73
74
75
# File 'lib/akeyless/models/gateway_update_migration.rb', line 73

def ad_target_name
  @ad_target_name
end

#ad_targets_path_template ⇒ Object

Path location template for migrating domain servers as SSH Targets e.g.: .../Servers/{COMPUTER_NAME} (Relevant only for Active Directory migration)



76
77
78
# File 'lib/akeyless/models/gateway_update_migration.rb', line 76

def ad_targets_path_template
  @ad_targets_path_template
end

#ad_user_base_dn ⇒ Object

Distinguished Name of User objects to search in Active Directory, e.g.: CN=Users,DC=example,DC=com (Relevant only for Active Directory migration)



79
80
81
# File 'lib/akeyless/models/gateway_update_migration.rb', line 79

def ad_user_base_dn
  @ad_user_base_dn
end

#ad_user_groups ⇒ Object

Comma-separated list of domain groups from which privileged domain users will be migrated (Relevant only for Active Directory migration)



82
83
84
# File 'lib/akeyless/models/gateway_update_migration.rb', line 82

def ad_user_groups
  @ad_user_groups
end

#as_ssh_port ⇒ Object

Set the SSH Port for further connection to the domain servers. Default is port 22 (Relevant only for Active Directory migration)



85
86
87
# File 'lib/akeyless/models/gateway_update_migration.rb', line 85

def as_ssh_port
  @as_ssh_port
end

#aws_key ⇒ Object

AWS Secret Access Key (relevant only for AWS migration)



88
89
90
# File 'lib/akeyless/models/gateway_update_migration.rb', line 88

def aws_key
  @aws_key
end

#aws_key_id ⇒ Object

AWS Access Key ID with sufficient permissions to get all secrets, e.g. 'arn:aws:secretsmanager:[Region]:[AccountId]:secret:[/path/to/secrets/*]' (relevant only for AWS migration)



91
92
93
# File 'lib/akeyless/models/gateway_update_migration.rb', line 91

def aws_key_id
  @aws_key_id
end

#aws_region ⇒ Object

AWS region of the required Secrets Manager (relevant only for AWS migration)



94
95
96
# File 'lib/akeyless/models/gateway_update_migration.rb', line 94

def aws_region
  @aws_region
end

#azure_client_id ⇒ Object

Azure Key Vault Access client ID, should be Azure AD App with a service principal (relevant only for Azure Key Vault migration)



97
98
99
# File 'lib/akeyless/models/gateway_update_migration.rb', line 97

def azure_client_id
  @azure_client_id
end

#azure_kv_name ⇒ Object

Azure Key Vault Name (relevant only for Azure Key Vault migration)



100
101
102
# File 'lib/akeyless/models/gateway_update_migration.rb', line 100

def azure_kv_name
  @azure_kv_name
end

#azure_secret ⇒ Object

Azure Key Vault secret (relevant only for Azure Key Vault migration)



103
104
105
# File 'lib/akeyless/models/gateway_update_migration.rb', line 103

def azure_secret
  @azure_secret
end

#azure_tenant_id ⇒ Object

Azure Key Vault Access tenant ID (relevant only for Azure Key Vault migration)



106
107
108
# File 'lib/akeyless/models/gateway_update_migration.rb', line 106

def azure_tenant_id
  @azure_tenant_id
end

#gcp_key ⇒ Object

Base64-encoded GCP Service Account private key text with sufficient permissions to Secrets Manager, Minimum required permission is Secret Manager Secret Accessor, e.g. 'roles/secretmanager.secretAccessor' (relevant only for GCP migration)



109
110
111
# File 'lib/akeyless/models/gateway_update_migration.rb', line 109

def gcp_key
  @gcp_key
end

#hashi_json ⇒ Object

Import secret key as json value or independent secrets (relevant only for HasiCorp Vault migration)



112
113
114
# File 'lib/akeyless/models/gateway_update_migration.rb', line 112

def hashi_json
  @hashi_json
end

#hashi_ns ⇒ Object

HashiCorp Vault Namespaces is a comma-separated list of namespaces which need to be imported into Akeyless Vault. For every provided namespace, all its child namespaces are imported as well, e.g. nmsp/subnmsp1/subnmsp2,nmsp/anothernmsp. By default, import all namespaces (relevant only for HasiCorp Vault migration)



115
116
117
# File 'lib/akeyless/models/gateway_update_migration.rb', line 115

def hashi_ns
  @hashi_ns
end

#hashi_token ⇒ Object

HashiCorp Vault access token with sufficient permissions to preform list & read operations on secrets objects (relevant only for HasiCorp Vault migration)



118
119
120
# File 'lib/akeyless/models/gateway_update_migration.rb', line 118

def hashi_token
  @hashi_token
end

#hashi_url ⇒ Object

HashiCorp Vault API URL, e.g. https://vault-mgr01:8200 (relevant only for HasiCorp Vault migration)



121
122
123
# File 'lib/akeyless/models/gateway_update_migration.rb', line 121

def hashi_url
  @hashi_url
end

#id ⇒ Object

Migration ID (Can be retrieved with gateway-list-migration command)



124
125
126
# File 'lib/akeyless/models/gateway_update_migration.rb', line 124

def id
  @id
end

#json ⇒ Object

Set output format to JSON



127
128
129
# File 'lib/akeyless/models/gateway_update_migration.rb', line 127

def json
  @json
end

#k8s_ca_certificate ⇒ Object

For Certificate Authentication method K8s Cluster CA certificate (relevant only for K8s migration with Certificate Authentication method)



130
131
132
# File 'lib/akeyless/models/gateway_update_migration.rb', line 130

def k8s_ca_certificate
  @k8s_ca_certificate
end

#k8s_client_certificate ⇒ Object

K8s Client certificate with sufficient permission to list and get secrets in the namespace(s) you selected (relevant only for K8s migration with Certificate Authentication method)



133
134
135
# File 'lib/akeyless/models/gateway_update_migration.rb', line 133

def k8s_client_certificate
  @k8s_client_certificate
end

#k8s_client_key ⇒ Object

K8s Client key (relevant only for K8s migration with Certificate Authentication method)



136
137
138
# File 'lib/akeyless/models/gateway_update_migration.rb', line 136

def k8s_client_key
  @k8s_client_key
end

#k8s_namespace ⇒ Object

K8s Namespace, Use this field to import secrets from a particular namespace only. By default, the secrets are imported from all namespaces (relevant only for K8s migration)



139
140
141
# File 'lib/akeyless/models/gateway_update_migration.rb', line 139

def k8s_namespace
  @k8s_namespace
end

#k8s_password ⇒ Object

K8s Client password (relevant only for K8s migration with Password Authentication method)



142
143
144
# File 'lib/akeyless/models/gateway_update_migration.rb', line 142

def k8s_password
  @k8s_password
end

#k8s_skip_system ⇒ Object

K8s Skip Control Plane Secrets, This option allows to avoid importing secrets from system namespaces (relevant only for K8s migration)



145
146
147
# File 'lib/akeyless/models/gateway_update_migration.rb', line 145

def k8s_skip_system
  @k8s_skip_system
end

#k8s_token ⇒ Object

For Token Authentication method K8s Bearer Token with sufficient permission to list and get secrets in the namespace(s) you selected (relevant only for K8s migration with Token Authentication method)



148
149
150
# File 'lib/akeyless/models/gateway_update_migration.rb', line 148

def k8s_token
  @k8s_token
end

#k8s_url ⇒ Object

K8s API Server URL, e.g. https://k8s-api.mycompany.com:6443 (relevant only for K8s migration)



151
152
153
# File 'lib/akeyless/models/gateway_update_migration.rb', line 151

def k8s_url
  @k8s_url
end

#k8s_username ⇒ Object

For Password Authentication method K8s Client username with sufficient permission to list and get secrets in the namespace(s) you selected (relevant only for K8s migration with Password Authentication method)



154
155
156
# File 'lib/akeyless/models/gateway_update_migration.rb', line 154

def k8s_username
  @k8s_username
end

#name ⇒ Object

Migration name



157
158
159
# File 'lib/akeyless/models/gateway_update_migration.rb', line 157

def name
  @name
end

#new_name ⇒ Object

New migration name



160
161
162
# File 'lib/akeyless/models/gateway_update_migration.rb', line 160

def new_name
  @new_name
end

#protection_key ⇒ Object

The name of the key that protects the classic key value (if empty, the account default key will be used)



163
164
165
# File 'lib/akeyless/models/gateway_update_migration.rb', line 163

def protection_key
  @protection_key
end

#target_location ⇒ Object

Target location in Akeyless for imported secrets



166
167
168
# File 'lib/akeyless/models/gateway_update_migration.rb', line 166

def target_location
  @target_location
end

#token ⇒ Object

Authentication token (see /auth and /configure)



169
170
171
# File 'lib/akeyless/models/gateway_update_migration.rb', line 169

def token
  @token
end

#uid_token ⇒ Object

The universal identity token, Required only for universal_identity authentication



172
173
174
# File 'lib/akeyless/models/gateway_update_migration.rb', line 172

def uid_token
  @uid_token
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



234
235
236
# File 'lib/akeyless/models/gateway_update_migration.rb', line 234

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/akeyless/models/gateway_update_migration.rb', line 175

def self.attribute_map
  {
    :'_1password_email' => :'1password-email',
    :'_1password_password' => :'1password-password',
    :'_1password_secret_key' => :'1password-secret-key',
    :'_1password_url' => :'1password-url',
    :'_1password_vaults' => :'1password-vaults',
    :'ad_auto_rotate_boolean' => :'AdAutoRotateBoolean',
    :'ad_discover_local_users_boolean' => :'AdDiscoverLocalUsersBoolean',
    :'ad_local_users_ignore_list' => :'AdLocalUsersIgnoreList',
    :'ad_sra_enable_rdp_boolean' => :'AdSRAEnableRDPBoolean',
    :'ad_auto_rotate' => :'ad_auto_rotate',
    :'ad_computer_base_dn' => :'ad_computer_base_dn',
    :'ad_discover_local_users' => :'ad_discover_local_users',
    :'ad_domain_name' => :'ad_domain_name',
    :'ad_domain_users_path_template' => :'ad_domain_users_path_template',
    :'ad_local_users_ignore' => :'ad_local_users_ignore',
    :'ad_local_users_path_template' => :'ad_local_users_path_template',
    :'ad_rotation_hour' => :'ad_rotation_hour',
    :'ad_rotation_interval' => :'ad_rotation_interval',
    :'ad_sra_enable_rdp' => :'ad_sra_enable_rdp',
    :'ad_target_name' => :'ad_target_name',
    :'ad_targets_path_template' => :'ad_targets_path_template',
    :'ad_user_base_dn' => :'ad_user_base_dn',
    :'ad_user_groups' => :'ad_user_groups',
    :'as_ssh_port' => :'as_ssh_port',
    :'aws_key' => :'aws-key',
    :'aws_key_id' => :'aws-key-id',
    :'aws_region' => :'aws-region',
    :'azure_client_id' => :'azure-client-id',
    :'azure_kv_name' => :'azure-kv-name',
    :'azure_secret' => :'azure-secret',
    :'azure_tenant_id' => :'azure-tenant-id',
    :'gcp_key' => :'gcp-key',
    :'hashi_json' => :'hashi-json',
    :'hashi_ns' => :'hashi-ns',
    :'hashi_token' => :'hashi-token',
    :'hashi_url' => :'hashi-url',
    :'id' => :'id',
    :'json' => :'json',
    :'k8s_ca_certificate' => :'k8s-ca-certificate',
    :'k8s_client_certificate' => :'k8s-client-certificate',
    :'k8s_client_key' => :'k8s-client-key',
    :'k8s_namespace' => :'k8s-namespace',
    :'k8s_password' => :'k8s-password',
    :'k8s_skip_system' => :'k8s-skip-system',
    :'k8s_token' => :'k8s-token',
    :'k8s_url' => :'k8s-url',
    :'k8s_username' => :'k8s-username',
    :'name' => :'name',
    :'new_name' => :'new_name',
    :'protection_key' => :'protection-key',
    :'target_location' => :'target-location',
    :'token' => :'token',
    :'uid_token' => :'uid-token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



636
637
638
# File 'lib/akeyless/models/gateway_update_migration.rb', line 636

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



298
299
300
301
# File 'lib/akeyless/models/gateway_update_migration.rb', line 298

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/akeyless/models/gateway_update_migration.rb', line 239

def self.openapi_types
  {
    :'_1password_email' => :'String',
    :'_1password_password' => :'String',
    :'_1password_secret_key' => :'String',
    :'_1password_url' => :'String',
    :'_1password_vaults' => :'Array<String>',
    :'ad_auto_rotate_boolean' => :'Boolean',
    :'ad_discover_local_users_boolean' => :'Boolean',
    :'ad_local_users_ignore_list' => :'Hash<String, Boolean>',
    :'ad_sra_enable_rdp_boolean' => :'Boolean',
    :'ad_auto_rotate' => :'String',
    :'ad_computer_base_dn' => :'String',
    :'ad_discover_local_users' => :'String',
    :'ad_domain_name' => :'String',
    :'ad_domain_users_path_template' => :'String',
    :'ad_local_users_ignore' => :'String',
    :'ad_local_users_path_template' => :'String',
    :'ad_rotation_hour' => :'Integer',
    :'ad_rotation_interval' => :'Integer',
    :'ad_sra_enable_rdp' => :'String',
    :'ad_target_name' => :'String',
    :'ad_targets_path_template' => :'String',
    :'ad_user_base_dn' => :'String',
    :'ad_user_groups' => :'String',
    :'as_ssh_port' => :'String',
    :'aws_key' => :'String',
    :'aws_key_id' => :'String',
    :'aws_region' => :'String',
    :'azure_client_id' => :'String',
    :'azure_kv_name' => :'String',
    :'azure_secret' => :'String',
    :'azure_tenant_id' => :'String',
    :'gcp_key' => :'String',
    :'hashi_json' => :'String',
    :'hashi_ns' => :'Array<String>',
    :'hashi_token' => :'String',
    :'hashi_url' => :'String',
    :'id' => :'String',
    :'json' => :'Boolean',
    :'k8s_ca_certificate' => :'Array<Integer>',
    :'k8s_client_certificate' => :'Array<Integer>',
    :'k8s_client_key' => :'Array<Integer>',
    :'k8s_namespace' => :'String',
    :'k8s_password' => :'String',
    :'k8s_skip_system' => :'Boolean',
    :'k8s_token' => :'String',
    :'k8s_url' => :'String',
    :'k8s_username' => :'String',
    :'name' => :'String',
    :'new_name' => :'String',
    :'protection_key' => :'String',
    :'target_location' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
# File 'lib/akeyless/models/gateway_update_migration.rb', line 563

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _1password_email == o._1password_email &&
      _1password_password == o._1password_password &&
      _1password_secret_key == o._1password_secret_key &&
      _1password_url == o._1password_url &&
      _1password_vaults == o._1password_vaults &&
      ad_auto_rotate_boolean == o.ad_auto_rotate_boolean &&
      ad_discover_local_users_boolean == o.ad_discover_local_users_boolean &&
      ad_local_users_ignore_list == o.ad_local_users_ignore_list &&
      ad_sra_enable_rdp_boolean == o.ad_sra_enable_rdp_boolean &&
      ad_auto_rotate == o.ad_auto_rotate &&
      ad_computer_base_dn == o.ad_computer_base_dn &&
      ad_discover_local_users == o.ad_discover_local_users &&
      ad_domain_name == o.ad_domain_name &&
      ad_domain_users_path_template == o.ad_domain_users_path_template &&
      ad_local_users_ignore == o.ad_local_users_ignore &&
      ad_local_users_path_template == o.ad_local_users_path_template &&
      ad_rotation_hour == o.ad_rotation_hour &&
      ad_rotation_interval == o.ad_rotation_interval &&
      ad_sra_enable_rdp == o.ad_sra_enable_rdp &&
      ad_target_name == o.ad_target_name &&
      ad_targets_path_template == o.ad_targets_path_template &&
      ad_user_base_dn == o.ad_user_base_dn &&
      ad_user_groups == o.ad_user_groups &&
      as_ssh_port == o.as_ssh_port &&
      aws_key == o.aws_key &&
      aws_key_id == o.aws_key_id &&
      aws_region == o.aws_region &&
      azure_client_id == o.azure_client_id &&
      azure_kv_name == o.azure_kv_name &&
      azure_secret == o.azure_secret &&
      azure_tenant_id == o.azure_tenant_id &&
      gcp_key == o.gcp_key &&
      hashi_json == o.hashi_json &&
      hashi_ns == o.hashi_ns &&
      hashi_token == o.hashi_token &&
      hashi_url == o.hashi_url &&
      id == o.id &&
      json == o.json &&
      k8s_ca_certificate == o.k8s_ca_certificate &&
      k8s_client_certificate == o.k8s_client_certificate &&
      k8s_client_key == o.k8s_client_key &&
      k8s_namespace == o.k8s_namespace &&
      k8s_password == o.k8s_password &&
      k8s_skip_system == o.k8s_skip_system &&
      k8s_token == o.k8s_token &&
      k8s_url == o.k8s_url &&
      k8s_username == o.k8s_username &&
      name == o.name &&
      new_name == o.new_name &&
      protection_key == o.protection_key &&
      target_location == o.target_location &&
      token == o.token &&
      uid_token == o.uid_token
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
# File 'lib/akeyless/models/gateway_update_migration.rb', line 667

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



738
739
740
741
742
743
744
745
746
747
748
749
750
# File 'lib/akeyless/models/gateway_update_migration.rb', line 738

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
# File 'lib/akeyless/models/gateway_update_migration.rb', line 643

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


623
624
625
# File 'lib/akeyless/models/gateway_update_migration.rb', line 623

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



629
630
631
# File 'lib/akeyless/models/gateway_update_migration.rb', line 629

def hash
  [_1password_email, _1password_password, _1password_secret_key, _1password_url, _1password_vaults, ad_auto_rotate_boolean, ad_discover_local_users_boolean, ad_local_users_ignore_list, ad_sra_enable_rdp_boolean, ad_auto_rotate, ad_computer_base_dn, ad_discover_local_users, ad_domain_name, ad_domain_users_path_template, ad_local_users_ignore, ad_local_users_path_template, ad_rotation_hour, ad_rotation_interval, ad_sra_enable_rdp, ad_target_name, ad_targets_path_template, ad_user_base_dn, ad_user_groups, as_ssh_port, aws_key, aws_key_id, aws_region, azure_client_id, azure_kv_name, azure_secret, azure_tenant_id, gcp_key, hashi_json, hashi_ns, hashi_token, hashi_url, id, json, k8s_ca_certificate, k8s_client_certificate, k8s_client_key, k8s_namespace, k8s_password, k8s_skip_system, k8s_token, k8s_url, k8s_username, name, new_name, protection_key, target_location, token, uid_token].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



545
546
547
548
549
550
551
552
# File 'lib/akeyless/models/gateway_update_migration.rb', line 545

def list_invalid_properties
  invalid_properties = Array.new
  if @target_location.nil?
    invalid_properties.push('invalid value for "target_location", target_location cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



714
715
716
# File 'lib/akeyless/models/gateway_update_migration.rb', line 714

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



720
721
722
723
724
725
726
727
728
729
730
731
732
# File 'lib/akeyless/models/gateway_update_migration.rb', line 720

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



708
709
710
# File 'lib/akeyless/models/gateway_update_migration.rb', line 708

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



556
557
558
559
# File 'lib/akeyless/models/gateway_update_migration.rb', line 556

def valid?
  return false if @target_location.nil?
  true
end