Class: Akeyless::GatewayUpdateProducerArtifactory

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/gateway_update_producer_artifactory.rb

Overview

gatewayUpdateProducerArtifactory is a command that updates artifactory producer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GatewayUpdateProducerArtifactory

Initializes the object



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayUpdateProducerArtifactory` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayUpdateProducerArtifactory`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'artifactory_admin_name')
    self.artifactory_admin_name = attributes[:'artifactory_admin_name']
  end

  if attributes.key?(:'artifactory_admin_pwd')
    self.artifactory_admin_pwd = attributes[:'artifactory_admin_pwd']
  end

  if attributes.key?(:'artifactory_token_audience')
    self.artifactory_token_audience = attributes[:'artifactory_token_audience']
  end

  if attributes.key?(:'artifactory_token_scope')
    self.artifactory_token_scope = attributes[:'artifactory_token_scope']
  end

  if attributes.key?(:'base_url')
    self.base_url = attributes[:'base_url']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '60m'
  end
end

Instance Attribute Details

#artifactory_admin_nameObject

Artifactory Admin Name



20
21
22
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 20

def artifactory_admin_name
  @artifactory_admin_name
end

#artifactory_admin_pwdObject

Artifactory Admin password



23
24
25
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 23

def artifactory_admin_pwd
  @artifactory_admin_pwd
end

#artifactory_token_audienceObject

Token Audience



26
27
28
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 26

def artifactory_token_audience
  @artifactory_token_audience
end

#artifactory_token_scopeObject

Token Scope



29
30
31
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 29

def artifactory_token_scope
  @artifactory_token_scope
end

#base_urlObject

Base URL



32
33
34
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 32

def base_url
  @base_url
end

#nameObject

Producer name



35
36
37
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 35

def name
  @name
end

#new_nameObject

Producer name



38
39
40
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 38

def new_name
  @new_name
end

#producer_encryption_key_nameObject

Dynamic producer encryption key



41
42
43
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 41

def producer_encryption_key_name
  @producer_encryption_key_name
end

#tagsObject

List of the tags attached to this secret



44
45
46
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 44

def tags
  @tags
end

#target_nameObject

Target name



47
48
49
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 47

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



50
51
52
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 50

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



53
54
55
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 53

def uid_token
  @uid_token
end

#user_ttlObject

User TTL



56
57
58
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 56

def user_ttl
  @user_ttl
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 78

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 59

def self.attribute_map
  {
    :'artifactory_admin_name' => :'artifactory-admin-name',
    :'artifactory_admin_pwd' => :'artifactory-admin-pwd',
    :'artifactory_token_audience' => :'artifactory-token-audience',
    :'artifactory_token_scope' => :'artifactory-token-scope',
    :'base_url' => :'base-url',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'user_ttl' => :'user-ttl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



242
243
244
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 242

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 83

def self.openapi_types
  {
    :'artifactory_admin_name' => :'String',
    :'artifactory_admin_pwd' => :'String',
    :'artifactory_token_audience' => :'String',
    :'artifactory_token_scope' => :'String',
    :'base_url' => :'String',
    :'name' => :'String',
    :'new_name' => :'String',
    :'producer_encryption_key_name' => :'String',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'user_ttl' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 209

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      artifactory_admin_name == o.artifactory_admin_name &&
      artifactory_admin_pwd == o.artifactory_admin_pwd &&
      artifactory_token_audience == o.artifactory_token_audience &&
      artifactory_token_scope == o.artifactory_token_scope &&
      base_url == o.base_url &&
      name == o.name &&
      new_name == o.new_name &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      user_ttl == o.user_ttl
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 273

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 344

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 249

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


229
230
231
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 229

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



235
236
237
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 235

def hash
  [artifactory_admin_name, artifactory_admin_pwd, artifactory_token_audience, artifactory_token_scope, base_url, name, new_name, producer_encryption_key_name, tags, target_name, token, uid_token, user_ttl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 181

def list_invalid_properties
  invalid_properties = Array.new
  if @artifactory_token_audience.nil?
    invalid_properties.push('invalid value for "artifactory_token_audience", artifactory_token_audience cannot be nil.')
  end

  if @artifactory_token_scope.nil?
    invalid_properties.push('invalid value for "artifactory_token_scope", artifactory_token_scope cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



320
321
322
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 320

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 326

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



314
315
316
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 314

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



200
201
202
203
204
205
# File 'lib/akeyless/models/gateway_update_producer_artifactory.rb', line 200

def valid?
  return false if @artifactory_token_audience.nil?
  return false if @artifactory_token_scope.nil?
  return false if @name.nil?
  true
end