Class: Akeyless::GatewayUpdateProducerAws

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/gateway_update_producer_aws.rb

Overview

gatewayUpdateProducerAws is a command that Updates aws producer [Deprecated: Use dynamic-secret-update-aws command]

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GatewayUpdateProducerAws

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 272

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayUpdateProducerAws` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayUpdateProducerAws`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_mode')
    self.access_mode = attributes[:'access_mode']
  end

  if attributes.key?(:'admin_rotation_interval_days')
    self.admin_rotation_interval_days = attributes[:'admin_rotation_interval_days']
  else
    self.admin_rotation_interval_days = 0
  end

  if attributes.key?(:'ara_enabled')
    self.ara_enabled = attributes[:'ara_enabled']
  end

  if attributes.key?(:'aws_access_key_id')
    self.aws_access_key_id = attributes[:'aws_access_key_id']
  end

  if attributes.key?(:'aws_access_secret_key')
    self.aws_access_secret_key = attributes[:'aws_access_secret_key']
  end

  if attributes.key?(:'aws_external_id')
    self.aws_external_id = attributes[:'aws_external_id']
  end

  if attributes.key?(:'aws_role_arns')
    self.aws_role_arns = attributes[:'aws_role_arns']
  end

  if attributes.key?(:'aws_user_console_access')
    self.aws_user_console_access = attributes[:'aws_user_console_access']
  else
    self.aws_user_console_access = false
  end

  if attributes.key?(:'aws_user_groups')
    self.aws_user_groups = attributes[:'aws_user_groups']
  end

  if attributes.key?(:'aws_user_policies')
    self.aws_user_policies = attributes[:'aws_user_policies']
  end

  if attributes.key?(:'aws_user_programmatic_access')
    self.aws_user_programmatic_access = attributes[:'aws_user_programmatic_access']
  else
    self.aws_user_programmatic_access = true
  end

  if attributes.key?(:'custom_username_template')
    self.custom_username_template = attributes[:'custom_username_template']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'enable_admin_rotation')
    self.enable_admin_rotation = attributes[:'enable_admin_rotation']
  else
    self.enable_admin_rotation = false
  end

  if attributes.key?(:'enable_agentic_runtime_authority')
    self.enable_agentic_runtime_authority = attributes[:'enable_agentic_runtime_authority']
  end

  if attributes.key?(:'enable_ai_quorum')
    self.enable_ai_quorum = attributes[:'enable_ai_quorum']
  end

  if attributes.key?(:'input_rule')
    if (value = attributes[:'input_rule']).is_a?(Array)
      self.input_rule = value
    end
  end

  if attributes.key?(:'item_custom_fields')
    if (value = attributes[:'item_custom_fields']).is_a?(Hash)
      self.item_custom_fields = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'output_rule')
    if (value = attributes[:'output_rule']).is_a?(Array)
      self.output_rule = value
    end
  end

  if attributes.key?(:'password_length')
    self.password_length = attributes[:'password_length']
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'region')
    self.region = attributes[:'region']
  else
    self.region = 'us-east-2'
  end

  if attributes.key?(:'secure_access_aws_account_id')
    self. = attributes[:'secure_access_aws_account_id']
  end

  if attributes.key?(:'secure_access_aws_native_cli')
    self.secure_access_aws_native_cli = attributes[:'secure_access_aws_native_cli']
  end

  if attributes.key?(:'secure_access_bastion_issuer')
    self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer']
  end

  if attributes.key?(:'secure_access_certificate_issuer')
    self.secure_access_certificate_issuer = attributes[:'secure_access_certificate_issuer']
  end

  if attributes.key?(:'secure_access_delay')
    self.secure_access_delay = attributes[:'secure_access_delay']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_web')
    self.secure_access_web = attributes[:'secure_access_web']
  else
    self.secure_access_web = true
  end

  if attributes.key?(:'secure_access_web_browsing')
    self.secure_access_web_browsing = attributes[:'secure_access_web_browsing']
  else
    self.secure_access_web_browsing = false
  end

  if attributes.key?(:'secure_access_web_proxy')
    self.secure_access_web_proxy = attributes[:'secure_access_web_proxy']
  else
    self.secure_access_web_proxy = false
  end

  if attributes.key?(:'session_tags')
    self.session_tags = attributes[:'session_tags']
  end

  if attributes.key?(:'skip_dry_run')
    self.skip_dry_run = attributes[:'skip_dry_run']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'transitive_tag_keys')
    self.transitive_tag_keys = attributes[:'transitive_tag_keys']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'use_capital_letters')
    self.use_capital_letters = attributes[:'use_capital_letters']
  end

  if attributes.key?(:'use_lower_letters')
    self.use_lower_letters = attributes[:'use_lower_letters']
  end

  if attributes.key?(:'use_numbers')
    self.use_numbers = attributes[:'use_numbers']
  end

  if attributes.key?(:'use_special_characters')
    self.use_special_characters = attributes[:'use_special_characters']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '60m'
  end
end

Instance Attribute Details

#access_modeObject

Returns the value of attribute access_mode.



19
20
21
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 19

def access_mode
  @access_mode
end

#admin_rotation_interval_daysObject

Admin credentials rotation interval (days)



22
23
24
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 22

def admin_rotation_interval_days
  @admin_rotation_interval_days
end

#ara_enabledObject

Enable or disable Agentic Runtime Authority rule enforcement for this item. Mirrors commands.AgenticRulesParams.AraEnabled.



25
26
27
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 25

def ara_enabled
  @ara_enabled
end

#aws_access_key_idObject

Access Key ID



28
29
30
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 28

def aws_access_key_id
  @aws_access_key_id
end

#aws_access_secret_keyObject

Secret Access Key



31
32
33
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 31

def aws_access_secret_key
  @aws_access_secret_key
end

#aws_external_idObject

The AWS External ID associated with the AWS role (relevant only for assume_role mode)



34
35
36
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 34

def aws_external_id
  @aws_external_id
end

#aws_role_arnsObject

AWS Role ARNs to be used in the Assume Role operation (relevant only for assume_role mode)



37
38
39
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 37

def aws_role_arns
  @aws_role_arns
end

#aws_user_console_accessObject

AWS User console access



40
41
42
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 40

def aws_user_console_access
  @aws_user_console_access
end

#aws_user_groupsObject

AWS User groups



43
44
45
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 43

def aws_user_groups
  @aws_user_groups
end

#aws_user_policiesObject

AWS User policies



46
47
48
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 46

def aws_user_policies
  @aws_user_policies
end

#aws_user_programmatic_accessObject

Enable AWS User programmatic access



49
50
51
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 49

def aws_user_programmatic_access
  @aws_user_programmatic_access
end

#custom_username_templateObject

Customize how temporary usernames are generated using go template



52
53
54
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 52

def custom_username_template
  @custom_username_template
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



55
56
57
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 55

def delete_protection
  @delete_protection
end

#enable_admin_rotationObject

Automatic admin credentials rotation



58
59
60
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 58

def enable_admin_rotation
  @enable_admin_rotation
end

#enable_agentic_runtime_authorityObject

EnableAra is the documented spelling of AraEnabled; --ara-enabled shipped first and stays as an undocumented alias.



61
62
63
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 61

def enable_agentic_runtime_authority
  @enable_agentic_runtime_authority
end

#enable_ai_quorumObject

Turns on AI Quorum checks for this item.



64
65
66
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 64

def enable_ai_quorum
  @enable_ai_quorum
end

#input_ruleObject

Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).



67
68
69
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 67

def input_rule
  @input_rule
end

#item_custom_fieldsObject

Additional custom fields to associate with the item



70
71
72
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 70

def item_custom_fields
  @item_custom_fields
end

#jsonObject

Set output format to JSON



73
74
75
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 73

def json
  @json
end

#nameObject

Dynamic secret name



76
77
78
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 76

def name
  @name
end

#new_nameObject

Dynamic secret name



79
80
81
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 79

def new_name
  @new_name
end

#output_ruleObject

Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)



82
83
84
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 82

def output_rule
  @output_rule
end

#password_lengthObject

The length of the password to be generated



85
86
87
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 85

def password_length
  @password_length
end

#producer_encryption_key_nameObject

Dynamic producer encryption key



88
89
90
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 88

def producer_encryption_key_name
  @producer_encryption_key_name
end

#regionObject

Region



91
92
93
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 91

def region
  @region
end

#secure_access_aws_account_idObject

The AWS account id



94
95
96
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 94

def 
  @secure_access_aws_account_id
end

#secure_access_aws_native_cliObject

The AWS native cli



97
98
99
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 97

def secure_access_aws_native_cli
  @secure_access_aws_native_cli
end

#secure_access_bastion_issuerObject

Deprecated. use secure-access-certificate-issuer



100
101
102
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 100

def secure_access_bastion_issuer
  @secure_access_bastion_issuer
end

#secure_access_certificate_issuerObject

Path to the SSH Certificate Issuer for your Akeyless Secure Access



103
104
105
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 103

def secure_access_certificate_issuer
  @secure_access_certificate_issuer
end

#secure_access_delayObject

The delay duration, in seconds, to wait after generating just-in-time credentials. Accepted range: 0-120 seconds



106
107
108
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 106

def secure_access_delay
  @secure_access_delay
end

#secure_access_enableObject

Enable/Disable secure remote access [true/false]



109
110
111
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 109

def secure_access_enable
  @secure_access_enable
end

#secure_access_webObject

Enable Web Secure Remote Access



112
113
114
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 112

def secure_access_web
  @secure_access_web
end

#secure_access_web_browsingObject

Secure browser via Akeyless's Secure Remote Access (SRA)



115
116
117
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 115

def secure_access_web_browsing
  @secure_access_web_browsing
end

#secure_access_web_proxyObject

Web-Proxy via Akeyless's Secure Remote Access (SRA)



118
119
120
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 118

def secure_access_web_proxy
  @secure_access_web_proxy
end

#session_tagsObject

String of Key value session tags comma separated, relevant only for Assumed Role



121
122
123
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 121

def session_tags
  @session_tags
end

#skip_dry_runObject

If set, dry-run will be skipped [true/false]



124
125
126
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 124

def skip_dry_run
  @skip_dry_run
end

#tagsObject

Add tags attached to this object



127
128
129
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 127

def tags
  @tags
end

#target_nameObject

Target name



130
131
132
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 130

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



133
134
135
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 133

def token
  @token
end

#transitive_tag_keysObject

String of transitive tag keys space separated, relevant only for Assumed Role



136
137
138
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 136

def transitive_tag_keys
  @transitive_tag_keys
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



139
140
141
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 139

def uid_token
  @uid_token
end

#use_capital_lettersObject

Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). [true/false]



142
143
144
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 142

def use_capital_letters
  @use_capital_letters
end

#use_lower_lettersObject

Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). [true/false]



145
146
147
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 145

def use_lower_letters
  @use_lower_letters
end

#use_numbersObject

Specifies whether the generated temporary password must contain at least one numeric character (0 to 9). [true/false]



148
149
150
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 148

def use_numbers
  @use_numbers
end

#use_special_charactersObject

Returns the value of attribute use_special_characters.



150
151
152
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 150

def use_special_characters
  @use_special_characters
end

#user_ttlObject

User TTL



153
154
155
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 153

def user_ttl
  @user_ttl
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 612

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



208
209
210
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 208

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 156

def self.attribute_map
  {
    :'access_mode' => :'access-mode',
    :'admin_rotation_interval_days' => :'admin-rotation-interval-days',
    :'ara_enabled' => :'ara-enabled',
    :'aws_access_key_id' => :'aws-access-key-id',
    :'aws_access_secret_key' => :'aws-access-secret-key',
    :'aws_external_id' => :'aws-external-id',
    :'aws_role_arns' => :'aws-role-arns',
    :'aws_user_console_access' => :'aws-user-console-access',
    :'aws_user_groups' => :'aws-user-groups',
    :'aws_user_policies' => :'aws-user-policies',
    :'aws_user_programmatic_access' => :'aws-user-programmatic-access',
    :'custom_username_template' => :'custom-username-template',
    :'delete_protection' => :'delete_protection',
    :'enable_admin_rotation' => :'enable-admin-rotation',
    :'enable_agentic_runtime_authority' => :'enable-agentic-runtime-authority',
    :'enable_ai_quorum' => :'enable-ai-quorum',
    :'input_rule' => :'input-rule',
    :'item_custom_fields' => :'item-custom-fields',
    :'json' => :'json',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'output_rule' => :'output-rule',
    :'password_length' => :'password-length',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'region' => :'region',
    :'secure_access_aws_account_id' => :'secure-access-aws-account-id',
    :'secure_access_aws_native_cli' => :'secure-access-aws-native-cli',
    :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer',
    :'secure_access_certificate_issuer' => :'secure-access-certificate-issuer',
    :'secure_access_delay' => :'secure-access-delay',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_web' => :'secure-access-web',
    :'secure_access_web_browsing' => :'secure-access-web-browsing',
    :'secure_access_web_proxy' => :'secure-access-web-proxy',
    :'session_tags' => :'session-tags',
    :'skip_dry_run' => :'skip-dry-run',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'transitive_tag_keys' => :'transitive-tag-keys',
    :'uid_token' => :'uid-token',
    :'use_capital_letters' => :'use-capital-letters',
    :'use_lower_letters' => :'use-lower-letters',
    :'use_numbers' => :'use-numbers',
    :'use_special_characters' => :'use-special-characters',
    :'user_ttl' => :'user-ttl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 588

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



265
266
267
268
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 265

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 213

def self.openapi_types
  {
    :'access_mode' => :'String',
    :'admin_rotation_interval_days' => :'Integer',
    :'ara_enabled' => :'Boolean',
    :'aws_access_key_id' => :'String',
    :'aws_access_secret_key' => :'String',
    :'aws_external_id' => :'String',
    :'aws_role_arns' => :'String',
    :'aws_user_console_access' => :'Boolean',
    :'aws_user_groups' => :'String',
    :'aws_user_policies' => :'String',
    :'aws_user_programmatic_access' => :'Boolean',
    :'custom_username_template' => :'String',
    :'delete_protection' => :'String',
    :'enable_admin_rotation' => :'Boolean',
    :'enable_agentic_runtime_authority' => :'Boolean',
    :'enable_ai_quorum' => :'Boolean',
    :'input_rule' => :'Array<String>',
    :'item_custom_fields' => :'Hash<String, String>',
    :'json' => :'Boolean',
    :'name' => :'String',
    :'new_name' => :'String',
    :'output_rule' => :'Array<String>',
    :'password_length' => :'String',
    :'producer_encryption_key_name' => :'String',
    :'region' => :'String',
    :'secure_access_aws_account_id' => :'String',
    :'secure_access_aws_native_cli' => :'Boolean',
    :'secure_access_bastion_issuer' => :'String',
    :'secure_access_certificate_issuer' => :'String',
    :'secure_access_delay' => :'Integer',
    :'secure_access_enable' => :'String',
    :'secure_access_web' => :'Boolean',
    :'secure_access_web_browsing' => :'Boolean',
    :'secure_access_web_proxy' => :'Boolean',
    :'session_tags' => :'String',
    :'skip_dry_run' => :'Boolean',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'transitive_tag_keys' => :'String',
    :'uid_token' => :'String',
    :'use_capital_letters' => :'String',
    :'use_lower_letters' => :'String',
    :'use_numbers' => :'String',
    :'use_special_characters' => :'String',
    :'user_ttl' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 522

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_mode == o.access_mode &&
      admin_rotation_interval_days == o.admin_rotation_interval_days &&
      ara_enabled == o.ara_enabled &&
      aws_access_key_id == o.aws_access_key_id &&
      aws_access_secret_key == o.aws_access_secret_key &&
      aws_external_id == o.aws_external_id &&
      aws_role_arns == o.aws_role_arns &&
      aws_user_console_access == o.aws_user_console_access &&
      aws_user_groups == o.aws_user_groups &&
      aws_user_policies == o.aws_user_policies &&
      aws_user_programmatic_access == o.aws_user_programmatic_access &&
      custom_username_template == o.custom_username_template &&
      delete_protection == o.delete_protection &&
      enable_admin_rotation == o.enable_admin_rotation &&
      enable_agentic_runtime_authority == o.enable_agentic_runtime_authority &&
      enable_ai_quorum == o.enable_ai_quorum &&
      input_rule == o.input_rule &&
      item_custom_fields == o.item_custom_fields &&
      json == o.json &&
      name == o.name &&
      new_name == o.new_name &&
      output_rule == o.output_rule &&
      password_length == o.password_length &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      region == o.region &&
       == o. &&
      secure_access_aws_native_cli == o.secure_access_aws_native_cli &&
      secure_access_bastion_issuer == o.secure_access_bastion_issuer &&
      secure_access_certificate_issuer == o.secure_access_certificate_issuer &&
      secure_access_delay == o.secure_access_delay &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_web == o.secure_access_web &&
      secure_access_web_browsing == o.secure_access_web_browsing &&
      secure_access_web_proxy == o.secure_access_web_proxy &&
      session_tags == o.session_tags &&
      skip_dry_run == o.skip_dry_run &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      transitive_tag_keys == o.transitive_tag_keys &&
      uid_token == o.uid_token &&
      use_capital_letters == o.use_capital_letters &&
      use_lower_letters == o.use_lower_letters &&
      use_numbers == o.use_numbers &&
      use_special_characters == o.use_special_characters &&
      user_ttl == o.user_ttl
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



683
684
685
686
687
688
689
690
691
692
693
694
695
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 683

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


575
576
577
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 575

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



581
582
583
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 581

def hash
  [access_mode, admin_rotation_interval_days, ara_enabled, aws_access_key_id, aws_access_secret_key, aws_external_id, aws_role_arns, aws_user_console_access, aws_user_groups, aws_user_policies, aws_user_programmatic_access, custom_username_template, delete_protection, enable_admin_rotation, enable_agentic_runtime_authority, enable_ai_quorum, input_rule, item_custom_fields, json, name, new_name, output_rule, password_length, producer_encryption_key_name, region, , secure_access_aws_native_cli, secure_access_bastion_issuer, secure_access_certificate_issuer, secure_access_delay, secure_access_enable, secure_access_web, secure_access_web_browsing, secure_access_web_proxy, session_tags, skip_dry_run, tags, target_name, token, transitive_tag_keys, uid_token, use_capital_letters, use_lower_letters, use_numbers, use_special_characters, user_ttl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



502
503
504
505
506
507
508
509
510
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 502

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



659
660
661
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 659

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



665
666
667
668
669
670
671
672
673
674
675
676
677
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 665

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



653
654
655
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 653

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



514
515
516
517
518
# File 'lib/akeyless/models/gateway_update_producer_aws.rb', line 514

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end