Class: Akeyless::GatewayUpdateProducerCertificateAutomation

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/gateway_update_producer_certificate_automation.rb

Overview

gatewayUpdateProducerCertificateAutomation is a command that updates a Certificate Automation dynamic secret producer to dynamically update certificates generated by Venafi or have Akeyless generated certificates using PKI be monitored by Venafi

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GatewayUpdateProducerCertificateAutomation

Initializes the object



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 159

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayUpdateProducerCertificateAutomation` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayUpdateProducerCertificateAutomation`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'admin_rotation_interval_days')
    self.admin_rotation_interval_days = attributes[:'admin_rotation_interval_days']
  else
    self.admin_rotation_interval_days = 0
  end

  if attributes.key?(:'allow_subdomains')
    self.allow_subdomains = attributes[:'allow_subdomains']
  end

  if attributes.key?(:'allowed_domains')
    if (value = attributes[:'allowed_domains']).is_a?(Array)
      self.allowed_domains = value
    end
  end

  if attributes.key?(:'auto_generated_folder')
    self.auto_generated_folder = attributes[:'auto_generated_folder']
  end

  if attributes.key?(:'enable_admin_rotation')
    self.enable_admin_rotation = attributes[:'enable_admin_rotation']
  else
    self.enable_admin_rotation = false
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'root_first_in_chain')
    self.root_first_in_chain = attributes[:'root_first_in_chain']
  end

  if attributes.key?(:'sign_using_akeyless_pki')
    self.sign_using_akeyless_pki = attributes[:'sign_using_akeyless_pki']
  end

  if attributes.key?(:'signer_key_name')
    self.signer_key_name = attributes[:'signer_key_name']
  end

  if attributes.key?(:'store_private_key')
    self.store_private_key = attributes[:'store_private_key']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  end

  if attributes.key?(:'venafi_api_key')
    self.venafi_api_key = attributes[:'venafi_api_key']
  end

  if attributes.key?(:'venafi_baseurl')
    self.venafi_baseurl = attributes[:'venafi_baseurl']
  end

  if attributes.key?(:'venafi_password')
    self.venafi_password = attributes[:'venafi_password']
  end

  if attributes.key?(:'venafi_use_tpp')
    self.venafi_use_tpp = attributes[:'venafi_use_tpp']
  end

  if attributes.key?(:'venafi_username')
    self.venafi_username = attributes[:'venafi_username']
  end

  if attributes.key?(:'venafi_zone')
    self.venafi_zone = attributes[:'venafi_zone']
  end
end

Instance Attribute Details

#admin_rotation_interval_daysObject

Admin credentials rotation interval (days)



20
21
22
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 20

def admin_rotation_interval_days
  @admin_rotation_interval_days
end

#allow_subdomainsObject

Allow subdomains



23
24
25
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 23

def allow_subdomains
  @allow_subdomains
end

#allowed_domainsObject

Allowed domains



26
27
28
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 26

def allowed_domains
  @allowed_domains
end

#auto_generated_folderObject

Auto generated folder



29
30
31
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 29

def auto_generated_folder
  @auto_generated_folder
end

#enable_admin_rotationObject

Automatic admin credentials rotation



32
33
34
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 32

def enable_admin_rotation
  @enable_admin_rotation
end

#nameObject

Producer name



35
36
37
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 35

def name
  @name
end

#new_nameObject

Producer name



38
39
40
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 38

def new_name
  @new_name
end

#producer_encryption_key_nameObject

Dynamic producer encryption key



41
42
43
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 41

def producer_encryption_key_name
  @producer_encryption_key_name
end

#root_first_in_chainObject

Root first in chain



44
45
46
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 44

def root_first_in_chain
  @root_first_in_chain
end

#sign_using_akeyless_pkiObject

Use Akeyless PKI issuer or Venafi issuer



47
48
49
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 47

def sign_using_akeyless_pki
  @sign_using_akeyless_pki
end

#signer_key_nameObject

Signer key name



50
51
52
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 50

def signer_key_name
  @signer_key_name
end

#store_private_keyObject

Store private key



53
54
55
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 53

def store_private_key
  @store_private_key
end

#tagsObject

List of the tags attached to this secret



56
57
58
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 56

def tags
  @tags
end

#target_nameObject

Target name



59
60
61
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 59

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



62
63
64
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 62

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



65
66
67
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 65

def uid_token
  @uid_token
end

#user_ttlObject

User TTL in time.Duration format (2160h / 129600m / etc...). When using sign-using-akeyless-pki certificates created will have this validity period, otherwise the user-ttl is taken from the Validity Period field of the Zone's' Issuing Template. When using cert-manager it is advised to have a TTL of above 60 days (1440h). For more information - https://cert-manager.io/docs/usage/certificate/



68
69
70
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 68

def user_ttl
  @user_ttl
end

#venafi_api_keyObject

Venafi API key



71
72
73
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 71

def venafi_api_key
  @venafi_api_key
end

#venafi_baseurlObject

Venafi Baseurl



74
75
76
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 74

def venafi_baseurl
  @venafi_baseurl
end

#venafi_passwordObject

Venafi Password



77
78
79
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 77

def venafi_password
  @venafi_password
end

#venafi_use_tppObject

Venafi using TPP



80
81
82
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 80

def venafi_use_tpp
  @venafi_use_tpp
end

#venafi_usernameObject

Venafi Username



83
84
85
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 83

def venafi_username
  @venafi_username
end

#venafi_zoneObject

Venafi Zone



86
87
88
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 86

def venafi_zone
  @venafi_zone
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



118
119
120
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 118

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 89

def self.attribute_map
  {
    :'admin_rotation_interval_days' => :'admin-rotation-interval-days',
    :'allow_subdomains' => :'allow-subdomains',
    :'allowed_domains' => :'allowed-domains',
    :'auto_generated_folder' => :'auto-generated-folder',
    :'enable_admin_rotation' => :'enable-admin-rotation',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'root_first_in_chain' => :'root-first-in-chain',
    :'sign_using_akeyless_pki' => :'sign-using-akeyless-pki',
    :'signer_key_name' => :'signer-key-name',
    :'store_private_key' => :'store-private-key',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'user_ttl' => :'user-ttl',
    :'venafi_api_key' => :'venafi-api-key',
    :'venafi_baseurl' => :'venafi-baseurl',
    :'venafi_password' => :'venafi-password',
    :'venafi_use_tpp' => :'venafi-use-tpp',
    :'venafi_username' => :'venafi-username',
    :'venafi_zone' => :'venafi-zone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



336
337
338
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 336

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



152
153
154
155
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 152

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 123

def self.openapi_types
  {
    :'admin_rotation_interval_days' => :'Integer',
    :'allow_subdomains' => :'Boolean',
    :'allowed_domains' => :'Array<String>',
    :'auto_generated_folder' => :'String',
    :'enable_admin_rotation' => :'Boolean',
    :'name' => :'String',
    :'new_name' => :'String',
    :'producer_encryption_key_name' => :'String',
    :'root_first_in_chain' => :'Boolean',
    :'sign_using_akeyless_pki' => :'Boolean',
    :'signer_key_name' => :'String',
    :'store_private_key' => :'Boolean',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'user_ttl' => :'String',
    :'venafi_api_key' => :'String',
    :'venafi_baseurl' => :'String',
    :'venafi_password' => :'String',
    :'venafi_use_tpp' => :'Boolean',
    :'venafi_username' => :'String',
    :'venafi_zone' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 293

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      admin_rotation_interval_days == o.admin_rotation_interval_days &&
      allow_subdomains == o.allow_subdomains &&
      allowed_domains == o.allowed_domains &&
      auto_generated_folder == o.auto_generated_folder &&
      enable_admin_rotation == o.enable_admin_rotation &&
      name == o.name &&
      new_name == o.new_name &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      root_first_in_chain == o.root_first_in_chain &&
      sign_using_akeyless_pki == o.sign_using_akeyless_pki &&
      signer_key_name == o.signer_key_name &&
      store_private_key == o.store_private_key &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      user_ttl == o.user_ttl &&
      venafi_api_key == o.venafi_api_key &&
      venafi_baseurl == o.venafi_baseurl &&
      venafi_password == o.venafi_password &&
      venafi_use_tpp == o.venafi_use_tpp &&
      venafi_username == o.venafi_username &&
      venafi_zone == o.venafi_zone
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 367

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 438

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 343

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


323
324
325
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 323

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



329
330
331
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 329

def hash
  [admin_rotation_interval_days, allow_subdomains, allowed_domains, auto_generated_folder, enable_admin_rotation, name, new_name, producer_encryption_key_name, root_first_in_chain, sign_using_akeyless_pki, signer_key_name, store_private_key, tags, target_name, token, uid_token, user_ttl, venafi_api_key, venafi_baseurl, venafi_password, venafi_use_tpp, venafi_username, venafi_zone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



275
276
277
278
279
280
281
282
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 275

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



414
415
416
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 414

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 420

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



408
409
410
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 408

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



286
287
288
289
# File 'lib/akeyless/models/gateway_update_producer_certificate_automation.rb', line 286

def valid?
  return false if @name.nil?
  true
end