Class: Akeyless::GatewayUpdateProducerGithub

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/gateway_update_producer_github.rb

Overview

gatewayUpdateProducerGithub is a command that updates github producer [Deprecated: Use dynamic-secret-update-github command]

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GatewayUpdateProducerGithub

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 154

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayUpdateProducerGithub` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayUpdateProducerGithub`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ara_enabled')
    self.ara_enabled = attributes[:'ara_enabled']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'github_app_id')
    self.github_app_id = attributes[:'github_app_id']
  end

  if attributes.key?(:'github_app_private_key')
    self.github_app_private_key = attributes[:'github_app_private_key']
  end

  if attributes.key?(:'github_base_url')
    self.github_base_url = attributes[:'github_base_url']
  else
    self.github_base_url = 'https://api.github.com/'
  end

  if attributes.key?(:'input_rule')
    if (value = attributes[:'input_rule']).is_a?(Array)
      self.input_rule = value
    end
  end

  if attributes.key?(:'installation_id')
    self.installation_id = attributes[:'installation_id']
  end

  if attributes.key?(:'installation_organization')
    self.installation_organization = attributes[:'installation_organization']
  end

  if attributes.key?(:'installation_repository')
    self.installation_repository = attributes[:'installation_repository']
  end

  if attributes.key?(:'item_custom_fields')
    if (value = attributes[:'item_custom_fields']).is_a?(Hash)
      self.item_custom_fields = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'output_rule')
    if (value = attributes[:'output_rule']).is_a?(Array)
      self.output_rule = value
    end
  end

  if attributes.key?(:'skip_dry_run')
    self.skip_dry_run = attributes[:'skip_dry_run']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'token_permissions')
    if (value = attributes[:'token_permissions']).is_a?(Array)
      self.token_permissions = value
    end
  end

  if attributes.key?(:'token_repositories')
    if (value = attributes[:'token_repositories']).is_a?(Array)
      self.token_repositories = value
    end
  end

  if attributes.key?(:'token_ttl')
    self.token_ttl = attributes[:'token_ttl']
  else
    self.token_ttl = '60m'
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end
end

Instance Attribute Details

#ara_enabledObject

Enable or disable Agentic Runtime Authority rule enforcement for this item. Mirrors commands.AgenticRulesParams.AraEnabled.



20
21
22
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 20

def ara_enabled
  @ara_enabled
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



23
24
25
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 23

def delete_protection
  @delete_protection
end

#github_app_idObject

Github app id



26
27
28
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 26

def github_app_id
  @github_app_id
end

#github_app_private_keyObject

App private key



29
30
31
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 29

def github_app_private_key
  @github_app_private_key
end

#github_base_urlObject

Base URL



32
33
34
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 32

def github_base_url
  @github_base_url
end

#input_ruleObject

Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).



35
36
37
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 35

def input_rule
  @input_rule
end

#installation_idObject

GitHub application installation id



38
39
40
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 38

def installation_id
  @installation_id
end

#installation_organizationObject

Optional, mutually exclusive with installation id, GitHub organization name



41
42
43
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 41

def installation_organization
  @installation_organization
end

#installation_repositoryObject

Optional, mutually exclusive with installation id, GitHub repository '/'



44
45
46
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 44

def installation_repository
  @installation_repository
end

#item_custom_fieldsObject

Additional custom fields to associate with the item



47
48
49
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 47

def item_custom_fields
  @item_custom_fields
end

#jsonObject

Set output format to JSON



50
51
52
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 50

def json
  @json
end

#nameObject

Dynamic secret name



53
54
55
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 53

def name
  @name
end

#new_nameObject

Dynamic secret name



56
57
58
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 56

def new_name
  @new_name
end

#output_ruleObject

Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)



59
60
61
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 59

def output_rule
  @output_rule
end

#skip_dry_runObject

If set, dry-run will be skipped



62
63
64
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 62

def skip_dry_run
  @skip_dry_run
end

#tagsObject

Add tags attached to this object



65
66
67
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 65

def tags
  @tags
end

#target_nameObject

Target name



68
69
70
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 68

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



71
72
73
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 71

def token
  @token
end

#token_permissionsObject

Optional - installation token's allowed permissions



74
75
76
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 74

def token_permissions
  @token_permissions
end

#token_repositoriesObject

Optional - installation token's allowed repositories



77
78
79
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 77

def token_repositories
  @token_repositories
end

#token_ttlObject

Token TTL



80
81
82
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 80

def token_ttl
  @token_ttl
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



83
84
85
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 83

def uid_token
  @uid_token
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 364

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



114
115
116
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 114

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 86

def self.attribute_map
  {
    :'ara_enabled' => :'ara-enabled',
    :'delete_protection' => :'delete_protection',
    :'github_app_id' => :'github-app-id',
    :'github_app_private_key' => :'github-app-private-key',
    :'github_base_url' => :'github-base-url',
    :'input_rule' => :'input-rule',
    :'installation_id' => :'installation-id',
    :'installation_organization' => :'installation-organization',
    :'installation_repository' => :'installation-repository',
    :'item_custom_fields' => :'item-custom-fields',
    :'json' => :'json',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'output_rule' => :'output-rule',
    :'skip_dry_run' => :'skip_dry_run',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'token_permissions' => :'token-permissions',
    :'token_repositories' => :'token-repositories',
    :'token_ttl' => :'token-ttl',
    :'uid_token' => :'uid-token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 340

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



147
148
149
150
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 147

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 119

def self.openapi_types
  {
    :'ara_enabled' => :'Boolean',
    :'delete_protection' => :'String',
    :'github_app_id' => :'Integer',
    :'github_app_private_key' => :'String',
    :'github_base_url' => :'String',
    :'input_rule' => :'Array<String>',
    :'installation_id' => :'Integer',
    :'installation_organization' => :'String',
    :'installation_repository' => :'String',
    :'item_custom_fields' => :'Hash<String, String>',
    :'json' => :'Boolean',
    :'name' => :'String',
    :'new_name' => :'String',
    :'output_rule' => :'Array<String>',
    :'skip_dry_run' => :'String',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'token_permissions' => :'Array<String>',
    :'token_repositories' => :'Array<String>',
    :'token_ttl' => :'String',
    :'uid_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 298

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ara_enabled == o.ara_enabled &&
      delete_protection == o.delete_protection &&
      github_app_id == o.github_app_id &&
      github_app_private_key == o.github_app_private_key &&
      github_base_url == o.github_base_url &&
      input_rule == o.input_rule &&
      installation_id == o.installation_id &&
      installation_organization == o.installation_organization &&
      installation_repository == o.installation_repository &&
      item_custom_fields == o.item_custom_fields &&
      json == o.json &&
      name == o.name &&
      new_name == o.new_name &&
      output_rule == o.output_rule &&
      skip_dry_run == o.skip_dry_run &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      token_permissions == o.token_permissions &&
      token_repositories == o.token_repositories &&
      token_ttl == o.token_ttl &&
      uid_token == o.uid_token
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



435
436
437
438
439
440
441
442
443
444
445
446
447
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 435

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


327
328
329
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 327

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



333
334
335
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 333

def hash
  [ara_enabled, delete_protection, github_app_id, github_app_private_key, github_base_url, input_rule, installation_id, installation_organization, installation_repository, item_custom_fields, json, name, new_name, output_rule, skip_dry_run, tags, target_name, token, token_permissions, token_repositories, token_ttl, uid_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



278
279
280
281
282
283
284
285
286
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 278

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



411
412
413
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 411

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



417
418
419
420
421
422
423
424
425
426
427
428
429
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 417

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



405
406
407
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 405

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



290
291
292
293
294
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 290

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end