Class: Akeyless::GatewayUpdateProducerGke

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/gateway_update_producer_gke.rb

Overview

gatewayUpdateProducerGke is a command that updates gke producer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GatewayUpdateProducerGke

Initializes the object



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 129

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayUpdateProducerGke` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayUpdateProducerGke`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'gke_account_key')
    self. = attributes[:'gke_account_key']
  end

  if attributes.key?(:'gke_cluster_cert')
    self.gke_cluster_cert = attributes[:'gke_cluster_cert']
  end

  if attributes.key?(:'gke_cluster_endpoint')
    self.gke_cluster_endpoint = attributes[:'gke_cluster_endpoint']
  end

  if attributes.key?(:'gke_cluster_name')
    self.gke_cluster_name = attributes[:'gke_cluster_name']
  end

  if attributes.key?(:'gke_service_account_email')
    self. = attributes[:'gke_service_account_email']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'secure_access_allow_port_forwading')
    self.secure_access_allow_port_forwading = attributes[:'secure_access_allow_port_forwading']
  end

  if attributes.key?(:'secure_access_bastion_issuer')
    self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer']
  end

  if attributes.key?(:'secure_access_cluster_endpoint')
    self.secure_access_cluster_endpoint = attributes[:'secure_access_cluster_endpoint']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_web')
    self.secure_access_web = attributes[:'secure_access_web']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '60m'
  end
end

Instance Attribute Details

#gke_account_keyObject

GKE Service Account key file path



20
21
22
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 20

def 
  
end

#gke_cluster_certObject

GKE cluster CA certificate



23
24
25
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 23

def gke_cluster_cert
  @gke_cluster_cert
end

#gke_cluster_endpointObject

GKE cluster URL endpoint



26
27
28
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 26

def gke_cluster_endpoint
  @gke_cluster_endpoint
end

#gke_cluster_nameObject

GKE cluster name



29
30
31
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 29

def gke_cluster_name
  @gke_cluster_name
end

#gke_service_account_emailObject

GKE service account email



32
33
34
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 32

def 
  
end

#nameObject

Producer name



35
36
37
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 35

def name
  @name
end

#new_nameObject

Producer name



38
39
40
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 38

def new_name
  @new_name
end

#producer_encryption_key_nameObject

Dynamic producer encryption key



41
42
43
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 41

def producer_encryption_key_name
  @producer_encryption_key_name
end

#secure_access_allow_port_forwadingObject

Returns the value of attribute secure_access_allow_port_forwading.



43
44
45
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 43

def secure_access_allow_port_forwading
  @secure_access_allow_port_forwading
end

#secure_access_bastion_issuerObject

Returns the value of attribute secure_access_bastion_issuer.



45
46
47
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 45

def secure_access_bastion_issuer
  @secure_access_bastion_issuer
end

#secure_access_cluster_endpointObject

Returns the value of attribute secure_access_cluster_endpoint.



47
48
49
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 47

def secure_access_cluster_endpoint
  @secure_access_cluster_endpoint
end

#secure_access_enableObject

Returns the value of attribute secure_access_enable.



49
50
51
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 49

def secure_access_enable
  @secure_access_enable
end

#secure_access_webObject

Returns the value of attribute secure_access_web.



51
52
53
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 51

def secure_access_web
  @secure_access_web
end

#tagsObject

List of the tags attached to this secret



54
55
56
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 54

def tags
  @tags
end

#target_nameObject

Target name



57
58
59
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 57

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



60
61
62
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 60

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



63
64
65
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 63

def uid_token
  @uid_token
end

#user_ttlObject

User TTL



66
67
68
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 66

def user_ttl
  @user_ttl
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



93
94
95
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 93

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 69

def self.attribute_map
  {
    :'gke_account_key' => :'gke-account-key',
    :'gke_cluster_cert' => :'gke-cluster-cert',
    :'gke_cluster_endpoint' => :'gke-cluster-endpoint',
    :'gke_cluster_name' => :'gke-cluster-name',
    :'gke_service_account_email' => :'gke-service-account-email',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'secure_access_allow_port_forwading' => :'secure-access-allow-port-forwading',
    :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer',
    :'secure_access_cluster_endpoint' => :'secure-access-cluster-endpoint',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_web' => :'secure-access-web',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'user_ttl' => :'user-ttl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



277
278
279
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 277

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



122
123
124
125
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 122

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 98

def self.openapi_types
  {
    :'gke_account_key' => :'String',
    :'gke_cluster_cert' => :'String',
    :'gke_cluster_endpoint' => :'String',
    :'gke_cluster_name' => :'String',
    :'gke_service_account_email' => :'String',
    :'name' => :'String',
    :'new_name' => :'String',
    :'producer_encryption_key_name' => :'String',
    :'secure_access_allow_port_forwading' => :'Boolean',
    :'secure_access_bastion_issuer' => :'String',
    :'secure_access_cluster_endpoint' => :'String',
    :'secure_access_enable' => :'String',
    :'secure_access_web' => :'Boolean',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'user_ttl' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 239

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      gke_cluster_cert == o.gke_cluster_cert &&
      gke_cluster_endpoint == o.gke_cluster_endpoint &&
      gke_cluster_name == o.gke_cluster_name &&
       == o. &&
      name == o.name &&
      new_name == o.new_name &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      secure_access_allow_port_forwading == o.secure_access_allow_port_forwading &&
      secure_access_bastion_issuer == o.secure_access_bastion_issuer &&
      secure_access_cluster_endpoint == o.secure_access_cluster_endpoint &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_web == o.secure_access_web &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      user_ttl == o.user_ttl
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 308

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 379

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 284

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


264
265
266
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 264

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



270
271
272
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 270

def hash
  [, gke_cluster_cert, gke_cluster_endpoint, gke_cluster_name, , name, new_name, producer_encryption_key_name, secure_access_allow_port_forwading, secure_access_bastion_issuer, secure_access_cluster_endpoint, secure_access_enable, secure_access_web, tags, target_name, token, uid_token, user_ttl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



221
222
223
224
225
226
227
228
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 221

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



355
356
357
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 355

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 361

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



349
350
351
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 349

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



232
233
234
235
# File 'lib/akeyless/models/gateway_update_producer_gke.rb', line 232

def valid?
  return false if @name.nil?
  true
end