Class: Akeyless::GatewayUpdateProducerLdap
- Inherits:
-
Object
- Object
- Akeyless::GatewayUpdateProducerLdap
- Defined in:
- lib/akeyless/models/gateway_update_producer_ldap.rb
Overview
gatewayUpdateProducerLdap is a command that updates ldap producer [Deprecated: Use dynamic-secret-update-ldap command]
Instance Attribute Summary collapse
-
#bind_dn ⇒ Object
Bind DN.
-
#bind_dn_password ⇒ Object
Bind DN Password.
-
#custom_username_template ⇒ Object
Customize how temporary usernames are generated using go template.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#external_username ⇒ Object
Externally provided username [true/false].
-
#fixed_user_claim_keyname ⇒ Object
For externally provided users, denotes the key-name of IdP claim to extract the username from (relevant only for external-username=true).
-
#group_dn ⇒ Object
Group DN which the temporary user should be added.
-
#host_provider ⇒ Object
Host provider type [explicit/target], Default Host provider is explicit, Relevant only for Secure Remote Access of ssh cert issuer, ldap rotated secret and ldap dynamic secret.
-
#input_rule ⇒ Object
Agentic input rule in name=…,rule=…
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#ldap_ca_cert ⇒ Object
CA Certificate File Content.
-
#ldap_url ⇒ Object
LDAP Server URL.
-
#name ⇒ Object
Dynamic secret name.
-
#new_name ⇒ Object
Dynamic secret name.
-
#output_rule ⇒ Object
Agentic output rule in name=…,rule=…
-
#password_length ⇒ Object
The length of the password to be generated.
-
#producer_encryption_key_name ⇒ Object
Dynamic producer encryption key.
-
#provider_type ⇒ Object
Returns the value of attribute provider_type.
-
#secure_access_bastion_issuer ⇒ Object
Deprecated.
-
#secure_access_certificate_issuer ⇒ Object
Path to the SSH Certificate Issuer for your Akeyless Secure Access.
-
#secure_access_delay ⇒ Object
The delay duration, in seconds, to wait after generating just-in-time credentials.
-
#secure_access_enable ⇒ Object
Enable/Disable secure remote access [true/false].
-
#secure_access_host ⇒ Object
Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers).
-
#secure_access_rd_gateway_server ⇒ Object
RD Gateway server.
-
#secure_access_rdp_domain ⇒ Object
Required when the Dynamic Secret is used for a domain user.
-
#tags ⇒ Object
Add tags attached to this object.
-
#target ⇒ Object
A list of linked targets to be associated, Relevant only for Secure Remote Access for ssh cert issuer, ldap rotated secret and ldap dynamic secret, To specify multiple targets use argument multiple times.
-
#target_name ⇒ Object
Target name.
-
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`).
-
#token_expiration ⇒ Object
Token expiration.
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#user_attribute ⇒ Object
User Attribute.
-
#user_dn ⇒ Object
User DN.
-
#user_ttl ⇒ Object
User TTL.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GatewayUpdateProducerLdap
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ GatewayUpdateProducerLdap
Initializes the object
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 218 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayUpdateProducerLdap` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayUpdateProducerLdap`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'provider_type') self.provider_type = attributes[:'provider_type'] end if attributes.key?(:'bind_dn') self.bind_dn = attributes[:'bind_dn'] end if attributes.key?(:'bind_dn_password') self.bind_dn_password = attributes[:'bind_dn_password'] end if attributes.key?(:'custom_username_template') self.custom_username_template = attributes[:'custom_username_template'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'external_username') self.external_username = attributes[:'external_username'] else self.external_username = 'false' end if attributes.key?(:'fixed_user_claim_keyname') self.fixed_user_claim_keyname = attributes[:'fixed_user_claim_keyname'] else self.fixed_user_claim_keyname = 'ext_username' end if attributes.key?(:'group_dn') self.group_dn = attributes[:'group_dn'] end if attributes.key?(:'host_provider') self.host_provider = attributes[:'host_provider'] end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'ldap_ca_cert') self.ldap_ca_cert = attributes[:'ldap_ca_cert'] end if attributes.key?(:'ldap_url') self.ldap_url = attributes[:'ldap_url'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'new_name') self.new_name = attributes[:'new_name'] end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'password_length') self.password_length = attributes[:'password_length'] end if attributes.key?(:'producer_encryption_key_name') self.producer_encryption_key_name = attributes[:'producer_encryption_key_name'] end if attributes.key?(:'secure_access_bastion_issuer') self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer'] end if attributes.key?(:'secure_access_certificate_issuer') self.secure_access_certificate_issuer = attributes[:'secure_access_certificate_issuer'] end if attributes.key?(:'secure_access_delay') self.secure_access_delay = attributes[:'secure_access_delay'] end if attributes.key?(:'secure_access_enable') self.secure_access_enable = attributes[:'secure_access_enable'] end if attributes.key?(:'secure_access_host') if (value = attributes[:'secure_access_host']).is_a?(Array) self.secure_access_host = value end end if attributes.key?(:'secure_access_rd_gateway_server') self.secure_access_rd_gateway_server = attributes[:'secure_access_rd_gateway_server'] end if attributes.key?(:'secure_access_rdp_domain') self.secure_access_rdp_domain = attributes[:'secure_access_rdp_domain'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'target') if (value = attributes[:'target']).is_a?(Array) self.target = value end end if attributes.key?(:'target_name') self.target_name = attributes[:'target_name'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'token_expiration') self.token_expiration = attributes[:'token_expiration'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'user_attribute') self.user_attribute = attributes[:'user_attribute'] end if attributes.key?(:'user_dn') self.user_dn = attributes[:'user_dn'] end if attributes.key?(:'user_ttl') self.user_ttl = attributes[:'user_ttl'] else self.user_ttl = '60m' end end |
Instance Attribute Details
#bind_dn ⇒ Object
Bind DN
22 23 24 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 22 def bind_dn @bind_dn end |
#bind_dn_password ⇒ Object
Bind DN Password
25 26 27 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 25 def bind_dn_password @bind_dn_password end |
#custom_username_template ⇒ Object
Customize how temporary usernames are generated using go template
28 29 30 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 28 def custom_username_template @custom_username_template end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
31 32 33 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 31 def delete_protection @delete_protection end |
#external_username ⇒ Object
Externally provided username [true/false]
34 35 36 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 34 def external_username @external_username end |
#fixed_user_claim_keyname ⇒ Object
For externally provided users, denotes the key-name of IdP claim to extract the username from (relevant only for external-username=true)
37 38 39 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 37 def fixed_user_claim_keyname @fixed_user_claim_keyname end |
#group_dn ⇒ Object
Group DN which the temporary user should be added
40 41 42 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 40 def group_dn @group_dn end |
#host_provider ⇒ Object
Host provider type [explicit/target], Default Host provider is explicit, Relevant only for Secure Remote Access of ssh cert issuer, ldap rotated secret and ldap dynamic secret
43 44 45 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 43 def host_provider @host_provider end |
#input_rule ⇒ Object
Agentic input rule in name=…,rule=… format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).
46 47 48 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 46 def input_rule @input_rule end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
49 50 51 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 49 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
52 53 54 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 52 def json @json end |
#ldap_ca_cert ⇒ Object
CA Certificate File Content
55 56 57 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 55 def ldap_ca_cert @ldap_ca_cert end |
#ldap_url ⇒ Object
LDAP Server URL
58 59 60 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 58 def ldap_url @ldap_url end |
#name ⇒ Object
Dynamic secret name
61 62 63 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 61 def name @name end |
#new_name ⇒ Object
Dynamic secret name
64 65 66 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 64 def new_name @new_name end |
#output_rule ⇒ Object
Agentic output rule in name=…,rule=… format (e.g. name=rule1,rule=Mask secrets)
67 68 69 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 67 def output_rule @output_rule end |
#password_length ⇒ Object
The length of the password to be generated
70 71 72 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 70 def password_length @password_length end |
#producer_encryption_key_name ⇒ Object
Dynamic producer encryption key
73 74 75 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 73 def producer_encryption_key_name @producer_encryption_key_name end |
#provider_type ⇒ Object
Returns the value of attribute provider_type.
19 20 21 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 19 def provider_type @provider_type end |
#secure_access_bastion_issuer ⇒ Object
Deprecated. use secure-access-certificate-issuer
76 77 78 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 76 def secure_access_bastion_issuer @secure_access_bastion_issuer end |
#secure_access_certificate_issuer ⇒ Object
Path to the SSH Certificate Issuer for your Akeyless Secure Access
79 80 81 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 79 def secure_access_certificate_issuer @secure_access_certificate_issuer end |
#secure_access_delay ⇒ Object
The delay duration, in seconds, to wait after generating just-in-time credentials. Accepted range: 0-120 seconds
82 83 84 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 82 def secure_access_delay @secure_access_delay end |
#secure_access_enable ⇒ Object
Enable/Disable secure remote access [true/false]
85 86 87 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 85 def secure_access_enable @secure_access_enable end |
#secure_access_host ⇒ Object
Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)
88 89 90 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 88 def secure_access_host @secure_access_host end |
#secure_access_rd_gateway_server ⇒ Object
RD Gateway server
91 92 93 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 91 def secure_access_rd_gateway_server @secure_access_rd_gateway_server end |
#secure_access_rdp_domain ⇒ Object
Required when the Dynamic Secret is used for a domain user
94 95 96 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 94 def secure_access_rdp_domain @secure_access_rdp_domain end |
#tags ⇒ Object
Add tags attached to this object
97 98 99 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 97 def @tags end |
#target ⇒ Object
A list of linked targets to be associated, Relevant only for Secure Remote Access for ssh cert issuer, ldap rotated secret and ldap dynamic secret, To specify multiple targets use argument multiple times
100 101 102 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 100 def target @target end |
#target_name ⇒ Object
Target name
103 104 105 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 103 def target_name @target_name end |
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`)
106 107 108 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 106 def token @token end |
#token_expiration ⇒ Object
Token expiration
109 110 111 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 109 def token_expiration @token_expiration end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
112 113 114 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 112 def uid_token @uid_token end |
#user_attribute ⇒ Object
User Attribute
115 116 117 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 115 def user_attribute @user_attribute end |
#user_dn ⇒ Object
User DN
118 119 120 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 118 def user_dn @user_dn end |
#user_ttl ⇒ Object
User TTL
121 122 123 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 121 def user_ttl @user_ttl end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 495 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
165 166 167 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 165 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 124 def self.attribute_map { :'provider_type' => :'ProviderType', :'bind_dn' => :'bind-dn', :'bind_dn_password' => :'bind-dn-password', :'custom_username_template' => :'custom-username-template', :'delete_protection' => :'delete_protection', :'external_username' => :'external-username', :'fixed_user_claim_keyname' => :'fixed-user-claim-keyname', :'group_dn' => :'group-dn', :'host_provider' => :'host-provider', :'input_rule' => :'input-rule', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'ldap_ca_cert' => :'ldap-ca-cert', :'ldap_url' => :'ldap-url', :'name' => :'name', :'new_name' => :'new-name', :'output_rule' => :'output-rule', :'password_length' => :'password-length', :'producer_encryption_key_name' => :'producer-encryption-key-name', :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer', :'secure_access_certificate_issuer' => :'secure-access-certificate-issuer', :'secure_access_delay' => :'secure-access-delay', :'secure_access_enable' => :'secure-access-enable', :'secure_access_host' => :'secure-access-host', :'secure_access_rd_gateway_server' => :'secure-access-rd-gateway-server', :'secure_access_rdp_domain' => :'secure-access-rdp-domain', :'tags' => :'tags', :'target' => :'target', :'target_name' => :'target-name', :'token' => :'token', :'token_expiration' => :'token-expiration', :'uid_token' => :'uid-token', :'user_attribute' => :'user-attribute', :'user_dn' => :'user-dn', :'user_ttl' => :'user-ttl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 471 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
211 212 213 214 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 211 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 170 def self.openapi_types { :'provider_type' => :'String', :'bind_dn' => :'String', :'bind_dn_password' => :'String', :'custom_username_template' => :'String', :'delete_protection' => :'String', :'external_username' => :'String', :'fixed_user_claim_keyname' => :'String', :'group_dn' => :'String', :'host_provider' => :'String', :'input_rule' => :'Array<String>', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'ldap_ca_cert' => :'String', :'ldap_url' => :'String', :'name' => :'String', :'new_name' => :'String', :'output_rule' => :'Array<String>', :'password_length' => :'String', :'producer_encryption_key_name' => :'String', :'secure_access_bastion_issuer' => :'String', :'secure_access_certificate_issuer' => :'String', :'secure_access_delay' => :'Integer', :'secure_access_enable' => :'String', :'secure_access_host' => :'Array<String>', :'secure_access_rd_gateway_server' => :'String', :'secure_access_rdp_domain' => :'String', :'tags' => :'Array<String>', :'target' => :'Array<String>', :'target_name' => :'String', :'token' => :'String', :'token_expiration' => :'String', :'uid_token' => :'String', :'user_attribute' => :'String', :'user_dn' => :'String', :'user_ttl' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 416 def ==(o) return true if self.equal?(o) self.class == o.class && provider_type == o.provider_type && bind_dn == o.bind_dn && bind_dn_password == o.bind_dn_password && custom_username_template == o.custom_username_template && delete_protection == o.delete_protection && external_username == o.external_username && fixed_user_claim_keyname == o.fixed_user_claim_keyname && group_dn == o.group_dn && host_provider == o.host_provider && input_rule == o.input_rule && item_custom_fields == o.item_custom_fields && json == o.json && ldap_ca_cert == o.ldap_ca_cert && ldap_url == o.ldap_url && name == o.name && new_name == o.new_name && output_rule == o.output_rule && password_length == o.password_length && producer_encryption_key_name == o.producer_encryption_key_name && secure_access_bastion_issuer == o.secure_access_bastion_issuer && secure_access_certificate_issuer == o.secure_access_certificate_issuer && secure_access_delay == o.secure_access_delay && secure_access_enable == o.secure_access_enable && secure_access_host == o.secure_access_host && secure_access_rd_gateway_server == o.secure_access_rd_gateway_server && secure_access_rdp_domain == o.secure_access_rdp_domain && == o. && target == o.target && target_name == o.target_name && token == o.token && token_expiration == o.token_expiration && uid_token == o.uid_token && user_attribute == o.user_attribute && user_dn == o.user_dn && user_ttl == o.user_ttl end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
566 567 568 569 570 571 572 573 574 575 576 577 578 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 566 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
458 459 460 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 458 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
464 465 466 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 464 def hash [provider_type, bind_dn, bind_dn_password, custom_username_template, delete_protection, external_username, fixed_user_claim_keyname, group_dn, host_provider, input_rule, item_custom_fields, json, ldap_ca_cert, ldap_url, name, new_name, output_rule, password_length, producer_encryption_key_name, secure_access_bastion_issuer, secure_access_certificate_issuer, secure_access_delay, secure_access_enable, secure_access_host, secure_access_rd_gateway_server, secure_access_rdp_domain, , target, target_name, token, token_expiration, uid_token, user_attribute, user_dn, user_ttl].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
396 397 398 399 400 401 402 403 404 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 396 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
542 543 544 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 542 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
548 549 550 551 552 553 554 555 556 557 558 559 560 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 548 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
536 537 538 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 536 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
408 409 410 411 412 |
# File 'lib/akeyless/models/gateway_update_producer_ldap.rb', line 408 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |