Class: Akeyless::GatewayUpdateProducerMSSQL

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/gateway_update_producer_mssql.rb

Overview

gatewayUpdateProducerMSSQL is a command that updates mssql producer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GatewayUpdateProducerMSSQL

Initializes the object



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 149

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayUpdateProducerMSSQL` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayUpdateProducerMSSQL`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  end

  if attributes.key?(:'mssql_create_statements')
    self.mssql_create_statements = attributes[:'mssql_create_statements']
  end

  if attributes.key?(:'mssql_dbname')
    self.mssql_dbname = attributes[:'mssql_dbname']
  end

  if attributes.key?(:'mssql_host')
    self.mssql_host = attributes[:'mssql_host']
  else
    self.mssql_host = '127.0.0.1'
  end

  if attributes.key?(:'mssql_password')
    self.mssql_password = attributes[:'mssql_password']
  end

  if attributes.key?(:'mssql_port')
    self.mssql_port = attributes[:'mssql_port']
  else
    self.mssql_port = '1433'
  end

  if attributes.key?(:'mssql_revocation_statements')
    self.mssql_revocation_statements = attributes[:'mssql_revocation_statements']
  end

  if attributes.key?(:'mssql_username')
    self.mssql_username = attributes[:'mssql_username']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'secure_access_bastion_issuer')
    self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer']
  end

  if attributes.key?(:'secure_access_db_schema')
    self.secure_access_db_schema = attributes[:'secure_access_db_schema']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_host')
    if (value = attributes[:'secure_access_host']).is_a?(Array)
      self.secure_access_host = value
    end
  end

  if attributes.key?(:'secure_access_web')
    self.secure_access_web = attributes[:'secure_access_web']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '60m'
  end
end

Instance Attribute Details

#delete_protection ⇒ Object

Protection from accidental deletion of this item



20
21
22
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 20

def delete_protection
  @delete_protection
end

#json ⇒ Object

Set output format to JSON



23
24
25
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 23

def json
  @json
end

#mssql_create_statements ⇒ Object

MSSQL Creation statements



26
27
28
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 26

def mssql_create_statements
  @mssql_create_statements
end

#mssql_dbname ⇒ Object

MSSQL Name



29
30
31
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 29

def mssql_dbname
  @mssql_dbname
end

#mssql_host ⇒ Object

MSSQL Host



32
33
34
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 32

def mssql_host
  @mssql_host
end

#mssql_password ⇒ Object

MSSQL Password



35
36
37
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 35

def mssql_password
  @mssql_password
end

#mssql_port ⇒ Object

MSSQL Port



38
39
40
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 38

def mssql_port
  @mssql_port
end

#mssql_revocation_statements ⇒ Object

MSSQL Revocation statements



41
42
43
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 41

def mssql_revocation_statements
  @mssql_revocation_statements
end

#mssql_username ⇒ Object

MSSQL Username



44
45
46
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 44

def mssql_username
  @mssql_username
end

#name ⇒ Object

Producer name



47
48
49
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 47

def name
  @name
end

#new_name ⇒ Object

Producer name



50
51
52
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 50

def new_name
  @new_name
end

#producer_encryption_key_name ⇒ Object

Dynamic producer encryption key



53
54
55
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 53

def producer_encryption_key_name
  @producer_encryption_key_name
end

#secure_access_bastion_issuer ⇒ Object

Returns the value of attribute secure_access_bastion_issuer.



55
56
57
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 55

def secure_access_bastion_issuer
  @secure_access_bastion_issuer
end

#secure_access_db_schema ⇒ Object

Returns the value of attribute secure_access_db_schema.



57
58
59
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 57

def secure_access_db_schema
  @secure_access_db_schema
end

#secure_access_enable ⇒ Object

Returns the value of attribute secure_access_enable.



59
60
61
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 59

def secure_access_enable
  @secure_access_enable
end

#secure_access_host ⇒ Object

Returns the value of attribute secure_access_host.



61
62
63
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 61

def secure_access_host
  @secure_access_host
end

#secure_access_web ⇒ Object

Returns the value of attribute secure_access_web.



63
64
65
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 63

def secure_access_web
  @secure_access_web
end

#tags ⇒ Object

List of the tags attached to this secret



66
67
68
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 66

def tags
  @tags
end

#target_name ⇒ Object

Target name



69
70
71
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 69

def target_name
  @target_name
end

#token ⇒ Object

Authentication token (see /auth and /configure)



72
73
74
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 72

def token
  @token
end

#uid_token ⇒ Object

The universal identity token, Required only for universal_identity authentication



75
76
77
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 75

def uid_token
  @uid_token
end

#user_ttl ⇒ Object

User TTL



78
79
80
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 78

def user_ttl
  @user_ttl
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



109
110
111
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 109

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 81

def self.attribute_map
  {
    :'delete_protection' => :'delete_protection',
    :'json' => :'json',
    :'mssql_create_statements' => :'mssql-create-statements',
    :'mssql_dbname' => :'mssql-dbname',
    :'mssql_host' => :'mssql-host',
    :'mssql_password' => :'mssql-password',
    :'mssql_port' => :'mssql-port',
    :'mssql_revocation_statements' => :'mssql-revocation-statements',
    :'mssql_username' => :'mssql-username',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer',
    :'secure_access_db_schema' => :'secure-access-db-schema',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_host' => :'secure-access-host',
    :'secure_access_web' => :'secure-access-web',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'user_ttl' => :'user-ttl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



323
324
325
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 323

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



142
143
144
145
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 142

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 114

def self.openapi_types
  {
    :'delete_protection' => :'String',
    :'json' => :'Boolean',
    :'mssql_create_statements' => :'String',
    :'mssql_dbname' => :'String',
    :'mssql_host' => :'String',
    :'mssql_password' => :'String',
    :'mssql_port' => :'String',
    :'mssql_revocation_statements' => :'String',
    :'mssql_username' => :'String',
    :'name' => :'String',
    :'new_name' => :'String',
    :'producer_encryption_key_name' => :'String',
    :'secure_access_bastion_issuer' => :'String',
    :'secure_access_db_schema' => :'String',
    :'secure_access_enable' => :'String',
    :'secure_access_host' => :'Array<String>',
    :'secure_access_web' => :'Boolean',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'user_ttl' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 281

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      delete_protection == o.delete_protection &&
      json == o.json &&
      mssql_create_statements == o.mssql_create_statements &&
      mssql_dbname == o.mssql_dbname &&
      mssql_host == o.mssql_host &&
      mssql_password == o.mssql_password &&
      mssql_port == o.mssql_port &&
      mssql_revocation_statements == o.mssql_revocation_statements &&
      mssql_username == o.mssql_username &&
      name == o.name &&
      new_name == o.new_name &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      secure_access_bastion_issuer == o.secure_access_bastion_issuer &&
      secure_access_db_schema == o.secure_access_db_schema &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_host == o.secure_access_host &&
      secure_access_web == o.secure_access_web &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      user_ttl == o.user_ttl
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 354

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 425

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 330

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


310
311
312
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 310

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.



316
317
318
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 316

def hash
  [delete_protection, json, mssql_create_statements, mssql_dbname, mssql_host, mssql_password, mssql_port, mssql_revocation_statements, mssql_username, name, new_name, producer_encryption_key_name, secure_access_bastion_issuer, secure_access_db_schema, secure_access_enable, secure_access_host, secure_access_web, tags, target_name, token, uid_token, user_ttl].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?



263
264
265
266
267
268
269
270
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 263

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)



401
402
403
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 401

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash



407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 407

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object



395
396
397
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 395

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid



274
275
276
277
# File 'lib/akeyless/models/gateway_update_producer_mssql.rb', line 274

def valid?
  return false if @name.nil?
  true
end