Class: Akeyless::GatewayUpdateProducerNativeK8S

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/gateway_update_producer_native_k8_s.rb

Overview

gatewayUpdateProducerNativeK8S is a command that updates k8s producer [Deprecated: Use dynamic-secret-update-k8s command]

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GatewayUpdateProducerNativeK8S

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 239

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayUpdateProducerNativeK8S` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayUpdateProducerNativeK8S`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ara_enabled')
    self.ara_enabled = attributes[:'ara_enabled']
  end

  if attributes.key?(:'custom_username_template')
    self.custom_username_template = attributes[:'custom_username_template']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'input_rule')
    if (value = attributes[:'input_rule']).is_a?(Array)
      self.input_rule = value
    end
  end

  if attributes.key?(:'item_custom_fields')
    if (value = attributes[:'item_custom_fields']).is_a?(Hash)
      self.item_custom_fields = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'k8s_allowed_namespaces')
    self.k8s_allowed_namespaces = attributes[:'k8s_allowed_namespaces']
  end

  if attributes.key?(:'k8s_cluster_ca_cert')
    self.k8s_cluster_ca_cert = attributes[:'k8s_cluster_ca_cert']
  end

  if attributes.key?(:'k8s_cluster_endpoint')
    self.k8s_cluster_endpoint = attributes[:'k8s_cluster_endpoint']
  end

  if attributes.key?(:'k8s_cluster_name')
    self.k8s_cluster_name = attributes[:'k8s_cluster_name']
  end

  if attributes.key?(:'k8s_cluster_token')
    self.k8s_cluster_token = attributes[:'k8s_cluster_token']
  end

  if attributes.key?(:'k8s_namespace')
    self.k8s_namespace = attributes[:'k8s_namespace']
  end

  if attributes.key?(:'k8s_predefined_role_name')
    self.k8s_predefined_role_name = attributes[:'k8s_predefined_role_name']
  end

  if attributes.key?(:'k8s_predefined_role_type')
    self.k8s_predefined_role_type = attributes[:'k8s_predefined_role_type']
  end

  if attributes.key?(:'k8s_rolebinding_yaml_data')
    self.k8s_rolebinding_yaml_data = attributes[:'k8s_rolebinding_yaml_data']
  end

  if attributes.key?(:'k8s_rolebinding_yaml_def')
    self.k8s_rolebinding_yaml_def = attributes[:'k8s_rolebinding_yaml_def']
  end

  if attributes.key?(:'k8s_service_account')
    self. = attributes[:'k8s_service_account']
  end

  if attributes.key?(:'k8s_service_account_type')
    self. = attributes[:'k8s_service_account_type']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'output_rule')
    if (value = attributes[:'output_rule']).is_a?(Array)
      self.output_rule = value
    end
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'secure_access_allow_port_forwading')
    self.secure_access_allow_port_forwading = attributes[:'secure_access_allow_port_forwading']
  end

  if attributes.key?(:'secure_access_bastion_issuer')
    self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer']
  end

  if attributes.key?(:'secure_access_certificate_issuer')
    self.secure_access_certificate_issuer = attributes[:'secure_access_certificate_issuer']
  end

  if attributes.key?(:'secure_access_cluster_endpoint')
    self.secure_access_cluster_endpoint = attributes[:'secure_access_cluster_endpoint']
  end

  if attributes.key?(:'secure_access_dashboard_url')
    self.secure_access_dashboard_url = attributes[:'secure_access_dashboard_url']
  end

  if attributes.key?(:'secure_access_delay')
    self.secure_access_delay = attributes[:'secure_access_delay']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_web')
    self.secure_access_web = attributes[:'secure_access_web']
  else
    self.secure_access_web = false
  end

  if attributes.key?(:'secure_access_web_browsing')
    self.secure_access_web_browsing = attributes[:'secure_access_web_browsing']
  else
    self.secure_access_web_browsing = false
  end

  if attributes.key?(:'secure_access_web_proxy')
    self.secure_access_web_proxy = attributes[:'secure_access_web_proxy']
  else
    self.secure_access_web_proxy = false
  end

  if attributes.key?(:'skip_dry_run')
    self.skip_dry_run = attributes[:'skip_dry_run']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'use_gw_service_account')
    self. = attributes[:'use_gw_service_account']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '60m'
  end
end

Instance Attribute Details

#ara_enabledObject

Enable or disable Agentic Runtime Authority rule enforcement for this item. Mirrors commands.AgenticRulesParams.AraEnabled.



20
21
22
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 20

def ara_enabled
  @ara_enabled
end

#custom_username_templateObject

Customize how temporary usernames are generated using go template



23
24
25
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 23

def custom_username_template
  @custom_username_template
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



26
27
28
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 26

def delete_protection
  @delete_protection
end

#input_ruleObject

Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).



29
30
31
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 29

def input_rule
  @input_rule
end

#item_custom_fieldsObject

Additional custom fields to associate with the item



32
33
34
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 32

def item_custom_fields
  @item_custom_fields
end

#jsonObject

Set output format to JSON



35
36
37
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 35

def json
  @json
end

#k8s_allowed_namespacesObject

Comma-separated list of allowed K8S namespaces for the generated ServiceAccount (relevant only for k8s-service-account-type=dynamic)



38
39
40
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 38

def k8s_allowed_namespaces
  @k8s_allowed_namespaces
end

#k8s_cluster_ca_certObject

K8S cluster CA certificate



41
42
43
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 41

def k8s_cluster_ca_cert
  @k8s_cluster_ca_cert
end

#k8s_cluster_endpointObject

K8S cluster URL endpoint



44
45
46
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 44

def k8s_cluster_endpoint
  @k8s_cluster_endpoint
end

#k8s_cluster_nameObject

K8S cluster name



47
48
49
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 47

def k8s_cluster_name
  @k8s_cluster_name
end

#k8s_cluster_tokenObject

K8S cluster Bearer token



50
51
52
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 50

def k8s_cluster_token
  @k8s_cluster_token
end

#k8s_namespaceObject

K8S Namespace where the ServiceAccount exists.



53
54
55
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 53

def k8s_namespace
  @k8s_namespace
end

#k8s_predefined_role_nameObject

The pre-existing Role or ClusterRole name to bind the generated ServiceAccount to (relevant only for k8s-service-account-type=dynamic)



56
57
58
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 56

def k8s_predefined_role_name
  @k8s_predefined_role_name
end

#k8s_predefined_role_typeObject

Specifies the type of the pre-existing K8S role [Role, ClusterRole] (relevant only for k8s-service-account-type=dynamic)



59
60
61
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 59

def k8s_predefined_role_type
  @k8s_predefined_role_type
end

#k8s_rolebinding_yaml_dataObject

Content of the yaml in a Base64 format.



62
63
64
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 62

def k8s_rolebinding_yaml_data
  @k8s_rolebinding_yaml_data
end

#k8s_rolebinding_yaml_defObject

Path to yaml file that contains definitions of K8S role and role binding (relevant only for k8s-service-account-type=dynamic)



65
66
67
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 65

def k8s_rolebinding_yaml_def
  @k8s_rolebinding_yaml_def
end

#k8s_service_accountObject

K8S ServiceAccount to extract token from.



68
69
70
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 68

def 
  @k8s_service_account
end

#k8s_service_account_typeObject

K8S ServiceAccount type [fixed, dynamic].



71
72
73
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 71

def 
  @k8s_service_account_type
end

#nameObject

Dynamic secret name



74
75
76
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 74

def name
  @name
end

#new_nameObject

Dynamic secret name



77
78
79
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 77

def new_name
  @new_name
end

#output_ruleObject

Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)



80
81
82
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 80

def output_rule
  @output_rule
end

#producer_encryption_key_nameObject

Dynamic producer encryption key



83
84
85
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 83

def producer_encryption_key_name
  @producer_encryption_key_name
end

#secure_access_allow_port_forwadingObject

Enable Port forwarding while using CLI access



86
87
88
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 86

def secure_access_allow_port_forwading
  @secure_access_allow_port_forwading
end

#secure_access_bastion_issuerObject

Deprecated. use secure-access-certificate-issuer



89
90
91
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 89

def secure_access_bastion_issuer
  @secure_access_bastion_issuer
end

#secure_access_certificate_issuerObject

Path to the SSH Certificate Issuer for your Akeyless Secure Access



92
93
94
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 92

def secure_access_certificate_issuer
  @secure_access_certificate_issuer
end

#secure_access_cluster_endpointObject

The K8s cluster endpoint URL



95
96
97
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 95

def secure_access_cluster_endpoint
  @secure_access_cluster_endpoint
end

#secure_access_dashboard_urlObject

The K8s dashboard url



98
99
100
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 98

def secure_access_dashboard_url
  @secure_access_dashboard_url
end

#secure_access_delayObject

The delay duration, in seconds, to wait after generating just-in-time credentials. Accepted range: 0-120 seconds



101
102
103
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 101

def secure_access_delay
  @secure_access_delay
end

#secure_access_enableObject

Enable/Disable secure remote access [true/false]



104
105
106
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 104

def secure_access_enable
  @secure_access_enable
end

#secure_access_webObject

Enable Web Secure Remote Access



107
108
109
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 107

def secure_access_web
  @secure_access_web
end

#secure_access_web_browsingObject

Secure browser via Akeyless's Secure Remote Access (SRA)



110
111
112
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 110

def secure_access_web_browsing
  @secure_access_web_browsing
end

#secure_access_web_proxyObject

Web-Proxy via Akeyless's Secure Remote Access (SRA)



113
114
115
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 113

def secure_access_web_proxy
  @secure_access_web_proxy
end

#skip_dry_runObject

If set, dry-run will be skipped



116
117
118
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 116

def skip_dry_run
  @skip_dry_run
end

#tagsObject

Add tags attached to this object



119
120
121
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 119

def tags
  @tags
end

#target_nameObject

Target name



122
123
124
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 122

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



125
126
127
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 125

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



128
129
130
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 128

def uid_token
  @uid_token
end

#use_gw_service_accountObject

Use the GW's service account



131
132
133
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 131

def 
  @use_gw_service_account
end

#user_ttlObject

User TTL



134
135
136
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 134

def user_ttl
  @user_ttl
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 534

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



182
183
184
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 182

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 137

def self.attribute_map
  {
    :'ara_enabled' => :'ara-enabled',
    :'custom_username_template' => :'custom-username-template',
    :'delete_protection' => :'delete_protection',
    :'input_rule' => :'input-rule',
    :'item_custom_fields' => :'item-custom-fields',
    :'json' => :'json',
    :'k8s_allowed_namespaces' => :'k8s-allowed-namespaces',
    :'k8s_cluster_ca_cert' => :'k8s-cluster-ca-cert',
    :'k8s_cluster_endpoint' => :'k8s-cluster-endpoint',
    :'k8s_cluster_name' => :'k8s-cluster-name',
    :'k8s_cluster_token' => :'k8s-cluster-token',
    :'k8s_namespace' => :'k8s-namespace',
    :'k8s_predefined_role_name' => :'k8s-predefined-role-name',
    :'k8s_predefined_role_type' => :'k8s-predefined-role-type',
    :'k8s_rolebinding_yaml_data' => :'k8s-rolebinding-yaml-data',
    :'k8s_rolebinding_yaml_def' => :'k8s-rolebinding-yaml-def',
    :'k8s_service_account' => :'k8s-service-account',
    :'k8s_service_account_type' => :'k8s-service-account-type',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'output_rule' => :'output-rule',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'secure_access_allow_port_forwading' => :'secure-access-allow-port-forwading',
    :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer',
    :'secure_access_certificate_issuer' => :'secure-access-certificate-issuer',
    :'secure_access_cluster_endpoint' => :'secure-access-cluster-endpoint',
    :'secure_access_dashboard_url' => :'secure-access-dashboard-url',
    :'secure_access_delay' => :'secure-access-delay',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_web' => :'secure-access-web',
    :'secure_access_web_browsing' => :'secure-access-web-browsing',
    :'secure_access_web_proxy' => :'secure-access-web-proxy',
    :'skip_dry_run' => :'skip_dry_run',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'use_gw_service_account' => :'use-gw-service-account',
    :'user_ttl' => :'user-ttl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 510

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



232
233
234
235
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 232

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 187

def self.openapi_types
  {
    :'ara_enabled' => :'Boolean',
    :'custom_username_template' => :'String',
    :'delete_protection' => :'String',
    :'input_rule' => :'Array<String>',
    :'item_custom_fields' => :'Hash<String, String>',
    :'json' => :'Boolean',
    :'k8s_allowed_namespaces' => :'String',
    :'k8s_cluster_ca_cert' => :'String',
    :'k8s_cluster_endpoint' => :'String',
    :'k8s_cluster_name' => :'String',
    :'k8s_cluster_token' => :'String',
    :'k8s_namespace' => :'String',
    :'k8s_predefined_role_name' => :'String',
    :'k8s_predefined_role_type' => :'String',
    :'k8s_rolebinding_yaml_data' => :'String',
    :'k8s_rolebinding_yaml_def' => :'String',
    :'k8s_service_account' => :'String',
    :'k8s_service_account_type' => :'String',
    :'name' => :'String',
    :'new_name' => :'String',
    :'output_rule' => :'Array<String>',
    :'producer_encryption_key_name' => :'String',
    :'secure_access_allow_port_forwading' => :'Boolean',
    :'secure_access_bastion_issuer' => :'String',
    :'secure_access_certificate_issuer' => :'String',
    :'secure_access_cluster_endpoint' => :'String',
    :'secure_access_dashboard_url' => :'String',
    :'secure_access_delay' => :'Integer',
    :'secure_access_enable' => :'String',
    :'secure_access_web' => :'Boolean',
    :'secure_access_web_browsing' => :'Boolean',
    :'secure_access_web_proxy' => :'Boolean',
    :'skip_dry_run' => :'String',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'use_gw_service_account' => :'Boolean',
    :'user_ttl' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 451

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ara_enabled == o.ara_enabled &&
      custom_username_template == o.custom_username_template &&
      delete_protection == o.delete_protection &&
      input_rule == o.input_rule &&
      item_custom_fields == o.item_custom_fields &&
      json == o.json &&
      k8s_allowed_namespaces == o.k8s_allowed_namespaces &&
      k8s_cluster_ca_cert == o.k8s_cluster_ca_cert &&
      k8s_cluster_endpoint == o.k8s_cluster_endpoint &&
      k8s_cluster_name == o.k8s_cluster_name &&
      k8s_cluster_token == o.k8s_cluster_token &&
      k8s_namespace == o.k8s_namespace &&
      k8s_predefined_role_name == o.k8s_predefined_role_name &&
      k8s_predefined_role_type == o.k8s_predefined_role_type &&
      k8s_rolebinding_yaml_data == o.k8s_rolebinding_yaml_data &&
      k8s_rolebinding_yaml_def == o.k8s_rolebinding_yaml_def &&
       == o. &&
       == o. &&
      name == o.name &&
      new_name == o.new_name &&
      output_rule == o.output_rule &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      secure_access_allow_port_forwading == o.secure_access_allow_port_forwading &&
      secure_access_bastion_issuer == o.secure_access_bastion_issuer &&
      secure_access_certificate_issuer == o.secure_access_certificate_issuer &&
      secure_access_cluster_endpoint == o.secure_access_cluster_endpoint &&
      secure_access_dashboard_url == o.secure_access_dashboard_url &&
      secure_access_delay == o.secure_access_delay &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_web == o.secure_access_web &&
      secure_access_web_browsing == o.secure_access_web_browsing &&
      secure_access_web_proxy == o.secure_access_web_proxy &&
      skip_dry_run == o.skip_dry_run &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
       == o. &&
      user_ttl == o.user_ttl
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



605
606
607
608
609
610
611
612
613
614
615
616
617
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 605

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


497
498
499
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 497

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



503
504
505
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 503

def hash
  [ara_enabled, custom_username_template, delete_protection, input_rule, item_custom_fields, json, k8s_allowed_namespaces, k8s_cluster_ca_cert, k8s_cluster_endpoint, k8s_cluster_name, k8s_cluster_token, k8s_namespace, k8s_predefined_role_name, k8s_predefined_role_type, k8s_rolebinding_yaml_data, k8s_rolebinding_yaml_def, , , name, new_name, output_rule, producer_encryption_key_name, secure_access_allow_port_forwading, secure_access_bastion_issuer, secure_access_certificate_issuer, secure_access_cluster_endpoint, secure_access_dashboard_url, secure_access_delay, secure_access_enable, secure_access_web, secure_access_web_browsing, secure_access_web_proxy, skip_dry_run, tags, target_name, token, uid_token, , user_ttl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



431
432
433
434
435
436
437
438
439
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 431

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



581
582
583
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 581

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 587

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



575
576
577
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 575

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



443
444
445
446
447
# File 'lib/akeyless/models/gateway_update_producer_native_k8_s.rb', line 443

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end