Class: Akeyless::GatewayUpdateProducerRabbitMQ
- Inherits:
-
Object
- Object
- Akeyless::GatewayUpdateProducerRabbitMQ
- Defined in:
- lib/akeyless/models/gateway_update_producer_rabbit_mq.rb
Overview
gatewayUpdateProducerRabbitMQ is a command that updates rabbitmq producer [Deprecated: Use dynamic-secret-update-rabbitmq command]
Instance Attribute Summary collapse
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#input_rule ⇒ Object
Agentic input rule in name=…,rule=…
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#name ⇒ Object
Dynamic secret name.
-
#new_name ⇒ Object
Dynamic secret name.
-
#output_rule ⇒ Object
Agentic output rule in name=…,rule=…
-
#password_length ⇒ Object
The length of the password to be generated.
-
#producer_encryption_key_name ⇒ Object
Dynamic producer encryption key.
-
#rabbitmq_admin_pwd ⇒ Object
RabbitMQ Admin password.
-
#rabbitmq_admin_user ⇒ Object
RabbitMQ Admin User.
-
#rabbitmq_server_uri ⇒ Object
Server URI.
-
#rabbitmq_user_conf_permission ⇒ Object
User configuration permission.
-
#rabbitmq_user_read_permission ⇒ Object
User read permission.
-
#rabbitmq_user_tags ⇒ Object
User Tags.
-
#rabbitmq_user_vhost ⇒ Object
User Virtual Host.
-
#rabbitmq_user_write_permission ⇒ Object
User write permission.
-
#secure_access_enable ⇒ Object
Enable/Disable secure remote access [true/false].
-
#secure_access_url ⇒ Object
Destination URL to inject secrets.
-
#secure_access_web ⇒ Object
Enable Web Secure Remote Access.
-
#secure_access_web_browsing ⇒ Object
Secure browser via Akeyless’s Secure Remote Access (SRA).
-
#secure_access_web_proxy ⇒ Object
Web-Proxy via Akeyless’s Secure Remote Access (SRA).
-
#tags ⇒ Object
Add tags attached to this object.
-
#target_name ⇒ Object
Target name.
-
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`).
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#user_ttl ⇒ Object
User TTL.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GatewayUpdateProducerRabbitMQ
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ GatewayUpdateProducerRabbitMQ
Initializes the object
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 179 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayUpdateProducerRabbitMQ` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayUpdateProducerRabbitMQ`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'new_name') self.new_name = attributes[:'new_name'] end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'password_length') self.password_length = attributes[:'password_length'] end if attributes.key?(:'producer_encryption_key_name') self.producer_encryption_key_name = attributes[:'producer_encryption_key_name'] end if attributes.key?(:'rabbitmq_admin_pwd') self.rabbitmq_admin_pwd = attributes[:'rabbitmq_admin_pwd'] end if attributes.key?(:'rabbitmq_admin_user') self.rabbitmq_admin_user = attributes[:'rabbitmq_admin_user'] end if attributes.key?(:'rabbitmq_server_uri') self.rabbitmq_server_uri = attributes[:'rabbitmq_server_uri'] end if attributes.key?(:'rabbitmq_user_conf_permission') self. = attributes[:'rabbitmq_user_conf_permission'] end if attributes.key?(:'rabbitmq_user_read_permission') self. = attributes[:'rabbitmq_user_read_permission'] end if attributes.key?(:'rabbitmq_user_tags') self. = attributes[:'rabbitmq_user_tags'] end if attributes.key?(:'rabbitmq_user_vhost') self.rabbitmq_user_vhost = attributes[:'rabbitmq_user_vhost'] end if attributes.key?(:'rabbitmq_user_write_permission') self. = attributes[:'rabbitmq_user_write_permission'] end if attributes.key?(:'secure_access_enable') self.secure_access_enable = attributes[:'secure_access_enable'] end if attributes.key?(:'secure_access_url') self.secure_access_url = attributes[:'secure_access_url'] end if attributes.key?(:'secure_access_web') self.secure_access_web = attributes[:'secure_access_web'] else self.secure_access_web = true end if attributes.key?(:'secure_access_web_browsing') self.secure_access_web_browsing = attributes[:'secure_access_web_browsing'] else self.secure_access_web_browsing = false end if attributes.key?(:'secure_access_web_proxy') self.secure_access_web_proxy = attributes[:'secure_access_web_proxy'] else self.secure_access_web_proxy = false end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'target_name') self.target_name = attributes[:'target_name'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'user_ttl') self.user_ttl = attributes[:'user_ttl'] else self.user_ttl = '60m' end end |
Instance Attribute Details
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
20 21 22 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 20 def delete_protection @delete_protection end |
#input_rule ⇒ Object
Agentic input rule in name=…,rule=… format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).
23 24 25 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 23 def input_rule @input_rule end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
26 27 28 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 26 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
29 30 31 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 29 def json @json end |
#name ⇒ Object
Dynamic secret name
32 33 34 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 32 def name @name end |
#new_name ⇒ Object
Dynamic secret name
35 36 37 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 35 def new_name @new_name end |
#output_rule ⇒ Object
Agentic output rule in name=…,rule=… format (e.g. name=rule1,rule=Mask secrets)
38 39 40 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 38 def output_rule @output_rule end |
#password_length ⇒ Object
The length of the password to be generated
41 42 43 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 41 def password_length @password_length end |
#producer_encryption_key_name ⇒ Object
Dynamic producer encryption key
44 45 46 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 44 def producer_encryption_key_name @producer_encryption_key_name end |
#rabbitmq_admin_pwd ⇒ Object
RabbitMQ Admin password
47 48 49 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 47 def rabbitmq_admin_pwd @rabbitmq_admin_pwd end |
#rabbitmq_admin_user ⇒ Object
RabbitMQ Admin User
50 51 52 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 50 def rabbitmq_admin_user @rabbitmq_admin_user end |
#rabbitmq_server_uri ⇒ Object
Server URI
53 54 55 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 53 def rabbitmq_server_uri @rabbitmq_server_uri end |
#rabbitmq_user_conf_permission ⇒ Object
User configuration permission
56 57 58 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 56 def @rabbitmq_user_conf_permission end |
#rabbitmq_user_read_permission ⇒ Object
User read permission
59 60 61 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 59 def @rabbitmq_user_read_permission end |
#rabbitmq_user_tags ⇒ Object
User Tags
62 63 64 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 62 def @rabbitmq_user_tags end |
#rabbitmq_user_vhost ⇒ Object
User Virtual Host
65 66 67 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 65 def rabbitmq_user_vhost @rabbitmq_user_vhost end |
#rabbitmq_user_write_permission ⇒ Object
User write permission
68 69 70 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 68 def @rabbitmq_user_write_permission end |
#secure_access_enable ⇒ Object
Enable/Disable secure remote access [true/false]
71 72 73 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 71 def secure_access_enable @secure_access_enable end |
#secure_access_url ⇒ Object
Destination URL to inject secrets
74 75 76 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 74 def secure_access_url @secure_access_url end |
#secure_access_web ⇒ Object
Enable Web Secure Remote Access
77 78 79 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 77 def secure_access_web @secure_access_web end |
#secure_access_web_browsing ⇒ Object
Secure browser via Akeyless’s Secure Remote Access (SRA)
80 81 82 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 80 def secure_access_web_browsing @secure_access_web_browsing end |
#secure_access_web_proxy ⇒ Object
Web-Proxy via Akeyless’s Secure Remote Access (SRA)
83 84 85 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 83 def secure_access_web_proxy @secure_access_web_proxy end |
#tags ⇒ Object
Add tags attached to this object
86 87 88 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 86 def @tags end |
#target_name ⇒ Object
Target name
89 90 91 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 89 def target_name @target_name end |
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`)
92 93 94 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 92 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
95 96 97 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 95 def uid_token @uid_token end |
#user_ttl ⇒ Object
User TTL
98 99 100 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 98 def user_ttl @user_ttl end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 414 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
134 135 136 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 134 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 101 def self.attribute_map { :'delete_protection' => :'delete_protection', :'input_rule' => :'input-rule', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'name' => :'name', :'new_name' => :'new-name', :'output_rule' => :'output-rule', :'password_length' => :'password-length', :'producer_encryption_key_name' => :'producer-encryption-key-name', :'rabbitmq_admin_pwd' => :'rabbitmq-admin-pwd', :'rabbitmq_admin_user' => :'rabbitmq-admin-user', :'rabbitmq_server_uri' => :'rabbitmq-server-uri', :'rabbitmq_user_conf_permission' => :'rabbitmq-user-conf-permission', :'rabbitmq_user_read_permission' => :'rabbitmq-user-read-permission', :'rabbitmq_user_tags' => :'rabbitmq-user-tags', :'rabbitmq_user_vhost' => :'rabbitmq-user-vhost', :'rabbitmq_user_write_permission' => :'rabbitmq-user-write-permission', :'secure_access_enable' => :'secure-access-enable', :'secure_access_url' => :'secure-access-url', :'secure_access_web' => :'secure-access-web', :'secure_access_web_browsing' => :'secure-access-web-browsing', :'secure_access_web_proxy' => :'secure-access-web-proxy', :'tags' => :'tags', :'target_name' => :'target-name', :'token' => :'token', :'uid_token' => :'uid-token', :'user_ttl' => :'user-ttl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 390 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
172 173 174 175 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 172 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 139 def self.openapi_types { :'delete_protection' => :'String', :'input_rule' => :'Array<String>', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'name' => :'String', :'new_name' => :'String', :'output_rule' => :'Array<String>', :'password_length' => :'String', :'producer_encryption_key_name' => :'String', :'rabbitmq_admin_pwd' => :'String', :'rabbitmq_admin_user' => :'String', :'rabbitmq_server_uri' => :'String', :'rabbitmq_user_conf_permission' => :'String', :'rabbitmq_user_read_permission' => :'String', :'rabbitmq_user_tags' => :'String', :'rabbitmq_user_vhost' => :'String', :'rabbitmq_user_write_permission' => :'String', :'secure_access_enable' => :'String', :'secure_access_url' => :'String', :'secure_access_web' => :'Boolean', :'secure_access_web_browsing' => :'Boolean', :'secure_access_web_proxy' => :'Boolean', :'tags' => :'Array<String>', :'target_name' => :'String', :'token' => :'String', :'uid_token' => :'String', :'user_ttl' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 343 def ==(o) return true if self.equal?(o) self.class == o.class && delete_protection == o.delete_protection && input_rule == o.input_rule && item_custom_fields == o.item_custom_fields && json == o.json && name == o.name && new_name == o.new_name && output_rule == o.output_rule && password_length == o.password_length && producer_encryption_key_name == o.producer_encryption_key_name && rabbitmq_admin_pwd == o.rabbitmq_admin_pwd && rabbitmq_admin_user == o.rabbitmq_admin_user && rabbitmq_server_uri == o.rabbitmq_server_uri && == o. && == o. && == o. && rabbitmq_user_vhost == o.rabbitmq_user_vhost && == o. && secure_access_enable == o.secure_access_enable && secure_access_url == o.secure_access_url && secure_access_web == o.secure_access_web && secure_access_web_browsing == o.secure_access_web_browsing && secure_access_web_proxy == o.secure_access_web_proxy && == o. && target_name == o.target_name && token == o.token && uid_token == o.uid_token && user_ttl == o.user_ttl end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 485 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
377 378 379 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 377 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
383 384 385 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 383 def hash [delete_protection, input_rule, item_custom_fields, json, name, new_name, output_rule, password_length, producer_encryption_key_name, rabbitmq_admin_pwd, rabbitmq_admin_user, rabbitmq_server_uri, , , , rabbitmq_user_vhost, , secure_access_enable, secure_access_url, secure_access_web, secure_access_web_browsing, secure_access_web_proxy, , target_name, token, uid_token, user_ttl].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
323 324 325 326 327 328 329 330 331 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 323 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
461 462 463 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 461 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 467 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
455 456 457 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 455 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
335 336 337 338 339 |
# File 'lib/akeyless/models/gateway_update_producer_rabbit_mq.rb', line 335 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |