Class: Akeyless::GatewayUpdateProducerRedis
- Inherits:
-
Object
- Object
- Akeyless::GatewayUpdateProducerRedis
- Defined in:
- lib/akeyless/models/gateway_update_producer_redis.rb
Overview
gatewayUpdateProducerRedis is a command that updates redis producer [Deprecated: Use dynamic-secret-update-redis command]
Instance Attribute Summary collapse
-
#acl_rules ⇒ Object
A JSON array list of redis ACL rules to attach to the created user.
-
#ara_enabled ⇒ Object
Enable or disable Agentic Runtime Authority rule enforcement for this item.
-
#custom_username_template ⇒ Object
Customize how temporary usernames are generated using go template.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#host ⇒ Object
Redis Host.
-
#input_rule ⇒ Object
Agentic input rule in name=...,rule=...
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#name ⇒ Object
Dynamic secret name.
-
#new_name ⇒ Object
Dynamic secret name.
-
#output_rule ⇒ Object
Agentic output rule in name=...,rule=...
-
#password ⇒ Object
Redis Password.
-
#password_length ⇒ Object
The length of the password to be generated.
-
#port ⇒ Object
Redis Port.
-
#producer_encryption_key_name ⇒ Object
Dynamic producer encryption key.
-
#skip_dry_run ⇒ Object
If set, dry-run will be skipped.
-
#ssl ⇒ Object
Enable/Disable SSL [true/false].
-
#ssl_certificate ⇒ Object
SSL CA certificate in base64 encoding generated from a trusted Certificate Authority (CA).
-
#tags ⇒ Object
Add tags attached to this object.
-
#target_name ⇒ Object
Target name.
-
#token ⇒ Object
Authentication token (see
/authand/configure). -
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#use_capital_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z).
-
#use_lower_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z).
-
#use_numbers ⇒ Object
Specifies whether the generated temporary password must contain at least one numeric character (0 to 9).
-
#use_special_characters ⇒ Object
Returns the value of attribute use_special_characters.
-
#user_ttl ⇒ Object
User TTL.
-
#username ⇒ Object
Redis Username.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GatewayUpdateProducerRedis
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ GatewayUpdateProducerRedis
Initializes the object
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 183 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayUpdateProducerRedis` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayUpdateProducerRedis`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'acl_rules') self.acl_rules = attributes[:'acl_rules'] end if attributes.key?(:'ara_enabled') self.ara_enabled = attributes[:'ara_enabled'] end if attributes.key?(:'custom_username_template') self.custom_username_template = attributes[:'custom_username_template'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'host') self.host = attributes[:'host'] else self.host = '127.0.0.1' end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'new_name') self.new_name = attributes[:'new_name'] end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'password') self.password = attributes[:'password'] end if attributes.key?(:'password_length') self.password_length = attributes[:'password_length'] end if attributes.key?(:'port') self.port = attributes[:'port'] else self.port = '6379' end if attributes.key?(:'producer_encryption_key_name') self.producer_encryption_key_name = attributes[:'producer_encryption_key_name'] end if attributes.key?(:'skip_dry_run') self.skip_dry_run = attributes[:'skip_dry_run'] end if attributes.key?(:'ssl') self.ssl = attributes[:'ssl'] else self.ssl = false end if attributes.key?(:'ssl_certificate') self.ssl_certificate = attributes[:'ssl_certificate'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'target_name') self.target_name = attributes[:'target_name'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'use_capital_letters') self.use_capital_letters = attributes[:'use_capital_letters'] end if attributes.key?(:'use_lower_letters') self.use_lower_letters = attributes[:'use_lower_letters'] end if attributes.key?(:'use_numbers') self.use_numbers = attributes[:'use_numbers'] end if attributes.key?(:'use_special_characters') self.use_special_characters = attributes[:'use_special_characters'] end if attributes.key?(:'user_ttl') self.user_ttl = attributes[:'user_ttl'] else self.user_ttl = '60m' end if attributes.key?(:'username') self.username = attributes[:'username'] end end |
Instance Attribute Details
#acl_rules ⇒ Object
A JSON array list of redis ACL rules to attach to the created user. For available rules see the ACL CAT command https://redis.io/commands/acl-cat By default the user will have permissions to read all keys '["~*", "+@read"]'
20 21 22 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 20 def acl_rules @acl_rules end |
#ara_enabled ⇒ Object
Enable or disable Agentic Runtime Authority rule enforcement for this item. Mirrors commands.AgenticRulesParams.AraEnabled.
23 24 25 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 23 def ara_enabled @ara_enabled end |
#custom_username_template ⇒ Object
Customize how temporary usernames are generated using go template
26 27 28 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 26 def custom_username_template @custom_username_template end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
29 30 31 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 29 def delete_protection @delete_protection end |
#host ⇒ Object
Redis Host
32 33 34 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 32 def host @host end |
#input_rule ⇒ Object
Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).
35 36 37 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 35 def input_rule @input_rule end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
38 39 40 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 38 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
41 42 43 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 41 def json @json end |
#name ⇒ Object
Dynamic secret name
44 45 46 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 44 def name @name end |
#new_name ⇒ Object
Dynamic secret name
47 48 49 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 47 def new_name @new_name end |
#output_rule ⇒ Object
Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)
50 51 52 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 50 def output_rule @output_rule end |
#password ⇒ Object
Redis Password
53 54 55 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 53 def password @password end |
#password_length ⇒ Object
The length of the password to be generated
56 57 58 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 56 def password_length @password_length end |
#port ⇒ Object
Redis Port
59 60 61 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 59 def port @port end |
#producer_encryption_key_name ⇒ Object
Dynamic producer encryption key
62 63 64 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 62 def producer_encryption_key_name @producer_encryption_key_name end |
#skip_dry_run ⇒ Object
If set, dry-run will be skipped
65 66 67 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 65 def skip_dry_run @skip_dry_run end |
#ssl ⇒ Object
Enable/Disable SSL [true/false]
68 69 70 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 68 def ssl @ssl end |
#ssl_certificate ⇒ Object
SSL CA certificate in base64 encoding generated from a trusted Certificate Authority (CA)
71 72 73 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 71 def ssl_certificate @ssl_certificate end |
#tags ⇒ Object
Add tags attached to this object
74 75 76 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 74 def @tags end |
#target_name ⇒ Object
Target name
77 78 79 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 77 def target_name @target_name end |
#token ⇒ Object
Authentication token (see /auth and /configure)
80 81 82 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 80 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
83 84 85 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 83 def uid_token @uid_token end |
#use_capital_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). [true/false]
86 87 88 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 86 def use_capital_letters @use_capital_letters end |
#use_lower_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). [true/false]
89 90 91 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 89 def use_lower_letters @use_lower_letters end |
#use_numbers ⇒ Object
Specifies whether the generated temporary password must contain at least one numeric character (0 to 9). [true/false]
92 93 94 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 92 def use_numbers @use_numbers end |
#use_special_characters ⇒ Object
Returns the value of attribute use_special_characters.
94 95 96 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 94 def use_special_characters @use_special_characters end |
#user_ttl ⇒ Object
User TTL
97 98 99 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 97 def user_ttl @user_ttl end |
#username ⇒ Object
Redis Username
100 101 102 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 100 def username @username end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 423 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
137 138 139 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 137 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 103 def self.attribute_map { :'acl_rules' => :'acl-rules', :'ara_enabled' => :'ara-enabled', :'custom_username_template' => :'custom-username-template', :'delete_protection' => :'delete_protection', :'host' => :'host', :'input_rule' => :'input-rule', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'name' => :'name', :'new_name' => :'new-name', :'output_rule' => :'output-rule', :'password' => :'password', :'password_length' => :'password-length', :'port' => :'port', :'producer_encryption_key_name' => :'producer-encryption-key-name', :'skip_dry_run' => :'skip_dry_run', :'ssl' => :'ssl', :'ssl_certificate' => :'ssl-certificate', :'tags' => :'tags', :'target_name' => :'target-name', :'token' => :'token', :'uid_token' => :'uid-token', :'use_capital_letters' => :'use-capital-letters', :'use_lower_letters' => :'use-lower-letters', :'use_numbers' => :'use-numbers', :'use_special_characters' => :'use-special-characters', :'user_ttl' => :'user-ttl', :'username' => :'username' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 399 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
176 177 178 179 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 176 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 142 def self.openapi_types { :'acl_rules' => :'String', :'ara_enabled' => :'Boolean', :'custom_username_template' => :'String', :'delete_protection' => :'String', :'host' => :'String', :'input_rule' => :'Array<String>', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'name' => :'String', :'new_name' => :'String', :'output_rule' => :'Array<String>', :'password' => :'String', :'password_length' => :'String', :'port' => :'String', :'producer_encryption_key_name' => :'String', :'skip_dry_run' => :'String', :'ssl' => :'Boolean', :'ssl_certificate' => :'String', :'tags' => :'Array<String>', :'target_name' => :'String', :'token' => :'String', :'uid_token' => :'String', :'use_capital_letters' => :'String', :'use_lower_letters' => :'String', :'use_numbers' => :'String', :'use_special_characters' => :'String', :'user_ttl' => :'String', :'username' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 351 def ==(o) return true if self.equal?(o) self.class == o.class && acl_rules == o.acl_rules && ara_enabled == o.ara_enabled && custom_username_template == o.custom_username_template && delete_protection == o.delete_protection && host == o.host && input_rule == o.input_rule && item_custom_fields == o.item_custom_fields && json == o.json && name == o.name && new_name == o.new_name && output_rule == o.output_rule && password == o.password && password_length == o.password_length && port == o.port && producer_encryption_key_name == o.producer_encryption_key_name && skip_dry_run == o.skip_dry_run && ssl == o.ssl && ssl_certificate == o.ssl_certificate && == o. && target_name == o.target_name && token == o.token && uid_token == o.uid_token && use_capital_letters == o.use_capital_letters && use_lower_letters == o.use_lower_letters && use_numbers == o.use_numbers && use_special_characters == o.use_special_characters && user_ttl == o.user_ttl && username == o.username end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
494 495 496 497 498 499 500 501 502 503 504 505 506 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 494 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
386 387 388 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 386 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
392 393 394 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 392 def hash [acl_rules, ara_enabled, custom_username_template, delete_protection, host, input_rule, item_custom_fields, json, name, new_name, output_rule, password, password_length, port, producer_encryption_key_name, skip_dry_run, ssl, ssl_certificate, , target_name, token, uid_token, use_capital_letters, use_lower_letters, use_numbers, use_special_characters, user_ttl, username].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
331 332 333 334 335 336 337 338 339 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 331 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
470 471 472 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 470 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
476 477 478 479 480 481 482 483 484 485 486 487 488 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 476 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
464 465 466 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 464 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
343 344 345 346 347 |
# File 'lib/akeyless/models/gateway_update_producer_redis.rb', line 343 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |