Class: Akeyless::GatewayUpdateRemoteAccessRdpRecordings
- Inherits:
-
Object
- Object
- Akeyless::GatewayUpdateRemoteAccessRdpRecordings
- Defined in:
- lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb
Overview
gatewayUpdateRemoteAccessRdpRecordings is a command that update remote access rdp recording config
Instance Attribute Summary collapse
-
#aws_storage_access_key_id ⇒ Object
AWS access key id.
-
#aws_storage_bucket_name ⇒ Object
The AWS bucket name.
-
#aws_storage_bucket_prefix ⇒ Object
The folder name in S3 bucket.
-
#aws_storage_endpoint_url ⇒ Object
Custom AWS endpoint URL for S3-compatible storage (e.g. a private AWS endpoint).
-
#aws_storage_region ⇒ Object
The region where the storage is located.
-
#aws_storage_secret_access_key ⇒ Object
AWS secret access key.
-
#azure_storage_account_name ⇒ Object
Azure account name.
-
#azure_storage_client_id ⇒ Object
Azure client id.
-
#azure_storage_client_secret ⇒ Object
Azure client secret.
-
#azure_storage_container_name ⇒ Object
Azure container name.
-
#azure_storage_tenant_id ⇒ Object
Azure tenant id.
-
#json ⇒ Object
Set output format to JSON.
-
#rdp_session_recording ⇒ Object
Enable recording of rdp session [true/false].
-
#rdp_session_recording_compress ⇒ Object
Whether to compress recording files before upload.
-
#rdp_session_recording_encryption_key ⇒ Object
If provided, this key will be used to encrypt uploaded recordings.
-
#rdp_session_recording_quality ⇒ Object
RDP session recording quality [low/medium/high].
-
#rdp_session_storage ⇒ Object
Rdp session recording storage destination [local/aws/azure].
-
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`).
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GatewayUpdateRemoteAccessRdpRecordings
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ GatewayUpdateRemoteAccessRdpRecordings
Initializes the object
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 139 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayUpdateRemoteAccessRdpRecordings` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayUpdateRemoteAccessRdpRecordings`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'aws_storage_access_key_id') self.aws_storage_access_key_id = attributes[:'aws_storage_access_key_id'] end if attributes.key?(:'aws_storage_bucket_name') self.aws_storage_bucket_name = attributes[:'aws_storage_bucket_name'] end if attributes.key?(:'aws_storage_bucket_prefix') self.aws_storage_bucket_prefix = attributes[:'aws_storage_bucket_prefix'] end if attributes.key?(:'aws_storage_endpoint_url') self.aws_storage_endpoint_url = attributes[:'aws_storage_endpoint_url'] end if attributes.key?(:'aws_storage_region') self.aws_storage_region = attributes[:'aws_storage_region'] end if attributes.key?(:'aws_storage_secret_access_key') self.aws_storage_secret_access_key = attributes[:'aws_storage_secret_access_key'] end if attributes.key?(:'azure_storage_account_name') self.azure_storage_account_name = attributes[:'azure_storage_account_name'] end if attributes.key?(:'azure_storage_client_id') self.azure_storage_client_id = attributes[:'azure_storage_client_id'] end if attributes.key?(:'azure_storage_client_secret') self.azure_storage_client_secret = attributes[:'azure_storage_client_secret'] end if attributes.key?(:'azure_storage_container_name') self.azure_storage_container_name = attributes[:'azure_storage_container_name'] end if attributes.key?(:'azure_storage_tenant_id') self.azure_storage_tenant_id = attributes[:'azure_storage_tenant_id'] end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'rdp_session_recording') self.rdp_session_recording = attributes[:'rdp_session_recording'] end if attributes.key?(:'rdp_session_recording_compress') self.rdp_session_recording_compress = attributes[:'rdp_session_recording_compress'] end if attributes.key?(:'rdp_session_recording_encryption_key') self.rdp_session_recording_encryption_key = attributes[:'rdp_session_recording_encryption_key'] end if attributes.key?(:'rdp_session_recording_quality') self.rdp_session_recording_quality = attributes[:'rdp_session_recording_quality'] end if attributes.key?(:'rdp_session_storage') self.rdp_session_storage = attributes[:'rdp_session_storage'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end end |
Instance Attribute Details
#aws_storage_access_key_id ⇒ Object
AWS access key id. For more information refer to docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_access-keys.html
20 21 22 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 20 def aws_storage_access_key_id @aws_storage_access_key_id end |
#aws_storage_bucket_name ⇒ Object
The AWS bucket name. For more information refer to docs.aws.amazon.com/s3/
23 24 25 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 23 def aws_storage_bucket_name @aws_storage_bucket_name end |
#aws_storage_bucket_prefix ⇒ Object
The folder name in S3 bucket. For more information refer to docs.aws.amazon.com/s3/
26 27 28 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 26 def aws_storage_bucket_prefix @aws_storage_bucket_prefix end |
#aws_storage_endpoint_url ⇒ Object
Custom AWS endpoint URL for S3-compatible storage (e.g. a private AWS endpoint)
29 30 31 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 29 def aws_storage_endpoint_url @aws_storage_endpoint_url end |
#aws_storage_region ⇒ Object
The region where the storage is located
32 33 34 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 32 def aws_storage_region @aws_storage_region end |
#aws_storage_secret_access_key ⇒ Object
AWS secret access key. For more information refer to docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_access-keys.html
35 36 37 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 35 def aws_storage_secret_access_key @aws_storage_secret_access_key end |
#azure_storage_account_name ⇒ Object
Azure account name. For more information refer to learn.microsoft.com/en-us/azure/storage/common/storage-account-overview
38 39 40 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 38 def azure_storage_account_name @azure_storage_account_name end |
#azure_storage_client_id ⇒ Object
Azure client id. For more information refer to learn.microsoft.com/en-us/azure/storage/common/storage-account-get-info?tabs=portal
41 42 43 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 41 def azure_storage_client_id @azure_storage_client_id end |
#azure_storage_client_secret ⇒ Object
Azure client secret. For more information refer to learn.microsoft.com/en-us/azure/storage/common/storage-account-get-info?tabs=portal
44 45 46 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 44 def azure_storage_client_secret @azure_storage_client_secret end |
#azure_storage_container_name ⇒ Object
Azure container name. For more information refer to learn.microsoft.com/en-us/rest/api/storageservices/naming-and-referencing-containers–blobs–and-metadata
47 48 49 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 47 def azure_storage_container_name @azure_storage_container_name end |
#azure_storage_tenant_id ⇒ Object
Azure tenant id. For more information refer to learn.microsoft.com/en-us/entra/fundamentals/how-to-find-tenant
50 51 52 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 50 def azure_storage_tenant_id @azure_storage_tenant_id end |
#json ⇒ Object
Set output format to JSON
53 54 55 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 53 def json @json end |
#rdp_session_recording ⇒ Object
Enable recording of rdp session [true/false]
56 57 58 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 56 def rdp_session_recording @rdp_session_recording end |
#rdp_session_recording_compress ⇒ Object
Whether to compress recording files before upload
59 60 61 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 59 def rdp_session_recording_compress @rdp_session_recording_compress end |
#rdp_session_recording_encryption_key ⇒ Object
If provided, this key will be used to encrypt uploaded recordings.
62 63 64 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 62 def rdp_session_recording_encryption_key @rdp_session_recording_encryption_key end |
#rdp_session_recording_quality ⇒ Object
RDP session recording quality [low/medium/high]
65 66 67 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 65 def rdp_session_recording_quality @rdp_session_recording_quality end |
#rdp_session_storage ⇒ Object
Rdp session recording storage destination [local/aws/azure]
68 69 70 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 68 def rdp_session_storage @rdp_session_storage end |
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`)
71 72 73 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 71 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
74 75 76 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 74 def uid_token @uid_token end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 311 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
102 103 104 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 102 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 77 def self.attribute_map { :'aws_storage_access_key_id' => :'aws-storage-access-key-id', :'aws_storage_bucket_name' => :'aws-storage-bucket-name', :'aws_storage_bucket_prefix' => :'aws-storage-bucket-prefix', :'aws_storage_endpoint_url' => :'aws-storage-endpoint-url', :'aws_storage_region' => :'aws-storage-region', :'aws_storage_secret_access_key' => :'aws-storage-secret-access-key', :'azure_storage_account_name' => :'azure-storage-account-name', :'azure_storage_client_id' => :'azure-storage-client-id', :'azure_storage_client_secret' => :'azure-storage-client-secret', :'azure_storage_container_name' => :'azure-storage-container-name', :'azure_storage_tenant_id' => :'azure-storage-tenant-id', :'json' => :'json', :'rdp_session_recording' => :'rdp-session-recording', :'rdp_session_recording_compress' => :'rdp-session-recording-compress', :'rdp_session_recording_encryption_key' => :'rdp-session-recording-encryption-key', :'rdp_session_recording_quality' => :'rdp-session-recording-quality', :'rdp_session_storage' => :'rdp-session-storage', :'token' => :'token', :'uid_token' => :'uid-token' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 287 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
132 133 134 135 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 132 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 107 def self.openapi_types { :'aws_storage_access_key_id' => :'String', :'aws_storage_bucket_name' => :'String', :'aws_storage_bucket_prefix' => :'String', :'aws_storage_endpoint_url' => :'String', :'aws_storage_region' => :'String', :'aws_storage_secret_access_key' => :'String', :'azure_storage_account_name' => :'String', :'azure_storage_client_id' => :'String', :'azure_storage_client_secret' => :'String', :'azure_storage_container_name' => :'String', :'azure_storage_tenant_id' => :'String', :'json' => :'Boolean', :'rdp_session_recording' => :'String', :'rdp_session_recording_compress' => :'Boolean', :'rdp_session_recording_encryption_key' => :'String', :'rdp_session_recording_quality' => :'String', :'rdp_session_storage' => :'String', :'token' => :'String', :'uid_token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 248 def ==(o) return true if self.equal?(o) self.class == o.class && aws_storage_access_key_id == o.aws_storage_access_key_id && aws_storage_bucket_name == o.aws_storage_bucket_name && aws_storage_bucket_prefix == o.aws_storage_bucket_prefix && aws_storage_endpoint_url == o.aws_storage_endpoint_url && aws_storage_region == o.aws_storage_region && aws_storage_secret_access_key == o.aws_storage_secret_access_key && azure_storage_account_name == o.azure_storage_account_name && azure_storage_client_id == o.azure_storage_client_id && azure_storage_client_secret == o.azure_storage_client_secret && azure_storage_container_name == o.azure_storage_container_name && azure_storage_tenant_id == o.azure_storage_tenant_id && json == o.json && rdp_session_recording == o.rdp_session_recording && rdp_session_recording_compress == o.rdp_session_recording_compress && rdp_session_recording_encryption_key == o.rdp_session_recording_encryption_key && rdp_session_recording_quality == o.rdp_session_recording_quality && rdp_session_storage == o.rdp_session_storage && token == o.token && uid_token == o.uid_token end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 382 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
274 275 276 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 274 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
280 281 282 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 280 def hash [aws_storage_access_key_id, aws_storage_bucket_name, aws_storage_bucket_prefix, aws_storage_endpoint_url, aws_storage_region, aws_storage_secret_access_key, azure_storage_account_name, azure_storage_client_id, azure_storage_client_secret, azure_storage_container_name, azure_storage_tenant_id, json, rdp_session_recording, rdp_session_recording_compress, rdp_session_recording_encryption_key, rdp_session_recording_quality, rdp_session_storage, token, uid_token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
233 234 235 236 237 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 233 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
358 359 360 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 358 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 364 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
352 353 354 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 352 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
241 242 243 244 |
# File 'lib/akeyless/models/gateway_update_remote_access_rdp_recordings.rb', line 241 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |