Class: Akeyless::GetPKICertificate

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/get_pki_certificate.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GetPKICertificate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/akeyless/models/get_pki_certificate.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GetPKICertificate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GetPKICertificate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'alt_names')
    self.alt_names = attributes[:'alt_names']
  end

  if attributes.key?(:'cert_issuer_name')
    self.cert_issuer_name = attributes[:'cert_issuer_name']
  end

  if attributes.key?(:'common_name')
    self.common_name = attributes[:'common_name']
  end

  if attributes.key?(:'extended_key_usage')
    self.extended_key_usage = attributes[:'extended_key_usage']
  end

  if attributes.key?(:'key_data_base64')
    self.key_data_base64 = attributes[:'key_data_base64']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'ttl')
    self.ttl = attributes[:'ttl']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'uri_sans')
    self.uri_sans = attributes[:'uri_sans']
  end
end

Instance Attribute Details

#alt_names ⇒ Object

The Subject Alternative Names to be included in the PKI certificate (in a comma-delimited list)



19
20
21
# File 'lib/akeyless/models/get_pki_certificate.rb', line 19

def alt_names
  @alt_names
end

#cert_issuer_name ⇒ Object

The name of the PKI certificate issuer



22
23
24
# File 'lib/akeyless/models/get_pki_certificate.rb', line 22

def cert_issuer_name
  @cert_issuer_name
end

#common_name ⇒ Object

The common name to be included in the PKI certificate



25
26
27
# File 'lib/akeyless/models/get_pki_certificate.rb', line 25

def common_name
  @common_name
end

#extended_key_usage ⇒ Object

A comma-separated list of extended key usage requests which will be used for certificate issuance. Supported values: 'clientauth', 'serverauth'.



28
29
30
# File 'lib/akeyless/models/get_pki_certificate.rb', line 28

def extended_key_usage
  @extended_key_usage
end

#key_data_base64 ⇒ Object

PKI key file contents. If this option is used, the certificate will be printed to stdout



31
32
33
# File 'lib/akeyless/models/get_pki_certificate.rb', line 31

def key_data_base64
  @key_data_base64
end

#token ⇒ Object

Authentication token (see /auth and /configure)



34
35
36
# File 'lib/akeyless/models/get_pki_certificate.rb', line 34

def token
  @token
end

#ttl ⇒ Object

Updated certificate lifetime in seconds (must be less than the Certificate Issuer default TTL)



37
38
39
# File 'lib/akeyless/models/get_pki_certificate.rb', line 37

def ttl
  @ttl
end

#uid_token ⇒ Object

The universal identity token, Required only for universal_identity authentication



40
41
42
# File 'lib/akeyless/models/get_pki_certificate.rb', line 40

def uid_token
  @uid_token
end

#uri_sans ⇒ Object

The URI Subject Alternative Names to be included in the PKI certificate (in a comma-delimited list)



43
44
45
# File 'lib/akeyless/models/get_pki_certificate.rb', line 43

def uri_sans
  @uri_sans
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/akeyless/models/get_pki_certificate.rb', line 61

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/akeyless/models/get_pki_certificate.rb', line 46

def self.attribute_map
  {
    :'alt_names' => :'alt-names',
    :'cert_issuer_name' => :'cert-issuer-name',
    :'common_name' => :'common-name',
    :'extended_key_usage' => :'extended-key-usage',
    :'key_data_base64' => :'key-data-base64',
    :'token' => :'token',
    :'ttl' => :'ttl',
    :'uid_token' => :'uid-token',
    :'uri_sans' => :'uri-sans'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



187
188
189
# File 'lib/akeyless/models/get_pki_certificate.rb', line 187

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



81
82
83
84
# File 'lib/akeyless/models/get_pki_certificate.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/akeyless/models/get_pki_certificate.rb', line 66

def self.openapi_types
  {
    :'alt_names' => :'String',
    :'cert_issuer_name' => :'String',
    :'common_name' => :'String',
    :'extended_key_usage' => :'String',
    :'key_data_base64' => :'String',
    :'token' => :'String',
    :'ttl' => :'Integer',
    :'uid_token' => :'String',
    :'uri_sans' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/akeyless/models/get_pki_certificate.rb', line 158

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      alt_names == o.alt_names &&
      cert_issuer_name == o.cert_issuer_name &&
      common_name == o.common_name &&
      extended_key_usage == o.extended_key_usage &&
      key_data_base64 == o.key_data_base64 &&
      token == o.token &&
      ttl == o.ttl &&
      uid_token == o.uid_token &&
      uri_sans == o.uri_sans
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/akeyless/models/get_pki_certificate.rb', line 218

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/akeyless/models/get_pki_certificate.rb', line 289

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/akeyless/models/get_pki_certificate.rb', line 194

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


174
175
176
# File 'lib/akeyless/models/get_pki_certificate.rb', line 174

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



180
181
182
# File 'lib/akeyless/models/get_pki_certificate.rb', line 180

def hash
  [alt_names, cert_issuer_name, common_name, extended_key_usage, key_data_base64, token, ttl, uid_token, uri_sans].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
145
146
147
# File 'lib/akeyless/models/get_pki_certificate.rb', line 140

def list_invalid_properties
  invalid_properties = Array.new
  if @cert_issuer_name.nil?
    invalid_properties.push('invalid value for "cert_issuer_name", cert_issuer_name cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



265
266
267
# File 'lib/akeyless/models/get_pki_certificate.rb', line 265

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/akeyless/models/get_pki_certificate.rb', line 271

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



259
260
261
# File 'lib/akeyless/models/get_pki_certificate.rb', line 259

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



151
152
153
154
# File 'lib/akeyless/models/get_pki_certificate.rb', line 151

def valid?
  return false if @cert_issuer_name.nil?
  true
end