Class: Akeyless::ItemGeneralInfo

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/item_general_info.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ItemGeneralInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/akeyless/models/item_general_info.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::ItemGeneralInfo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::ItemGeneralInfo`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'agentic_rules')
    self.agentic_rules = attributes[:'agentic_rules']
  end

  if attributes.key?(:'cert_issue_details')
    self.cert_issue_details = attributes[:'cert_issue_details']
  end

  if attributes.key?(:'certificate_chain_info')
    self.certificate_chain_info = attributes[:'certificate_chain_info']
  end

  if attributes.key?(:'certificate_format')
    self.certificate_format = attributes[:'certificate_format']
  end

  if attributes.key?(:'certificates_template_info')
    self.certificates_template_info = attributes[:'certificates_template_info']
  end

  if attributes.key?(:'classic_key_details')
    self.classic_key_details = attributes[:'classic_key_details']
  end

  if attributes.key?(:'cluster_gw_url')
    self.cluster_gw_url = attributes[:'cluster_gw_url']
  end

  if attributes.key?(:'display_metadata')
    self. = attributes[:'display_metadata']
  end

  if attributes.key?(:'dynamic_secret_producer_details')
    self.dynamic_secret_producer_details = attributes[:'dynamic_secret_producer_details']
  end

  if attributes.key?(:'expiration_events')
    if (value = attributes[:'expiration_events']).is_a?(Array)
      self.expiration_events = value
    end
  end

  if attributes.key?(:'importer_info')
    self.importer_info = attributes[:'importer_info']
  end

  if attributes.key?(:'issuer_overview_info')
    self.issuer_overview_info = attributes[:'issuer_overview_info']
  end

  if attributes.key?(:'next_rotation_events')
    if (value = attributes[:'next_rotation_events']).is_a?(Array)
      self.next_rotation_events = value
    end
  end

  if attributes.key?(:'oidc_client_info')
    self.oidc_client_info = attributes[:'oidc_client_info']
  end

  if attributes.key?(:'password_policy')
    self.password_policy = attributes[:'password_policy']
  end

  if attributes.key?(:'rotated_secret_details')
    self.rotated_secret_details = attributes[:'rotated_secret_details']
  end

  if attributes.key?(:'secure_remote_access_details')
    self.secure_remote_access_details = attributes[:'secure_remote_access_details']
  end

  if attributes.key?(:'static_secret_info')
    self.static_secret_info = attributes[:'static_secret_info']
  end

  if attributes.key?(:'tokenizer_info')
    self.tokenizer_info = attributes[:'tokenizer_info']
  end
end

Instance Attribute Details

#agentic_rulesObject

Returns the value of attribute agentic_rules.



18
19
20
# File 'lib/akeyless/models/item_general_info.rb', line 18

def agentic_rules
  @agentic_rules
end

#cert_issue_detailsObject

Returns the value of attribute cert_issue_details.



20
21
22
# File 'lib/akeyless/models/item_general_info.rb', line 20

def cert_issue_details
  @cert_issue_details
end

#certificate_chain_infoObject

Returns the value of attribute certificate_chain_info.



22
23
24
# File 'lib/akeyless/models/item_general_info.rb', line 22

def certificate_chain_info
  @certificate_chain_info
end

#certificate_formatObject

Returns the value of attribute certificate_format.



24
25
26
# File 'lib/akeyless/models/item_general_info.rb', line 24

def certificate_format
  @certificate_format
end

#certificates_template_infoObject

Returns the value of attribute certificates_template_info.



26
27
28
# File 'lib/akeyless/models/item_general_info.rb', line 26

def certificates_template_info
  @certificates_template_info
end

#classic_key_detailsObject

Returns the value of attribute classic_key_details.



28
29
30
# File 'lib/akeyless/models/item_general_info.rb', line 28

def classic_key_details
  @classic_key_details
end

#cluster_gw_urlObject

Returns the value of attribute cluster_gw_url.



30
31
32
# File 'lib/akeyless/models/item_general_info.rb', line 30

def cluster_gw_url
  @cluster_gw_url
end

#display_metadataObject

Returns the value of attribute display_metadata.



32
33
34
# File 'lib/akeyless/models/item_general_info.rb', line 32

def 
  @display_metadata
end

#dynamic_secret_producer_detailsObject

Returns the value of attribute dynamic_secret_producer_details.



34
35
36
# File 'lib/akeyless/models/item_general_info.rb', line 34

def dynamic_secret_producer_details
  @dynamic_secret_producer_details
end

#expiration_eventsObject

Returns the value of attribute expiration_events.



36
37
38
# File 'lib/akeyless/models/item_general_info.rb', line 36

def expiration_events
  @expiration_events
end

#importer_infoObject

Returns the value of attribute importer_info.



38
39
40
# File 'lib/akeyless/models/item_general_info.rb', line 38

def importer_info
  @importer_info
end

#issuer_overview_infoObject

Returns the value of attribute issuer_overview_info.



40
41
42
# File 'lib/akeyless/models/item_general_info.rb', line 40

def issuer_overview_info
  @issuer_overview_info
end

#next_rotation_eventsObject

Returns the value of attribute next_rotation_events.



42
43
44
# File 'lib/akeyless/models/item_general_info.rb', line 42

def next_rotation_events
  @next_rotation_events
end

#oidc_client_infoObject

Returns the value of attribute oidc_client_info.



44
45
46
# File 'lib/akeyless/models/item_general_info.rb', line 44

def oidc_client_info
  @oidc_client_info
end

#password_policyObject

Returns the value of attribute password_policy.



46
47
48
# File 'lib/akeyless/models/item_general_info.rb', line 46

def password_policy
  @password_policy
end

#rotated_secret_detailsObject

Returns the value of attribute rotated_secret_details.



48
49
50
# File 'lib/akeyless/models/item_general_info.rb', line 48

def rotated_secret_details
  @rotated_secret_details
end

#secure_remote_access_detailsObject

Returns the value of attribute secure_remote_access_details.



50
51
52
# File 'lib/akeyless/models/item_general_info.rb', line 50

def secure_remote_access_details
  @secure_remote_access_details
end

#static_secret_infoObject

Returns the value of attribute static_secret_info.



52
53
54
# File 'lib/akeyless/models/item_general_info.rb', line 52

def static_secret_info
  @static_secret_info
end

#tokenizer_infoObject

Returns the value of attribute tokenizer_info.



54
55
56
# File 'lib/akeyless/models/item_general_info.rb', line 54

def tokenizer_info
  @tokenizer_info
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/akeyless/models/item_general_info.rb', line 293

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/akeyless/models/item_general_info.rb', line 82

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/akeyless/models/item_general_info.rb', line 57

def self.attribute_map
  {
    :'agentic_rules' => :'agentic_rules',
    :'cert_issue_details' => :'cert_issue_details',
    :'certificate_chain_info' => :'certificate_chain_info',
    :'certificate_format' => :'certificate_format',
    :'certificates_template_info' => :'certificates_template_info',
    :'classic_key_details' => :'classic_key_details',
    :'cluster_gw_url' => :'cluster_gw_url',
    :'display_metadata' => :'display_metadata',
    :'dynamic_secret_producer_details' => :'dynamic_secret_producer_details',
    :'expiration_events' => :'expiration_events',
    :'importer_info' => :'importer_info',
    :'issuer_overview_info' => :'issuer_overview_info',
    :'next_rotation_events' => :'next_rotation_events',
    :'oidc_client_info' => :'oidc_client_info',
    :'password_policy' => :'password_policy',
    :'rotated_secret_details' => :'rotated_secret_details',
    :'secure_remote_access_details' => :'secure_remote_access_details',
    :'static_secret_info' => :'static_secret_info',
    :'tokenizer_info' => :'tokenizer_info'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/akeyless/models/item_general_info.rb', line 269

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
# File 'lib/akeyless/models/item_general_info.rb', line 112

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/akeyless/models/item_general_info.rb', line 87

def self.openapi_types
  {
    :'agentic_rules' => :'AgenticRules',
    :'cert_issue_details' => :'CertificateIssueInfo',
    :'certificate_chain_info' => :'CertificateChainInfo',
    :'certificate_format' => :'String',
    :'certificates_template_info' => :'CertificateTemplateInfo',
    :'classic_key_details' => :'ClassicKeyDetailsInfo',
    :'cluster_gw_url' => :'String',
    :'display_metadata' => :'String',
    :'dynamic_secret_producer_details' => :'DynamicSecretProducerInfo',
    :'expiration_events' => :'Array<CertificateExpirationEvent>',
    :'importer_info' => :'ImporterInfo',
    :'issuer_overview_info' => :'IssuerOverviewInfo',
    :'next_rotation_events' => :'Array<NextAutoRotationEvent>',
    :'oidc_client_info' => :'OidcClientInfo',
    :'password_policy' => :'PasswordPolicyInfo',
    :'rotated_secret_details' => :'RotatedSecretDetailsInfo',
    :'secure_remote_access_details' => :'SecureRemoteAccess',
    :'static_secret_info' => :'StaticSecretDetailsInfo',
    :'tokenizer_info' => :'TokenizerInfo'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/akeyless/models/item_general_info.rb', line 230

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      agentic_rules == o.agentic_rules &&
      cert_issue_details == o.cert_issue_details &&
      certificate_chain_info == o.certificate_chain_info &&
      certificate_format == o.certificate_format &&
      certificates_template_info == o.certificates_template_info &&
      classic_key_details == o.classic_key_details &&
      cluster_gw_url == o.cluster_gw_url &&
       == o. &&
      dynamic_secret_producer_details == o.dynamic_secret_producer_details &&
      expiration_events == o.expiration_events &&
      importer_info == o.importer_info &&
      issuer_overview_info == o.issuer_overview_info &&
      next_rotation_events == o.next_rotation_events &&
      oidc_client_info == o.oidc_client_info &&
      password_policy == o.password_policy &&
      rotated_secret_details == o.rotated_secret_details &&
      secure_remote_access_details == o.secure_remote_access_details &&
      static_secret_info == o.static_secret_info &&
      tokenizer_info == o.tokenizer_info
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/akeyless/models/item_general_info.rb', line 364

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


256
257
258
# File 'lib/akeyless/models/item_general_info.rb', line 256

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



262
263
264
# File 'lib/akeyless/models/item_general_info.rb', line 262

def hash
  [agentic_rules, cert_issue_details, certificate_chain_info, certificate_format, certificates_template_info, classic_key_details, cluster_gw_url, , dynamic_secret_producer_details, expiration_events, importer_info, issuer_overview_info, next_rotation_events, oidc_client_info, password_policy, rotated_secret_details, secure_remote_access_details, static_secret_info, tokenizer_info].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



215
216
217
218
219
# File 'lib/akeyless/models/item_general_info.rb', line 215

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



340
341
342
# File 'lib/akeyless/models/item_general_info.rb', line 340

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/akeyless/models/item_general_info.rb', line 346

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



334
335
336
# File 'lib/akeyless/models/item_general_info.rb', line 334

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



223
224
225
226
# File 'lib/akeyless/models/item_general_info.rb', line 223

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end