Class: Akeyless::ListItems

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/list_items.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ListItems

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/akeyless/models/list_items.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::ListItems` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::ListItems`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'accessibility')
    self.accessibility = attributes[:'accessibility']
  else
    self.accessibility = 'regular'
  end

  if attributes.key?(:'advanced_filter')
    self.advanced_filter = attributes[:'advanced_filter']
  end

  if attributes.key?(:'ara_only')
    self.ara_only = attributes[:'ara_only']
  else
    self.ara_only = false
  end

  if attributes.key?(:'auto_pagination')
    self.auto_pagination = attributes[:'auto_pagination']
  else
    self.auto_pagination = 'enabled'
  end

  if attributes.key?(:'current_folder')
    self.current_folder = attributes[:'current_folder']
  else
    self.current_folder = false
  end

  if attributes.key?(:'filter')
    self.filter = attributes[:'filter']
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'minimal_view')
    self.minimal_view = attributes[:'minimal_view']
  end

  if attributes.key?(:'modified_after')
    self.modified_after = attributes[:'modified_after']
  end

  if attributes.key?(:'pagination_token')
    self.pagination_token = attributes[:'pagination_token']
  end

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  end

  if attributes.key?(:'sra_only')
    self.sra_only = attributes[:'sra_only']
  else
    self.sra_only = false
  end

  if attributes.key?(:'sub_types')
    if (value = attributes[:'sub_types']).is_a?(Array)
      self.sub_types = value
    end
  end

  if attributes.key?(:'tag')
    self.tag = attributes[:'tag']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'type')
    if (value = attributes[:'type']).is_a?(Array)
      self.type = value
    end
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end
end

Instance Attribute Details

#accessibilityObject

for personal password manager



19
20
21
# File 'lib/akeyless/models/list_items.rb', line 19

def accessibility
  @accessibility
end

#advanced_filterObject

Filter by item name/username/website or part of it



22
23
24
# File 'lib/akeyless/models/list_items.rb', line 22

def advanced_filter
  @advanced_filter
end

#ara_onlyObject

Filter by items with ARA functionality enabled



25
26
27
# File 'lib/akeyless/models/list_items.rb', line 25

def ara_only
  @ara_only
end

#auto_paginationObject

Retrieve all items using pagination, when disabled retrieving only first 1000 items



28
29
30
# File 'lib/akeyless/models/list_items.rb', line 28

def auto_pagination
  @auto_pagination
end

#current_folderObject

List only items in the current folder (excludes subfolders)



31
32
33
# File 'lib/akeyless/models/list_items.rb', line 31

def current_folder
  @current_folder
end

#filterObject

Filter by item name or part of it



34
35
36
# File 'lib/akeyless/models/list_items.rb', line 34

def filter
  @filter
end

#jsonObject

Set output format to JSON



37
38
39
# File 'lib/akeyless/models/list_items.rb', line 37

def json
  @json
end

#minimal_viewObject

Show only basic information of the items



40
41
42
# File 'lib/akeyless/models/list_items.rb', line 40

def minimal_view
  @minimal_view
end

#modified_afterObject

List only secrets modified after specified date (in unix time)



43
44
45
# File 'lib/akeyless/models/list_items.rb', line 43

def modified_after
  @modified_after
end

#pagination_tokenObject

Next page reference



46
47
48
# File 'lib/akeyless/models/list_items.rb', line 46

def pagination_token
  @pagination_token
end

#pathObject

Path to folder



49
50
51
# File 'lib/akeyless/models/list_items.rb', line 49

def path
  @path
end

#sra_onlyObject

Filter by items with SRA functionality enabled



52
53
54
# File 'lib/akeyless/models/list_items.rb', line 52

def sra_only
  @sra_only
end

#sub_typesObject

Returns the value of attribute sub_types.



54
55
56
# File 'lib/akeyless/models/list_items.rb', line 54

def sub_types
  @sub_types
end

#tagObject

Filter by item tag



57
58
59
# File 'lib/akeyless/models/list_items.rb', line 57

def tag
  @tag
end

#tokenObject

Authentication token (see ‘/auth` and `/configure`)



60
61
62
# File 'lib/akeyless/models/list_items.rb', line 60

def token
  @token
end

#typeObject

The item types list of the requested items. In case it is empty, all types of items will be returned. options: [key, static-secret, dynamic-secret, classic-key]



63
64
65
# File 'lib/akeyless/models/list_items.rb', line 63

def type
  @type
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



66
67
68
# File 'lib/akeyless/models/list_items.rb', line 66

def uid_token
  @uid_token
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/akeyless/models/list_items.rb', line 303

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/akeyless/models/list_items.rb', line 92

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/akeyless/models/list_items.rb', line 69

def self.attribute_map
  {
    :'accessibility' => :'accessibility',
    :'advanced_filter' => :'advanced-filter',
    :'ara_only' => :'ara-only',
    :'auto_pagination' => :'auto-pagination',
    :'current_folder' => :'current-folder',
    :'filter' => :'filter',
    :'json' => :'json',
    :'minimal_view' => :'minimal-view',
    :'modified_after' => :'modified-after',
    :'pagination_token' => :'pagination-token',
    :'path' => :'path',
    :'sra_only' => :'sra-only',
    :'sub_types' => :'sub-types',
    :'tag' => :'tag',
    :'token' => :'token',
    :'type' => :'type',
    :'uid_token' => :'uid-token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/akeyless/models/list_items.rb', line 279

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
# File 'lib/akeyless/models/list_items.rb', line 120

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/akeyless/models/list_items.rb', line 97

def self.openapi_types
  {
    :'accessibility' => :'String',
    :'advanced_filter' => :'String',
    :'ara_only' => :'Boolean',
    :'auto_pagination' => :'String',
    :'current_folder' => :'Boolean',
    :'filter' => :'String',
    :'json' => :'Boolean',
    :'minimal_view' => :'Boolean',
    :'modified_after' => :'Integer',
    :'pagination_token' => :'String',
    :'path' => :'String',
    :'sra_only' => :'Boolean',
    :'sub_types' => :'Array<String>',
    :'tag' => :'String',
    :'token' => :'String',
    :'type' => :'Array<String>',
    :'uid_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/akeyless/models/list_items.rb', line 242

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      accessibility == o.accessibility &&
      advanced_filter == o.advanced_filter &&
      ara_only == o.ara_only &&
      auto_pagination == o.auto_pagination &&
      current_folder == o.current_folder &&
      filter == o.filter &&
      json == o.json &&
      minimal_view == o.minimal_view &&
      modified_after == o.modified_after &&
      pagination_token == o.pagination_token &&
      path == o.path &&
      sra_only == o.sra_only &&
      sub_types == o.sub_types &&
      tag == o.tag &&
      token == o.token &&
      type == o.type &&
      uid_token == o.uid_token
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/akeyless/models/list_items.rb', line 374

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


266
267
268
# File 'lib/akeyless/models/list_items.rb', line 266

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



272
273
274
# File 'lib/akeyless/models/list_items.rb', line 272

def hash
  [accessibility, advanced_filter, ara_only, auto_pagination, current_folder, filter, json, minimal_view, modified_after, pagination_token, path, sra_only, sub_types, tag, token, type, uid_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



227
228
229
230
231
# File 'lib/akeyless/models/list_items.rb', line 227

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



350
351
352
# File 'lib/akeyless/models/list_items.rb', line 350

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/akeyless/models/list_items.rb', line 356

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



344
345
346
# File 'lib/akeyless/models/list_items.rb', line 344

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



235
236
237
238
# File 'lib/akeyless/models/list_items.rb', line 235

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end