Class: Akeyless::NotiForwarder

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/noti_forwarder.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ NotiForwarder

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/akeyless/models/noti_forwarder.rb', line 123

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::NotiForwarder` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::NotiForwarder`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'client_permissions')
    if (value = attributes[:'client_permissions']).is_a?(Array)
      self.client_permissions = value
    end
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  end

  if attributes.key?(:'endpoint')
    self.endpoint = attributes[:'endpoint']
  end

  if attributes.key?(:'event_types')
    if (value = attributes[:'event_types']).is_a?(Array)
      self.event_types = value
    end
  end

  if attributes.key?(:'gateway_cluster_id')
    self.gateway_cluster_id = attributes[:'gateway_cluster_id']
  end

  if attributes.key?(:'is_enabled')
    self.is_enabled = attributes[:'is_enabled']
  end

  if attributes.key?(:'last_version')
    self.last_version = attributes[:'last_version']
  end

  if attributes.key?(:'modification_date')
    self.modification_date = attributes[:'modification_date']
  end

  if attributes.key?(:'noti_forwarder_id')
    self.noti_forwarder_id = attributes[:'noti_forwarder_id']
  end

  if attributes.key?(:'noti_forwarder_name')
    self.noti_forwarder_name = attributes[:'noti_forwarder_name']
  end

  if attributes.key?(:'noti_forwarder_type')
    self.noti_forwarder_type = attributes[:'noti_forwarder_type']
  end

  if attributes.key?(:'noti_forwarder_versions')
    if (value = attributes[:'noti_forwarder_versions']).is_a?(Array)
      self.noti_forwarder_versions = value
    end
  end

  if attributes.key?(:'paths')
    if (value = attributes[:'paths']).is_a?(Array)
      self.paths = value
    end
  end

  if attributes.key?(:'protection_key')
    self.protection_key = attributes[:'protection_key']
  end

  if attributes.key?(:'runner_type')
    self.runner_type = attributes[:'runner_type']
  end

  if attributes.key?(:'timespan_in_seconds')
    self.timespan_in_seconds = attributes[:'timespan_in_seconds']
  end

  if attributes.key?(:'to_emails')
    if (value = attributes[:'to_emails']).is_a?(Array)
      self.to_emails = value
    end
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'with_customer_fragment')
    self.with_customer_fragment = attributes[:'with_customer_fragment']
  end
end

Instance Attribute Details

#client_permissionsObject

Returns the value of attribute client_permissions.



18
19
20
# File 'lib/akeyless/models/noti_forwarder.rb', line 18

def client_permissions
  @client_permissions
end

#commentObject

Returns the value of attribute comment.



20
21
22
# File 'lib/akeyless/models/noti_forwarder.rb', line 20

def comment
  @comment
end

#creation_dateObject

Returns the value of attribute creation_date.



22
23
24
# File 'lib/akeyless/models/noti_forwarder.rb', line 22

def creation_date
  @creation_date
end

#endpointObject

Returns the value of attribute endpoint.



24
25
26
# File 'lib/akeyless/models/noti_forwarder.rb', line 24

def endpoint
  @endpoint
end

#event_typesObject

Returns the value of attribute event_types.



26
27
28
# File 'lib/akeyless/models/noti_forwarder.rb', line 26

def event_types
  @event_types
end

#gateway_cluster_idObject

Returns the value of attribute gateway_cluster_id.



28
29
30
# File 'lib/akeyless/models/noti_forwarder.rb', line 28

def gateway_cluster_id
  @gateway_cluster_id
end

#is_enabledObject

Returns the value of attribute is_enabled.



30
31
32
# File 'lib/akeyless/models/noti_forwarder.rb', line 30

def is_enabled
  @is_enabled
end

#last_versionObject

Returns the value of attribute last_version.



32
33
34
# File 'lib/akeyless/models/noti_forwarder.rb', line 32

def last_version
  @last_version
end

#modification_dateObject

Returns the value of attribute modification_date.



34
35
36
# File 'lib/akeyless/models/noti_forwarder.rb', line 34

def modification_date
  @modification_date
end

#noti_forwarder_idObject

Returns the value of attribute noti_forwarder_id.



36
37
38
# File 'lib/akeyless/models/noti_forwarder.rb', line 36

def noti_forwarder_id
  @noti_forwarder_id
end

#noti_forwarder_nameObject

Returns the value of attribute noti_forwarder_name.



38
39
40
# File 'lib/akeyless/models/noti_forwarder.rb', line 38

def noti_forwarder_name
  @noti_forwarder_name
end

#noti_forwarder_typeObject

Returns the value of attribute noti_forwarder_type.



40
41
42
# File 'lib/akeyless/models/noti_forwarder.rb', line 40

def noti_forwarder_type
  @noti_forwarder_type
end

#noti_forwarder_versionsObject

Returns the value of attribute noti_forwarder_versions.



42
43
44
# File 'lib/akeyless/models/noti_forwarder.rb', line 42

def noti_forwarder_versions
  @noti_forwarder_versions
end

#pathsObject

Returns the value of attribute paths.



44
45
46
# File 'lib/akeyless/models/noti_forwarder.rb', line 44

def paths
  @paths
end

#protection_keyObject

Returns the value of attribute protection_key.



46
47
48
# File 'lib/akeyless/models/noti_forwarder.rb', line 46

def protection_key
  @protection_key
end

#runner_typeObject

Returns the value of attribute runner_type.



48
49
50
# File 'lib/akeyless/models/noti_forwarder.rb', line 48

def runner_type
  @runner_type
end

#timespan_in_secondsObject

Returns the value of attribute timespan_in_seconds.



50
51
52
# File 'lib/akeyless/models/noti_forwarder.rb', line 50

def timespan_in_seconds
  @timespan_in_seconds
end

#to_emailsObject

Returns the value of attribute to_emails.



52
53
54
# File 'lib/akeyless/models/noti_forwarder.rb', line 52

def to_emails
  @to_emails
end

#usernameObject

Returns the value of attribute username.



54
55
56
# File 'lib/akeyless/models/noti_forwarder.rb', line 54

def username
  @username
end

#with_customer_fragmentObject

Returns the value of attribute with_customer_fragment.



56
57
58
# File 'lib/akeyless/models/noti_forwarder.rb', line 56

def with_customer_fragment
  @with_customer_fragment
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/akeyless/models/noti_forwarder.rb', line 308

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/akeyless/models/noti_forwarder.rb', line 85

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/akeyless/models/noti_forwarder.rb', line 59

def self.attribute_map
  {
    :'client_permissions' => :'client_permissions',
    :'comment' => :'comment',
    :'creation_date' => :'creation_date',
    :'endpoint' => :'endpoint',
    :'event_types' => :'event_types',
    :'gateway_cluster_id' => :'gateway_cluster_id',
    :'is_enabled' => :'is_enabled',
    :'last_version' => :'last_version',
    :'modification_date' => :'modification_date',
    :'noti_forwarder_id' => :'noti_forwarder_id',
    :'noti_forwarder_name' => :'noti_forwarder_name',
    :'noti_forwarder_type' => :'noti_forwarder_type',
    :'noti_forwarder_versions' => :'noti_forwarder_versions',
    :'paths' => :'paths',
    :'protection_key' => :'protection_key',
    :'runner_type' => :'runner_type',
    :'timespan_in_seconds' => :'timespan_in_seconds',
    :'to_emails' => :'to_emails',
    :'username' => :'username',
    :'with_customer_fragment' => :'with_customer_fragment'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/akeyless/models/noti_forwarder.rb', line 284

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



116
117
118
119
# File 'lib/akeyless/models/noti_forwarder.rb', line 116

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/akeyless/models/noti_forwarder.rb', line 90

def self.openapi_types
  {
    :'client_permissions' => :'Array<String>',
    :'comment' => :'String',
    :'creation_date' => :'Time',
    :'endpoint' => :'String',
    :'event_types' => :'Array<String>',
    :'gateway_cluster_id' => :'Integer',
    :'is_enabled' => :'Boolean',
    :'last_version' => :'Integer',
    :'modification_date' => :'Time',
    :'noti_forwarder_id' => :'Integer',
    :'noti_forwarder_name' => :'String',
    :'noti_forwarder_type' => :'String',
    :'noti_forwarder_versions' => :'Array<ItemVersion>',
    :'paths' => :'Array<String>',
    :'protection_key' => :'String',
    :'runner_type' => :'String',
    :'timespan_in_seconds' => :'Integer',
    :'to_emails' => :'Array<EmailEntry>',
    :'username' => :'String',
    :'with_customer_fragment' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/akeyless/models/noti_forwarder.rb', line 244

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      client_permissions == o.client_permissions &&
      comment == o.comment &&
      creation_date == o.creation_date &&
      endpoint == o.endpoint &&
      event_types == o.event_types &&
      gateway_cluster_id == o.gateway_cluster_id &&
      is_enabled == o.is_enabled &&
      last_version == o.last_version &&
      modification_date == o.modification_date &&
      noti_forwarder_id == o.noti_forwarder_id &&
      noti_forwarder_name == o.noti_forwarder_name &&
      noti_forwarder_type == o.noti_forwarder_type &&
      noti_forwarder_versions == o.noti_forwarder_versions &&
      paths == o.paths &&
      protection_key == o.protection_key &&
      runner_type == o.runner_type &&
      timespan_in_seconds == o.timespan_in_seconds &&
      to_emails == o.to_emails &&
      username == o.username &&
      with_customer_fragment == o.with_customer_fragment
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/akeyless/models/noti_forwarder.rb', line 379

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


271
272
273
# File 'lib/akeyless/models/noti_forwarder.rb', line 271

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



277
278
279
# File 'lib/akeyless/models/noti_forwarder.rb', line 277

def hash
  [client_permissions, comment, creation_date, endpoint, event_types, gateway_cluster_id, is_enabled, last_version, modification_date, noti_forwarder_id, noti_forwarder_name, noti_forwarder_type, noti_forwarder_versions, paths, protection_key, runner_type, timespan_in_seconds, to_emails, username, with_customer_fragment].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



229
230
231
232
233
# File 'lib/akeyless/models/noti_forwarder.rb', line 229

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



355
356
357
# File 'lib/akeyless/models/noti_forwarder.rb', line 355

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/akeyless/models/noti_forwarder.rb', line 361

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



349
350
351
# File 'lib/akeyless/models/noti_forwarder.rb', line 349

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



237
238
239
240
# File 'lib/akeyless/models/noti_forwarder.rb', line 237

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end