Class: Akeyless::OAuth2AccessRules

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/o_auth2_access_rules.rb

Overview

OAuth2AccessRules contains access rules specific to OAuth2 authentication method.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OAuth2AccessRules

Initializes the object



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::OAuth2AccessRules` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::OAuth2AccessRules`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'audience')
    self.audience = attributes[:'audience']
  end

  if attributes.key?(:'bound_claims')
    if (value = attributes[:'bound_claims']).is_a?(Array)
      self.bound_claims = value
    end
  end

  if attributes.key?(:'bound_clients_id')
    if (value = attributes[:'bound_clients_id']).is_a?(Array)
      self.bound_clients_id = value
    end
  end

  if attributes.key?(:'issuer')
    self.issuer = attributes[:'issuer']
  end

  if attributes.key?(:'jwks_json_data')
    self.jwks_json_data = attributes[:'jwks_json_data']
  end

  if attributes.key?(:'jwks_uri')
    self.jwks_uri = attributes[:'jwks_uri']
  end

  if attributes.key?(:'unique_identifier')
    self.unique_identifier = attributes[:'unique_identifier']
  end
end

Instance Attribute Details

#audienceObject

The audience in the JWT.



20
21
22
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 20

def audience
  @audience
end

#bound_claimsObject

The claims that login is restricted to.



23
24
25
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 23

def bound_claims
  @bound_claims
end

#bound_clients_idObject

The clients ids that login is restricted to.



26
27
28
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 26

def bound_clients_id
  @bound_clients_id
end

#issuerObject

Issuer URL



29
30
31
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 29

def issuer
  @issuer
end

#jwks_json_dataObject

The JSON Web Key Set (JWKS) that containing the public keys that should be used to verify any JSON Web Token (JWT) issued by the authorization server. base64 encoded string



32
33
34
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 32

def jwks_json_data
  @jwks_json_data
end

#jwks_uriObject

The URL to the JSON Web Key Set (JWKS) that containing the public keys that should be used to verify any JSON Web Token (JWT) issued by the authorization server.



35
36
37
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 35

def jwks_uri
  @jwks_uri
end

#unique_identifierObject

A unique identifier to distinguish different users



38
39
40
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 38

def unique_identifier
  @unique_identifier
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 193

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 54

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 41

def self.attribute_map
  {
    :'audience' => :'audience',
    :'bound_claims' => :'bound_claims',
    :'bound_clients_id' => :'bound_clients_id',
    :'issuer' => :'issuer',
    :'jwks_json_data' => :'jwks_json_data',
    :'jwks_uri' => :'jwks_uri',
    :'unique_identifier' => :'unique_identifier'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 169

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 59

def self.openapi_types
  {
    :'audience' => :'String',
    :'bound_claims' => :'Array<OAuth2CustomClaim>',
    :'bound_clients_id' => :'Array<String>',
    :'issuer' => :'String',
    :'jwks_json_data' => :'String',
    :'jwks_uri' => :'String',
    :'unique_identifier' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



142
143
144
145
146
147
148
149
150
151
152
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 142

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      audience == o.audience &&
      bound_claims == o.bound_claims &&
      bound_clients_id == o.bound_clients_id &&
      issuer == o.issuer &&
      jwks_json_data == o.jwks_json_data &&
      jwks_uri == o.jwks_uri &&
      unique_identifier == o.unique_identifier
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 264

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


156
157
158
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 156

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



162
163
164
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 162

def hash
  [audience, bound_claims, bound_clients_id, issuer, jwks_json_data, jwks_uri, unique_identifier].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



127
128
129
130
131
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



240
241
242
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 240

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 246

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



234
235
236
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 234

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



135
136
137
138
# File 'lib/akeyless/models/o_auth2_access_rules.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end