Class: Akeyless::Role

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/role.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Role

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/akeyless/models/role.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::Role` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::Role`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_date')
    self.access_date = attributes[:'access_date']
  end

  if attributes.key?(:'client_permissions')
    if (value = attributes[:'client_permissions']).is_a?(Array)
      self.client_permissions = value
    end
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  end

  if attributes.key?(:'modification_date')
    self.modification_date = attributes[:'modification_date']
  end

  if attributes.key?(:'role_auth_methods_assoc')
    if (value = attributes[:'role_auth_methods_assoc']).is_a?(Array)
      self.role_auth_methods_assoc = value
    end
  end

  if attributes.key?(:'role_name')
    self.role_name = attributes[:'role_name']
  end

  if attributes.key?(:'rules')
    self.rules = attributes[:'rules']
  end
end

Instance Attribute Details

#access_dateObject

Returns the value of attribute access_date.



18
19
20
# File 'lib/akeyless/models/role.rb', line 18

def access_date
  @access_date
end

#client_permissionsObject

Returns the value of attribute client_permissions.



20
21
22
# File 'lib/akeyless/models/role.rb', line 20

def client_permissions
  @client_permissions
end

#commentObject

Returns the value of attribute comment.



22
23
24
# File 'lib/akeyless/models/role.rb', line 22

def comment
  @comment
end

#creation_dateObject

Returns the value of attribute creation_date.



24
25
26
# File 'lib/akeyless/models/role.rb', line 24

def creation_date
  @creation_date
end

#modification_dateObject

Returns the value of attribute modification_date.



26
27
28
# File 'lib/akeyless/models/role.rb', line 26

def modification_date
  @modification_date
end

#role_auth_methods_assocObject

Returns the value of attribute role_auth_methods_assoc.



28
29
30
# File 'lib/akeyless/models/role.rb', line 28

def role_auth_methods_assoc
  @role_auth_methods_assoc
end

#role_nameObject

Returns the value of attribute role_name.



30
31
32
# File 'lib/akeyless/models/role.rb', line 30

def role_name
  @role_name
end

#rulesObject

Returns the value of attribute rules.



32
33
34
# File 'lib/akeyless/models/role.rb', line 32

def rules
  @rules
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/akeyless/models/role.rb', line 194

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/akeyless/models/role.rb', line 49

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/akeyless/models/role.rb', line 35

def self.attribute_map
  {
    :'access_date' => :'access_date',
    :'client_permissions' => :'client_permissions',
    :'comment' => :'comment',
    :'creation_date' => :'creation_date',
    :'modification_date' => :'modification_date',
    :'role_auth_methods_assoc' => :'role_auth_methods_assoc',
    :'role_name' => :'role_name',
    :'rules' => :'rules'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/akeyless/models/role.rb', line 170

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



68
69
70
71
# File 'lib/akeyless/models/role.rb', line 68

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/akeyless/models/role.rb', line 54

def self.openapi_types
  {
    :'access_date' => :'Time',
    :'client_permissions' => :'Array<String>',
    :'comment' => :'String',
    :'creation_date' => :'Time',
    :'modification_date' => :'Time',
    :'role_auth_methods_assoc' => :'Array<RoleAuthMethodAssociation>',
    :'role_name' => :'String',
    :'rules' => :'Rules'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/akeyless/models/role.rb', line 142

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_date == o.access_date &&
      client_permissions == o.client_permissions &&
      comment == o.comment &&
      creation_date == o.creation_date &&
      modification_date == o.modification_date &&
      role_auth_methods_assoc == o.role_auth_methods_assoc &&
      role_name == o.role_name &&
      rules == o.rules
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/akeyless/models/role.rb', line 265

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


157
158
159
# File 'lib/akeyless/models/role.rb', line 157

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



163
164
165
# File 'lib/akeyless/models/role.rb', line 163

def hash
  [access_date, client_permissions, comment, creation_date, modification_date, role_auth_methods_assoc, role_name, rules].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
# File 'lib/akeyless/models/role.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



241
242
243
# File 'lib/akeyless/models/role.rb', line 241

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/akeyless/models/role.rb', line 247

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



235
236
237
# File 'lib/akeyless/models/role.rb', line 235

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
# File 'lib/akeyless/models/role.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end