Class: Akeyless::RotatedSecretCreateLdap
- Inherits:
-
Object
- Object
- Akeyless::RotatedSecretCreateLdap
- Defined in:
- lib/akeyless/models/rotated_secret_create_ldap.rb
Instance Attribute Summary collapse
-
#authentication_credentials ⇒ Object
The credentials to connect with use-user-creds/use-target-creds.
-
#auto_rotate ⇒ Object
Returns the value of attribute auto_rotate.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#description ⇒ Object
Description of the object.
-
#host_provider ⇒ Object
Host provider type [explicit/target], Default Host provider is explicit, Relevant only for Secure Remote Access of ssh cert issuer, ldap rotated secret and ldap dynamic secret.
-
#input_rule ⇒ Object
Agentic input rule in name=…,rule=…
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#key ⇒ Object
Returns the value of attribute key.
-
#lock_during_sra_session ⇒ Object
Lock this secret for read/update while an SRA session is active.
-
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
-
#name ⇒ Object
Rotated secret name.
-
#output_rule ⇒ Object
Agentic output rule in name=…,rule=…
-
#password_length ⇒ Object
The length of the password to be generated.
-
#provider_type ⇒ Object
Returns the value of attribute provider_type.
-
#rotate_after_disconnect ⇒ Object
StringOrBool accepts JSON strings, booleans, and numbers for backward compatibility with older SDK versions that send boolean values for rotate-after-disconnect.
-
#rotated_password ⇒ Object
rotated-username password (relevant only for rotator-type=ldap).
-
#rotated_username ⇒ Object
username to be rotated, if selected use-self-creds at rotator-creds-type, this username will try to rotate it’s own password, if use-target-creds is selected, target credentials will be use to rotate the rotated-password (relevant only for rotator-type=ldap).
-
#rotation_event_in ⇒ Object
How many days before the rotation of the item would you like to be notified.
-
#rotation_hour ⇒ Object
Returns the value of attribute rotation_hour.
-
#rotation_interval ⇒ Object
Returns the value of attribute rotation_interval.
-
#rotator_type ⇒ Object
The rotator type.
-
#secure_access_bastion_issuer ⇒ Object
Deprecated.
-
#secure_access_certificate_issuer ⇒ Object
Path to the SSH Certificate Issuer for your Akeyless Secure Access.
-
#secure_access_enable ⇒ Object
Enable/Disable secure remote access [true/false].
-
#secure_access_host ⇒ Object
Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers).
-
#secure_access_rdp_domain ⇒ Object
Default domain name server.
-
#secure_access_url ⇒ Object
Destination URL to inject secrets.
-
#secure_access_web ⇒ Object
Enable Web Secure Remote Access.
-
#secure_access_web_browsing ⇒ Object
Secure browser via Akeyless’s Secure Remote Access (SRA).
-
#secure_access_web_proxy ⇒ Object
Web-Proxy via Akeyless’s Secure Remote Access (SRA).
-
#tags ⇒ Object
Add tags attached to this object.
-
#target ⇒ Object
A list of linked targets to be associated, Relevant only for Secure Remote Access for ssh cert issuer, ldap rotated secret and ldap dynamic secret, To specify multiple targets use argument multiple times.
-
#target_name ⇒ Object
The target name to associate.
-
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`).
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#use_capital_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z).
-
#use_lower_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z).
-
#use_numbers ⇒ Object
Specifies whether the generated temporary password must contain at least one numeric character (0 to 9).
-
#use_special_characters ⇒ Object
Returns the value of attribute use_special_characters.
-
#user_attribute ⇒ Object
LDAP User Attribute, Default value "cn".
-
#user_dn ⇒ Object
Base DN to Perform User Search.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RotatedSecretCreateLdap
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RotatedSecretCreateLdap
Initializes the object
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 247 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::RotatedSecretCreateLdap` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::RotatedSecretCreateLdap`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'provider_type') self.provider_type = attributes[:'provider_type'] end if attributes.key?(:'authentication_credentials') self.authentication_credentials = attributes[:'authentication_credentials'] else self.authentication_credentials = 'use-user-creds' end if attributes.key?(:'auto_rotate') self.auto_rotate = attributes[:'auto_rotate'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'host_provider') self.host_provider = attributes[:'host_provider'] end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'lock_during_sra_session') self.lock_during_sra_session = attributes[:'lock_during_sra_session'] end if attributes.key?(:'max_versions') self.max_versions = attributes[:'max_versions'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'password_length') self.password_length = attributes[:'password_length'] end if attributes.key?(:'rotate_after_disconnect') self.rotate_after_disconnect = attributes[:'rotate_after_disconnect'] end if attributes.key?(:'rotated_password') self.rotated_password = attributes[:'rotated_password'] end if attributes.key?(:'rotated_username') self.rotated_username = attributes[:'rotated_username'] end if attributes.key?(:'rotation_event_in') if (value = attributes[:'rotation_event_in']).is_a?(Array) self.rotation_event_in = value end end if attributes.key?(:'rotation_hour') self.rotation_hour = attributes[:'rotation_hour'] end if attributes.key?(:'rotation_interval') self.rotation_interval = attributes[:'rotation_interval'] end if attributes.key?(:'rotator_type') self.rotator_type = attributes[:'rotator_type'] else self.rotator_type = nil end if attributes.key?(:'secure_access_bastion_issuer') self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer'] end if attributes.key?(:'secure_access_certificate_issuer') self.secure_access_certificate_issuer = attributes[:'secure_access_certificate_issuer'] end if attributes.key?(:'secure_access_enable') self.secure_access_enable = attributes[:'secure_access_enable'] end if attributes.key?(:'secure_access_host') if (value = attributes[:'secure_access_host']).is_a?(Array) self.secure_access_host = value end end if attributes.key?(:'secure_access_rdp_domain') self.secure_access_rdp_domain = attributes[:'secure_access_rdp_domain'] end if attributes.key?(:'secure_access_url') self.secure_access_url = attributes[:'secure_access_url'] end if attributes.key?(:'secure_access_web') self.secure_access_web = attributes[:'secure_access_web'] else self.secure_access_web = false end if attributes.key?(:'secure_access_web_browsing') self.secure_access_web_browsing = attributes[:'secure_access_web_browsing'] else self.secure_access_web_browsing = false end if attributes.key?(:'secure_access_web_proxy') self.secure_access_web_proxy = attributes[:'secure_access_web_proxy'] else self.secure_access_web_proxy = false end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'target') if (value = attributes[:'target']).is_a?(Array) self.target = value end end if attributes.key?(:'target_name') self.target_name = attributes[:'target_name'] else self.target_name = nil end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'use_capital_letters') self.use_capital_letters = attributes[:'use_capital_letters'] end if attributes.key?(:'use_lower_letters') self.use_lower_letters = attributes[:'use_lower_letters'] end if attributes.key?(:'use_numbers') self.use_numbers = attributes[:'use_numbers'] end if attributes.key?(:'use_special_characters') self.use_special_characters = attributes[:'use_special_characters'] end if attributes.key?(:'user_attribute') self.user_attribute = attributes[:'user_attribute'] else self.user_attribute = 'cn' end if attributes.key?(:'user_dn') self.user_dn = attributes[:'user_dn'] end end |
Instance Attribute Details
#authentication_credentials ⇒ Object
The credentials to connect with use-user-creds/use-target-creds
21 22 23 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 21 def authentication_credentials @authentication_credentials end |
#auto_rotate ⇒ Object
Returns the value of attribute auto_rotate.
23 24 25 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 23 def auto_rotate @auto_rotate end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
26 27 28 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 26 def delete_protection @delete_protection end |
#description ⇒ Object
Description of the object
29 30 31 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 29 def description @description end |
#host_provider ⇒ Object
Host provider type [explicit/target], Default Host provider is explicit, Relevant only for Secure Remote Access of ssh cert issuer, ldap rotated secret and ldap dynamic secret
32 33 34 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 32 def host_provider @host_provider end |
#input_rule ⇒ Object
Agentic input rule in name=…,rule=… format (e.g. name=rule1,rule=Sanitize input)
35 36 37 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 35 def input_rule @input_rule end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
38 39 40 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 38 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
41 42 43 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 41 def json @json end |
#key ⇒ Object
Returns the value of attribute key.
43 44 45 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 43 def key @key end |
#lock_during_sra_session ⇒ Object
Lock this secret for read/update while an SRA session is active
46 47 48 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 46 def lock_during_sra_session @lock_during_sra_session end |
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
49 50 51 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 49 def max_versions @max_versions end |
#name ⇒ Object
Rotated secret name
52 53 54 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 52 def name @name end |
#output_rule ⇒ Object
Agentic output rule in name=…,rule=… format (e.g. name=rule1,rule=Mask secrets)
55 56 57 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 55 def output_rule @output_rule end |
#password_length ⇒ Object
The length of the password to be generated
58 59 60 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 58 def password_length @password_length end |
#provider_type ⇒ Object
Returns the value of attribute provider_type.
18 19 20 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 18 def provider_type @provider_type end |
#rotate_after_disconnect ⇒ Object
StringOrBool accepts JSON strings, booleans, and numbers for backward compatibility with older SDK versions that send boolean values for rotate-after-disconnect.
61 62 63 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 61 def rotate_after_disconnect @rotate_after_disconnect end |
#rotated_password ⇒ Object
rotated-username password (relevant only for rotator-type=ldap)
64 65 66 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 64 def rotated_password @rotated_password end |
#rotated_username ⇒ Object
username to be rotated, if selected use-self-creds at rotator-creds-type, this username will try to rotate it’s own password, if use-target-creds is selected, target credentials will be use to rotate the rotated-password (relevant only for rotator-type=ldap)
67 68 69 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 67 def rotated_username @rotated_username end |
#rotation_event_in ⇒ Object
How many days before the rotation of the item would you like to be notified
70 71 72 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 70 def rotation_event_in @rotation_event_in end |
#rotation_hour ⇒ Object
Returns the value of attribute rotation_hour.
72 73 74 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 72 def rotation_hour @rotation_hour end |
#rotation_interval ⇒ Object
Returns the value of attribute rotation_interval.
74 75 76 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 74 def rotation_interval @rotation_interval end |
#rotator_type ⇒ Object
The rotator type. options: [target/ldap]
77 78 79 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 77 def rotator_type @rotator_type end |
#secure_access_bastion_issuer ⇒ Object
Deprecated. use secure-access-certificate-issuer
80 81 82 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 80 def secure_access_bastion_issuer @secure_access_bastion_issuer end |
#secure_access_certificate_issuer ⇒ Object
Path to the SSH Certificate Issuer for your Akeyless Secure Access
83 84 85 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 83 def secure_access_certificate_issuer @secure_access_certificate_issuer end |
#secure_access_enable ⇒ Object
Enable/Disable secure remote access [true/false]
86 87 88 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 86 def secure_access_enable @secure_access_enable end |
#secure_access_host ⇒ Object
Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)
89 90 91 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 89 def secure_access_host @secure_access_host end |
#secure_access_rdp_domain ⇒ Object
Default domain name server. i.e. microsoft.com
92 93 94 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 92 def secure_access_rdp_domain @secure_access_rdp_domain end |
#secure_access_url ⇒ Object
Destination URL to inject secrets
95 96 97 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 95 def secure_access_url @secure_access_url end |
#secure_access_web ⇒ Object
Enable Web Secure Remote Access
98 99 100 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 98 def secure_access_web @secure_access_web end |
#secure_access_web_browsing ⇒ Object
Secure browser via Akeyless’s Secure Remote Access (SRA)
101 102 103 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 101 def secure_access_web_browsing @secure_access_web_browsing end |
#secure_access_web_proxy ⇒ Object
Web-Proxy via Akeyless’s Secure Remote Access (SRA)
104 105 106 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 104 def secure_access_web_proxy @secure_access_web_proxy end |
#tags ⇒ Object
Add tags attached to this object
107 108 109 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 107 def @tags end |
#target ⇒ Object
A list of linked targets to be associated, Relevant only for Secure Remote Access for ssh cert issuer, ldap rotated secret and ldap dynamic secret, To specify multiple targets use argument multiple times
110 111 112 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 110 def target @target end |
#target_name ⇒ Object
The target name to associate
113 114 115 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 113 def target_name @target_name end |
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`)
116 117 118 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 116 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
119 120 121 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 119 def uid_token @uid_token end |
#use_capital_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). [true/false]
122 123 124 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 122 def use_capital_letters @use_capital_letters end |
#use_lower_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). [true/false]
125 126 127 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 125 def use_lower_letters @use_lower_letters end |
#use_numbers ⇒ Object
Specifies whether the generated temporary password must contain at least one numeric character (0 to 9). [true/false]
128 129 130 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 128 def use_numbers @use_numbers end |
#use_special_characters ⇒ Object
Returns the value of attribute use_special_characters.
130 131 132 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 130 def use_special_characters @use_special_characters end |
#user_attribute ⇒ Object
LDAP User Attribute, Default value "cn"
133 134 135 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 133 def user_attribute @user_attribute end |
#user_dn ⇒ Object
Base DN to Perform User Search
136 137 138 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 136 def user_dn @user_dn end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 579 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
187 188 189 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 187 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 139 def self.attribute_map { :'provider_type' => :'ProviderType', :'authentication_credentials' => :'authentication-credentials', :'auto_rotate' => :'auto-rotate', :'delete_protection' => :'delete_protection', :'description' => :'description', :'host_provider' => :'host-provider', :'input_rule' => :'input-rule', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'key' => :'key', :'lock_during_sra_session' => :'lock-during-sra-session', :'max_versions' => :'max-versions', :'name' => :'name', :'output_rule' => :'output-rule', :'password_length' => :'password-length', :'rotate_after_disconnect' => :'rotate-after-disconnect', :'rotated_password' => :'rotated-password', :'rotated_username' => :'rotated-username', :'rotation_event_in' => :'rotation-event-in', :'rotation_hour' => :'rotation-hour', :'rotation_interval' => :'rotation-interval', :'rotator_type' => :'rotator-type', :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer', :'secure_access_certificate_issuer' => :'secure-access-certificate-issuer', :'secure_access_enable' => :'secure-access-enable', :'secure_access_host' => :'secure-access-host', :'secure_access_rdp_domain' => :'secure-access-rdp-domain', :'secure_access_url' => :'secure-access-url', :'secure_access_web' => :'secure-access-web', :'secure_access_web_browsing' => :'secure-access-web-browsing', :'secure_access_web_proxy' => :'secure-access-web-proxy', :'tags' => :'tags', :'target' => :'target', :'target_name' => :'target-name', :'token' => :'token', :'uid_token' => :'uid-token', :'use_capital_letters' => :'use-capital-letters', :'use_lower_letters' => :'use-lower-letters', :'use_numbers' => :'use-numbers', :'use_special_characters' => :'use-special-characters', :'user_attribute' => :'user-attribute', :'user_dn' => :'user-dn' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 555 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
240 241 242 243 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 240 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 192 def self.openapi_types { :'provider_type' => :'String', :'authentication_credentials' => :'String', :'auto_rotate' => :'String', :'delete_protection' => :'String', :'description' => :'String', :'host_provider' => :'String', :'input_rule' => :'Array<String>', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'key' => :'String', :'lock_during_sra_session' => :'String', :'max_versions' => :'String', :'name' => :'String', :'output_rule' => :'Array<String>', :'password_length' => :'String', :'rotate_after_disconnect' => :'String', :'rotated_password' => :'String', :'rotated_username' => :'String', :'rotation_event_in' => :'Array<String>', :'rotation_hour' => :'Integer', :'rotation_interval' => :'String', :'rotator_type' => :'String', :'secure_access_bastion_issuer' => :'String', :'secure_access_certificate_issuer' => :'String', :'secure_access_enable' => :'String', :'secure_access_host' => :'Array<String>', :'secure_access_rdp_domain' => :'String', :'secure_access_url' => :'String', :'secure_access_web' => :'Boolean', :'secure_access_web_browsing' => :'Boolean', :'secure_access_web_proxy' => :'Boolean', :'tags' => :'Array<String>', :'target' => :'Array<String>', :'target_name' => :'String', :'token' => :'String', :'uid_token' => :'String', :'use_capital_letters' => :'String', :'use_lower_letters' => :'String', :'use_numbers' => :'String', :'use_special_characters' => :'String', :'user_attribute' => :'String', :'user_dn' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 493 def ==(o) return true if self.equal?(o) self.class == o.class && provider_type == o.provider_type && authentication_credentials == o.authentication_credentials && auto_rotate == o.auto_rotate && delete_protection == o.delete_protection && description == o.description && host_provider == o.host_provider && input_rule == o.input_rule && item_custom_fields == o.item_custom_fields && json == o.json && key == o.key && lock_during_sra_session == o.lock_during_sra_session && max_versions == o.max_versions && name == o.name && output_rule == o.output_rule && password_length == o.password_length && rotate_after_disconnect == o.rotate_after_disconnect && rotated_password == o.rotated_password && rotated_username == o.rotated_username && rotation_event_in == o.rotation_event_in && rotation_hour == o.rotation_hour && rotation_interval == o.rotation_interval && rotator_type == o.rotator_type && secure_access_bastion_issuer == o.secure_access_bastion_issuer && secure_access_certificate_issuer == o.secure_access_certificate_issuer && secure_access_enable == o.secure_access_enable && secure_access_host == o.secure_access_host && secure_access_rdp_domain == o.secure_access_rdp_domain && secure_access_url == o.secure_access_url && secure_access_web == o.secure_access_web && secure_access_web_browsing == o.secure_access_web_browsing && secure_access_web_proxy == o.secure_access_web_proxy && == o. && target == o.target && target_name == o.target_name && token == o.token && uid_token == o.uid_token && use_capital_letters == o.use_capital_letters && use_lower_letters == o.use_lower_letters && use_numbers == o.use_numbers && use_special_characters == o.use_special_characters && user_attribute == o.user_attribute && user_dn == o.user_dn end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
650 651 652 653 654 655 656 657 658 659 660 661 662 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 650 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
542 543 544 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 542 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
548 549 550 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 548 def hash [provider_type, authentication_credentials, auto_rotate, delete_protection, description, host_provider, input_rule, item_custom_fields, json, key, lock_during_sra_session, max_versions, name, output_rule, password_length, rotate_after_disconnect, rotated_password, rotated_username, rotation_event_in, rotation_hour, rotation_interval, rotator_type, secure_access_bastion_issuer, secure_access_certificate_issuer, secure_access_enable, secure_access_host, secure_access_rdp_domain, secure_access_url, secure_access_web, secure_access_web_browsing, secure_access_web_proxy, , target, target_name, token, uid_token, use_capital_letters, use_lower_letters, use_numbers, use_special_characters, user_attribute, user_dn].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 463 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @rotator_type.nil? invalid_properties.push('invalid value for "rotator_type", rotator_type cannot be nil.') end if @target_name.nil? invalid_properties.push('invalid value for "target_name", target_name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
626 627 628 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 626 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
632 633 634 635 636 637 638 639 640 641 642 643 644 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 632 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
620 621 622 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 620 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
483 484 485 486 487 488 489 |
# File 'lib/akeyless/models/rotated_secret_create_ldap.rb', line 483 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @rotator_type.nil? return false if @target_name.nil? true end |