Class: Akeyless::RotatedSecretCreateOpenAI
- Inherits:
-
Object
- Object
- Akeyless::RotatedSecretCreateOpenAI
- Defined in:
- lib/akeyless/models/rotated_secret_create_open_ai.rb
Overview
rotatedSecretCreateOpenAI is a command that creates a rotated secret for an OpenAI target by rotating the admin API key configured on the target.
Instance Attribute Summary collapse
-
#api_key ⇒ Object
Admin API key value to rotate (relevant only for rotator-type=api-key).
-
#api_key_id ⇒ Object
Admin API key ID to rotate (relevant only for rotator-type=api-key).
-
#authentication_credentials ⇒ Object
The credentials to connect with use-user-creds/use-target-creds.
-
#auto_rotate ⇒ Object
Whether to automatically rotate every –rotation-interval days, or disable existing automatic rotation [true/false].
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#description ⇒ Object
Description of the object.
-
#input_rule ⇒ Object
Agentic input rule in name=…,rule=…
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#key ⇒ Object
The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used).
-
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
-
#name ⇒ Object
Rotated secret name.
-
#output_rule ⇒ Object
Agentic output rule in name=…,rule=…
-
#password_length ⇒ Object
The length of the password to be generated.
-
#rotation_event_in ⇒ Object
How many days before the rotation of the item would you like to be notified.
-
#rotation_hour ⇒ Object
The Hour of the rotation in UTC.
-
#rotation_interval ⇒ Object
The number of days to wait between every automatic key rotation (1-365).
-
#rotator_type ⇒ Object
The rotator type.
-
#tags ⇒ Object
Add tags attached to this object.
-
#target_name ⇒ Object
The target name to associate.
-
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`).
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#use_capital_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z).
-
#use_lower_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z).
-
#use_numbers ⇒ Object
Specifies whether the generated temporary password must contain at least one numeric character (0 to 9).
-
#use_special_characters ⇒ Object
Returns the value of attribute use_special_characters.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RotatedSecretCreateOpenAI
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RotatedSecretCreateOpenAI
Initializes the object
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 173 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::RotatedSecretCreateOpenAI` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::RotatedSecretCreateOpenAI`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'api_key') self.api_key = attributes[:'api_key'] end if attributes.key?(:'api_key_id') self.api_key_id = attributes[:'api_key_id'] end if attributes.key?(:'authentication_credentials') self.authentication_credentials = attributes[:'authentication_credentials'] else self.authentication_credentials = 'use-user-creds' end if attributes.key?(:'auto_rotate') self.auto_rotate = attributes[:'auto_rotate'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'max_versions') self.max_versions = attributes[:'max_versions'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'password_length') self.password_length = attributes[:'password_length'] end if attributes.key?(:'rotation_event_in') if (value = attributes[:'rotation_event_in']).is_a?(Array) self.rotation_event_in = value end end if attributes.key?(:'rotation_hour') self.rotation_hour = attributes[:'rotation_hour'] end if attributes.key?(:'rotation_interval') self.rotation_interval = attributes[:'rotation_interval'] end if attributes.key?(:'rotator_type') self.rotator_type = attributes[:'rotator_type'] else self.rotator_type = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'target_name') self.target_name = attributes[:'target_name'] else self.target_name = nil end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'use_capital_letters') self.use_capital_letters = attributes[:'use_capital_letters'] end if attributes.key?(:'use_lower_letters') self.use_lower_letters = attributes[:'use_lower_letters'] end if attributes.key?(:'use_numbers') self.use_numbers = attributes[:'use_numbers'] end if attributes.key?(:'use_special_characters') self.use_special_characters = attributes[:'use_special_characters'] end end |
Instance Attribute Details
#api_key ⇒ Object
Admin API key value to rotate (relevant only for rotator-type=api-key)
20 21 22 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 20 def api_key @api_key end |
#api_key_id ⇒ Object
Admin API key ID to rotate (relevant only for rotator-type=api-key)
23 24 25 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 23 def api_key_id @api_key_id end |
#authentication_credentials ⇒ Object
The credentials to connect with use-user-creds/use-target-creds
26 27 28 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 26 def authentication_credentials @authentication_credentials end |
#auto_rotate ⇒ Object
Whether to automatically rotate every –rotation-interval days, or disable existing automatic rotation [true/false]
29 30 31 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 29 def auto_rotate @auto_rotate end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
32 33 34 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 32 def delete_protection @delete_protection end |
#description ⇒ Object
Description of the object
35 36 37 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 35 def description @description end |
#input_rule ⇒ Object
Agentic input rule in name=…,rule=… format (e.g. name=rule1,rule=Sanitize input)
38 39 40 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 38 def input_rule @input_rule end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
41 42 43 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 41 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
44 45 46 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 44 def json @json end |
#key ⇒ Object
The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)
47 48 49 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 47 def key @key end |
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
50 51 52 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 50 def max_versions @max_versions end |
#name ⇒ Object
Rotated secret name
53 54 55 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 53 def name @name end |
#output_rule ⇒ Object
Agentic output rule in name=…,rule=… format (e.g. name=rule1,rule=Mask secrets)
56 57 58 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 56 def output_rule @output_rule end |
#password_length ⇒ Object
The length of the password to be generated
59 60 61 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 59 def password_length @password_length end |
#rotation_event_in ⇒ Object
How many days before the rotation of the item would you like to be notified
62 63 64 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 62 def rotation_event_in @rotation_event_in end |
#rotation_hour ⇒ Object
The Hour of the rotation in UTC
65 66 67 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 65 def rotation_hour @rotation_hour end |
#rotation_interval ⇒ Object
The number of days to wait between every automatic key rotation (1-365)
68 69 70 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 68 def rotation_interval @rotation_interval end |
#rotator_type ⇒ Object
The rotator type. options: [target/api-key]
71 72 73 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 71 def rotator_type @rotator_type end |
#tags ⇒ Object
Add tags attached to this object
74 75 76 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 74 def @tags end |
#target_name ⇒ Object
The target name to associate
77 78 79 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 77 def target_name @target_name end |
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`)
80 81 82 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 80 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
83 84 85 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 83 def uid_token @uid_token end |
#use_capital_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). [true/false]
86 87 88 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 86 def use_capital_letters @use_capital_letters end |
#use_lower_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). [true/false]
89 90 91 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 89 def use_lower_letters @use_lower_letters end |
#use_numbers ⇒ Object
Specifies whether the generated temporary password must contain at least one numeric character (0 to 9). [true/false]
92 93 94 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 92 def use_numbers @use_numbers end |
#use_special_characters ⇒ Object
Returns the value of attribute use_special_characters.
94 95 96 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 94 def use_special_characters @use_special_characters end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 413 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
129 130 131 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 129 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 97 def self.attribute_map { :'api_key' => :'api-key', :'api_key_id' => :'api-key-id', :'authentication_credentials' => :'authentication-credentials', :'auto_rotate' => :'auto-rotate', :'delete_protection' => :'delete_protection', :'description' => :'description', :'input_rule' => :'input-rule', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'key' => :'key', :'max_versions' => :'max-versions', :'name' => :'name', :'output_rule' => :'output-rule', :'password_length' => :'password-length', :'rotation_event_in' => :'rotation-event-in', :'rotation_hour' => :'rotation-hour', :'rotation_interval' => :'rotation-interval', :'rotator_type' => :'rotator-type', :'tags' => :'tags', :'target_name' => :'target-name', :'token' => :'token', :'uid_token' => :'uid-token', :'use_capital_letters' => :'use-capital-letters', :'use_lower_letters' => :'use-lower-letters', :'use_numbers' => :'use-numbers', :'use_special_characters' => :'use-special-characters' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 389 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
166 167 168 169 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 166 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 134 def self.openapi_types { :'api_key' => :'String', :'api_key_id' => :'String', :'authentication_credentials' => :'String', :'auto_rotate' => :'String', :'delete_protection' => :'String', :'description' => :'String', :'input_rule' => :'Array<String>', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'key' => :'String', :'max_versions' => :'String', :'name' => :'String', :'output_rule' => :'Array<String>', :'password_length' => :'String', :'rotation_event_in' => :'Array<String>', :'rotation_hour' => :'Integer', :'rotation_interval' => :'String', :'rotator_type' => :'String', :'tags' => :'Array<String>', :'target_name' => :'String', :'token' => :'String', :'uid_token' => :'String', :'use_capital_letters' => :'String', :'use_lower_letters' => :'String', :'use_numbers' => :'String', :'use_special_characters' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 343 def ==(o) return true if self.equal?(o) self.class == o.class && api_key == o.api_key && api_key_id == o.api_key_id && authentication_credentials == o.authentication_credentials && auto_rotate == o.auto_rotate && delete_protection == o.delete_protection && description == o.description && input_rule == o.input_rule && item_custom_fields == o.item_custom_fields && json == o.json && key == o.key && max_versions == o.max_versions && name == o.name && output_rule == o.output_rule && password_length == o.password_length && rotation_event_in == o.rotation_event_in && rotation_hour == o.rotation_hour && rotation_interval == o.rotation_interval && rotator_type == o.rotator_type && == o. && target_name == o.target_name && token == o.token && uid_token == o.uid_token && use_capital_letters == o.use_capital_letters && use_lower_letters == o.use_lower_letters && use_numbers == o.use_numbers && use_special_characters == o.use_special_characters end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
484 485 486 487 488 489 490 491 492 493 494 495 496 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 484 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
376 377 378 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 376 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
382 383 384 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 382 def hash [api_key, api_key_id, authentication_credentials, auto_rotate, delete_protection, description, input_rule, item_custom_fields, json, key, max_versions, name, output_rule, password_length, rotation_event_in, rotation_hour, rotation_interval, rotator_type, , target_name, token, uid_token, use_capital_letters, use_lower_letters, use_numbers, use_special_characters].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 313 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @rotator_type.nil? invalid_properties.push('invalid value for "rotator_type", rotator_type cannot be nil.') end if @target_name.nil? invalid_properties.push('invalid value for "target_name", target_name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
460 461 462 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 460 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
466 467 468 469 470 471 472 473 474 475 476 477 478 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 466 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
454 455 456 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 454 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
333 334 335 336 337 338 339 |
# File 'lib/akeyless/models/rotated_secret_create_open_ai.rb', line 333 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @rotator_type.nil? return false if @target_name.nil? true end |