Class: Akeyless::RotatedSecretDeleteSync
- Inherits:
-
Object
- Object
- Akeyless::RotatedSecretDeleteSync
- Defined in:
- lib/akeyless/models/rotated_secret_delete_sync.rb
Instance Attribute Summary collapse
-
#delete_from_usc ⇒ Object
Delete the secret from the remote target USC as well.
-
#environments ⇒ Object
GitHub environments to sync to.
-
#json ⇒ Object
Set output format to JSON.
-
#name ⇒ Object
Rotated secret name.
-
#remote_secret_name ⇒ Object
Remote Secret Name to disambiguate when multiple syncs exist under the same USC.
-
#repositories ⇒ Object
GitHub repositories to delete from.
-
#token ⇒ Object
Authentication token (see
/authand/configure). -
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#usc_name ⇒ Object
Universal Secret Connector name.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RotatedSecretDeleteSync
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RotatedSecretDeleteSync
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::RotatedSecretDeleteSync` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::RotatedSecretDeleteSync`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'delete_from_usc') self.delete_from_usc = attributes[:'delete_from_usc'] else self.delete_from_usc = false end if attributes.key?(:'environments') self.environments = attributes[:'environments'] end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'remote_secret_name') self.remote_secret_name = attributes[:'remote_secret_name'] end if attributes.key?(:'repositories') self.repositories = attributes[:'repositories'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'usc_name') self.usc_name = attributes[:'usc_name'] else self.usc_name = nil end end |
Instance Attribute Details
#delete_from_usc ⇒ Object
Delete the secret from the remote target USC as well
19 20 21 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 19 def delete_from_usc @delete_from_usc end |
#environments ⇒ Object
GitHub environments to sync to. Relevant only for GitHub targets. Syncs to all environments defined on the selected USC by default, or to one or more specific repositories associated with that USC item when specified (e.g. --environments repo1/env1,repo2/env2).
22 23 24 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 22 def environments @environments end |
#json ⇒ Object
Set output format to JSON
25 26 27 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 25 def json @json end |
#name ⇒ Object
Rotated secret name
28 29 30 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 28 def name @name end |
#remote_secret_name ⇒ Object
Remote Secret Name to disambiguate when multiple syncs exist under the same USC
31 32 33 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 31 def remote_secret_name @remote_secret_name end |
#repositories ⇒ Object
GitHub repositories to delete from. Defaults to all repositories available on the selected USC. GitHub repositories to sync to. Relevant only for GitHub targets. Syncs to all repositories defined on the selected USC by default, or to one or more specific repositories associated with that USC item when specified (e.g. --repositories repo1,repo2).
34 35 36 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 34 def repositories @repositories end |
#token ⇒ Object
Authentication token (see /auth and /configure)
37 38 39 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 37 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
40 41 42 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 40 def uid_token @uid_token end |
#usc_name ⇒ Object
Universal Secret Connector name
43 44 45 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 43 def usc_name @usc_name end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 226 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 61 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 46 def self.attribute_map { :'delete_from_usc' => :'delete-from-usc', :'environments' => :'environments', :'json' => :'json', :'name' => :'name', :'remote_secret_name' => :'remote-secret-name', :'repositories' => :'repositories', :'token' => :'token', :'uid_token' => :'uid-token', :'usc_name' => :'usc-name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 202 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 66 def self.openapi_types { :'delete_from_usc' => :'Boolean', :'environments' => :'String', :'json' => :'Boolean', :'name' => :'String', :'remote_secret_name' => :'String', :'repositories' => :'String', :'token' => :'String', :'uid_token' => :'String', :'usc_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 173 def ==(o) return true if self.equal?(o) self.class == o.class && delete_from_usc == o.delete_from_usc && environments == o.environments && json == o.json && name == o.name && remote_secret_name == o.remote_secret_name && repositories == o.repositories && token == o.token && uid_token == o.uid_token && usc_name == o.usc_name end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 297 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
189 190 191 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 189 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
195 196 197 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 195 def hash [delete_from_usc, environments, json, name, remote_secret_name, repositories, token, uid_token, usc_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 148 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @usc_name.nil? invalid_properties.push('invalid value for "usc_name", usc_name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
273 274 275 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 273 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 279 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
267 268 269 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 267 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
164 165 166 167 168 169 |
# File 'lib/akeyless/models/rotated_secret_delete_sync.rb', line 164 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @usc_name.nil? true end |