Class: Akeyless::RotatedSecretDetailsInfo

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/rotated_secret_details_info.rb

Overview

RotatedSecretDetailsInfo The rotated secret rotator info

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RotatedSecretDetailsInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 150

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::RotatedSecretDetailsInfo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::RotatedSecretDetailsInfo`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'aws_user_name')
    self.aws_user_name = attributes[:'aws_user_name']
  end

  if attributes.key?(:'delete_previous_version_in_days')
    self.delete_previous_version_in_days = attributes[:'delete_previous_version_in_days']
  end

  if attributes.key?(:'enable_custom_password_policy')
    self.enable_custom_password_policy = attributes[:'enable_custom_password_policy']
  end

  if attributes.key?(:'grace_rotation')
    self.grace_rotation = attributes[:'grace_rotation']
  end

  if attributes.key?(:'grace_rotation_hour')
    self.grace_rotation_hour = attributes[:'grace_rotation_hour']
  end

  if attributes.key?(:'grace_rotation_interval')
    self.grace_rotation_interval = attributes[:'grace_rotation_interval']
  end

  if attributes.key?(:'grace_rotation_timing')
    self.grace_rotation_timing = attributes[:'grace_rotation_timing']
  end

  if attributes.key?(:'gw_cluster_id')
    self.gw_cluster_id = attributes[:'gw_cluster_id']
  end

  if attributes.key?(:'iis_apps_details')
    if (value = attributes[:'iis_apps_details']).is_a?(Array)
      self.iis_apps_details = value
    end
  end

  if attributes.key?(:'key_algorithm')
    self.key_algorithm = attributes[:'key_algorithm']
  end

  if attributes.key?(:'last_rotation_error')
    self.last_rotation_error = attributes[:'last_rotation_error']
  end

  if attributes.key?(:'managed_by_akeyless')
    self.managed_by_akeyless = attributes[:'managed_by_akeyless']
  end

  if attributes.key?(:'max_versions')
    self.max_versions = attributes[:'max_versions']
  end

  if attributes.key?(:'next_auto_rotate_type')
    self.next_auto_rotate_type = attributes[:'next_auto_rotate_type']
  end

  if attributes.key?(:'number_of_versions_to_save')
    self.number_of_versions_to_save = attributes[:'number_of_versions_to_save']
  end

  if attributes.key?(:'public_key_remote_path')
    self.public_key_remote_path = attributes[:'public_key_remote_path']
  end

  if attributes.key?(:'rotation_hour')
    self.rotation_hour = attributes[:'rotation_hour']
  end

  if attributes.key?(:'rotation_interval_min')
    self.rotation_interval_min = attributes[:'rotation_interval_min']
  end

  if attributes.key?(:'rotation_statement')
    self.rotation_statement = attributes[:'rotation_statement']
  end

  if attributes.key?(:'rotator_creds_type')
    self.rotator_creds_type = attributes[:'rotator_creds_type']
  end

  if attributes.key?(:'rotator_status')
    self.rotator_status = attributes[:'rotator_status']
  end

  if attributes.key?(:'rotator_type')
    self.rotator_type = attributes[:'rotator_type']
  end

  if attributes.key?(:'same_password')
    self.same_password = attributes[:'same_password']
  end

  if attributes.key?(:'services_details')
    if (value = attributes[:'services_details']).is_a?(Array)
      self.services_details = value
    end
  end

  if attributes.key?(:'skip_dry_run')
    self.skip_dry_run = attributes[:'skip_dry_run']
  end

  if attributes.key?(:'timeout_seconds')
    self.timeout_seconds = attributes[:'timeout_seconds']
  end
end

Instance Attribute Details

#aws_user_nameObject

Returns the value of attribute aws_user_name.



19
20
21
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 19

def aws_user_name
  @aws_user_name
end

#delete_previous_version_in_daysObject

Returns the value of attribute delete_previous_version_in_days.



21
22
23
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 21

def delete_previous_version_in_days
  @delete_previous_version_in_days
end

#enable_custom_password_policyObject

Returns the value of attribute enable_custom_password_policy.



23
24
25
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 23

def enable_custom_password_policy
  @enable_custom_password_policy
end

#grace_rotationObject

Returns the value of attribute grace_rotation.



25
26
27
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 25

def grace_rotation
  @grace_rotation
end

#grace_rotation_hourObject

Returns the value of attribute grace_rotation_hour.



27
28
29
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 27

def grace_rotation_hour
  @grace_rotation_hour
end

#grace_rotation_intervalObject

Returns the value of attribute grace_rotation_interval.



29
30
31
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 29

def grace_rotation_interval
  @grace_rotation_interval
end

#grace_rotation_timingObject

Returns the value of attribute grace_rotation_timing.



31
32
33
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 31

def grace_rotation_timing
  @grace_rotation_timing
end

#gw_cluster_idObject

Returns the value of attribute gw_cluster_id.



33
34
35
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 33

def gw_cluster_id
  @gw_cluster_id
end

#iis_apps_detailsObject

Returns the value of attribute iis_apps_details.



35
36
37
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 35

def iis_apps_details
  @iis_apps_details
end

#key_algorithmObject

SSHKeyAlgorithm identifies the key algorithm an SSH rotated secret uses. Kept apart from Algorithm, which is an encryption-key enum and has no ECDSA-384 or ECDSA-521.



38
39
40
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 38

def key_algorithm
  @key_algorithm
end

#last_rotation_errorObject

Returns the value of attribute last_rotation_error.



40
41
42
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 40

def last_rotation_error
  @last_rotation_error
end

#managed_by_akeylessObject

Returns the value of attribute managed_by_akeyless.



42
43
44
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 42

def managed_by_akeyless
  @managed_by_akeyless
end

#max_versionsObject

Returns the value of attribute max_versions.



44
45
46
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 44

def max_versions
  @max_versions
end

#next_auto_rotate_typeObject

Returns the value of attribute next_auto_rotate_type.



46
47
48
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 46

def next_auto_rotate_type
  @next_auto_rotate_type
end

#number_of_versions_to_saveObject

Returns the value of attribute number_of_versions_to_save.



48
49
50
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 48

def number_of_versions_to_save
  @number_of_versions_to_save
end

#public_key_remote_pathObject

Returns the value of attribute public_key_remote_path.



50
51
52
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 50

def public_key_remote_path
  @public_key_remote_path
end

#rotation_hourObject

Returns the value of attribute rotation_hour.



52
53
54
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 52

def rotation_hour
  @rotation_hour
end

#rotation_interval_minObject

Returns the value of attribute rotation_interval_min.



54
55
56
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 54

def rotation_interval_min
  @rotation_interval_min
end

#rotation_statementObject

Returns the value of attribute rotation_statement.



56
57
58
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 56

def rotation_statement
  @rotation_statement
end

#rotator_creds_typeObject

Returns the value of attribute rotator_creds_type.



58
59
60
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 58

def rotator_creds_type
  @rotator_creds_type
end

#rotator_statusObject

RotationStatus defines types of rotation Status



61
62
63
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 61

def rotator_status
  @rotator_status
end

#rotator_typeObject

Returns the value of attribute rotator_type.



63
64
65
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 63

def rotator_type
  @rotator_type
end

#same_passwordObject

Returns the value of attribute same_password.



65
66
67
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 65

def same_password
  @same_password
end

#services_detailsObject

Returns the value of attribute services_details.



67
68
69
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 67

def services_details
  @services_details
end

#skip_dry_runObject

Returns the value of attribute skip_dry_run.



69
70
71
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 69

def skip_dry_run
  @skip_dry_run
end

#timeout_secondsObject

Returns the value of attribute timeout_seconds.



71
72
73
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 71

def timeout_seconds
  @timeout_seconds
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 359

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



106
107
108
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 106

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 74

def self.attribute_map
  {
    :'aws_user_name' => :'aws_user_name',
    :'delete_previous_version_in_days' => :'delete_previous_version_in_days',
    :'enable_custom_password_policy' => :'enable_custom_password_policy',
    :'grace_rotation' => :'grace_rotation',
    :'grace_rotation_hour' => :'grace_rotation_hour',
    :'grace_rotation_interval' => :'grace_rotation_interval',
    :'grace_rotation_timing' => :'grace_rotation_timing',
    :'gw_cluster_id' => :'gw_cluster_id',
    :'iis_apps_details' => :'iis_apps_details',
    :'key_algorithm' => :'key_algorithm',
    :'last_rotation_error' => :'last_rotation_error',
    :'managed_by_akeyless' => :'managed_by_akeyless',
    :'max_versions' => :'max_versions',
    :'next_auto_rotate_type' => :'next_auto_rotate_type',
    :'number_of_versions_to_save' => :'number_of_versions_to_save',
    :'public_key_remote_path' => :'public_key_remote_path',
    :'rotation_hour' => :'rotation_hour',
    :'rotation_interval_min' => :'rotation_interval_min',
    :'rotation_statement' => :'rotation_statement',
    :'rotator_creds_type' => :'rotator_creds_type',
    :'rotator_status' => :'rotator_status',
    :'rotator_type' => :'rotator_type',
    :'same_password' => :'same_password',
    :'services_details' => :'services_details',
    :'skip_dry_run' => :'skip_dry_run',
    :'timeout_seconds' => :'timeout_seconds'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 335

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



143
144
145
146
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 143

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 111

def self.openapi_types
  {
    :'aws_user_name' => :'String',
    :'delete_previous_version_in_days' => :'Integer',
    :'enable_custom_password_policy' => :'Boolean',
    :'grace_rotation' => :'Boolean',
    :'grace_rotation_hour' => :'Integer',
    :'grace_rotation_interval' => :'Integer',
    :'grace_rotation_timing' => :'String',
    :'gw_cluster_id' => :'Integer',
    :'iis_apps_details' => :'Array<WindowsService>',
    :'key_algorithm' => :'String',
    :'last_rotation_error' => :'String',
    :'managed_by_akeyless' => :'Boolean',
    :'max_versions' => :'Integer',
    :'next_auto_rotate_type' => :'String',
    :'number_of_versions_to_save' => :'Integer',
    :'public_key_remote_path' => :'String',
    :'rotation_hour' => :'Integer',
    :'rotation_interval_min' => :'Boolean',
    :'rotation_statement' => :'String',
    :'rotator_creds_type' => :'String',
    :'rotator_status' => :'String',
    :'rotator_type' => :'String',
    :'same_password' => :'Boolean',
    :'services_details' => :'Array<WindowsService>',
    :'skip_dry_run' => :'Boolean',
    :'timeout_seconds' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 289

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      aws_user_name == o.aws_user_name &&
      delete_previous_version_in_days == o.delete_previous_version_in_days &&
      enable_custom_password_policy == o.enable_custom_password_policy &&
      grace_rotation == o.grace_rotation &&
      grace_rotation_hour == o.grace_rotation_hour &&
      grace_rotation_interval == o.grace_rotation_interval &&
      grace_rotation_timing == o.grace_rotation_timing &&
      gw_cluster_id == o.gw_cluster_id &&
      iis_apps_details == o.iis_apps_details &&
      key_algorithm == o.key_algorithm &&
      last_rotation_error == o.last_rotation_error &&
      managed_by_akeyless == o.managed_by_akeyless &&
      max_versions == o.max_versions &&
      next_auto_rotate_type == o.next_auto_rotate_type &&
      number_of_versions_to_save == o.number_of_versions_to_save &&
      public_key_remote_path == o.public_key_remote_path &&
      rotation_hour == o.rotation_hour &&
      rotation_interval_min == o.rotation_interval_min &&
      rotation_statement == o.rotation_statement &&
      rotator_creds_type == o.rotator_creds_type &&
      rotator_status == o.rotator_status &&
      rotator_type == o.rotator_type &&
      same_password == o.same_password &&
      services_details == o.services_details &&
      skip_dry_run == o.skip_dry_run &&
      timeout_seconds == o.timeout_seconds
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 430

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


322
323
324
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 322

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



328
329
330
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 328

def hash
  [aws_user_name, delete_previous_version_in_days, enable_custom_password_policy, grace_rotation, grace_rotation_hour, grace_rotation_interval, grace_rotation_timing, gw_cluster_id, iis_apps_details, key_algorithm, last_rotation_error, managed_by_akeyless, max_versions, next_auto_rotate_type, number_of_versions_to_save, public_key_remote_path, rotation_hour, rotation_interval_min, rotation_statement, rotator_creds_type, rotator_status, rotator_type, same_password, services_details, skip_dry_run, timeout_seconds].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



274
275
276
277
278
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 274

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



406
407
408
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 406

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 412

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



400
401
402
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 400

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



282
283
284
285
# File 'lib/akeyless/models/rotated_secret_details_info.rb', line 282

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end