Class: Akeyless::RotatedSecretUpdateOpenAI
- Inherits:
-
Object
- Object
- Akeyless::RotatedSecretUpdateOpenAI
- Defined in:
- lib/akeyless/models/rotated_secret_update_open_ai.rb
Overview
rotatedSecretUpdateOpenAI is a command that updates an OpenAI rotated secret.
Instance Attribute Summary collapse
-
#add_tag ⇒ Object
List of the new tags that will be attached to this item.
-
#api_key ⇒ Object
Admin API key value to update (relevant only for rotator-type=api-key).
-
#api_key_id ⇒ Object
Admin API key ID to update (relevant only for rotator-type=api-key).
-
#authentication_credentials ⇒ Object
The credentials to connect with use-user-creds/use-target-creds.
-
#auto_rotate ⇒ Object
Returns the value of attribute auto_rotate.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#description ⇒ Object
Description of the object.
-
#input_rule ⇒ Object
Agentic input rule in name=…,rule=…
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#keep_prev_version ⇒ Object
Whether to keep previous version [true/false].
-
#key ⇒ Object
Returns the value of attribute key.
-
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
-
#name ⇒ Object
Rotated secret name.
-
#new_name ⇒ Object
New item name.
-
#output_rule ⇒ Object
Agentic output rule in name=…,rule=…
-
#password_length ⇒ Object
The length of the password to be generated.
-
#rm_tag ⇒ Object
List of the existent tags that will be removed from this item.
-
#rotation_event_in ⇒ Object
How many days before the rotation of the item would you like to be notified.
-
#rotation_hour ⇒ Object
Returns the value of attribute rotation_hour.
-
#rotation_interval ⇒ Object
Returns the value of attribute rotation_interval.
-
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`).
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#use_capital_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z).
-
#use_lower_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z).
-
#use_numbers ⇒ Object
Specifies whether the generated temporary password must contain at least one numeric character (0 to 9).
-
#use_special_characters ⇒ Object
Returns the value of attribute use_special_characters.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RotatedSecretUpdateOpenAI
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RotatedSecretUpdateOpenAI
Initializes the object
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 174 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::RotatedSecretUpdateOpenAI` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::RotatedSecretUpdateOpenAI`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'add_tag') if (value = attributes[:'add_tag']).is_a?(Array) self.add_tag = value end end if attributes.key?(:'api_key') self.api_key = attributes[:'api_key'] end if attributes.key?(:'api_key_id') self.api_key_id = attributes[:'api_key_id'] end if attributes.key?(:'authentication_credentials') self.authentication_credentials = attributes[:'authentication_credentials'] else self.authentication_credentials = 'use-user-creds' end if attributes.key?(:'auto_rotate') self.auto_rotate = attributes[:'auto_rotate'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = 'default_metadata' end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'keep_prev_version') self.keep_prev_version = attributes[:'keep_prev_version'] end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'max_versions') self.max_versions = attributes[:'max_versions'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'new_name') self.new_name = attributes[:'new_name'] end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'password_length') self.password_length = attributes[:'password_length'] end if attributes.key?(:'rm_tag') if (value = attributes[:'rm_tag']).is_a?(Array) self.rm_tag = value end end if attributes.key?(:'rotation_event_in') if (value = attributes[:'rotation_event_in']).is_a?(Array) self.rotation_event_in = value end end if attributes.key?(:'rotation_hour') self.rotation_hour = attributes[:'rotation_hour'] end if attributes.key?(:'rotation_interval') self.rotation_interval = attributes[:'rotation_interval'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'use_capital_letters') self.use_capital_letters = attributes[:'use_capital_letters'] end if attributes.key?(:'use_lower_letters') self.use_lower_letters = attributes[:'use_lower_letters'] end if attributes.key?(:'use_numbers') self.use_numbers = attributes[:'use_numbers'] end if attributes.key?(:'use_special_characters') self.use_special_characters = attributes[:'use_special_characters'] end end |
Instance Attribute Details
#add_tag ⇒ Object
List of the new tags that will be attached to this item
20 21 22 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 20 def add_tag @add_tag end |
#api_key ⇒ Object
Admin API key value to update (relevant only for rotator-type=api-key)
23 24 25 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 23 def api_key @api_key end |
#api_key_id ⇒ Object
Admin API key ID to update (relevant only for rotator-type=api-key)
26 27 28 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 26 def api_key_id @api_key_id end |
#authentication_credentials ⇒ Object
The credentials to connect with use-user-creds/use-target-creds
29 30 31 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 29 def authentication_credentials @authentication_credentials end |
#auto_rotate ⇒ Object
Returns the value of attribute auto_rotate.
31 32 33 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 31 def auto_rotate @auto_rotate end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
34 35 36 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 34 def delete_protection @delete_protection end |
#description ⇒ Object
Description of the object
37 38 39 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 37 def description @description end |
#input_rule ⇒ Object
Agentic input rule in name=…,rule=… format (e.g. name=rule1,rule=Sanitize input)
40 41 42 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 40 def input_rule @input_rule end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
43 44 45 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 43 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
46 47 48 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 46 def json @json end |
#keep_prev_version ⇒ Object
Whether to keep previous version [true/false]. If not set, use default according to account settings
49 50 51 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 49 def keep_prev_version @keep_prev_version end |
#key ⇒ Object
Returns the value of attribute key.
51 52 53 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 51 def key @key end |
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
54 55 56 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 54 def max_versions @max_versions end |
#name ⇒ Object
Rotated secret name
57 58 59 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 57 def name @name end |
#new_name ⇒ Object
New item name
60 61 62 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 60 def new_name @new_name end |
#output_rule ⇒ Object
Agentic output rule in name=…,rule=… format (e.g. name=rule1,rule=Mask secrets)
63 64 65 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 63 def output_rule @output_rule end |
#password_length ⇒ Object
The length of the password to be generated
66 67 68 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 66 def password_length @password_length end |
#rm_tag ⇒ Object
List of the existent tags that will be removed from this item
69 70 71 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 69 def rm_tag @rm_tag end |
#rotation_event_in ⇒ Object
How many days before the rotation of the item would you like to be notified
72 73 74 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 72 def rotation_event_in @rotation_event_in end |
#rotation_hour ⇒ Object
Returns the value of attribute rotation_hour.
74 75 76 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 74 def rotation_hour @rotation_hour end |
#rotation_interval ⇒ Object
Returns the value of attribute rotation_interval.
76 77 78 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 76 def rotation_interval @rotation_interval end |
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`)
79 80 81 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 79 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
82 83 84 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 82 def uid_token @uid_token end |
#use_capital_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). [true/false]
85 86 87 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 85 def use_capital_letters @use_capital_letters end |
#use_lower_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). [true/false]
88 89 90 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 88 def use_lower_letters @use_lower_letters end |
#use_numbers ⇒ Object
Specifies whether the generated temporary password must contain at least one numeric character (0 to 9). [true/false]
91 92 93 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 91 def use_numbers @use_numbers end |
#use_special_characters ⇒ Object
Returns the value of attribute use_special_characters.
93 94 95 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 93 def use_special_characters @use_special_characters end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 409 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
129 130 131 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 129 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 96 def self.attribute_map { :'add_tag' => :'add-tag', :'api_key' => :'api-key', :'api_key_id' => :'api-key-id', :'authentication_credentials' => :'authentication-credentials', :'auto_rotate' => :'auto-rotate', :'delete_protection' => :'delete_protection', :'description' => :'description', :'input_rule' => :'input-rule', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'keep_prev_version' => :'keep-prev-version', :'key' => :'key', :'max_versions' => :'max-versions', :'name' => :'name', :'new_name' => :'new-name', :'output_rule' => :'output-rule', :'password_length' => :'password-length', :'rm_tag' => :'rm-tag', :'rotation_event_in' => :'rotation-event-in', :'rotation_hour' => :'rotation-hour', :'rotation_interval' => :'rotation-interval', :'token' => :'token', :'uid_token' => :'uid-token', :'use_capital_letters' => :'use-capital-letters', :'use_lower_letters' => :'use-lower-letters', :'use_numbers' => :'use-numbers', :'use_special_characters' => :'use-special-characters' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 385 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
167 168 169 170 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 167 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 134 def self.openapi_types { :'add_tag' => :'Array<String>', :'api_key' => :'String', :'api_key_id' => :'String', :'authentication_credentials' => :'String', :'auto_rotate' => :'String', :'delete_protection' => :'String', :'description' => :'String', :'input_rule' => :'Array<String>', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'keep_prev_version' => :'String', :'key' => :'String', :'max_versions' => :'String', :'name' => :'String', :'new_name' => :'String', :'output_rule' => :'Array<String>', :'password_length' => :'String', :'rm_tag' => :'Array<String>', :'rotation_event_in' => :'Array<String>', :'rotation_hour' => :'Integer', :'rotation_interval' => :'String', :'token' => :'String', :'uid_token' => :'String', :'use_capital_letters' => :'String', :'use_lower_letters' => :'String', :'use_numbers' => :'String', :'use_special_characters' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 338 def ==(o) return true if self.equal?(o) self.class == o.class && add_tag == o.add_tag && api_key == o.api_key && api_key_id == o.api_key_id && authentication_credentials == o.authentication_credentials && auto_rotate == o.auto_rotate && delete_protection == o.delete_protection && description == o.description && input_rule == o.input_rule && item_custom_fields == o.item_custom_fields && json == o.json && keep_prev_version == o.keep_prev_version && key == o.key && max_versions == o.max_versions && name == o.name && new_name == o.new_name && output_rule == o.output_rule && password_length == o.password_length && rm_tag == o.rm_tag && rotation_event_in == o.rotation_event_in && rotation_hour == o.rotation_hour && rotation_interval == o.rotation_interval && token == o.token && uid_token == o.uid_token && use_capital_letters == o.use_capital_letters && use_lower_letters == o.use_lower_letters && use_numbers == o.use_numbers && use_special_characters == o.use_special_characters end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 480 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
372 373 374 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 372 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
378 379 380 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 378 def hash [add_tag, api_key, api_key_id, authentication_credentials, auto_rotate, delete_protection, description, input_rule, item_custom_fields, json, keep_prev_version, key, max_versions, name, new_name, output_rule, password_length, rm_tag, rotation_event_in, rotation_hour, rotation_interval, token, uid_token, use_capital_letters, use_lower_letters, use_numbers, use_special_characters].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
318 319 320 321 322 323 324 325 326 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 318 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
456 457 458 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 456 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
462 463 464 465 466 467 468 469 470 471 472 473 474 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 462 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
450 451 452 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 450 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
330 331 332 333 334 |
# File 'lib/akeyless/models/rotated_secret_update_open_ai.rb', line 330 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |