Class: Akeyless::RotatedSecretUpdateSplunk

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/rotated_secret_update_splunk.rb

Overview

rotatedSecretUpdateSplunk is a command that updates a rotated secret for a Splunk target. It reuses the rotator type chosen at create time.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RotatedSecretUpdateSplunk

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 224

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::RotatedSecretUpdateSplunk` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::RotatedSecretUpdateSplunk`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'add_tag')
    if (value = attributes[:'add_tag']).is_a?(Array)
      self.add_tag = value
    end
  end

  if attributes.key?(:'ara_enabled')
    self.ara_enabled = attributes[:'ara_enabled']
  end

  if attributes.key?(:'audience')
    self.audience = attributes[:'audience']
  end

  if attributes.key?(:'authentication_credentials')
    self.authentication_credentials = attributes[:'authentication_credentials']
  else
    self.authentication_credentials = 'use-user-creds'
  end

  if attributes.key?(:'auto_rotate')
    self.auto_rotate = attributes[:'auto_rotate']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = 'default_metadata'
  end

  if attributes.key?(:'enable_agentic_runtime_authority')
    self.enable_agentic_runtime_authority = attributes[:'enable_agentic_runtime_authority']
  end

  if attributes.key?(:'enable_ai_quorum')
    self.enable_ai_quorum = attributes[:'enable_ai_quorum']
  end

  if attributes.key?(:'expiration_date')
    self.expiration_date = attributes[:'expiration_date']
  end

  if attributes.key?(:'hec_token')
    self.hec_token = attributes[:'hec_token']
  end

  if attributes.key?(:'input_rule')
    if (value = attributes[:'input_rule']).is_a?(Array)
      self.input_rule = value
    end
  end

  if attributes.key?(:'item_custom_fields')
    if (value = attributes[:'item_custom_fields']).is_a?(Hash)
      self.item_custom_fields = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'keep_prev_version')
    self.keep_prev_version = attributes[:'keep_prev_version']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'lock_on_read')
    self.lock_on_read = attributes[:'lock_on_read']
  end

  if attributes.key?(:'lock_ttl')
    self.lock_ttl = attributes[:'lock_ttl']
  end

  if attributes.key?(:'max_versions')
    self.max_versions = attributes[:'max_versions']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'output_rule')
    if (value = attributes[:'output_rule']).is_a?(Array)
      self.output_rule = value
    end
  end

  if attributes.key?(:'password_length')
    self.password_length = attributes[:'password_length']
  end

  if attributes.key?(:'rm_tag')
    if (value = attributes[:'rm_tag']).is_a?(Array)
      self.rm_tag = value
    end
  end

  if attributes.key?(:'rotate_on_unlock')
    self.rotate_on_unlock = attributes[:'rotate_on_unlock']
  end

  if attributes.key?(:'rotation_event_in')
    if (value = attributes[:'rotation_event_in']).is_a?(Array)
      self.rotation_event_in = value
    end
  end

  if attributes.key?(:'rotation_hour')
    self.rotation_hour = attributes[:'rotation_hour']
  end

  if attributes.key?(:'rotation_interval')
    self.rotation_interval = attributes[:'rotation_interval']
  end

  if attributes.key?(:'skip_dry_run')
    self.skip_dry_run = attributes[:'skip_dry_run']
  end

  if attributes.key?(:'splunk_token')
    self.splunk_token = attributes[:'splunk_token']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'token_owner')
    self.token_owner = attributes[:'token_owner']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'use_capital_letters')
    self.use_capital_letters = attributes[:'use_capital_letters']
  end

  if attributes.key?(:'use_lower_letters')
    self.use_lower_letters = attributes[:'use_lower_letters']
  end

  if attributes.key?(:'use_numbers')
    self.use_numbers = attributes[:'use_numbers']
  end

  if attributes.key?(:'use_special_characters')
    self.use_special_characters = attributes[:'use_special_characters']
  end
end

Instance Attribute Details

#add_tagObject

List of the new tags that will be attached to this item



20
21
22
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 20

def add_tag
  @add_tag
end

#ara_enabledObject

Enable or disable Agentic Runtime Authority rule enforcement for this item. When false, user-defined input/output rules are stored but not enforced; the base security validation still runs. AraEnabled is tri-state (nil/true/false), not a plain bool: it self-encodes its wire value (see akl.OptionalBool) so an explicit false survives the curl-proxy relay instead of being dropped like a default-false bool flag.



23
24
25
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 23

def ara_enabled
  @ara_enabled
end

#audienceObject

Token audience for Splunk token creation (relevant only for rotator-type=token)



26
27
28
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 26

def audience
  @audience
end

#authentication_credentialsObject

The credentials to connect with use-user-creds/use-target-creds



29
30
31
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 29

def authentication_credentials
  @authentication_credentials
end

#auto_rotateObject

Returns the value of attribute auto_rotate.



31
32
33
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 31

def auto_rotate
  @auto_rotate
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



34
35
36
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 34

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



37
38
39
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 37

def description
  @description
end

#enable_agentic_runtime_authorityObject

EnableAra is the documented spelling of AraEnabled. Both set the same field; --ara-enabled shipped first and stays as an undocumented alias so existing scripts and the Terraform provider keep working.



40
41
42
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 40

def enable_agentic_runtime_authority
  @enable_agentic_runtime_authority
end

#enable_ai_quorumObject

Turns on AI Quorum checks for this item.



43
44
45
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 43

def enable_ai_quorum
  @enable_ai_quorum
end

#expiration_dateObject

Token expiration date in YYYY-MM-DD format (relevant only for rotator-type=token when manual rotation is selected). Time will be set to 00:00 UTC.



46
47
48
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 46

def expiration_date
  @expiration_date
end

#hec_tokenObject

For rotator-type=hec-token, optionally set/replace the stored HEC token value.



49
50
51
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 49

def hec_token
  @hec_token
end

#input_ruleObject

Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input)



52
53
54
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 52

def input_rule
  @input_rule
end

#item_custom_fieldsObject

Additional custom fields to associate with the item



55
56
57
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 55

def item_custom_fields
  @item_custom_fields
end

#jsonObject

Set output format to JSON



58
59
60
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 58

def json
  @json
end

#keep_prev_versionObject

Whether to keep previous version [true/false]. If not set, use default according to account settings



61
62
63
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 61

def keep_prev_version
  @keep_prev_version
end

#keyObject

Returns the value of attribute key.



63
64
65
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 63

def key
  @key
end

#lock_on_readObject

Lock this secret after each successful value read



66
67
68
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 66

def lock_on_read
  @lock_on_read
end

#lock_ttlObject

Lock TTL in minutes



69
70
71
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 69

def lock_ttl
  @lock_ttl
end

#max_versionsObject

Set the maximum number of versions, limited by the account settings defaults.



72
73
74
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 72

def max_versions
  @max_versions
end

#nameObject

Rotated secret name



75
76
77
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 75

def name
  @name
end

#new_nameObject

New item name



78
79
80
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 78

def new_name
  @new_name
end

#output_ruleObject

Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)



81
82
83
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 81

def output_rule
  @output_rule
end

#password_lengthObject

The length of the password to be generated



84
85
86
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 84

def password_length
  @password_length
end

#rm_tagObject

List of the existent tags that will be removed from this item



87
88
89
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 87

def rm_tag
  @rm_tag
end

#rotate_on_unlockObject

Rotate this secret after it is unlocked



90
91
92
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 90

def rotate_on_unlock
  @rotate_on_unlock
end

#rotation_event_inObject

How many days before the rotation of the item would you like to be notified



93
94
95
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 93

def rotation_event_in
  @rotation_event_in
end

#rotation_hourObject

Returns the value of attribute rotation_hour.



95
96
97
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 95

def rotation_hour
  @rotation_hour
end

#rotation_intervalObject

Returns the value of attribute rotation_interval.



97
98
99
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 97

def rotation_interval
  @rotation_interval
end

#skip_dry_runObject

If set, dry-run will be skipped [true/false]



100
101
102
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 100

def skip_dry_run
  @skip_dry_run
end

#splunk_tokenObject

For rotator-type=token, optionally set/replace the stored Splunk authentication token value.



103
104
105
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 103

def splunk_token
  @splunk_token
end

#tokenObject

Authentication token (see /auth and /configure)



106
107
108
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 106

def token
  @token
end

#token_ownerObject

For rotator-type=token, specify the Splunk username that the new token should be issued for. (Splunk 10 requires name= when creating auth tokens.)



109
110
111
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 109

def token_owner
  @token_owner
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



112
113
114
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 112

def uid_token
  @uid_token
end

#use_capital_lettersObject

Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). [true/false]



115
116
117
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 115

def use_capital_letters
  @use_capital_letters
end

#use_lower_lettersObject

Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). [true/false]



118
119
120
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 118

def use_lower_letters
  @use_lower_letters
end

#use_numbersObject

Specifies whether the generated temporary password must contain at least one numeric character (0 to 9). [true/false]



121
122
123
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 121

def use_numbers
  @use_numbers
end

#use_special_charactersObject

Returns the value of attribute use_special_characters.



123
124
125
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 123

def use_special_characters
  @use_special_characters
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 509

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



169
170
171
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 169

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 126

def self.attribute_map
  {
    :'add_tag' => :'add-tag',
    :'ara_enabled' => :'ara-enabled',
    :'audience' => :'audience',
    :'authentication_credentials' => :'authentication-credentials',
    :'auto_rotate' => :'auto-rotate',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'enable_agentic_runtime_authority' => :'enable-agentic-runtime-authority',
    :'enable_ai_quorum' => :'enable-ai-quorum',
    :'expiration_date' => :'expiration-date',
    :'hec_token' => :'hec-token',
    :'input_rule' => :'input-rule',
    :'item_custom_fields' => :'item-custom-fields',
    :'json' => :'json',
    :'keep_prev_version' => :'keep-prev-version',
    :'key' => :'key',
    :'lock_on_read' => :'lock-on-read',
    :'lock_ttl' => :'lock-ttl',
    :'max_versions' => :'max-versions',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'output_rule' => :'output-rule',
    :'password_length' => :'password-length',
    :'rm_tag' => :'rm-tag',
    :'rotate_on_unlock' => :'rotate-on-unlock',
    :'rotation_event_in' => :'rotation-event-in',
    :'rotation_hour' => :'rotation-hour',
    :'rotation_interval' => :'rotation-interval',
    :'skip_dry_run' => :'skip-dry-run',
    :'splunk_token' => :'splunk-token',
    :'token' => :'token',
    :'token_owner' => :'token-owner',
    :'uid_token' => :'uid-token',
    :'use_capital_letters' => :'use-capital-letters',
    :'use_lower_letters' => :'use-lower-letters',
    :'use_numbers' => :'use-numbers',
    :'use_special_characters' => :'use-special-characters'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 485

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



217
218
219
220
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 217

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 174

def self.openapi_types
  {
    :'add_tag' => :'Array<String>',
    :'ara_enabled' => :'Boolean',
    :'audience' => :'String',
    :'authentication_credentials' => :'String',
    :'auto_rotate' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'enable_agentic_runtime_authority' => :'Boolean',
    :'enable_ai_quorum' => :'Boolean',
    :'expiration_date' => :'String',
    :'hec_token' => :'String',
    :'input_rule' => :'Array<String>',
    :'item_custom_fields' => :'Hash<String, String>',
    :'json' => :'Boolean',
    :'keep_prev_version' => :'String',
    :'key' => :'String',
    :'lock_on_read' => :'String',
    :'lock_ttl' => :'String',
    :'max_versions' => :'String',
    :'name' => :'String',
    :'new_name' => :'String',
    :'output_rule' => :'Array<String>',
    :'password_length' => :'String',
    :'rm_tag' => :'Array<String>',
    :'rotate_on_unlock' => :'String',
    :'rotation_event_in' => :'Array<String>',
    :'rotation_hour' => :'Integer',
    :'rotation_interval' => :'String',
    :'skip_dry_run' => :'Boolean',
    :'splunk_token' => :'String',
    :'token' => :'String',
    :'token_owner' => :'String',
    :'uid_token' => :'String',
    :'use_capital_letters' => :'String',
    :'use_lower_letters' => :'String',
    :'use_numbers' => :'String',
    :'use_special_characters' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 428

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      add_tag == o.add_tag &&
      ara_enabled == o.ara_enabled &&
      audience == o.audience &&
      authentication_credentials == o.authentication_credentials &&
      auto_rotate == o.auto_rotate &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      enable_agentic_runtime_authority == o.enable_agentic_runtime_authority &&
      enable_ai_quorum == o.enable_ai_quorum &&
      expiration_date == o.expiration_date &&
      hec_token == o.hec_token &&
      input_rule == o.input_rule &&
      item_custom_fields == o.item_custom_fields &&
      json == o.json &&
      keep_prev_version == o.keep_prev_version &&
      key == o.key &&
      lock_on_read == o.lock_on_read &&
      lock_ttl == o.lock_ttl &&
      max_versions == o.max_versions &&
      name == o.name &&
      new_name == o.new_name &&
      output_rule == o.output_rule &&
      password_length == o.password_length &&
      rm_tag == o.rm_tag &&
      rotate_on_unlock == o.rotate_on_unlock &&
      rotation_event_in == o.rotation_event_in &&
      rotation_hour == o.rotation_hour &&
      rotation_interval == o.rotation_interval &&
      skip_dry_run == o.skip_dry_run &&
      splunk_token == o.splunk_token &&
      token == o.token &&
      token_owner == o.token_owner &&
      uid_token == o.uid_token &&
      use_capital_letters == o.use_capital_letters &&
      use_lower_letters == o.use_lower_letters &&
      use_numbers == o.use_numbers &&
      use_special_characters == o.use_special_characters
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



580
581
582
583
584
585
586
587
588
589
590
591
592
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 580

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


472
473
474
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 472

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



478
479
480
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 478

def hash
  [add_tag, ara_enabled, audience, authentication_credentials, auto_rotate, delete_protection, description, enable_agentic_runtime_authority, enable_ai_quorum, expiration_date, hec_token, input_rule, item_custom_fields, json, keep_prev_version, key, lock_on_read, lock_ttl, max_versions, name, new_name, output_rule, password_length, rm_tag, rotate_on_unlock, rotation_event_in, rotation_hour, rotation_interval, skip_dry_run, splunk_token, token, token_owner, uid_token, use_capital_letters, use_lower_letters, use_numbers, use_special_characters].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



408
409
410
411
412
413
414
415
416
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 408

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



556
557
558
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 556

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



562
563
564
565
566
567
568
569
570
571
572
573
574
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 562

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



550
551
552
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 550

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



420
421
422
423
424
# File 'lib/akeyless/models/rotated_secret_update_splunk.rb', line 420

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end