Class: Akeyless::RotatedSecretUpdateSsh
- Inherits:
-
Object
- Object
- Akeyless::RotatedSecretUpdateSsh
- Defined in:
- lib/akeyless/models/rotated_secret_update_ssh.rb
Instance Attribute Summary collapse
-
#add_tag ⇒ Object
List of the new tags that will be attached to this item.
-
#ara_enabled ⇒ Object
Enable or disable Agentic Runtime Authority rule enforcement for this item.
-
#authentication_credentials ⇒ Object
The credentials to connect with use-user-creds/use-target-creds.
-
#auto_rotate ⇒ Object
Returns the value of attribute auto_rotate.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#description ⇒ Object
Description of the object.
-
#enable_agentic_runtime_authority ⇒ Object
EnableAra is the documented spelling of AraEnabled.
-
#enable_ai_quorum ⇒ Object
Turns on AI Quorum checks for this item.
-
#host_provider ⇒ Object
Host provider type [explicit/target], Default Host provider is explicit, Relevant only for SRA items.
-
#input_rule ⇒ Object
Agentic input rule in name=...,rule=...
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#keep_prev_version ⇒ Object
Whether to keep previous version [true/false].
-
#key ⇒ Object
Returns the value of attribute key.
-
#key_algorithm ⇒ Object
The key algorithm to generate with when no private key is supplied, leave empty to keep the current algorithm.
-
#key_data_base64 ⇒ Object
Private key file contents encoded using base64.
-
#lock_during_sra_session ⇒ Object
Lock this secret for read/update while an SRA session is active.
-
#lock_on_read ⇒ Object
Lock this secret after each successful value read.
-
#lock_ttl ⇒ Object
Lock TTL in minutes.
-
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
-
#name ⇒ Object
Rotated secret name.
-
#new_name ⇒ Object
New item name.
-
#output_rule ⇒ Object
Agentic output rule in name=...,rule=...
-
#password_length ⇒ Object
The length of the password to be generated.
-
#provider_type ⇒ Object
Returns the value of attribute provider_type.
-
#public_key_remote_path ⇒ Object
The path to the public key that will be rotated on the server.
-
#rm_tag ⇒ Object
List of the existent tags that will be removed from this item.
-
#rotate_after_disconnect ⇒ Object
StringOrBool accepts JSON strings, booleans, and numbers for backward compatibility with older SDK versions that send boolean values for rotate-after-disconnect.
-
#rotate_on_unlock ⇒ Object
Rotate this secret after it is unlocked.
-
#rotated_password ⇒ Object
rotated-username password (relevant only for rotator-type=password).
-
#rotated_username ⇒ Object
username to be rotated, if selected use-self-creds at rotator-creds-type, this username will try to rotate it's own password, if use-target-creds is selected, target credentials will be use to rotate the rotated-password (relevant only for rotator-type=password).
-
#rotation_event_in ⇒ Object
How many days before the rotation of the item would you like to be notified.
-
#rotation_hour ⇒ Object
Returns the value of attribute rotation_hour.
-
#rotation_interval ⇒ Object
Returns the value of attribute rotation_interval.
-
#rotator_custom_cmd ⇒ Object
Custom rotation command.
-
#rotator_type ⇒ Object
The rotator type.
-
#same_password ⇒ Object
Rotate same password for each host from the Linked Target (relevant only for Linked Target).
-
#secure_access_allow_external_user ⇒ Object
Allow providing external user for a domain users.
-
#secure_access_bastion_issuer ⇒ Object
Deprecated.
-
#secure_access_certificate_issuer ⇒ Object
Path to the SSH Certificate Issuer for your Akeyless Secure Access.
-
#secure_access_enable ⇒ Object
Enable/Disable secure remote access [true/false].
-
#secure_access_enforce_hosts_restriction ⇒ Object
Enforce connections only to allowed SRA hosts.
-
#secure_access_host ⇒ Object
Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers).
-
#secure_access_rdp_domain ⇒ Object
Default domain name server.
-
#secure_access_rdp_user ⇒ Object
Override the RDP Domain username.
-
#secure_access_ssh_creds ⇒ Object
Secret values contains SSH Credentials, either Private Key or Password [password/private-key] (relevant only for Static-Secret or Rotated-secret).
-
#secure_access_ssh_user ⇒ Object
Override the SSH username as indicated in SSH Certificate Issuer.
-
#secure_access_target_type ⇒ Object
Specify target type.
-
#secure_access_url ⇒ Object
Destination URL to inject secrets.
-
#secure_access_web ⇒ Object
Enable Web Secure Remote Access.
-
#secure_access_web_browsing ⇒ Object
Secure browser via Akeyless's Secure Remote Access (SRA).
-
#secure_access_web_proxy ⇒ Object
Web-Proxy via Akeyless's Secure Remote Access (SRA).
-
#skip_dry_run ⇒ Object
If set, dry-run will be skipped [true/false].
-
#target ⇒ Object
A list of targets to be associated with an SRA item, To specify multiple targets use argument multiple times.
-
#token ⇒ Object
Authentication token (see
/authand/configure). -
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#use_capital_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z).
-
#use_lower_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z).
-
#use_numbers ⇒ Object
Specifies whether the generated temporary password must contain at least one numeric character (0 to 9).
-
#use_special_characters ⇒ Object
Returns the value of attribute use_special_characters.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RotatedSecretUpdateSsh
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RotatedSecretUpdateSsh
Initializes the object
337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 337 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::RotatedSecretUpdateSsh` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::RotatedSecretUpdateSsh`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'provider_type') self.provider_type = attributes[:'provider_type'] end if attributes.key?(:'add_tag') if (value = attributes[:'add_tag']).is_a?(Array) self.add_tag = value end end if attributes.key?(:'ara_enabled') self.ara_enabled = attributes[:'ara_enabled'] end if attributes.key?(:'authentication_credentials') self.authentication_credentials = attributes[:'authentication_credentials'] else self.authentication_credentials = 'use-user-creds' end if attributes.key?(:'auto_rotate') self.auto_rotate = attributes[:'auto_rotate'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = 'default_metadata' end if attributes.key?(:'enable_agentic_runtime_authority') self. = attributes[:'enable_agentic_runtime_authority'] end if attributes.key?(:'enable_ai_quorum') self.enable_ai_quorum = attributes[:'enable_ai_quorum'] end if attributes.key?(:'host_provider') self.host_provider = attributes[:'host_provider'] end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'keep_prev_version') self.keep_prev_version = attributes[:'keep_prev_version'] end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'key_algorithm') self.key_algorithm = attributes[:'key_algorithm'] end if attributes.key?(:'key_data_base64') self.key_data_base64 = attributes[:'key_data_base64'] end if attributes.key?(:'lock_during_sra_session') self.lock_during_sra_session = attributes[:'lock_during_sra_session'] end if attributes.key?(:'lock_on_read') self.lock_on_read = attributes[:'lock_on_read'] end if attributes.key?(:'lock_ttl') self.lock_ttl = attributes[:'lock_ttl'] end if attributes.key?(:'max_versions') self.max_versions = attributes[:'max_versions'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'new_name') self.new_name = attributes[:'new_name'] end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'password_length') self.password_length = attributes[:'password_length'] end if attributes.key?(:'public_key_remote_path') self.public_key_remote_path = attributes[:'public_key_remote_path'] end if attributes.key?(:'rm_tag') if (value = attributes[:'rm_tag']).is_a?(Array) self.rm_tag = value end end if attributes.key?(:'rotate_after_disconnect') self.rotate_after_disconnect = attributes[:'rotate_after_disconnect'] end if attributes.key?(:'rotate_on_unlock') self.rotate_on_unlock = attributes[:'rotate_on_unlock'] end if attributes.key?(:'rotated_password') self.rotated_password = attributes[:'rotated_password'] end if attributes.key?(:'rotated_username') self.rotated_username = attributes[:'rotated_username'] end if attributes.key?(:'rotation_event_in') if (value = attributes[:'rotation_event_in']).is_a?(Array) self.rotation_event_in = value end end if attributes.key?(:'rotation_hour') self.rotation_hour = attributes[:'rotation_hour'] end if attributes.key?(:'rotation_interval') self.rotation_interval = attributes[:'rotation_interval'] end if attributes.key?(:'rotator_custom_cmd') self.rotator_custom_cmd = attributes[:'rotator_custom_cmd'] end if attributes.key?(:'rotator_type') self.rotator_type = attributes[:'rotator_type'] else self.rotator_type = nil end if attributes.key?(:'same_password') self.same_password = attributes[:'same_password'] end if attributes.key?(:'secure_access_allow_external_user') self.secure_access_allow_external_user = attributes[:'secure_access_allow_external_user'] else self.secure_access_allow_external_user = false end if attributes.key?(:'secure_access_bastion_issuer') self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer'] end if attributes.key?(:'secure_access_certificate_issuer') self.secure_access_certificate_issuer = attributes[:'secure_access_certificate_issuer'] end if attributes.key?(:'secure_access_enable') self.secure_access_enable = attributes[:'secure_access_enable'] end if attributes.key?(:'secure_access_enforce_hosts_restriction') self.secure_access_enforce_hosts_restriction = attributes[:'secure_access_enforce_hosts_restriction'] end if attributes.key?(:'secure_access_host') if (value = attributes[:'secure_access_host']).is_a?(Array) self.secure_access_host = value end end if attributes.key?(:'secure_access_rdp_domain') self.secure_access_rdp_domain = attributes[:'secure_access_rdp_domain'] end if attributes.key?(:'secure_access_rdp_user') self.secure_access_rdp_user = attributes[:'secure_access_rdp_user'] end if attributes.key?(:'secure_access_ssh_creds') self.secure_access_ssh_creds = attributes[:'secure_access_ssh_creds'] end if attributes.key?(:'secure_access_ssh_user') self.secure_access_ssh_user = attributes[:'secure_access_ssh_user'] end if attributes.key?(:'secure_access_target_type') self.secure_access_target_type = attributes[:'secure_access_target_type'] else self.secure_access_target_type = 'false' end if attributes.key?(:'secure_access_url') self.secure_access_url = attributes[:'secure_access_url'] end if attributes.key?(:'secure_access_web') self.secure_access_web = attributes[:'secure_access_web'] else self.secure_access_web = true end if attributes.key?(:'secure_access_web_browsing') self.secure_access_web_browsing = attributes[:'secure_access_web_browsing'] else self.secure_access_web_browsing = false end if attributes.key?(:'secure_access_web_proxy') self.secure_access_web_proxy = attributes[:'secure_access_web_proxy'] else self.secure_access_web_proxy = false end if attributes.key?(:'skip_dry_run') self.skip_dry_run = attributes[:'skip_dry_run'] end if attributes.key?(:'target') if (value = attributes[:'target']).is_a?(Array) self.target = value end end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'use_capital_letters') self.use_capital_letters = attributes[:'use_capital_letters'] end if attributes.key?(:'use_lower_letters') self.use_lower_letters = attributes[:'use_lower_letters'] end if attributes.key?(:'use_numbers') self.use_numbers = attributes[:'use_numbers'] end if attributes.key?(:'use_special_characters') self.use_special_characters = attributes[:'use_special_characters'] end end |
Instance Attribute Details
#add_tag ⇒ Object
List of the new tags that will be attached to this item
21 22 23 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 21 def add_tag @add_tag end |
#ara_enabled ⇒ Object
Enable or disable Agentic Runtime Authority rule enforcement for this item. When false, user-defined input/output rules are stored but not enforced; the base security validation still runs. AraEnabled is tri-state (nil/true/false), not a plain bool: it self-encodes its wire value (see akl.OptionalBool) so an explicit false survives the curl-proxy relay instead of being dropped like a default-false bool flag.
24 25 26 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 24 def ara_enabled @ara_enabled end |
#authentication_credentials ⇒ Object
The credentials to connect with use-user-creds/use-target-creds
27 28 29 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 27 def authentication_credentials @authentication_credentials end |
#auto_rotate ⇒ Object
Returns the value of attribute auto_rotate.
29 30 31 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 29 def auto_rotate @auto_rotate end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
32 33 34 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 32 def delete_protection @delete_protection end |
#description ⇒ Object
Description of the object
35 36 37 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 35 def description @description end |
#enable_agentic_runtime_authority ⇒ Object
EnableAra is the documented spelling of AraEnabled. Both set the same field; --ara-enabled shipped first and stays as an undocumented alias so existing scripts and the Terraform provider keep working.
38 39 40 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 38 def @enable_agentic_runtime_authority end |
#enable_ai_quorum ⇒ Object
Turns on AI Quorum checks for this item.
41 42 43 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 41 def enable_ai_quorum @enable_ai_quorum end |
#host_provider ⇒ Object
Host provider type [explicit/target], Default Host provider is explicit, Relevant only for SRA items.
44 45 46 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 44 def host_provider @host_provider end |
#input_rule ⇒ Object
Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input)
47 48 49 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 47 def input_rule @input_rule end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
50 51 52 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 50 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
53 54 55 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 53 def json @json end |
#keep_prev_version ⇒ Object
Whether to keep previous version [true/false]. If not set, use default according to account settings
56 57 58 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 56 def keep_prev_version @keep_prev_version end |
#key ⇒ Object
Returns the value of attribute key.
58 59 60 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 58 def key @key end |
#key_algorithm ⇒ Object
The key algorithm to generate with when no private key is supplied, leave empty to keep the current algorithm. options: [ED25519/RSA2048/RSA3072/RSA4096/ECDSA256/ECDSA384/ECDSA521]
61 62 63 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 61 def key_algorithm @key_algorithm end |
#key_data_base64 ⇒ Object
Private key file contents encoded using base64
64 65 66 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 64 def key_data_base64 @key_data_base64 end |
#lock_during_sra_session ⇒ Object
Lock this secret for read/update while an SRA session is active
67 68 69 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 67 def lock_during_sra_session @lock_during_sra_session end |
#lock_on_read ⇒ Object
Lock this secret after each successful value read
70 71 72 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 70 def lock_on_read @lock_on_read end |
#lock_ttl ⇒ Object
Lock TTL in minutes
73 74 75 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 73 def lock_ttl @lock_ttl end |
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
76 77 78 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 76 def max_versions @max_versions end |
#name ⇒ Object
Rotated secret name
79 80 81 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 79 def name @name end |
#new_name ⇒ Object
New item name
82 83 84 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 82 def new_name @new_name end |
#output_rule ⇒ Object
Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)
85 86 87 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 85 def output_rule @output_rule end |
#password_length ⇒ Object
The length of the password to be generated
88 89 90 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 88 def password_length @password_length end |
#provider_type ⇒ Object
Returns the value of attribute provider_type.
18 19 20 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 18 def provider_type @provider_type end |
#public_key_remote_path ⇒ Object
The path to the public key that will be rotated on the server
91 92 93 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 91 def public_key_remote_path @public_key_remote_path end |
#rm_tag ⇒ Object
List of the existent tags that will be removed from this item
94 95 96 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 94 def rm_tag @rm_tag end |
#rotate_after_disconnect ⇒ Object
StringOrBool accepts JSON strings, booleans, and numbers for backward compatibility with older SDK versions that send boolean values for rotate-after-disconnect.
97 98 99 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 97 def rotate_after_disconnect @rotate_after_disconnect end |
#rotate_on_unlock ⇒ Object
Rotate this secret after it is unlocked
100 101 102 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 100 def rotate_on_unlock @rotate_on_unlock end |
#rotated_password ⇒ Object
rotated-username password (relevant only for rotator-type=password)
103 104 105 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 103 def rotated_password @rotated_password end |
#rotated_username ⇒ Object
username to be rotated, if selected use-self-creds at rotator-creds-type, this username will try to rotate it's own password, if use-target-creds is selected, target credentials will be use to rotate the rotated-password (relevant only for rotator-type=password)
106 107 108 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 106 def rotated_username @rotated_username end |
#rotation_event_in ⇒ Object
How many days before the rotation of the item would you like to be notified
109 110 111 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 109 def rotation_event_in @rotation_event_in end |
#rotation_hour ⇒ Object
Returns the value of attribute rotation_hour.
111 112 113 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 111 def rotation_hour @rotation_hour end |
#rotation_interval ⇒ Object
Returns the value of attribute rotation_interval.
113 114 115 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 113 def rotation_interval @rotation_interval end |
#rotator_custom_cmd ⇒ Object
Custom rotation command
116 117 118 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 116 def rotator_custom_cmd @rotator_custom_cmd end |
#rotator_type ⇒ Object
The rotator type. options: [target/password/key]
119 120 121 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 119 def rotator_type @rotator_type end |
#same_password ⇒ Object
Rotate same password for each host from the Linked Target (relevant only for Linked Target)
122 123 124 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 122 def same_password @same_password end |
#secure_access_allow_external_user ⇒ Object
Allow providing external user for a domain users
125 126 127 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 125 def secure_access_allow_external_user @secure_access_allow_external_user end |
#secure_access_bastion_issuer ⇒ Object
Deprecated. use secure-access-certificate-issuer
128 129 130 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 128 def secure_access_bastion_issuer @secure_access_bastion_issuer end |
#secure_access_certificate_issuer ⇒ Object
Path to the SSH Certificate Issuer for your Akeyless Secure Access
131 132 133 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 131 def secure_access_certificate_issuer @secure_access_certificate_issuer end |
#secure_access_enable ⇒ Object
Enable/Disable secure remote access [true/false]
134 135 136 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 134 def secure_access_enable @secure_access_enable end |
#secure_access_enforce_hosts_restriction ⇒ Object
Enforce connections only to allowed SRA hosts
137 138 139 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 137 def secure_access_enforce_hosts_restriction @secure_access_enforce_hosts_restriction end |
#secure_access_host ⇒ Object
Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)
140 141 142 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 140 def secure_access_host @secure_access_host end |
#secure_access_rdp_domain ⇒ Object
Default domain name server. i.e. microsoft.com
143 144 145 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 143 def secure_access_rdp_domain @secure_access_rdp_domain end |
#secure_access_rdp_user ⇒ Object
Override the RDP Domain username
146 147 148 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 146 def secure_access_rdp_user @secure_access_rdp_user end |
#secure_access_ssh_creds ⇒ Object
Secret values contains SSH Credentials, either Private Key or Password [password/private-key] (relevant only for Static-Secret or Rotated-secret)
149 150 151 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 149 def secure_access_ssh_creds @secure_access_ssh_creds end |
#secure_access_ssh_user ⇒ Object
Override the SSH username as indicated in SSH Certificate Issuer
152 153 154 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 152 def secure_access_ssh_user @secure_access_ssh_user end |
#secure_access_target_type ⇒ Object
Specify target type. Options are ssh or rdp
155 156 157 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 155 def secure_access_target_type @secure_access_target_type end |
#secure_access_url ⇒ Object
Destination URL to inject secrets
158 159 160 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 158 def secure_access_url @secure_access_url end |
#secure_access_web ⇒ Object
Enable Web Secure Remote Access
161 162 163 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 161 def secure_access_web @secure_access_web end |
#secure_access_web_browsing ⇒ Object
Secure browser via Akeyless's Secure Remote Access (SRA)
164 165 166 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 164 def secure_access_web_browsing @secure_access_web_browsing end |
#secure_access_web_proxy ⇒ Object
Web-Proxy via Akeyless's Secure Remote Access (SRA)
167 168 169 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 167 def secure_access_web_proxy @secure_access_web_proxy end |
#skip_dry_run ⇒ Object
If set, dry-run will be skipped [true/false]
170 171 172 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 170 def skip_dry_run @skip_dry_run end |
#target ⇒ Object
A list of targets to be associated with an SRA item, To specify multiple targets use argument multiple times
173 174 175 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 173 def target @target end |
#token ⇒ Object
Authentication token (see /auth and /configure)
176 177 178 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 176 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
179 180 181 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 179 def uid_token @uid_token end |
#use_capital_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). [true/false]
182 183 184 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 182 def use_capital_letters @use_capital_letters end |
#use_lower_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). [true/false]
185 186 187 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 185 def use_lower_letters @use_lower_letters end |
#use_numbers ⇒ Object
Specifies whether the generated temporary password must contain at least one numeric character (0 to 9). [true/false]
188 189 190 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 188 def use_numbers @use_numbers end |
#use_special_characters ⇒ Object
Returns the value of attribute use_special_characters.
190 191 192 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 190 def use_special_characters @use_special_characters end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 758 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
259 260 261 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 259 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 193 def self.attribute_map { :'provider_type' => :'ProviderType', :'add_tag' => :'add-tag', :'ara_enabled' => :'ara-enabled', :'authentication_credentials' => :'authentication-credentials', :'auto_rotate' => :'auto-rotate', :'delete_protection' => :'delete_protection', :'description' => :'description', :'enable_agentic_runtime_authority' => :'enable-agentic-runtime-authority', :'enable_ai_quorum' => :'enable-ai-quorum', :'host_provider' => :'host-provider', :'input_rule' => :'input-rule', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'keep_prev_version' => :'keep-prev-version', :'key' => :'key', :'key_algorithm' => :'key-algorithm', :'key_data_base64' => :'key-data-base64', :'lock_during_sra_session' => :'lock-during-sra-session', :'lock_on_read' => :'lock-on-read', :'lock_ttl' => :'lock-ttl', :'max_versions' => :'max-versions', :'name' => :'name', :'new_name' => :'new-name', :'output_rule' => :'output-rule', :'password_length' => :'password-length', :'public_key_remote_path' => :'public-key-remote-path', :'rm_tag' => :'rm-tag', :'rotate_after_disconnect' => :'rotate-after-disconnect', :'rotate_on_unlock' => :'rotate-on-unlock', :'rotated_password' => :'rotated-password', :'rotated_username' => :'rotated-username', :'rotation_event_in' => :'rotation-event-in', :'rotation_hour' => :'rotation-hour', :'rotation_interval' => :'rotation-interval', :'rotator_custom_cmd' => :'rotator-custom-cmd', :'rotator_type' => :'rotator-type', :'same_password' => :'same-password', :'secure_access_allow_external_user' => :'secure-access-allow-external-user', :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer', :'secure_access_certificate_issuer' => :'secure-access-certificate-issuer', :'secure_access_enable' => :'secure-access-enable', :'secure_access_enforce_hosts_restriction' => :'secure-access-enforce-hosts-restriction', :'secure_access_host' => :'secure-access-host', :'secure_access_rdp_domain' => :'secure-access-rdp-domain', :'secure_access_rdp_user' => :'secure-access-rdp-user', :'secure_access_ssh_creds' => :'secure-access-ssh-creds', :'secure_access_ssh_user' => :'secure-access-ssh-user', :'secure_access_target_type' => :'secure-access-target-type', :'secure_access_url' => :'secure-access-url', :'secure_access_web' => :'secure-access-web', :'secure_access_web_browsing' => :'secure-access-web-browsing', :'secure_access_web_proxy' => :'secure-access-web-proxy', :'skip_dry_run' => :'skip-dry-run', :'target' => :'target', :'token' => :'token', :'uid_token' => :'uid-token', :'use_capital_letters' => :'use-capital-letters', :'use_lower_letters' => :'use-lower-letters', :'use_numbers' => :'use-numbers', :'use_special_characters' => :'use-special-characters' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 734 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
330 331 332 333 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 330 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 264 def self.openapi_types { :'provider_type' => :'String', :'add_tag' => :'Array<String>', :'ara_enabled' => :'Boolean', :'authentication_credentials' => :'String', :'auto_rotate' => :'String', :'delete_protection' => :'String', :'description' => :'String', :'enable_agentic_runtime_authority' => :'Boolean', :'enable_ai_quorum' => :'Boolean', :'host_provider' => :'String', :'input_rule' => :'Array<String>', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'keep_prev_version' => :'String', :'key' => :'String', :'key_algorithm' => :'String', :'key_data_base64' => :'String', :'lock_during_sra_session' => :'String', :'lock_on_read' => :'String', :'lock_ttl' => :'String', :'max_versions' => :'String', :'name' => :'String', :'new_name' => :'String', :'output_rule' => :'Array<String>', :'password_length' => :'String', :'public_key_remote_path' => :'String', :'rm_tag' => :'Array<String>', :'rotate_after_disconnect' => :'String', :'rotate_on_unlock' => :'String', :'rotated_password' => :'String', :'rotated_username' => :'String', :'rotation_event_in' => :'Array<String>', :'rotation_hour' => :'Integer', :'rotation_interval' => :'String', :'rotator_custom_cmd' => :'String', :'rotator_type' => :'String', :'same_password' => :'String', :'secure_access_allow_external_user' => :'Boolean', :'secure_access_bastion_issuer' => :'String', :'secure_access_certificate_issuer' => :'String', :'secure_access_enable' => :'String', :'secure_access_enforce_hosts_restriction' => :'Boolean', :'secure_access_host' => :'Array<String>', :'secure_access_rdp_domain' => :'String', :'secure_access_rdp_user' => :'String', :'secure_access_ssh_creds' => :'String', :'secure_access_ssh_user' => :'String', :'secure_access_target_type' => :'String', :'secure_access_url' => :'String', :'secure_access_web' => :'Boolean', :'secure_access_web_browsing' => :'Boolean', :'secure_access_web_proxy' => :'Boolean', :'skip_dry_run' => :'Boolean', :'target' => :'Array<String>', :'token' => :'String', :'uid_token' => :'String', :'use_capital_letters' => :'String', :'use_lower_letters' => :'String', :'use_numbers' => :'String', :'use_special_characters' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 654 def ==(o) return true if self.equal?(o) self.class == o.class && provider_type == o.provider_type && add_tag == o.add_tag && ara_enabled == o.ara_enabled && authentication_credentials == o.authentication_credentials && auto_rotate == o.auto_rotate && delete_protection == o.delete_protection && description == o.description && == o. && enable_ai_quorum == o.enable_ai_quorum && host_provider == o.host_provider && input_rule == o.input_rule && item_custom_fields == o.item_custom_fields && json == o.json && keep_prev_version == o.keep_prev_version && key == o.key && key_algorithm == o.key_algorithm && key_data_base64 == o.key_data_base64 && lock_during_sra_session == o.lock_during_sra_session && lock_on_read == o.lock_on_read && lock_ttl == o.lock_ttl && max_versions == o.max_versions && name == o.name && new_name == o.new_name && output_rule == o.output_rule && password_length == o.password_length && public_key_remote_path == o.public_key_remote_path && rm_tag == o.rm_tag && rotate_after_disconnect == o.rotate_after_disconnect && rotate_on_unlock == o.rotate_on_unlock && rotated_password == o.rotated_password && rotated_username == o.rotated_username && rotation_event_in == o.rotation_event_in && rotation_hour == o.rotation_hour && rotation_interval == o.rotation_interval && rotator_custom_cmd == o.rotator_custom_cmd && rotator_type == o.rotator_type && same_password == o.same_password && secure_access_allow_external_user == o.secure_access_allow_external_user && secure_access_bastion_issuer == o.secure_access_bastion_issuer && secure_access_certificate_issuer == o.secure_access_certificate_issuer && secure_access_enable == o.secure_access_enable && secure_access_enforce_hosts_restriction == o.secure_access_enforce_hosts_restriction && secure_access_host == o.secure_access_host && secure_access_rdp_domain == o.secure_access_rdp_domain && secure_access_rdp_user == o.secure_access_rdp_user && secure_access_ssh_creds == o.secure_access_ssh_creds && secure_access_ssh_user == o.secure_access_ssh_user && secure_access_target_type == o.secure_access_target_type && secure_access_url == o.secure_access_url && secure_access_web == o.secure_access_web && secure_access_web_browsing == o.secure_access_web_browsing && secure_access_web_proxy == o.secure_access_web_proxy && skip_dry_run == o.skip_dry_run && target == o.target && token == o.token && uid_token == o.uid_token && use_capital_letters == o.use_capital_letters && use_lower_letters == o.use_lower_letters && use_numbers == o.use_numbers && use_special_characters == o.use_special_characters end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
829 830 831 832 833 834 835 836 837 838 839 840 841 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 829 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
721 722 723 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 721 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
727 728 729 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 727 def hash [provider_type, add_tag, ara_enabled, authentication_credentials, auto_rotate, delete_protection, description, , enable_ai_quorum, host_provider, input_rule, item_custom_fields, json, keep_prev_version, key, key_algorithm, key_data_base64, lock_during_sra_session, lock_on_read, lock_ttl, max_versions, name, new_name, output_rule, password_length, public_key_remote_path, rm_tag, rotate_after_disconnect, rotate_on_unlock, rotated_password, rotated_username, rotation_event_in, rotation_hour, rotation_interval, rotator_custom_cmd, rotator_type, same_password, secure_access_allow_external_user, secure_access_bastion_issuer, secure_access_certificate_issuer, secure_access_enable, secure_access_enforce_hosts_restriction, secure_access_host, secure_access_rdp_domain, secure_access_rdp_user, secure_access_ssh_creds, secure_access_ssh_user, secure_access_target_type, secure_access_url, secure_access_web, secure_access_web_browsing, secure_access_web_proxy, skip_dry_run, target, token, uid_token, use_capital_letters, use_lower_letters, use_numbers, use_special_characters].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 629 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @rotator_type.nil? invalid_properties.push('invalid value for "rotator_type", rotator_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
805 806 807 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 805 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
811 812 813 814 815 816 817 818 819 820 821 822 823 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 811 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
799 800 801 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 799 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
645 646 647 648 649 650 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 645 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @rotator_type.nil? true end |