Class: Akeyless::SignDataWithClassicKey

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/sign_data_with_classic_key.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SignDataWithClassicKey

Initializes the object



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::SignDataWithClassicKey` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::SignDataWithClassicKey`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'data')
    self.data = attributes[:'data']
  end

  if attributes.key?(:'display_id')
    self.display_id = attributes[:'display_id']
  end

  if attributes.key?(:'hashed')
    self.hashed = attributes[:'hashed']
  else
    self.hashed = false
  end

  if attributes.key?(:'hashing_method')
    self.hashing_method = attributes[:'hashing_method']
  else
    self.hashing_method = 'SHA256'
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end
end

Instance Attribute Details

#dataObject

Data



19
20
21
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 19

def data
  @data
end

#display_idObject

The name of the key to use in the sign data process



22
23
24
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 22

def display_id
  @display_id
end

#hashedObject

Defines whether the data should be hashed as part of the signing. If true, the data will not be hashed



25
26
27
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 25

def hashed
  @hashed
end

#hashing_methodObject

HashingMethod



28
29
30
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 28

def hashing_method
  @hashing_method
end

#jsonObject

Set output format to JSON



31
32
33
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 31

def json
  @json
end

#nameObject

ClassicKey name



34
35
36
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 34

def name
  @name
end

#tokenObject

Authentication token (see /auth and /configure)



37
38
39
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 37

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



40
41
42
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 40

def uid_token
  @uid_token
end

#versionObject

classic key version



43
44
45
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 43

def version
  @version
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 61

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 46

def self.attribute_map
  {
    :'data' => :'data',
    :'display_id' => :'display-id',
    :'hashed' => :'hashed',
    :'hashing_method' => :'hashing-method',
    :'json' => :'json',
    :'name' => :'name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'version' => :'version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



208
209
210
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 208

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 66

def self.openapi_types
  {
    :'data' => :'String',
    :'display_id' => :'String',
    :'hashed' => :'Boolean',
    :'hashing_method' => :'String',
    :'json' => :'Boolean',
    :'name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'version' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 179

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      data == o.data &&
      display_id == o.display_id &&
      hashed == o.hashed &&
      hashing_method == o.hashing_method &&
      json == o.json &&
      name == o.name &&
      token == o.token &&
      uid_token == o.uid_token &&
      version == o.version
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 239

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 310

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 215

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


195
196
197
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 195

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



201
202
203
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 201

def hash
  [data, display_id, hashed, hashing_method, json, name, token, uid_token, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 146

def list_invalid_properties
  invalid_properties = Array.new
  if @data.nil?
    invalid_properties.push('invalid value for "data", data cannot be nil.')
  end

  if @display_id.nil?
    invalid_properties.push('invalid value for "display_id", display_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



286
287
288
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 286

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 292

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



280
281
282
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 280

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



169
170
171
172
173
174
175
# File 'lib/akeyless/models/sign_data_with_classic_key.rb', line 169

def valid?
  return false if @data.nil?
  return false if @display_id.nil?
  return false if @name.nil?
  return false if @version.nil?
  true
end