Class: Akeyless::TargetCreateAzure

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/target_create_azure.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TargetCreateAzure

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/akeyless/models/target_create_azure.rb', line 143

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::TargetCreateAzure` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::TargetCreateAzure`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'azure_cloud')
    self.azure_cloud = attributes[:'azure_cloud']
  else
    self.azure_cloud = 'AzureCloud'
  end

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'client_secret')
    self.client_secret = attributes[:'client_secret']
  end

  if attributes.key?(:'connection_type')
    self.connection_type = attributes[:'connection_type']
  else
    self.connection_type = 'credentials'
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'lock_on_read')
    self.lock_on_read = attributes[:'lock_on_read']
  end

  if attributes.key?(:'lock_ttl')
    self.lock_ttl = attributes[:'lock_ttl']
  end

  if attributes.key?(:'max_versions')
    self.max_versions = attributes[:'max_versions']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'resource_group_name')
    self.resource_group_name = attributes[:'resource_group_name']
  end

  if attributes.key?(:'resource_name')
    self.resource_name = attributes[:'resource_name']
  end

  if attributes.key?(:'rotate_on_unlock')
    self.rotate_on_unlock = attributes[:'rotate_on_unlock']
  end

  if attributes.key?(:'subscription_id')
    self.subscription_id = attributes[:'subscription_id']
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'use_gw_cloud_identity')
    self.use_gw_cloud_identity = attributes[:'use_gw_cloud_identity']
  end
end

Instance Attribute Details

#azure_cloudObject

Azure cloud environment to use. Values: AzureCloud (default), AzureUSGovernment, AzureChinaCloud.



19
20
21
# File 'lib/akeyless/models/target_create_azure.rb', line 19

def azure_cloud
  @azure_cloud
end

#client_idObject

Azure client/application id



22
23
24
# File 'lib/akeyless/models/target_create_azure.rb', line 22

def client_id
  @client_id
end

#client_secretObject

Azure client secret



25
26
27
# File 'lib/akeyless/models/target_create_azure.rb', line 25

def client_secret
  @client_secret
end

#connection_typeObject

Type of connection [credentials/cloud-identity]



28
29
30
# File 'lib/akeyless/models/target_create_azure.rb', line 28

def connection_type
  @connection_type
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



31
32
33
# File 'lib/akeyless/models/target_create_azure.rb', line 31

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



34
35
36
# File 'lib/akeyless/models/target_create_azure.rb', line 34

def description
  @description
end

#jsonObject

Set output format to JSON



37
38
39
# File 'lib/akeyless/models/target_create_azure.rb', line 37

def json
  @json
end

#keyObject

The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)



40
41
42
# File 'lib/akeyless/models/target_create_azure.rb', line 40

def key
  @key
end

#lock_on_readObject

Lock this secret after each successful value read



43
44
45
# File 'lib/akeyless/models/target_create_azure.rb', line 43

def lock_on_read
  @lock_on_read
end

#lock_ttlObject

Lock TTL in minutes



46
47
48
# File 'lib/akeyless/models/target_create_azure.rb', line 46

def lock_ttl
  @lock_ttl
end

#max_versionsObject

Set the maximum number of versions, limited by the account settings defaults.



49
50
51
# File 'lib/akeyless/models/target_create_azure.rb', line 49

def max_versions
  @max_versions
end

#nameObject

Target name



52
53
54
# File 'lib/akeyless/models/target_create_azure.rb', line 52

def name
  @name
end

#resource_group_nameObject

The Resource Group name in your Azure subscription



55
56
57
# File 'lib/akeyless/models/target_create_azure.rb', line 55

def resource_group_name
  @resource_group_name
end

#resource_nameObject

The name of the relevant Resource



58
59
60
# File 'lib/akeyless/models/target_create_azure.rb', line 58

def resource_name
  @resource_name
end

#rotate_on_unlockObject

Rotate this secret after it is unlocked



61
62
63
# File 'lib/akeyless/models/target_create_azure.rb', line 61

def rotate_on_unlock
  @rotate_on_unlock
end

#subscription_idObject

Azure Subscription Id



64
65
66
# File 'lib/akeyless/models/target_create_azure.rb', line 64

def subscription_id
  @subscription_id
end

#tenant_idObject

Azure tenant id



67
68
69
# File 'lib/akeyless/models/target_create_azure.rb', line 67

def tenant_id
  @tenant_id
end

#tokenObject

Authentication token (see /auth and /configure)



70
71
72
# File 'lib/akeyless/models/target_create_azure.rb', line 70

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



73
74
75
# File 'lib/akeyless/models/target_create_azure.rb', line 73

def uid_token
  @uid_token
end

#use_gw_cloud_identityObject

Use the GW's Cloud IAM [Deprecated: Use connection-type=cloud-identity]



76
77
78
# File 'lib/akeyless/models/target_create_azure.rb', line 76

def use_gw_cloud_identity
  @use_gw_cloud_identity
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/akeyless/models/target_create_azure.rb', line 331

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



105
106
107
# File 'lib/akeyless/models/target_create_azure.rb', line 105

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/akeyless/models/target_create_azure.rb', line 79

def self.attribute_map
  {
    :'azure_cloud' => :'azure-cloud',
    :'client_id' => :'client-id',
    :'client_secret' => :'client-secret',
    :'connection_type' => :'connection-type',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'json' => :'json',
    :'key' => :'key',
    :'lock_on_read' => :'lock-on-read',
    :'lock_ttl' => :'lock-ttl',
    :'max_versions' => :'max-versions',
    :'name' => :'name',
    :'resource_group_name' => :'resource-group-name',
    :'resource_name' => :'resource-name',
    :'rotate_on_unlock' => :'rotate-on-unlock',
    :'subscription_id' => :'subscription-id',
    :'tenant_id' => :'tenant-id',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'use_gw_cloud_identity' => :'use-gw-cloud-identity'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/akeyless/models/target_create_azure.rb', line 307

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



136
137
138
139
# File 'lib/akeyless/models/target_create_azure.rb', line 136

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/akeyless/models/target_create_azure.rb', line 110

def self.openapi_types
  {
    :'azure_cloud' => :'String',
    :'client_id' => :'String',
    :'client_secret' => :'String',
    :'connection_type' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'json' => :'Boolean',
    :'key' => :'String',
    :'lock_on_read' => :'String',
    :'lock_ttl' => :'String',
    :'max_versions' => :'String',
    :'name' => :'String',
    :'resource_group_name' => :'String',
    :'resource_name' => :'String',
    :'rotate_on_unlock' => :'String',
    :'subscription_id' => :'String',
    :'tenant_id' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'use_gw_cloud_identity' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/akeyless/models/target_create_azure.rb', line 267

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      azure_cloud == o.azure_cloud &&
      client_id == o.client_id &&
      client_secret == o.client_secret &&
      connection_type == o.connection_type &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      json == o.json &&
      key == o.key &&
      lock_on_read == o.lock_on_read &&
      lock_ttl == o.lock_ttl &&
      max_versions == o.max_versions &&
      name == o.name &&
      resource_group_name == o.resource_group_name &&
      resource_name == o.resource_name &&
      rotate_on_unlock == o.rotate_on_unlock &&
      subscription_id == o.subscription_id &&
      tenant_id == o.tenant_id &&
      token == o.token &&
      uid_token == o.uid_token &&
      use_gw_cloud_identity == o.use_gw_cloud_identity
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/akeyless/models/target_create_azure.rb', line 402

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


294
295
296
# File 'lib/akeyless/models/target_create_azure.rb', line 294

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



300
301
302
# File 'lib/akeyless/models/target_create_azure.rb', line 300

def hash
  [azure_cloud, client_id, client_secret, connection_type, delete_protection, description, json, key, lock_on_read, lock_ttl, max_versions, name, resource_group_name, resource_name, rotate_on_unlock, subscription_id, tenant_id, token, uid_token, use_gw_cloud_identity].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



247
248
249
250
251
252
253
254
255
# File 'lib/akeyless/models/target_create_azure.rb', line 247

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



378
379
380
# File 'lib/akeyless/models/target_create_azure.rb', line 378

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/akeyless/models/target_create_azure.rb', line 384

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



372
373
374
# File 'lib/akeyless/models/target_create_azure.rb', line 372

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



259
260
261
262
263
# File 'lib/akeyless/models/target_create_azure.rb', line 259

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end