Class: Akeyless::TargetCreateDB

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/target_create_db.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TargetCreateDB

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'lib/akeyless/models/target_create_db.rb', line 250

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::TargetCreateDB` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::TargetCreateDB`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'azure_client_id')
    self.azure_client_id = attributes[:'azure_client_id']
  end

  if attributes.key?(:'azure_client_secret')
    self.azure_client_secret = attributes[:'azure_client_secret']
  end

  if attributes.key?(:'azure_tenant_id')
    self.azure_tenant_id = attributes[:'azure_tenant_id']
  end

  if attributes.key?(:'client_certificate')
    self.client_certificate = attributes[:'client_certificate']
  end

  if attributes.key?(:'client_key_passphrase')
    self.client_key_passphrase = attributes[:'client_key_passphrase']
  end

  if attributes.key?(:'client_private_key')
    self.client_private_key = attributes[:'client_private_key']
  end

  if attributes.key?(:'cloud_service_provider')
    self.cloud_service_provider = attributes[:'cloud_service_provider']
  end

  if attributes.key?(:'cluster_mode')
    self.cluster_mode = attributes[:'cluster_mode']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'connection_type')
    self.connection_type = attributes[:'connection_type']
  else
    self.connection_type = 'credentials'
  end

  if attributes.key?(:'db_name')
    self.db_name = attributes[:'db_name']
  end

  if attributes.key?(:'db_server_certificates')
    self.db_server_certificates = attributes[:'db_server_certificates']
  end

  if attributes.key?(:'db_server_name')
    self.db_server_name = attributes[:'db_server_name']
  end

  if attributes.key?(:'db_type')
    self.db_type = attributes[:'db_type']
  else
    self.db_type = nil
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'enable_mtls')
    self.enable_mtls = attributes[:'enable_mtls']
  end

  if attributes.key?(:'host')
    self.host = attributes[:'host']
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'max_versions')
    self.max_versions = attributes[:'max_versions']
  end

  if attributes.key?(:'mongodb_atlas')
    self.mongodb_atlas = attributes[:'mongodb_atlas']
  end

  if attributes.key?(:'mongodb_atlas_api_private_key')
    self.mongodb_atlas_api_private_key = attributes[:'mongodb_atlas_api_private_key']
  end

  if attributes.key?(:'mongodb_atlas_api_public_key')
    self.mongodb_atlas_api_public_key = attributes[:'mongodb_atlas_api_public_key']
  end

  if attributes.key?(:'mongodb_atlas_project_id')
    self.mongodb_atlas_project_id = attributes[:'mongodb_atlas_project_id']
  end

  if attributes.key?(:'mongodb_default_auth_db')
    self.mongodb_default_auth_db = attributes[:'mongodb_default_auth_db']
  end

  if attributes.key?(:'mongodb_uri_options')
    self.mongodb_uri_options = attributes[:'mongodb_uri_options']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'oracle_service_name')
    self.oracle_service_name = attributes[:'oracle_service_name']
  end

  if attributes.key?(:'oracle_wallet_login_type')
    self. = attributes[:'oracle_wallet_login_type']
  end

  if attributes.key?(:'oracle_wallet_p12_file_data')
    self.oracle_wallet_p12_file_data = attributes[:'oracle_wallet_p12_file_data']
  end

  if attributes.key?(:'oracle_wallet_sso_file_data')
    self.oracle_wallet_sso_file_data = attributes[:'oracle_wallet_sso_file_data']
  end

  if attributes.key?(:'parent_target_name')
    self.parent_target_name = attributes[:'parent_target_name']
  end

  if attributes.key?(:'port')
    self.port = attributes[:'port']
  end

  if attributes.key?(:'pwd')
    self.pwd = attributes[:'pwd']
  end

  if attributes.key?(:'snowflake_account')
    self. = attributes[:'snowflake_account']
  end

  if attributes.key?(:'snowflake_api_private_key')
    self.snowflake_api_private_key = attributes[:'snowflake_api_private_key']
  end

  if attributes.key?(:'snowflake_api_private_key_password')
    self.snowflake_api_private_key_password = attributes[:'snowflake_api_private_key_password']
  end

  if attributes.key?(:'ssl')
    self.ssl = attributes[:'ssl']
  else
    self.ssl = false
  end

  if attributes.key?(:'ssl_certificate')
    self.ssl_certificate = attributes[:'ssl_certificate']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'user_name')
    self.user_name = attributes[:'user_name']
  end
end

Instance Attribute Details

#azure_client_idObject

(Optional) Client id (relevant for "cloud-service-provider" only)



19
20
21
# File 'lib/akeyless/models/target_create_db.rb', line 19

def azure_client_id
  @azure_client_id
end

#azure_client_secretObject

(Optional) Client secret (relevant for "cloud-service-provider" only)



22
23
24
# File 'lib/akeyless/models/target_create_db.rb', line 22

def azure_client_secret
  @azure_client_secret
end

#azure_tenant_idObject

(Optional) Tenant id (relevant for "cloud-service-provider" only)



25
26
27
# File 'lib/akeyless/models/target_create_db.rb', line 25

def azure_tenant_id
  @azure_tenant_id
end

#client_certificateObject

Client certificate for mutual TLS



28
29
30
# File 'lib/akeyless/models/target_create_db.rb', line 28

def client_certificate
  @client_certificate
end

#client_key_passphraseObject

Client private key passphrase for mutual TLS



31
32
33
# File 'lib/akeyless/models/target_create_db.rb', line 31

def client_key_passphrase
  @client_key_passphrase
end

#client_private_keyObject

Client private key for mutual TLS



34
35
36
# File 'lib/akeyless/models/target_create_db.rb', line 34

def client_private_key
  @client_private_key
end

#cloud_service_providerObject

(Optional) Cloud service provider (currently only supports Azure)



37
38
39
# File 'lib/akeyless/models/target_create_db.rb', line 37

def cloud_service_provider
  @cloud_service_provider
end

#cluster_modeObject

Cluster Mode



40
41
42
# File 'lib/akeyless/models/target_create_db.rb', line 40

def cluster_mode
  @cluster_mode
end

#commentObject

Deprecated - use description



43
44
45
# File 'lib/akeyless/models/target_create_db.rb', line 43

def comment
  @comment
end

#connection_typeObject

Type of connection to mssql database [credentials/cloud-identity/wallet/parent-target]



46
47
48
# File 'lib/akeyless/models/target_create_db.rb', line 46

def connection_type
  @connection_type
end

#db_nameObject

Returns the value of attribute db_name.



48
49
50
# File 'lib/akeyless/models/target_create_db.rb', line 48

def db_name
  @db_name
end

#db_server_certificatesObject

(Optional) DB server certificates



51
52
53
# File 'lib/akeyless/models/target_create_db.rb', line 51

def db_server_certificates
  @db_server_certificates
end

#db_server_nameObject

(Optional) Server name for certificate verification



54
55
56
# File 'lib/akeyless/models/target_create_db.rb', line 54

def db_server_name
  @db_server_name
end

#db_typeObject

Returns the value of attribute db_type.



56
57
58
# File 'lib/akeyless/models/target_create_db.rb', line 56

def db_type
  @db_type
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



59
60
61
# File 'lib/akeyless/models/target_create_db.rb', line 59

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



62
63
64
# File 'lib/akeyless/models/target_create_db.rb', line 62

def description
  @description
end

#enable_mtlsObject

Enable mutual TLS



65
66
67
# File 'lib/akeyless/models/target_create_db.rb', line 65

def enable_mtls
  @enable_mtls
end

#hostObject

Returns the value of attribute host.



67
68
69
# File 'lib/akeyless/models/target_create_db.rb', line 67

def host
  @host
end

#jsonObject

Set output format to JSON



70
71
72
# File 'lib/akeyless/models/target_create_db.rb', line 70

def json
  @json
end

#keyObject

The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)



73
74
75
# File 'lib/akeyless/models/target_create_db.rb', line 73

def key
  @key
end

#max_versionsObject

Set the maximum number of versions, limited by the account settings defaults.



76
77
78
# File 'lib/akeyless/models/target_create_db.rb', line 76

def max_versions
  @max_versions
end

#mongodb_atlasObject

Returns the value of attribute mongodb_atlas.



78
79
80
# File 'lib/akeyless/models/target_create_db.rb', line 78

def mongodb_atlas
  @mongodb_atlas
end

#mongodb_atlas_api_private_keyObject

MongoDB Atlas private key



81
82
83
# File 'lib/akeyless/models/target_create_db.rb', line 81

def mongodb_atlas_api_private_key
  @mongodb_atlas_api_private_key
end

#mongodb_atlas_api_public_keyObject

MongoDB Atlas public key



84
85
86
# File 'lib/akeyless/models/target_create_db.rb', line 84

def mongodb_atlas_api_public_key
  @mongodb_atlas_api_public_key
end

#mongodb_atlas_project_idObject

MongoDB Atlas project ID



87
88
89
# File 'lib/akeyless/models/target_create_db.rb', line 87

def mongodb_atlas_project_id
  @mongodb_atlas_project_id
end

#mongodb_default_auth_dbObject

MongoDB server default authentication database



90
91
92
# File 'lib/akeyless/models/target_create_db.rb', line 90

def mongodb_default_auth_db
  @mongodb_default_auth_db
end

#mongodb_uri_optionsObject

MongoDB server URI options



93
94
95
# File 'lib/akeyless/models/target_create_db.rb', line 93

def mongodb_uri_options
  @mongodb_uri_options
end

#nameObject

Target name



96
97
98
# File 'lib/akeyless/models/target_create_db.rb', line 96

def name
  @name
end

#oracle_service_nameObject

Oracle db service name



99
100
101
# File 'lib/akeyless/models/target_create_db.rb', line 99

def oracle_service_name
  @oracle_service_name
end

#oracle_wallet_login_typeObject

Oracle Wallet login type (password/mtls)



102
103
104
# File 'lib/akeyless/models/target_create_db.rb', line 102

def 
  @oracle_wallet_login_type
end

#oracle_wallet_p12_file_dataObject

Oracle wallet p12 file data in base64



105
106
107
# File 'lib/akeyless/models/target_create_db.rb', line 105

def oracle_wallet_p12_file_data
  @oracle_wallet_p12_file_data
end

#oracle_wallet_sso_file_dataObject

Oracle wallet sso file data in base64



108
109
110
# File 'lib/akeyless/models/target_create_db.rb', line 108

def oracle_wallet_sso_file_data
  @oracle_wallet_sso_file_data
end

#parent_target_nameObject

Name of the parent target, relevant only when connection-type is parent-target



111
112
113
# File 'lib/akeyless/models/target_create_db.rb', line 111

def parent_target_name
  @parent_target_name
end

#portObject

Returns the value of attribute port.



113
114
115
# File 'lib/akeyless/models/target_create_db.rb', line 113

def port
  @port
end

#pwdObject

Returns the value of attribute pwd.



115
116
117
# File 'lib/akeyless/models/target_create_db.rb', line 115

def pwd
  @pwd
end

#snowflake_accountObject

Returns the value of attribute snowflake_account.



117
118
119
# File 'lib/akeyless/models/target_create_db.rb', line 117

def 
  @snowflake_account
end

#snowflake_api_private_keyObject

RSA Private key (base64 encoded)



120
121
122
# File 'lib/akeyless/models/target_create_db.rb', line 120

def snowflake_api_private_key
  @snowflake_api_private_key
end

#snowflake_api_private_key_passwordObject

The Private key passphrase



123
124
125
# File 'lib/akeyless/models/target_create_db.rb', line 123

def snowflake_api_private_key_password
  @snowflake_api_private_key_password
end

#sslObject

Enable/Disable SSL [true/false]



126
127
128
# File 'lib/akeyless/models/target_create_db.rb', line 126

def ssl
  @ssl
end

#ssl_certificateObject

SSL connection certificate



129
130
131
# File 'lib/akeyless/models/target_create_db.rb', line 129

def ssl_certificate
  @ssl_certificate
end

#tokenObject

Authentication token (see ‘/auth` and `/configure`)



132
133
134
# File 'lib/akeyless/models/target_create_db.rb', line 132

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



135
136
137
# File 'lib/akeyless/models/target_create_db.rb', line 135

def uid_token
  @uid_token
end

#user_nameObject

Returns the value of attribute user_name.



137
138
139
# File 'lib/akeyless/models/target_create_db.rb', line 137

def user_name
  @user_name
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
# File 'lib/akeyless/models/target_create_db.rb', line 565

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



189
190
191
# File 'lib/akeyless/models/target_create_db.rb', line 189

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/akeyless/models/target_create_db.rb', line 140

def self.attribute_map
  {
    :'azure_client_id' => :'azure-client-id',
    :'azure_client_secret' => :'azure-client-secret',
    :'azure_tenant_id' => :'azure-tenant-id',
    :'client_certificate' => :'client-certificate',
    :'client_key_passphrase' => :'client-key-passphrase',
    :'client_private_key' => :'client-private-key',
    :'cloud_service_provider' => :'cloud-service-provider',
    :'cluster_mode' => :'cluster-mode',
    :'comment' => :'comment',
    :'connection_type' => :'connection-type',
    :'db_name' => :'db-name',
    :'db_server_certificates' => :'db-server-certificates',
    :'db_server_name' => :'db-server-name',
    :'db_type' => :'db-type',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'enable_mtls' => :'enable-mtls',
    :'host' => :'host',
    :'json' => :'json',
    :'key' => :'key',
    :'max_versions' => :'max-versions',
    :'mongodb_atlas' => :'mongodb-atlas',
    :'mongodb_atlas_api_private_key' => :'mongodb-atlas-api-private-key',
    :'mongodb_atlas_api_public_key' => :'mongodb-atlas-api-public-key',
    :'mongodb_atlas_project_id' => :'mongodb-atlas-project-id',
    :'mongodb_default_auth_db' => :'mongodb-default-auth-db',
    :'mongodb_uri_options' => :'mongodb-uri-options',
    :'name' => :'name',
    :'oracle_service_name' => :'oracle-service-name',
    :'oracle_wallet_login_type' => :'oracle-wallet-login-type',
    :'oracle_wallet_p12_file_data' => :'oracle-wallet-p12-file-data',
    :'oracle_wallet_sso_file_data' => :'oracle-wallet-sso-file-data',
    :'parent_target_name' => :'parent-target-name',
    :'port' => :'port',
    :'pwd' => :'pwd',
    :'snowflake_account' => :'snowflake-account',
    :'snowflake_api_private_key' => :'snowflake-api-private-key',
    :'snowflake_api_private_key_password' => :'snowflake-api-private-key-password',
    :'ssl' => :'ssl',
    :'ssl_certificate' => :'ssl-certificate',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'user_name' => :'user-name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
# File 'lib/akeyless/models/target_create_db.rb', line 541

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



243
244
245
246
# File 'lib/akeyless/models/target_create_db.rb', line 243

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/akeyless/models/target_create_db.rb', line 194

def self.openapi_types
  {
    :'azure_client_id' => :'String',
    :'azure_client_secret' => :'String',
    :'azure_tenant_id' => :'String',
    :'client_certificate' => :'String',
    :'client_key_passphrase' => :'String',
    :'client_private_key' => :'String',
    :'cloud_service_provider' => :'String',
    :'cluster_mode' => :'Boolean',
    :'comment' => :'String',
    :'connection_type' => :'String',
    :'db_name' => :'String',
    :'db_server_certificates' => :'String',
    :'db_server_name' => :'String',
    :'db_type' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'enable_mtls' => :'Boolean',
    :'host' => :'String',
    :'json' => :'Boolean',
    :'key' => :'String',
    :'max_versions' => :'String',
    :'mongodb_atlas' => :'Boolean',
    :'mongodb_atlas_api_private_key' => :'String',
    :'mongodb_atlas_api_public_key' => :'String',
    :'mongodb_atlas_project_id' => :'String',
    :'mongodb_default_auth_db' => :'String',
    :'mongodb_uri_options' => :'String',
    :'name' => :'String',
    :'oracle_service_name' => :'String',
    :'oracle_wallet_login_type' => :'String',
    :'oracle_wallet_p12_file_data' => :'String',
    :'oracle_wallet_sso_file_data' => :'String',
    :'parent_target_name' => :'String',
    :'port' => :'String',
    :'pwd' => :'String',
    :'snowflake_account' => :'String',
    :'snowflake_api_private_key' => :'String',
    :'snowflake_api_private_key_password' => :'String',
    :'ssl' => :'Boolean',
    :'ssl_certificate' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'user_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
# File 'lib/akeyless/models/target_create_db.rb', line 478

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      azure_client_id == o.azure_client_id &&
      azure_client_secret == o.azure_client_secret &&
      azure_tenant_id == o.azure_tenant_id &&
      client_certificate == o.client_certificate &&
      client_key_passphrase == o.client_key_passphrase &&
      client_private_key == o.client_private_key &&
      cloud_service_provider == o.cloud_service_provider &&
      cluster_mode == o.cluster_mode &&
      comment == o.comment &&
      connection_type == o.connection_type &&
      db_name == o.db_name &&
      db_server_certificates == o.db_server_certificates &&
      db_server_name == o.db_server_name &&
      db_type == o.db_type &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      enable_mtls == o.enable_mtls &&
      host == o.host &&
      json == o.json &&
      key == o.key &&
      max_versions == o.max_versions &&
      mongodb_atlas == o.mongodb_atlas &&
      mongodb_atlas_api_private_key == o.mongodb_atlas_api_private_key &&
      mongodb_atlas_api_public_key == o.mongodb_atlas_api_public_key &&
      mongodb_atlas_project_id == o.mongodb_atlas_project_id &&
      mongodb_default_auth_db == o.mongodb_default_auth_db &&
      mongodb_uri_options == o.mongodb_uri_options &&
      name == o.name &&
      oracle_service_name == o.oracle_service_name &&
       == o. &&
      oracle_wallet_p12_file_data == o.oracle_wallet_p12_file_data &&
      oracle_wallet_sso_file_data == o.oracle_wallet_sso_file_data &&
      parent_target_name == o.parent_target_name &&
      port == o.port &&
      pwd == o.pwd &&
       == o. &&
      snowflake_api_private_key == o.snowflake_api_private_key &&
      snowflake_api_private_key_password == o.snowflake_api_private_key_password &&
      ssl == o.ssl &&
      ssl_certificate == o.ssl_certificate &&
      token == o.token &&
      uid_token == o.uid_token &&
      user_name == o.user_name
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



636
637
638
639
640
641
642
643
644
645
646
647
648
# File 'lib/akeyless/models/target_create_db.rb', line 636

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


528
529
530
# File 'lib/akeyless/models/target_create_db.rb', line 528

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



534
535
536
# File 'lib/akeyless/models/target_create_db.rb', line 534

def hash
  [azure_client_id, azure_client_secret, azure_tenant_id, client_certificate, client_key_passphrase, client_private_key, cloud_service_provider, cluster_mode, comment, connection_type, db_name, db_server_certificates, db_server_name, db_type, delete_protection, description, enable_mtls, host, json, key, max_versions, mongodb_atlas, mongodb_atlas_api_private_key, mongodb_atlas_api_public_key, mongodb_atlas_project_id, mongodb_default_auth_db, mongodb_uri_options, name, oracle_service_name, , oracle_wallet_p12_file_data, oracle_wallet_sso_file_data, parent_target_name, port, pwd, , snowflake_api_private_key, snowflake_api_private_key_password, ssl, ssl_certificate, token, uid_token, user_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
# File 'lib/akeyless/models/target_create_db.rb', line 448

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @connection_type.nil?
    invalid_properties.push('invalid value for "connection_type", connection_type cannot be nil.')
  end

  if @db_type.nil?
    invalid_properties.push('invalid value for "db_type", db_type cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



612
613
614
# File 'lib/akeyless/models/target_create_db.rb', line 612

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



618
619
620
621
622
623
624
625
626
627
628
629
630
# File 'lib/akeyless/models/target_create_db.rb', line 618

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



606
607
608
# File 'lib/akeyless/models/target_create_db.rb', line 606

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



468
469
470
471
472
473
474
# File 'lib/akeyless/models/target_create_db.rb', line 468

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @connection_type.nil?
  return false if @db_type.nil?
  return false if @name.nil?
  true
end