Class: Akeyless::TargetCreateGoogleTrust

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/target_create_google_trust.rb

Overview

targetCreateGoogleTrust is a command that creates a new Google Trust target

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TargetCreateGoogleTrust

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/akeyless/models/target_create_google_trust.rb', line 129

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::TargetCreateGoogleTrust` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::TargetCreateGoogleTrust`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'acme_challenge')
    self.acme_challenge = attributes[:'acme_challenge']
  else
    self.acme_challenge = 'dns'
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'dns_target_creds')
    self.dns_target_creds = attributes[:'dns_target_creds']
  end

  if attributes.key?(:'eab_hmac_key')
    self.eab_hmac_key = attributes[:'eab_hmac_key']
  end

  if attributes.key?(:'eab_key_id')
    self.eab_key_id = attributes[:'eab_key_id']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'gcp_project')
    self.gcp_project = attributes[:'gcp_project']
  end

  if attributes.key?(:'google_trust_url')
    self.google_trust_url = attributes[:'google_trust_url']
  else
    self.google_trust_url = 'production'
  end

  if attributes.key?(:'hosted_zone')
    self.hosted_zone = attributes[:'hosted_zone']
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'max_versions')
    self.max_versions = attributes[:'max_versions']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'resource_group')
    self.resource_group = attributes[:'resource_group']
  end

  if attributes.key?(:'timeout')
    self.timeout = attributes[:'timeout']
  else
    self.timeout = '5m'
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end
end

Instance Attribute Details

#acme_challengeObject

ACME challenge type. Options: [dns]



20
21
22
# File 'lib/akeyless/models/target_create_google_trust.rb', line 20

def acme_challenge
  @acme_challenge
end

#descriptionObject

Description of the object



23
24
25
# File 'lib/akeyless/models/target_create_google_trust.rb', line 23

def description
  @description
end

#dns_target_credsObject

Name of existing cloud target for DNS credentials. Required when challenge type is dns. Supported providers: AWS, Azure, GCP



26
27
28
# File 'lib/akeyless/models/target_create_google_trust.rb', line 26

def dns_target_creds
  @dns_target_creds
end

#eab_hmac_keyObject

External Account Binding HMAC key (required for ACME account bootstrap on create)



29
30
31
# File 'lib/akeyless/models/target_create_google_trust.rb', line 29

def eab_hmac_key
  @eab_hmac_key
end

#eab_key_idObject

External Account Binding key identifier (required for ACME account bootstrap on create)



32
33
34
# File 'lib/akeyless/models/target_create_google_trust.rb', line 32

def eab_key_id
  @eab_key_id
end

#emailObject

Email address for ACME account registration



35
36
37
# File 'lib/akeyless/models/target_create_google_trust.rb', line 35

def email
  @email
end

#gcp_projectObject

GCP Cloud DNS project ID. Optional and can be derived from service account



38
39
40
# File 'lib/akeyless/models/target_create_google_trust.rb', line 38

def gcp_project
  @gcp_project
end

#google_trust_urlObject

Google Trust directory environment. Options: [production/staging]



41
42
43
# File 'lib/akeyless/models/target_create_google_trust.rb', line 41

def google_trust_url
  @google_trust_url
end

#hosted_zoneObject

AWS Route53 hosted zone ID. Required when DNS credentials target is AWS



44
45
46
# File 'lib/akeyless/models/target_create_google_trust.rb', line 44

def hosted_zone
  @hosted_zone
end

#jsonObject

Set output format to JSON



47
48
49
# File 'lib/akeyless/models/target_create_google_trust.rb', line 47

def json
  @json
end

#keyObject

The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)



50
51
52
# File 'lib/akeyless/models/target_create_google_trust.rb', line 50

def key
  @key
end

#max_versionsObject

Set the maximum number of versions, limited by the account settings defaults.



53
54
55
# File 'lib/akeyless/models/target_create_google_trust.rb', line 53

def max_versions
  @max_versions
end

#nameObject

Target name



56
57
58
# File 'lib/akeyless/models/target_create_google_trust.rb', line 56

def name
  @name
end

#resource_groupObject

Azure resource group name. Required when DNS credentials target is Azure



59
60
61
# File 'lib/akeyless/models/target_create_google_trust.rb', line 59

def resource_group
  @resource_group
end

#timeoutObject

Timeout for challenge validation



62
63
64
# File 'lib/akeyless/models/target_create_google_trust.rb', line 62

def timeout
  @timeout
end

#tokenObject

Authentication token (see /auth and /configure)



65
66
67
# File 'lib/akeyless/models/target_create_google_trust.rb', line 65

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



68
69
70
# File 'lib/akeyless/models/target_create_google_trust.rb', line 68

def uid_token
  @uid_token
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/akeyless/models/target_create_google_trust.rb', line 311

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



94
95
96
# File 'lib/akeyless/models/target_create_google_trust.rb', line 94

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/akeyless/models/target_create_google_trust.rb', line 71

def self.attribute_map
  {
    :'acme_challenge' => :'acme-challenge',
    :'description' => :'description',
    :'dns_target_creds' => :'dns-target-creds',
    :'eab_hmac_key' => :'eab-hmac-key',
    :'eab_key_id' => :'eab-key-id',
    :'email' => :'email',
    :'gcp_project' => :'gcp-project',
    :'google_trust_url' => :'google-trust-url',
    :'hosted_zone' => :'hosted-zone',
    :'json' => :'json',
    :'key' => :'key',
    :'max_versions' => :'max-versions',
    :'name' => :'name',
    :'resource_group' => :'resource-group',
    :'timeout' => :'timeout',
    :'token' => :'token',
    :'uid_token' => :'uid-token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/akeyless/models/target_create_google_trust.rb', line 287

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



122
123
124
125
# File 'lib/akeyless/models/target_create_google_trust.rb', line 122

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/akeyless/models/target_create_google_trust.rb', line 99

def self.openapi_types
  {
    :'acme_challenge' => :'String',
    :'description' => :'String',
    :'dns_target_creds' => :'String',
    :'eab_hmac_key' => :'String',
    :'eab_key_id' => :'String',
    :'email' => :'String',
    :'gcp_project' => :'String',
    :'google_trust_url' => :'String',
    :'hosted_zone' => :'String',
    :'json' => :'Boolean',
    :'key' => :'String',
    :'max_versions' => :'String',
    :'name' => :'String',
    :'resource_group' => :'String',
    :'timeout' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/akeyless/models/target_create_google_trust.rb', line 250

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      acme_challenge == o.acme_challenge &&
      description == o.description &&
      dns_target_creds == o.dns_target_creds &&
      eab_hmac_key == o.eab_hmac_key &&
      eab_key_id == o.eab_key_id &&
      email == o.email &&
      gcp_project == o.gcp_project &&
      google_trust_url == o.google_trust_url &&
      hosted_zone == o.hosted_zone &&
      json == o.json &&
      key == o.key &&
      max_versions == o.max_versions &&
      name == o.name &&
      resource_group == o.resource_group &&
      timeout == o.timeout &&
      token == o.token &&
      uid_token == o.uid_token
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/akeyless/models/target_create_google_trust.rb', line 382

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


274
275
276
# File 'lib/akeyless/models/target_create_google_trust.rb', line 274

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



280
281
282
# File 'lib/akeyless/models/target_create_google_trust.rb', line 280

def hash
  [acme_challenge, description, dns_target_creds, eab_hmac_key, eab_key_id, email, gcp_project, google_trust_url, hosted_zone, json, key, max_versions, name, resource_group, timeout, token, uid_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/akeyless/models/target_create_google_trust.rb', line 225

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



358
359
360
# File 'lib/akeyless/models/target_create_google_trust.rb', line 358

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/akeyless/models/target_create_google_trust.rb', line 364

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



352
353
354
# File 'lib/akeyless/models/target_create_google_trust.rb', line 352

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



241
242
243
244
245
246
# File 'lib/akeyless/models/target_create_google_trust.rb', line 241

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @email.nil?
  return false if @name.nil?
  true
end