Class: Akeyless::TargetCreateWindows

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/target_create_windows.rb

Overview

GatewayCreateProducerWindowsCmd is a command that creates a new windows target

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TargetCreateWindows

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/akeyless/models/target_create_windows.rb', line 144

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::TargetCreateWindows` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::TargetCreateWindows`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'certificate')
    self.certificate = attributes[:'certificate']
  end

  if attributes.key?(:'connection_type')
    self.connection_type = attributes[:'connection_type']
  else
    self.connection_type = 'credentials'
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'domain')
    self.domain = attributes[:'domain']
  end

  if attributes.key?(:'hostname')
    self.hostname = attributes[:'hostname']
  else
    self.hostname = nil
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'lock_on_read')
    self.lock_on_read = attributes[:'lock_on_read']
  end

  if attributes.key?(:'lock_ttl')
    self.lock_ttl = attributes[:'lock_ttl']
  end

  if attributes.key?(:'max_versions')
    self.max_versions = attributes[:'max_versions']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'parent_target_name')
    self.parent_target_name = attributes[:'parent_target_name']
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  else
    self.password = 'dummy_value'
  end

  if attributes.key?(:'port')
    self.port = attributes[:'port']
  else
    self.port = '5986'
  end

  if attributes.key?(:'rotate_on_unlock')
    self.rotate_on_unlock = attributes[:'rotate_on_unlock']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'use_tls')
    self.use_tls = attributes[:'use_tls']
  else
    self.use_tls = 'true'
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  else
    self.username = 'dummy_value'
  end
end

Instance Attribute Details

#certificateObject

SSL CA certificate in base64 encoding generated from a trusted Certificate Authority (CA)



20
21
22
# File 'lib/akeyless/models/target_create_windows.rb', line 20

def certificate
  @certificate
end

#connection_typeObject

Type of connection to Windows Server [credentials/parent-target]



23
24
25
# File 'lib/akeyless/models/target_create_windows.rb', line 23

def connection_type
  @connection_type
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



26
27
28
# File 'lib/akeyless/models/target_create_windows.rb', line 26

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



29
30
31
# File 'lib/akeyless/models/target_create_windows.rb', line 29

def description
  @description
end

#domainObject

User domain name



32
33
34
# File 'lib/akeyless/models/target_create_windows.rb', line 32

def domain
  @domain
end

#hostnameObject

Server hostname



35
36
37
# File 'lib/akeyless/models/target_create_windows.rb', line 35

def hostname
  @hostname
end

#jsonObject

Set output format to JSON



38
39
40
# File 'lib/akeyless/models/target_create_windows.rb', line 38

def json
  @json
end

#keyObject

The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)



41
42
43
# File 'lib/akeyless/models/target_create_windows.rb', line 41

def key
  @key
end

#lock_on_readObject

Lock this secret after each successful value read



44
45
46
# File 'lib/akeyless/models/target_create_windows.rb', line 44

def lock_on_read
  @lock_on_read
end

#lock_ttlObject

Lock TTL in minutes



47
48
49
# File 'lib/akeyless/models/target_create_windows.rb', line 47

def lock_ttl
  @lock_ttl
end

#max_versionsObject

Set the maximum number of versions, limited by the account settings defaults.



50
51
52
# File 'lib/akeyless/models/target_create_windows.rb', line 50

def max_versions
  @max_versions
end

#nameObject

Target name



53
54
55
# File 'lib/akeyless/models/target_create_windows.rb', line 53

def name
  @name
end

#parent_target_nameObject

Name of the parent target, relevant only when connection-type is parent-target



56
57
58
# File 'lib/akeyless/models/target_create_windows.rb', line 56

def parent_target_name
  @parent_target_name
end

#passwordObject

Privileged user password



59
60
61
# File 'lib/akeyless/models/target_create_windows.rb', line 59

def password
  @password
end

#portObject

Server WinRM port



62
63
64
# File 'lib/akeyless/models/target_create_windows.rb', line 62

def port
  @port
end

#rotate_on_unlockObject

Rotate this secret after it is unlocked



65
66
67
# File 'lib/akeyless/models/target_create_windows.rb', line 65

def rotate_on_unlock
  @rotate_on_unlock
end

#tokenObject

Authentication token (see /auth and /configure)



68
69
70
# File 'lib/akeyless/models/target_create_windows.rb', line 68

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



71
72
73
# File 'lib/akeyless/models/target_create_windows.rb', line 71

def uid_token
  @uid_token
end

#use_tlsObject

Enable/Disable TLS for WinRM over HTTPS [true/false]



74
75
76
# File 'lib/akeyless/models/target_create_windows.rb', line 74

def use_tls
  @use_tls
end

#usernameObject

Privileged username



77
78
79
# File 'lib/akeyless/models/target_create_windows.rb', line 77

def username
  @username
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/akeyless/models/target_create_windows.rb', line 355

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



106
107
108
# File 'lib/akeyless/models/target_create_windows.rb', line 106

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/akeyless/models/target_create_windows.rb', line 80

def self.attribute_map
  {
    :'certificate' => :'certificate',
    :'connection_type' => :'connection-type',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'domain' => :'domain',
    :'hostname' => :'hostname',
    :'json' => :'json',
    :'key' => :'key',
    :'lock_on_read' => :'lock-on-read',
    :'lock_ttl' => :'lock-ttl',
    :'max_versions' => :'max-versions',
    :'name' => :'name',
    :'parent_target_name' => :'parent-target-name',
    :'password' => :'password',
    :'port' => :'port',
    :'rotate_on_unlock' => :'rotate-on-unlock',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'use_tls' => :'use-tls',
    :'username' => :'username'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/akeyless/models/target_create_windows.rb', line 331

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



137
138
139
140
# File 'lib/akeyless/models/target_create_windows.rb', line 137

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/akeyless/models/target_create_windows.rb', line 111

def self.openapi_types
  {
    :'certificate' => :'String',
    :'connection_type' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'domain' => :'String',
    :'hostname' => :'String',
    :'json' => :'Boolean',
    :'key' => :'String',
    :'lock_on_read' => :'String',
    :'lock_ttl' => :'String',
    :'max_versions' => :'String',
    :'name' => :'String',
    :'parent_target_name' => :'String',
    :'password' => :'String',
    :'port' => :'String',
    :'rotate_on_unlock' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'use_tls' => :'String',
    :'username' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/akeyless/models/target_create_windows.rb', line 291

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      certificate == o.certificate &&
      connection_type == o.connection_type &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      domain == o.domain &&
      hostname == o.hostname &&
      json == o.json &&
      key == o.key &&
      lock_on_read == o.lock_on_read &&
      lock_ttl == o.lock_ttl &&
      max_versions == o.max_versions &&
      name == o.name &&
      parent_target_name == o.parent_target_name &&
      password == o.password &&
      port == o.port &&
      rotate_on_unlock == o.rotate_on_unlock &&
      token == o.token &&
      uid_token == o.uid_token &&
      use_tls == o.use_tls &&
      username == o.username
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/akeyless/models/target_create_windows.rb', line 426

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


318
319
320
# File 'lib/akeyless/models/target_create_windows.rb', line 318

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



324
325
326
# File 'lib/akeyless/models/target_create_windows.rb', line 324

def hash
  [certificate, connection_type, delete_protection, description, domain, hostname, json, key, lock_on_read, lock_ttl, max_versions, name, parent_target_name, password, port, rotate_on_unlock, token, uid_token, use_tls, username].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/akeyless/models/target_create_windows.rb', line 256

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @hostname.nil?
    invalid_properties.push('invalid value for "hostname", hostname cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @password.nil?
    invalid_properties.push('invalid value for "password", password cannot be nil.')
  end

  if @username.nil?
    invalid_properties.push('invalid value for "username", username cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



402
403
404
# File 'lib/akeyless/models/target_create_windows.rb', line 402

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/akeyless/models/target_create_windows.rb', line 408

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



396
397
398
# File 'lib/akeyless/models/target_create_windows.rb', line 396

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



280
281
282
283
284
285
286
287
# File 'lib/akeyless/models/target_create_windows.rb', line 280

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @hostname.nil?
  return false if @name.nil?
  return false if @password.nil?
  return false if @username.nil?
  true
end