Class: Akeyless::TargetUpdateLetsEncrypt

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/target_update_lets_encrypt.rb

Overview

targetUpdateLetsEncrypt is a command that updates an existing Let's Encrypt target

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TargetUpdateLetsEncrypt

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 151

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::TargetUpdateLetsEncrypt` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::TargetUpdateLetsEncrypt`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'acme_challenge')
    self.acme_challenge = attributes[:'acme_challenge']
  else
    self.acme_challenge = 'http'
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'dns_target_creds')
    self.dns_target_creds = attributes[:'dns_target_creds']
  end

  if attributes.key?(:'dns_zone')
    self.dns_zone = attributes[:'dns_zone']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'gcp_project')
    self.gcp_project = attributes[:'gcp_project']
  end

  if attributes.key?(:'hosted_zone')
    self.hosted_zone = attributes[:'hosted_zone']
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'keep_prev_version')
    self.keep_prev_version = attributes[:'keep_prev_version']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'lets_encrypt_url')
    self.lets_encrypt_url = attributes[:'lets_encrypt_url']
  else
    self.lets_encrypt_url = 'production'
  end

  if attributes.key?(:'lock_on_read')
    self.lock_on_read = attributes[:'lock_on_read']
  end

  if attributes.key?(:'lock_ttl')
    self.lock_ttl = attributes[:'lock_ttl']
  end

  if attributes.key?(:'max_versions')
    self.max_versions = attributes[:'max_versions']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'resource_group')
    self.resource_group = attributes[:'resource_group']
  end

  if attributes.key?(:'rotate_on_unlock')
    self.rotate_on_unlock = attributes[:'rotate_on_unlock']
  end

  if attributes.key?(:'timeout')
    self.timeout = attributes[:'timeout']
  else
    self.timeout = '5m'
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end
end

Instance Attribute Details

#acme_challengeObject

Returns the value of attribute acme_challenge.



19
20
21
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 19

def acme_challenge
  @acme_challenge
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



22
23
24
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 22

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



25
26
27
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 25

def description
  @description
end

#dns_target_credsObject

Name of existing cloud target for DNS credentials. Required when acme-challenge=dns. Supported: AWS, Azure, GCP, Cloudflare targets



28
29
30
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 28

def dns_target_creds
  @dns_target_creds
end

#dns_zoneObject

Cloudflare DNS zone identifier. Required when dns-target-creds points to Cloudflare target



31
32
33
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 31

def dns_zone
  @dns_zone
end

#emailObject

Email address for ACME account registration



34
35
36
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 34

def email
  @email
end

#gcp_projectObject

GCP Cloud DNS: Project ID. Optional - can be derived from service account



37
38
39
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 37

def gcp_project
  @gcp_project
end

#hosted_zoneObject

AWS Route53 hosted zone ID. Required when dns-target-creds points to AWS target



40
41
42
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 40

def hosted_zone
  @hosted_zone
end

#jsonObject

Set output format to JSON



43
44
45
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 43

def json
  @json
end

#keep_prev_versionObject

Whether to keep previous version [true/false]. If not set, use default according to account settings



46
47
48
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 46

def keep_prev_version
  @keep_prev_version
end

#keyObject

The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)



49
50
51
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 49

def key
  @key
end

#lets_encrypt_urlObject

Returns the value of attribute lets_encrypt_url.



51
52
53
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 51

def lets_encrypt_url
  @lets_encrypt_url
end

#lock_on_readObject

Lock this secret after each successful value read



54
55
56
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 54

def lock_on_read
  @lock_on_read
end

#lock_ttlObject

Lock TTL in minutes



57
58
59
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 57

def lock_ttl
  @lock_ttl
end

#max_versionsObject

Set the maximum number of versions, limited by the account settings defaults.



60
61
62
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 60

def max_versions
  @max_versions
end

#nameObject

Target name



63
64
65
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 63

def name
  @name
end

#new_nameObject

New target name



66
67
68
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 66

def new_name
  @new_name
end

#resource_groupObject

Azure resource group name. Required when dns-target-creds points to Azure target



69
70
71
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 69

def resource_group
  @resource_group
end

#rotate_on_unlockObject

Rotate this secret after it is unlocked



72
73
74
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 72

def rotate_on_unlock
  @rotate_on_unlock
end

#timeoutObject

Returns the value of attribute timeout.



74
75
76
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 74

def timeout
  @timeout
end

#tokenObject

Authentication token (see /auth and /configure)



77
78
79
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 77

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



80
81
82
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 80

def uid_token
  @uid_token
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 358

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



111
112
113
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 111

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 83

def self.attribute_map
  {
    :'acme_challenge' => :'acme-challenge',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'dns_target_creds' => :'dns-target-creds',
    :'dns_zone' => :'dns-zone',
    :'email' => :'email',
    :'gcp_project' => :'gcp-project',
    :'hosted_zone' => :'hosted-zone',
    :'json' => :'json',
    :'keep_prev_version' => :'keep-prev-version',
    :'key' => :'key',
    :'lets_encrypt_url' => :'lets-encrypt-url',
    :'lock_on_read' => :'lock-on-read',
    :'lock_ttl' => :'lock-ttl',
    :'max_versions' => :'max-versions',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'resource_group' => :'resource-group',
    :'rotate_on_unlock' => :'rotate-on-unlock',
    :'timeout' => :'timeout',
    :'token' => :'token',
    :'uid_token' => :'uid-token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 334

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



144
145
146
147
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 144

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 116

def self.openapi_types
  {
    :'acme_challenge' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'dns_target_creds' => :'String',
    :'dns_zone' => :'String',
    :'email' => :'String',
    :'gcp_project' => :'String',
    :'hosted_zone' => :'String',
    :'json' => :'Boolean',
    :'keep_prev_version' => :'String',
    :'key' => :'String',
    :'lets_encrypt_url' => :'String',
    :'lock_on_read' => :'String',
    :'lock_ttl' => :'String',
    :'max_versions' => :'String',
    :'name' => :'String',
    :'new_name' => :'String',
    :'resource_group' => :'String',
    :'rotate_on_unlock' => :'String',
    :'timeout' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 292

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      acme_challenge == o.acme_challenge &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      dns_target_creds == o.dns_target_creds &&
      dns_zone == o.dns_zone &&
      email == o.email &&
      gcp_project == o.gcp_project &&
      hosted_zone == o.hosted_zone &&
      json == o.json &&
      keep_prev_version == o.keep_prev_version &&
      key == o.key &&
      lets_encrypt_url == o.lets_encrypt_url &&
      lock_on_read == o.lock_on_read &&
      lock_ttl == o.lock_ttl &&
      max_versions == o.max_versions &&
      name == o.name &&
      new_name == o.new_name &&
      resource_group == o.resource_group &&
      rotate_on_unlock == o.rotate_on_unlock &&
      timeout == o.timeout &&
      token == o.token &&
      uid_token == o.uid_token
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 429

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


321
322
323
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 321

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



327
328
329
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 327

def hash
  [acme_challenge, delete_protection, description, dns_target_creds, dns_zone, email, gcp_project, hosted_zone, json, keep_prev_version, key, lets_encrypt_url, lock_on_read, lock_ttl, max_versions, name, new_name, resource_group, rotate_on_unlock, timeout, token, uid_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 267

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



405
406
407
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 405

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 411

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



399
400
401
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 399

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



283
284
285
286
287
288
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 283

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @email.nil?
  return false if @name.nil?
  true
end