Class: Akeyless::UpdateAWSTarget
- Inherits:
-
Object
- Object
- Akeyless::UpdateAWSTarget
- Defined in:
- lib/akeyless/models/update_aws_target.rb
Overview
updateAWSTarget is a command that updates a new target. [Deprecated: Use target-update-aws command]
Instance Attribute Summary collapse
-
#access_key ⇒ Object
AWS secret access key.
-
#access_key_id ⇒ Object
AWS access key ID.
-
#comment ⇒ Object
Deprecated - use description.
-
#description ⇒ Object
Description of the object.
-
#generate_external_id ⇒ Object
A unique auto-generated value used in your AWS account when configuring your AWS IAM role to securely delegate access to Akeyless.
-
#json ⇒ Object
Set output format to JSON.
-
#keep_prev_version ⇒ Object
Whether to keep previous version [true/false].
-
#key ⇒ Object
The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used).
-
#lock_on_read ⇒ Object
Lock this secret after each successful value read.
-
#lock_ttl ⇒ Object
Lock TTL in minutes.
-
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
-
#name ⇒ Object
Target name.
-
#new_name ⇒ Object
New target name.
-
#region ⇒ Object
AWS region.
-
#role_arn ⇒ Object
AWS IAM role identifier that Gateway will assume in your AWS account, relevant only when using external ID.
-
#rotate_on_unlock ⇒ Object
Rotate this secret after it is unlocked.
-
#session_token ⇒ Object
Required only for temporary security credentials retrieved using STS.
-
#token ⇒ Object
Authentication token (see
/authand/configure). -
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#update_version ⇒ Object
Deprecated.
-
#use_gw_cloud_identity ⇒ Object
Use the GW's Cloud IAM.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAWSTarget
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAWSTarget
Initializes the object
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/akeyless/models/update_aws_target.rb', line 149 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::UpdateAWSTarget` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::UpdateAWSTarget`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'access_key') self.access_key = attributes[:'access_key'] else self.access_key = nil end if attributes.key?(:'access_key_id') self.access_key_id = attributes[:'access_key_id'] else self.access_key_id = nil end if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'generate_external_id') self.generate_external_id = attributes[:'generate_external_id'] end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'keep_prev_version') self.keep_prev_version = attributes[:'keep_prev_version'] end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'lock_on_read') self.lock_on_read = attributes[:'lock_on_read'] end if attributes.key?(:'lock_ttl') self.lock_ttl = attributes[:'lock_ttl'] end if attributes.key?(:'max_versions') self.max_versions = attributes[:'max_versions'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'new_name') self.new_name = attributes[:'new_name'] end if attributes.key?(:'region') self.region = attributes[:'region'] else self.region = 'us-east-2' end if attributes.key?(:'role_arn') self.role_arn = attributes[:'role_arn'] end if attributes.key?(:'rotate_on_unlock') self.rotate_on_unlock = attributes[:'rotate_on_unlock'] end if attributes.key?(:'session_token') self.session_token = attributes[:'session_token'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'update_version') self.update_version = attributes[:'update_version'] end if attributes.key?(:'use_gw_cloud_identity') self.use_gw_cloud_identity = attributes[:'use_gw_cloud_identity'] end end |
Instance Attribute Details
#access_key ⇒ Object
AWS secret access key
20 21 22 |
# File 'lib/akeyless/models/update_aws_target.rb', line 20 def access_key @access_key end |
#access_key_id ⇒ Object
AWS access key ID
23 24 25 |
# File 'lib/akeyless/models/update_aws_target.rb', line 23 def access_key_id @access_key_id end |
#comment ⇒ Object
Deprecated - use description
26 27 28 |
# File 'lib/akeyless/models/update_aws_target.rb', line 26 def comment @comment end |
#description ⇒ Object
Description of the object
29 30 31 |
# File 'lib/akeyless/models/update_aws_target.rb', line 29 def description @description end |
#generate_external_id ⇒ Object
A unique auto-generated value used in your AWS account when configuring your AWS IAM role to securely delegate access to Akeyless. Relevant only when using GW cloud ID
32 33 34 |
# File 'lib/akeyless/models/update_aws_target.rb', line 32 def generate_external_id @generate_external_id end |
#json ⇒ Object
Set output format to JSON
35 36 37 |
# File 'lib/akeyless/models/update_aws_target.rb', line 35 def json @json end |
#keep_prev_version ⇒ Object
Whether to keep previous version [true/false]. If not set, use default according to account settings
38 39 40 |
# File 'lib/akeyless/models/update_aws_target.rb', line 38 def keep_prev_version @keep_prev_version end |
#key ⇒ Object
The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
41 42 43 |
# File 'lib/akeyless/models/update_aws_target.rb', line 41 def key @key end |
#lock_on_read ⇒ Object
Lock this secret after each successful value read
44 45 46 |
# File 'lib/akeyless/models/update_aws_target.rb', line 44 def lock_on_read @lock_on_read end |
#lock_ttl ⇒ Object
Lock TTL in minutes
47 48 49 |
# File 'lib/akeyless/models/update_aws_target.rb', line 47 def lock_ttl @lock_ttl end |
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
50 51 52 |
# File 'lib/akeyless/models/update_aws_target.rb', line 50 def max_versions @max_versions end |
#name ⇒ Object
Target name
53 54 55 |
# File 'lib/akeyless/models/update_aws_target.rb', line 53 def name @name end |
#new_name ⇒ Object
New target name
56 57 58 |
# File 'lib/akeyless/models/update_aws_target.rb', line 56 def new_name @new_name end |
#region ⇒ Object
AWS region
59 60 61 |
# File 'lib/akeyless/models/update_aws_target.rb', line 59 def region @region end |
#role_arn ⇒ Object
AWS IAM role identifier that Gateway will assume in your AWS account, relevant only when using external ID
62 63 64 |
# File 'lib/akeyless/models/update_aws_target.rb', line 62 def role_arn @role_arn end |
#rotate_on_unlock ⇒ Object
Rotate this secret after it is unlocked
65 66 67 |
# File 'lib/akeyless/models/update_aws_target.rb', line 65 def rotate_on_unlock @rotate_on_unlock end |
#session_token ⇒ Object
Required only for temporary security credentials retrieved using STS
68 69 70 |
# File 'lib/akeyless/models/update_aws_target.rb', line 68 def session_token @session_token end |
#token ⇒ Object
Authentication token (see /auth and /configure)
71 72 73 |
# File 'lib/akeyless/models/update_aws_target.rb', line 71 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
74 75 76 |
# File 'lib/akeyless/models/update_aws_target.rb', line 74 def uid_token @uid_token end |
#update_version ⇒ Object
Deprecated
77 78 79 |
# File 'lib/akeyless/models/update_aws_target.rb', line 77 def update_version @update_version end |
#use_gw_cloud_identity ⇒ Object
Use the GW's Cloud IAM
80 81 82 |
# File 'lib/akeyless/models/update_aws_target.rb', line 80 def use_gw_cloud_identity @use_gw_cloud_identity end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/akeyless/models/update_aws_target.rb', line 354 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
110 111 112 |
# File 'lib/akeyless/models/update_aws_target.rb', line 110 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/akeyless/models/update_aws_target.rb', line 83 def self.attribute_map { :'access_key' => :'access-key', :'access_key_id' => :'access-key-id', :'comment' => :'comment', :'description' => :'description', :'generate_external_id' => :'generate-external-id', :'json' => :'json', :'keep_prev_version' => :'keep-prev-version', :'key' => :'key', :'lock_on_read' => :'lock-on-read', :'lock_ttl' => :'lock-ttl', :'max_versions' => :'max-versions', :'name' => :'name', :'new_name' => :'new-name', :'region' => :'region', :'role_arn' => :'role-arn', :'rotate_on_unlock' => :'rotate-on-unlock', :'session_token' => :'session-token', :'token' => :'token', :'uid_token' => :'uid-token', :'update_version' => :'update-version', :'use_gw_cloud_identity' => :'use-gw-cloud-identity' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/akeyless/models/update_aws_target.rb', line 330 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
142 143 144 145 |
# File 'lib/akeyless/models/update_aws_target.rb', line 142 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/akeyless/models/update_aws_target.rb', line 115 def self.openapi_types { :'access_key' => :'String', :'access_key_id' => :'String', :'comment' => :'String', :'description' => :'String', :'generate_external_id' => :'Boolean', :'json' => :'Boolean', :'keep_prev_version' => :'String', :'key' => :'String', :'lock_on_read' => :'String', :'lock_ttl' => :'String', :'max_versions' => :'String', :'name' => :'String', :'new_name' => :'String', :'region' => :'String', :'role_arn' => :'String', :'rotate_on_unlock' => :'String', :'session_token' => :'String', :'token' => :'String', :'uid_token' => :'String', :'update_version' => :'Boolean', :'use_gw_cloud_identity' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/akeyless/models/update_aws_target.rb', line 289 def ==(o) return true if self.equal?(o) self.class == o.class && access_key == o.access_key && access_key_id == o.access_key_id && comment == o.comment && description == o.description && generate_external_id == o.generate_external_id && json == o.json && keep_prev_version == o.keep_prev_version && key == o.key && lock_on_read == o.lock_on_read && lock_ttl == o.lock_ttl && max_versions == o.max_versions && name == o.name && new_name == o.new_name && region == o.region && role_arn == o.role_arn && rotate_on_unlock == o.rotate_on_unlock && session_token == o.session_token && token == o.token && uid_token == o.uid_token && update_version == o.update_version && use_gw_cloud_identity == o.use_gw_cloud_identity end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/akeyless/models/update_aws_target.rb', line 425 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
317 318 319 |
# File 'lib/akeyless/models/update_aws_target.rb', line 317 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
323 324 325 |
# File 'lib/akeyless/models/update_aws_target.rb', line 323 def hash [access_key, access_key_id, comment, description, generate_external_id, json, keep_prev_version, key, lock_on_read, lock_ttl, max_versions, name, new_name, region, role_arn, rotate_on_unlock, session_token, token, uid_token, update_version, use_gw_cloud_identity].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/akeyless/models/update_aws_target.rb', line 259 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @access_key.nil? invalid_properties.push('invalid value for "access_key", access_key cannot be nil.') end if @access_key_id.nil? invalid_properties.push('invalid value for "access_key_id", access_key_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
401 402 403 |
# File 'lib/akeyless/models/update_aws_target.rb', line 401 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/akeyless/models/update_aws_target.rb', line 407 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
395 396 397 |
# File 'lib/akeyless/models/update_aws_target.rb', line 395 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
279 280 281 282 283 284 285 |
# File 'lib/akeyless/models/update_aws_target.rb', line 279 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @access_key.nil? return false if @access_key_id.nil? return false if @name.nil? true end |