Class: Akeyless::UpdateAuthMethodLDAP

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/update_auth_method_ldap.rb

Overview

updateAuthMethodLDAP is a command that updates a new auth method that will be able to authenticate using LDAP.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateAuthMethodLDAP

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::UpdateAuthMethodLDAP` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::UpdateAuthMethodLDAP`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_expires')
    self.access_expires = attributes[:'access_expires']
  else
    self.access_expires = 0
  end

  if attributes.key?(:'bound_ips')
    if (value = attributes[:'bound_ips']).is_a?(Array)
      self.bound_ips = value
    end
  end

  if attributes.key?(:'force_sub_claims')
    self.force_sub_claims = attributes[:'force_sub_claims']
  end

  if attributes.key?(:'gw_bound_ips')
    if (value = attributes[:'gw_bound_ips']).is_a?(Array)
      self.gw_bound_ips = value
    end
  end

  if attributes.key?(:'jwt_ttl')
    self.jwt_ttl = attributes[:'jwt_ttl']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'public_key_data')
    self.public_key_data = attributes[:'public_key_data']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'unique_identifier')
    self.unique_identifier = attributes[:'unique_identifier']
  end
end

Instance Attribute Details

#access_expires ⇒ Object

Access expiration date in Unix timestamp (select 0 for access without expiry date)



20
21
22
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 20

def access_expires
  @access_expires
end

#bound_ips ⇒ Object

A CIDR whitelist with the IPs that the access is restricted to



23
24
25
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 23

def bound_ips
  @bound_ips
end

#force_sub_claims ⇒ Object

if true: enforce role-association must include sub claims



26
27
28
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 26

def force_sub_claims
  @force_sub_claims
end

#gw_bound_ips ⇒ Object

A CIDR whitelist with the GW IPs that the access is restricted to



29
30
31
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 29

def gw_bound_ips
  @gw_bound_ips
end

#jwt_ttl ⇒ Object

Jwt TTL



32
33
34
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 32

def jwt_ttl
  @jwt_ttl
end

#name ⇒ Object

Auth Method name



35
36
37
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 35

def name
  @name
end

#new_name ⇒ Object

Auth Method new name



38
39
40
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 38

def new_name
  @new_name
end

#public_key_data ⇒ Object

A public key generated for LDAP authentication method on Akeyless in base64 format [RSA2048]



41
42
43
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 41

def public_key_data
  @public_key_data
end

#token ⇒ Object

Authentication token (see /auth and /configure)



44
45
46
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 44

def token
  @token
end

#uid_token ⇒ Object

The universal identity token, Required only for universal_identity authentication



47
48
49
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 47

def uid_token
  @uid_token
end

#unique_identifier ⇒ Object

A unique identifier (ID) value should be configured for OAuth2, LDAP and SAML authentication method types and is usually a value such as the email, username, or upn for example. Whenever a user logs in with a token, these authentication types issue a "sub claim" that contains details uniquely identifying that user. This sub claim includes a key containing the ID value that you configured, and is used to distinguish between different users from within the same organization.



50
51
52
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 50

def unique_identifier
  @unique_identifier
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 70

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 53

def self.attribute_map
  {
    :'access_expires' => :'access-expires',
    :'bound_ips' => :'bound-ips',
    :'force_sub_claims' => :'force-sub-claims',
    :'gw_bound_ips' => :'gw-bound-ips',
    :'jwt_ttl' => :'jwt-ttl',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'public_key_data' => :'public-key-data',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'unique_identifier' => :'unique-identifier'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



214
215
216
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 214

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



92
93
94
95
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 75

def self.openapi_types
  {
    :'access_expires' => :'Integer',
    :'bound_ips' => :'Array<String>',
    :'force_sub_claims' => :'Boolean',
    :'gw_bound_ips' => :'Array<String>',
    :'jwt_ttl' => :'Integer',
    :'name' => :'String',
    :'new_name' => :'String',
    :'public_key_data' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'unique_identifier' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 183

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_expires == o.access_expires &&
      bound_ips == o.bound_ips &&
      force_sub_claims == o.force_sub_claims &&
      gw_bound_ips == o.gw_bound_ips &&
      jwt_ttl == o.jwt_ttl &&
      name == o.name &&
      new_name == o.new_name &&
      public_key_data == o.public_key_data &&
      token == o.token &&
      uid_token == o.uid_token &&
      unique_identifier == o.unique_identifier
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 245

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 316

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 221

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


201
202
203
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 201

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



207
208
209
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 207

def hash
  [access_expires, bound_ips, force_sub_claims, gw_bound_ips, jwt_ttl, name, new_name, public_key_data, token, uid_token, unique_identifier].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
170
171
172
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 165

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



292
293
294
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 292

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 298

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



286
287
288
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 286

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



176
177
178
179
# File 'lib/akeyless/models/update_auth_method_ldap.rb', line 176

def valid?
  return false if @name.nil?
  true
end