Class: Akeyless::UpdateAzureTarget

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/update_azure_target.rb

Overview

updateAzureTarget is a command that updates an existing target. [Deprecated: Use target-update-azure command]

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateAzureTarget

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/akeyless/models/update_azure_target.rb', line 159

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::UpdateAzureTarget` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::UpdateAzureTarget`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'azure_cloud')
    self.azure_cloud = attributes[:'azure_cloud']
  else
    self.azure_cloud = 'AzureCloud'
  end

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'client_secret')
    self.client_secret = attributes[:'client_secret']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'connection_type')
    self.connection_type = attributes[:'connection_type']
  else
    self.connection_type = 'credentials'
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'keep_prev_version')
    self.keep_prev_version = attributes[:'keep_prev_version']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'lock_on_read')
    self.lock_on_read = attributes[:'lock_on_read']
  end

  if attributes.key?(:'lock_ttl')
    self.lock_ttl = attributes[:'lock_ttl']
  end

  if attributes.key?(:'max_versions')
    self.max_versions = attributes[:'max_versions']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'resource_group_name')
    self.resource_group_name = attributes[:'resource_group_name']
  end

  if attributes.key?(:'resource_name')
    self.resource_name = attributes[:'resource_name']
  end

  if attributes.key?(:'rotate_on_unlock')
    self.rotate_on_unlock = attributes[:'rotate_on_unlock']
  end

  if attributes.key?(:'subscription_id')
    self.subscription_id = attributes[:'subscription_id']
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'update_version')
    self.update_version = attributes[:'update_version']
  end

  if attributes.key?(:'use_gw_cloud_identity')
    self.use_gw_cloud_identity = attributes[:'use_gw_cloud_identity']
  end
end

Instance Attribute Details

#azure_cloudObject

Azure cloud environment to use. Values: AzureCloud (default), AzureUSGovernment, AzureChinaCloud.



20
21
22
# File 'lib/akeyless/models/update_azure_target.rb', line 20

def azure_cloud
  @azure_cloud
end

#client_idObject

Azure client/application id



23
24
25
# File 'lib/akeyless/models/update_azure_target.rb', line 23

def client_id
  @client_id
end

#client_secretObject

Azure client secret



26
27
28
# File 'lib/akeyless/models/update_azure_target.rb', line 26

def client_secret
  @client_secret
end

#commentObject

Deprecated - use description



29
30
31
# File 'lib/akeyless/models/update_azure_target.rb', line 29

def comment
  @comment
end

#connection_typeObject

Type of connection [credentials/cloud-identity]



32
33
34
# File 'lib/akeyless/models/update_azure_target.rb', line 32

def connection_type
  @connection_type
end

#descriptionObject

Description of the object



35
36
37
# File 'lib/akeyless/models/update_azure_target.rb', line 35

def description
  @description
end

#jsonObject

Set output format to JSON



38
39
40
# File 'lib/akeyless/models/update_azure_target.rb', line 38

def json
  @json
end

#keep_prev_versionObject

Whether to keep previous version [true/false]. If not set, use default according to account settings



41
42
43
# File 'lib/akeyless/models/update_azure_target.rb', line 41

def keep_prev_version
  @keep_prev_version
end

#keyObject

The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)



44
45
46
# File 'lib/akeyless/models/update_azure_target.rb', line 44

def key
  @key
end

#lock_on_readObject

Lock this secret after each successful value read



47
48
49
# File 'lib/akeyless/models/update_azure_target.rb', line 47

def lock_on_read
  @lock_on_read
end

#lock_ttlObject

Lock TTL in minutes



50
51
52
# File 'lib/akeyless/models/update_azure_target.rb', line 50

def lock_ttl
  @lock_ttl
end

#max_versionsObject

Set the maximum number of versions, limited by the account settings defaults.



53
54
55
# File 'lib/akeyless/models/update_azure_target.rb', line 53

def max_versions
  @max_versions
end

#nameObject

Target name



56
57
58
# File 'lib/akeyless/models/update_azure_target.rb', line 56

def name
  @name
end

#new_nameObject

New target name



59
60
61
# File 'lib/akeyless/models/update_azure_target.rb', line 59

def new_name
  @new_name
end

#resource_group_nameObject

The Resource Group name in your Azure subscription



62
63
64
# File 'lib/akeyless/models/update_azure_target.rb', line 62

def resource_group_name
  @resource_group_name
end

#resource_nameObject

The name of the relevant Resource



65
66
67
# File 'lib/akeyless/models/update_azure_target.rb', line 65

def resource_name
  @resource_name
end

#rotate_on_unlockObject

Rotate this secret after it is unlocked



68
69
70
# File 'lib/akeyless/models/update_azure_target.rb', line 68

def rotate_on_unlock
  @rotate_on_unlock
end

#subscription_idObject

Azure Subscription Id



71
72
73
# File 'lib/akeyless/models/update_azure_target.rb', line 71

def subscription_id
  @subscription_id
end

#tenant_idObject

Azure tenant id



74
75
76
# File 'lib/akeyless/models/update_azure_target.rb', line 74

def tenant_id
  @tenant_id
end

#tokenObject

Authentication token (see /auth and /configure)



77
78
79
# File 'lib/akeyless/models/update_azure_target.rb', line 77

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



80
81
82
# File 'lib/akeyless/models/update_azure_target.rb', line 80

def uid_token
  @uid_token
end

#update_versionObject

Deprecated



83
84
85
# File 'lib/akeyless/models/update_azure_target.rb', line 83

def update_version
  @update_version
end

#use_gw_cloud_identityObject

Use the GW's Cloud IAM [Deprecated: Use connection-type=cloud-identity]



86
87
88
# File 'lib/akeyless/models/update_azure_target.rb', line 86

def use_gw_cloud_identity
  @use_gw_cloud_identity
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/akeyless/models/update_azure_target.rb', line 362

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



118
119
120
# File 'lib/akeyless/models/update_azure_target.rb', line 118

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/akeyless/models/update_azure_target.rb', line 89

def self.attribute_map
  {
    :'azure_cloud' => :'azure-cloud',
    :'client_id' => :'client-id',
    :'client_secret' => :'client-secret',
    :'comment' => :'comment',
    :'connection_type' => :'connection-type',
    :'description' => :'description',
    :'json' => :'json',
    :'keep_prev_version' => :'keep-prev-version',
    :'key' => :'key',
    :'lock_on_read' => :'lock-on-read',
    :'lock_ttl' => :'lock-ttl',
    :'max_versions' => :'max-versions',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'resource_group_name' => :'resource-group-name',
    :'resource_name' => :'resource-name',
    :'rotate_on_unlock' => :'rotate-on-unlock',
    :'subscription_id' => :'subscription-id',
    :'tenant_id' => :'tenant-id',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'update_version' => :'update-version',
    :'use_gw_cloud_identity' => :'use-gw-cloud-identity'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/akeyless/models/update_azure_target.rb', line 338

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



152
153
154
155
# File 'lib/akeyless/models/update_azure_target.rb', line 152

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/akeyless/models/update_azure_target.rb', line 123

def self.openapi_types
  {
    :'azure_cloud' => :'String',
    :'client_id' => :'String',
    :'client_secret' => :'String',
    :'comment' => :'String',
    :'connection_type' => :'String',
    :'description' => :'String',
    :'json' => :'Boolean',
    :'keep_prev_version' => :'String',
    :'key' => :'String',
    :'lock_on_read' => :'String',
    :'lock_ttl' => :'String',
    :'max_versions' => :'String',
    :'name' => :'String',
    :'new_name' => :'String',
    :'resource_group_name' => :'String',
    :'resource_name' => :'String',
    :'rotate_on_unlock' => :'String',
    :'subscription_id' => :'String',
    :'tenant_id' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'update_version' => :'Boolean',
    :'use_gw_cloud_identity' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/akeyless/models/update_azure_target.rb', line 295

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      azure_cloud == o.azure_cloud &&
      client_id == o.client_id &&
      client_secret == o.client_secret &&
      comment == o.comment &&
      connection_type == o.connection_type &&
      description == o.description &&
      json == o.json &&
      keep_prev_version == o.keep_prev_version &&
      key == o.key &&
      lock_on_read == o.lock_on_read &&
      lock_ttl == o.lock_ttl &&
      max_versions == o.max_versions &&
      name == o.name &&
      new_name == o.new_name &&
      resource_group_name == o.resource_group_name &&
      resource_name == o.resource_name &&
      rotate_on_unlock == o.rotate_on_unlock &&
      subscription_id == o.subscription_id &&
      tenant_id == o.tenant_id &&
      token == o.token &&
      uid_token == o.uid_token &&
      update_version == o.update_version &&
      use_gw_cloud_identity == o.use_gw_cloud_identity
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/akeyless/models/update_azure_target.rb', line 433

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


325
326
327
# File 'lib/akeyless/models/update_azure_target.rb', line 325

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



331
332
333
# File 'lib/akeyless/models/update_azure_target.rb', line 331

def hash
  [azure_cloud, client_id, client_secret, comment, connection_type, description, json, keep_prev_version, key, lock_on_read, lock_ttl, max_versions, name, new_name, resource_group_name, resource_name, rotate_on_unlock, subscription_id, tenant_id, token, uid_token, update_version, use_gw_cloud_identity].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



275
276
277
278
279
280
281
282
283
# File 'lib/akeyless/models/update_azure_target.rb', line 275

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



409
410
411
# File 'lib/akeyless/models/update_azure_target.rb', line 409

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/akeyless/models/update_azure_target.rb', line 415

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



403
404
405
# File 'lib/akeyless/models/update_azure_target.rb', line 403

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



287
288
289
290
291
# File 'lib/akeyless/models/update_azure_target.rb', line 287

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end