Class: Akeyless::UpdateItem

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/update_item.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/akeyless/models/update_item.rb', line 360

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::UpdateItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::UpdateItem`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'provider_type')
    self.provider_type = attributes[:'provider_type']
  end

  if attributes.key?(:'accessibility')
    self.accessibility = attributes[:'accessibility']
  else
    self.accessibility = 'regular'
  end

  if attributes.key?(:'add_tag')
    if (value = attributes[:'add_tag']).is_a?(Array)
      self.add_tag = value
    end
  end

  if attributes.key?(:'ara_enabled')
    self.ara_enabled = attributes[:'ara_enabled']
  end

  if attributes.key?(:'cert_file_data')
    self.cert_file_data = attributes[:'cert_file_data']
  end

  if attributes.key?(:'certificate_format')
    self.certificate_format = attributes[:'certificate_format']
  end

  if attributes.key?(:'change_event')
    self.change_event = attributes[:'change_event']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = 'default_metadata'
  end

  if attributes.key?(:'enable_agentic_runtime_authority')
    self.enable_agentic_runtime_authority = attributes[:'enable_agentic_runtime_authority']
  end

  if attributes.key?(:'enable_ai_quorum')
    self.enable_ai_quorum = attributes[:'enable_ai_quorum']
  end

  if attributes.key?(:'expiration_event_in')
    if (value = attributes[:'expiration_event_in']).is_a?(Array)
      self.expiration_event_in = value
    end
  end

  if attributes.key?(:'gcp_sm_regions')
    self.gcp_sm_regions = attributes[:'gcp_sm_regions']
  end

  if attributes.key?(:'host_provider')
    self.host_provider = attributes[:'host_provider']
  end

  if attributes.key?(:'input_rule')
    if (value = attributes[:'input_rule']).is_a?(Array)
      self.input_rule = value
    end
  end

  if attributes.key?(:'item_custom_fields')
    if (value = attributes[:'item_custom_fields']).is_a?(Hash)
      self.item_custom_fields = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'lock_during_sra_session')
    self.lock_during_sra_session = attributes[:'lock_during_sra_session']
  end

  if attributes.key?(:'lock_on_read')
    self.lock_on_read = attributes[:'lock_on_read']
  end

  if attributes.key?(:'lock_ttl')
    self.lock_ttl = attributes[:'lock_ttl']
  end

  if attributes.key?(:'max_versions')
    self.max_versions = attributes[:'max_versions']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'new_metadata')
    self. = attributes[:'new_metadata']
  else
    self. = 'default_metadata'
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'output_rule')
    if (value = attributes[:'output_rule']).is_a?(Array)
      self.output_rule = value
    end
  end

  if attributes.key?(:'rm_tag')
    if (value = attributes[:'rm_tag']).is_a?(Array)
      self.rm_tag = value
    end
  end

  if attributes.key?(:'rotate_after_disconnect')
    self.rotate_after_disconnect = attributes[:'rotate_after_disconnect']
  end

  if attributes.key?(:'rotate_on_unlock')
    self.rotate_on_unlock = attributes[:'rotate_on_unlock']
  end

  if attributes.key?(:'secure_access_add_host')
    if (value = attributes[:'secure_access_add_host']).is_a?(Array)
      self.secure_access_add_host = value
    end
  end

  if attributes.key?(:'secure_access_allow_external_user')
    self.secure_access_allow_external_user = attributes[:'secure_access_allow_external_user']
  end

  if attributes.key?(:'secure_access_allow_port_forwading')
    self.secure_access_allow_port_forwading = attributes[:'secure_access_allow_port_forwading']
  end

  if attributes.key?(:'secure_access_api')
    self.secure_access_api = attributes[:'secure_access_api']
  end

  if attributes.key?(:'secure_access_aws_account_id')
    self. = attributes[:'secure_access_aws_account_id']
  end

  if attributes.key?(:'secure_access_aws_native_cli')
    self.secure_access_aws_native_cli = attributes[:'secure_access_aws_native_cli']
  end

  if attributes.key?(:'secure_access_aws_region')
    self.secure_access_aws_region = attributes[:'secure_access_aws_region']
  end

  if attributes.key?(:'secure_access_bastion_api')
    self.secure_access_bastion_api = attributes[:'secure_access_bastion_api']
  end

  if attributes.key?(:'secure_access_bastion_issuer')
    self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer']
  end

  if attributes.key?(:'secure_access_bastion_ssh')
    self.secure_access_bastion_ssh = attributes[:'secure_access_bastion_ssh']
  end

  if attributes.key?(:'secure_access_certificate_issuer')
    self.secure_access_certificate_issuer = attributes[:'secure_access_certificate_issuer']
  end

  if attributes.key?(:'secure_access_cluster_endpoint')
    self.secure_access_cluster_endpoint = attributes[:'secure_access_cluster_endpoint']
  end

  if attributes.key?(:'secure_access_dashboard_url')
    self.secure_access_dashboard_url = attributes[:'secure_access_dashboard_url']
  end

  if attributes.key?(:'secure_access_db_name')
    self.secure_access_db_name = attributes[:'secure_access_db_name']
  end

  if attributes.key?(:'secure_access_db_schema')
    self.secure_access_db_schema = attributes[:'secure_access_db_schema']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_enforce_hosts_restriction')
    self.secure_access_enforce_hosts_restriction = attributes[:'secure_access_enforce_hosts_restriction']
  end

  if attributes.key?(:'secure_access_gateway')
    self.secure_access_gateway = attributes[:'secure_access_gateway']
  end

  if attributes.key?(:'secure_access_host')
    if (value = attributes[:'secure_access_host']).is_a?(Array)
      self.secure_access_host = value
    end
  end

  if attributes.key?(:'secure_access_rd_gateway_server')
    self.secure_access_rd_gateway_server = attributes[:'secure_access_rd_gateway_server']
  end

  if attributes.key?(:'secure_access_rdp_domain')
    self.secure_access_rdp_domain = attributes[:'secure_access_rdp_domain']
  end

  if attributes.key?(:'secure_access_rdp_user')
    self.secure_access_rdp_user = attributes[:'secure_access_rdp_user']
  end

  if attributes.key?(:'secure_access_rm_host')
    if (value = attributes[:'secure_access_rm_host']).is_a?(Array)
      self.secure_access_rm_host = value
    end
  end

  if attributes.key?(:'secure_access_ssh')
    self.secure_access_ssh = attributes[:'secure_access_ssh']
  end

  if attributes.key?(:'secure_access_ssh_creds')
    self.secure_access_ssh_creds = attributes[:'secure_access_ssh_creds']
  end

  if attributes.key?(:'secure_access_ssh_creds_user')
    self.secure_access_ssh_creds_user = attributes[:'secure_access_ssh_creds_user']
  end

  if attributes.key?(:'secure_access_url')
    self.secure_access_url = attributes[:'secure_access_url']
  end

  if attributes.key?(:'secure_access_use_internal_bastion')
    self.secure_access_use_internal_bastion = attributes[:'secure_access_use_internal_bastion']
  end

  if attributes.key?(:'secure_access_use_internal_ssh_access')
    self.secure_access_use_internal_ssh_access = attributes[:'secure_access_use_internal_ssh_access']
  end

  if attributes.key?(:'secure_access_web_browsing')
    self.secure_access_web_browsing = attributes[:'secure_access_web_browsing']
  end

  if attributes.key?(:'secure_access_web_proxy')
    self.secure_access_web_proxy = attributes[:'secure_access_web_proxy']
  end

  if attributes.key?(:'target')
    if (value = attributes[:'target']).is_a?(Array)
      self.target = value
    end
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'usc_tags')
    self.usc_tags = attributes[:'usc_tags']
  end

  if attributes.key?(:'use_tags_as_filter')
    self.use_tags_as_filter = attributes[:'use_tags_as_filter']
  end
end

Instance Attribute Details

#accessibilityObject

for personal password manager



21
22
23
# File 'lib/akeyless/models/update_item.rb', line 21

def accessibility
  @accessibility
end

#add_tagObject

List of the new tags that will be attached to this item



24
25
26
# File 'lib/akeyless/models/update_item.rb', line 24

def add_tag
  @add_tag
end

#ara_enabledObject

Enable or disable Agentic Runtime Authority rule enforcement for this item. When false, user-defined input/output rules are stored but not enforced; the base security validation still runs. AraEnabled is tri-state (nil/true/false), not a plain bool: it self-encodes its wire value (see akl.OptionalBool) so an explicit false survives the curl-proxy relay instead of being dropped like a default-false bool flag.



27
28
29
# File 'lib/akeyless/models/update_item.rb', line 27

def ara_enabled
  @ara_enabled
end

#cert_file_dataObject

PEM Certificate in a Base64 format. Used for updating RSA keys' certificates.



30
31
32
# File 'lib/akeyless/models/update_item.rb', line 30

def cert_file_data
  @cert_file_data
end

#certificate_formatObject

Returns the value of attribute certificate_format.



32
33
34
# File 'lib/akeyless/models/update_item.rb', line 32

def certificate_format
  @certificate_format
end

#change_eventObject

Trigger an event when a secret value changed [true/false] (Relevant only for Static Secret)



35
36
37
# File 'lib/akeyless/models/update_item.rb', line 35

def change_event
  @change_event
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



38
39
40
# File 'lib/akeyless/models/update_item.rb', line 38

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



41
42
43
# File 'lib/akeyless/models/update_item.rb', line 41

def description
  @description
end

#enable_agentic_runtime_authorityObject

EnableAra is the documented spelling of AraEnabled. Both set the same field; --ara-enabled shipped first and stays as an undocumented alias so existing scripts and the Terraform provider keep working.



44
45
46
# File 'lib/akeyless/models/update_item.rb', line 44

def enable_agentic_runtime_authority
  @enable_agentic_runtime_authority
end

#enable_ai_quorumObject

Turns on AI Quorum checks for this item.



47
48
49
# File 'lib/akeyless/models/update_item.rb', line 47

def enable_ai_quorum
  @enable_ai_quorum
end

#expiration_event_inObject

How many days before the expiration of the certificate would you like to be notified.



50
51
52
# File 'lib/akeyless/models/update_item.rb', line 50

def expiration_event_in
  @expiration_event_in
end

#gcp_sm_regionsObject

GCP Secret Manager regions to query for regional secrets (comma-separated, e.g., us-east1,us-west1). Max 12 regions. USC with GCP targets only.



53
54
55
# File 'lib/akeyless/models/update_item.rb', line 53

def gcp_sm_regions
  @gcp_sm_regions
end

#host_providerObject

Host provider type [explicit/target], Default Host provider is explicit, Relevant only for SRA items.



56
57
58
# File 'lib/akeyless/models/update_item.rb', line 56

def host_provider
  @host_provider
end

#input_ruleObject

Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input)



59
60
61
# File 'lib/akeyless/models/update_item.rb', line 59

def input_rule
  @input_rule
end

#item_custom_fieldsObject

Additional custom fields to associate with the item



62
63
64
# File 'lib/akeyless/models/update_item.rb', line 62

def item_custom_fields
  @item_custom_fields
end

#jsonObject

Set output format to JSON



65
66
67
# File 'lib/akeyless/models/update_item.rb', line 65

def json
  @json
end

#lock_during_sra_sessionObject

Lock this secret for read/update while an SRA session is active



68
69
70
# File 'lib/akeyless/models/update_item.rb', line 68

def lock_during_sra_session
  @lock_during_sra_session
end

#lock_on_readObject

Lock this secret after each successful value read



71
72
73
# File 'lib/akeyless/models/update_item.rb', line 71

def lock_on_read
  @lock_on_read
end

#lock_ttlObject

Lock TTL in minutes



74
75
76
# File 'lib/akeyless/models/update_item.rb', line 74

def lock_ttl
  @lock_ttl
end

#max_versionsObject

Set the maximum number of versions, limited by the account settings defaults.



77
78
79
# File 'lib/akeyless/models/update_item.rb', line 77

def max_versions
  @max_versions
end

#nameObject

Current item name



80
81
82
# File 'lib/akeyless/models/update_item.rb', line 80

def name
  @name
end

#new_metadataObject

Deprecated - use description



83
84
85
# File 'lib/akeyless/models/update_item.rb', line 83

def 
  @new_metadata
end

#new_nameObject

New item name



86
87
88
# File 'lib/akeyless/models/update_item.rb', line 86

def new_name
  @new_name
end

#output_ruleObject

Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)



89
90
91
# File 'lib/akeyless/models/update_item.rb', line 89

def output_rule
  @output_rule
end

#provider_typeObject

Returns the value of attribute provider_type.



18
19
20
# File 'lib/akeyless/models/update_item.rb', line 18

def provider_type
  @provider_type
end

#rm_tagObject

List of the existent tags that will be removed from this item



92
93
94
# File 'lib/akeyless/models/update_item.rb', line 92

def rm_tag
  @rm_tag
end

#rotate_after_disconnectObject

StringOrBool accepts JSON strings, booleans, and numbers for backward compatibility with older SDK versions that send boolean values for rotate-after-disconnect.



95
96
97
# File 'lib/akeyless/models/update_item.rb', line 95

def rotate_after_disconnect
  @rotate_after_disconnect
end

#rotate_on_unlockObject

Rotate this secret after it is unlocked



98
99
100
# File 'lib/akeyless/models/update_item.rb', line 98

def rotate_on_unlock
  @rotate_on_unlock
end

#secure_access_add_hostObject

List of the new hosts that will be attached to SRA servers host



101
102
103
# File 'lib/akeyless/models/update_item.rb', line 101

def secure_access_add_host
  @secure_access_add_host
end

#secure_access_allow_external_userObject

Allow providing external user for a domain users [true/false]



104
105
106
# File 'lib/akeyless/models/update_item.rb', line 104

def secure_access_allow_external_user
  @secure_access_allow_external_user
end

#secure_access_allow_port_forwadingObject

Enable Port forwarding while using CLI access (relevant only for EKS/GKE/K8s Dynamic-Secret)



107
108
109
# File 'lib/akeyless/models/update_item.rb', line 107

def secure_access_allow_port_forwading
  @secure_access_allow_port_forwading
end

#secure_access_apiObject

Bastion's SSH control API endpoint. E.g. https://my.sra-server:9900 (relevant only for ssh cert issuer)



110
111
112
# File 'lib/akeyless/models/update_item.rb', line 110

def secure_access_api
  @secure_access_api
end

#secure_access_aws_account_idObject

The AWS account id (relevant only for aws)



113
114
115
# File 'lib/akeyless/models/update_item.rb', line 113

def 
  @secure_access_aws_account_id
end

#secure_access_aws_native_cliObject

The AWS native cli (relevant only for aws)



116
117
118
# File 'lib/akeyless/models/update_item.rb', line 116

def secure_access_aws_native_cli
  @secure_access_aws_native_cli
end

#secure_access_aws_regionObject

The AWS region (relevant only for aws)



119
120
121
# File 'lib/akeyless/models/update_item.rb', line 119

def secure_access_aws_region
  @secure_access_aws_region
end

#secure_access_bastion_apiObject

Deprecated. use secure-access-api



122
123
124
# File 'lib/akeyless/models/update_item.rb', line 122

def secure_access_bastion_api
  @secure_access_bastion_api
end

#secure_access_bastion_issuerObject

Deprecated. use secure-access-certificate-issuer



125
126
127
# File 'lib/akeyless/models/update_item.rb', line 125

def secure_access_bastion_issuer
  @secure_access_bastion_issuer
end

#secure_access_bastion_sshObject

Deprecated. use secure-access-ssh



128
129
130
# File 'lib/akeyless/models/update_item.rb', line 128

def secure_access_bastion_ssh
  @secure_access_bastion_ssh
end

#secure_access_certificate_issuerObject

Path to the SSH Certificate Issuer for your Akeyless Secure Access



131
132
133
# File 'lib/akeyless/models/update_item.rb', line 131

def secure_access_certificate_issuer
  @secure_access_certificate_issuer
end

#secure_access_cluster_endpointObject

The K8s cluster endpoint URL (relevant only for EKS/GKE/K8s Dynamic-Secret)



134
135
136
# File 'lib/akeyless/models/update_item.rb', line 134

def secure_access_cluster_endpoint
  @secure_access_cluster_endpoint
end

#secure_access_dashboard_urlObject

The K8s dashboard url (relevant only for k8s)



137
138
139
# File 'lib/akeyless/models/update_item.rb', line 137

def secure_access_dashboard_url
  @secure_access_dashboard_url
end

#secure_access_db_nameObject

The DB name (relevant only for DB Dynamic-Secret)



140
141
142
# File 'lib/akeyless/models/update_item.rb', line 140

def secure_access_db_name
  @secure_access_db_name
end

#secure_access_db_schemaObject

The DB schema (relevant only for DB Dynamic-Secret)



143
144
145
# File 'lib/akeyless/models/update_item.rb', line 143

def secure_access_db_schema
  @secure_access_db_schema
end

#secure_access_enableObject

Enable/Disable secure remote access [true/false]



146
147
148
# File 'lib/akeyless/models/update_item.rb', line 146

def secure_access_enable
  @secure_access_enable
end

#secure_access_enforce_hosts_restrictionObject

Enforce connections only to allowed SRA hosts



149
150
151
# File 'lib/akeyless/models/update_item.rb', line 149

def secure_access_enforce_hosts_restriction
  @secure_access_enforce_hosts_restriction
end

#secure_access_gatewayObject

Returns the value of attribute secure_access_gateway.



151
152
153
# File 'lib/akeyless/models/update_item.rb', line 151

def secure_access_gateway
  @secure_access_gateway
end

#secure_access_hostObject

Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)



154
155
156
# File 'lib/akeyless/models/update_item.rb', line 154

def secure_access_host
  @secure_access_host
end

#secure_access_rd_gateway_serverObject

RD Gateway server (relevant only for rdp)



157
158
159
# File 'lib/akeyless/models/update_item.rb', line 157

def secure_access_rd_gateway_server
  @secure_access_rd_gateway_server
end

#secure_access_rdp_domainObject

Required when the Dynamic Secret is used for a domain user (relevant only for RDP Dynamic-Secret)



160
161
162
# File 'lib/akeyless/models/update_item.rb', line 160

def secure_access_rdp_domain
  @secure_access_rdp_domain
end

#secure_access_rdp_userObject

Override the RDP Domain username



163
164
165
# File 'lib/akeyless/models/update_item.rb', line 163

def secure_access_rdp_user
  @secure_access_rdp_user
end

#secure_access_rm_hostObject

List of the existent hosts that will be removed from SRA servers host



166
167
168
# File 'lib/akeyless/models/update_item.rb', line 166

def secure_access_rm_host
  @secure_access_rm_host
end

#secure_access_sshObject

Bastion's SSH server. E.g. my.sra-server:22 (relevant only for ssh cert issuer)



169
170
171
# File 'lib/akeyless/models/update_item.rb', line 169

def secure_access_ssh
  @secure_access_ssh
end

#secure_access_ssh_credsObject

Secret values contains SSH Credentials, either Private Key or Password [password/private-key] (relevant only for Static-Secret or Rotated-secret)



172
173
174
# File 'lib/akeyless/models/update_item.rb', line 172

def secure_access_ssh_creds
  @secure_access_ssh_creds
end

#secure_access_ssh_creds_userObject

SSH username to connect to target server, must be in 'Allowed Users' list (relevant only for ssh cert issuer)



175
176
177
# File 'lib/akeyless/models/update_item.rb', line 175

def secure_access_ssh_creds_user
  @secure_access_ssh_creds_user
end

#secure_access_urlObject

Destination URL to inject secrets



178
179
180
# File 'lib/akeyless/models/update_item.rb', line 178

def secure_access_url
  @secure_access_url
end

#secure_access_use_internal_bastionObject

Deprecated. Use secure-access-use-internal-ssh-access



181
182
183
# File 'lib/akeyless/models/update_item.rb', line 181

def secure_access_use_internal_bastion
  @secure_access_use_internal_bastion
end

#secure_access_use_internal_ssh_accessObject

Use internal SSH Access



184
185
186
# File 'lib/akeyless/models/update_item.rb', line 184

def secure_access_use_internal_ssh_access
  @secure_access_use_internal_ssh_access
end

#secure_access_web_browsingObject

Secure browser via Akeyless's Secure Remote Access (SRA)



187
188
189
# File 'lib/akeyless/models/update_item.rb', line 187

def secure_access_web_browsing
  @secure_access_web_browsing
end

#secure_access_web_proxyObject

Web-Proxy via Akeyless's Secure Remote Access (SRA)



190
191
192
# File 'lib/akeyless/models/update_item.rb', line 190

def secure_access_web_proxy
  @secure_access_web_proxy
end

#targetObject

A list of targets to be associated with an SRA item, To specify multiple targets use argument multiple times



193
194
195
# File 'lib/akeyless/models/update_item.rb', line 193

def target
  @target
end

#tokenObject

Authentication token (see /auth and /configure)



196
197
198
# File 'lib/akeyless/models/update_item.rb', line 196

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



199
200
201
# File 'lib/akeyless/models/update_item.rb', line 199

def uid_token
  @uid_token
end

#usc_tagsObject

Comma-separated list of tags to apply to all secrets created/synced on the remote USC USC items only.



202
203
204
# File 'lib/akeyless/models/update_item.rb', line 202

def usc_tags
  @usc_tags
end

#use_tags_as_filterObject

Whether to filter the USC secret list using the specified usc-tags [true/false] USC items only.



205
206
207
# File 'lib/akeyless/models/update_item.rb', line 205

def use_tags_as_filter
  @use_tags_as_filter
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
# File 'lib/akeyless/models/update_item.rb', line 790

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



278
279
280
# File 'lib/akeyless/models/update_item.rb', line 278

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/akeyless/models/update_item.rb', line 208

def self.attribute_map
  {
    :'provider_type' => :'ProviderType',
    :'accessibility' => :'accessibility',
    :'add_tag' => :'add-tag',
    :'ara_enabled' => :'ara-enabled',
    :'cert_file_data' => :'cert-file-data',
    :'certificate_format' => :'certificate-format',
    :'change_event' => :'change-event',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'enable_agentic_runtime_authority' => :'enable-agentic-runtime-authority',
    :'enable_ai_quorum' => :'enable-ai-quorum',
    :'expiration_event_in' => :'expiration-event-in',
    :'gcp_sm_regions' => :'gcp-sm-regions',
    :'host_provider' => :'host-provider',
    :'input_rule' => :'input-rule',
    :'item_custom_fields' => :'item-custom-fields',
    :'json' => :'json',
    :'lock_during_sra_session' => :'lock-during-sra-session',
    :'lock_on_read' => :'lock-on-read',
    :'lock_ttl' => :'lock-ttl',
    :'max_versions' => :'max-versions',
    :'name' => :'name',
    :'new_metadata' => :'new-metadata',
    :'new_name' => :'new-name',
    :'output_rule' => :'output-rule',
    :'rm_tag' => :'rm-tag',
    :'rotate_after_disconnect' => :'rotate-after-disconnect',
    :'rotate_on_unlock' => :'rotate-on-unlock',
    :'secure_access_add_host' => :'secure-access-add-host',
    :'secure_access_allow_external_user' => :'secure-access-allow-external-user',
    :'secure_access_allow_port_forwading' => :'secure-access-allow-port-forwading',
    :'secure_access_api' => :'secure-access-api',
    :'secure_access_aws_account_id' => :'secure-access-aws-account-id',
    :'secure_access_aws_native_cli' => :'secure-access-aws-native-cli',
    :'secure_access_aws_region' => :'secure-access-aws-region',
    :'secure_access_bastion_api' => :'secure-access-bastion-api',
    :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer',
    :'secure_access_bastion_ssh' => :'secure-access-bastion-ssh',
    :'secure_access_certificate_issuer' => :'secure-access-certificate-issuer',
    :'secure_access_cluster_endpoint' => :'secure-access-cluster-endpoint',
    :'secure_access_dashboard_url' => :'secure-access-dashboard-url',
    :'secure_access_db_name' => :'secure-access-db-name',
    :'secure_access_db_schema' => :'secure-access-db-schema',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_enforce_hosts_restriction' => :'secure-access-enforce-hosts-restriction',
    :'secure_access_gateway' => :'secure-access-gateway',
    :'secure_access_host' => :'secure-access-host',
    :'secure_access_rd_gateway_server' => :'secure-access-rd-gateway-server',
    :'secure_access_rdp_domain' => :'secure-access-rdp-domain',
    :'secure_access_rdp_user' => :'secure-access-rdp-user',
    :'secure_access_rm_host' => :'secure-access-rm-host',
    :'secure_access_ssh' => :'secure-access-ssh',
    :'secure_access_ssh_creds' => :'secure-access-ssh-creds',
    :'secure_access_ssh_creds_user' => :'secure-access-ssh-creds-user',
    :'secure_access_url' => :'secure-access-url',
    :'secure_access_use_internal_bastion' => :'secure-access-use-internal-bastion',
    :'secure_access_use_internal_ssh_access' => :'secure-access-use-internal-ssh-access',
    :'secure_access_web_browsing' => :'secure-access-web-browsing',
    :'secure_access_web_proxy' => :'secure-access-web-proxy',
    :'target' => :'target',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'usc_tags' => :'usc-tags',
    :'use_tags_as_filter' => :'use-tags-as-filter'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
# File 'lib/akeyless/models/update_item.rb', line 766

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



353
354
355
356
# File 'lib/akeyless/models/update_item.rb', line 353

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/akeyless/models/update_item.rb', line 283

def self.openapi_types
  {
    :'provider_type' => :'String',
    :'accessibility' => :'String',
    :'add_tag' => :'Array<String>',
    :'ara_enabled' => :'Boolean',
    :'cert_file_data' => :'String',
    :'certificate_format' => :'String',
    :'change_event' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'enable_agentic_runtime_authority' => :'Boolean',
    :'enable_ai_quorum' => :'Boolean',
    :'expiration_event_in' => :'Array<String>',
    :'gcp_sm_regions' => :'String',
    :'host_provider' => :'String',
    :'input_rule' => :'Array<String>',
    :'item_custom_fields' => :'Hash<String, String>',
    :'json' => :'Boolean',
    :'lock_during_sra_session' => :'String',
    :'lock_on_read' => :'String',
    :'lock_ttl' => :'String',
    :'max_versions' => :'String',
    :'name' => :'String',
    :'new_metadata' => :'String',
    :'new_name' => :'String',
    :'output_rule' => :'Array<String>',
    :'rm_tag' => :'Array<String>',
    :'rotate_after_disconnect' => :'String',
    :'rotate_on_unlock' => :'String',
    :'secure_access_add_host' => :'Array<String>',
    :'secure_access_allow_external_user' => :'String',
    :'secure_access_allow_port_forwading' => :'Boolean',
    :'secure_access_api' => :'String',
    :'secure_access_aws_account_id' => :'String',
    :'secure_access_aws_native_cli' => :'Boolean',
    :'secure_access_aws_region' => :'String',
    :'secure_access_bastion_api' => :'String',
    :'secure_access_bastion_issuer' => :'String',
    :'secure_access_bastion_ssh' => :'String',
    :'secure_access_certificate_issuer' => :'String',
    :'secure_access_cluster_endpoint' => :'String',
    :'secure_access_dashboard_url' => :'String',
    :'secure_access_db_name' => :'String',
    :'secure_access_db_schema' => :'String',
    :'secure_access_enable' => :'String',
    :'secure_access_enforce_hosts_restriction' => :'Boolean',
    :'secure_access_gateway' => :'String',
    :'secure_access_host' => :'Array<String>',
    :'secure_access_rd_gateway_server' => :'String',
    :'secure_access_rdp_domain' => :'String',
    :'secure_access_rdp_user' => :'String',
    :'secure_access_rm_host' => :'Array<String>',
    :'secure_access_ssh' => :'String',
    :'secure_access_ssh_creds' => :'String',
    :'secure_access_ssh_creds_user' => :'String',
    :'secure_access_url' => :'String',
    :'secure_access_use_internal_bastion' => :'Boolean',
    :'secure_access_use_internal_ssh_access' => :'Boolean',
    :'secure_access_web_browsing' => :'Boolean',
    :'secure_access_web_proxy' => :'Boolean',
    :'target' => :'Array<String>',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'usc_tags' => :'String',
    :'use_tags_as_filter' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
# File 'lib/akeyless/models/update_item.rb', line 682

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      provider_type == o.provider_type &&
      accessibility == o.accessibility &&
      add_tag == o.add_tag &&
      ara_enabled == o.ara_enabled &&
      cert_file_data == o.cert_file_data &&
      certificate_format == o.certificate_format &&
      change_event == o.change_event &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      enable_agentic_runtime_authority == o.enable_agentic_runtime_authority &&
      enable_ai_quorum == o.enable_ai_quorum &&
      expiration_event_in == o.expiration_event_in &&
      gcp_sm_regions == o.gcp_sm_regions &&
      host_provider == o.host_provider &&
      input_rule == o.input_rule &&
      item_custom_fields == o.item_custom_fields &&
      json == o.json &&
      lock_during_sra_session == o.lock_during_sra_session &&
      lock_on_read == o.lock_on_read &&
      lock_ttl == o.lock_ttl &&
      max_versions == o.max_versions &&
      name == o.name &&
       == o. &&
      new_name == o.new_name &&
      output_rule == o.output_rule &&
      rm_tag == o.rm_tag &&
      rotate_after_disconnect == o.rotate_after_disconnect &&
      rotate_on_unlock == o.rotate_on_unlock &&
      secure_access_add_host == o.secure_access_add_host &&
      secure_access_allow_external_user == o.secure_access_allow_external_user &&
      secure_access_allow_port_forwading == o.secure_access_allow_port_forwading &&
      secure_access_api == o.secure_access_api &&
       == o. &&
      secure_access_aws_native_cli == o.secure_access_aws_native_cli &&
      secure_access_aws_region == o.secure_access_aws_region &&
      secure_access_bastion_api == o.secure_access_bastion_api &&
      secure_access_bastion_issuer == o.secure_access_bastion_issuer &&
      secure_access_bastion_ssh == o.secure_access_bastion_ssh &&
      secure_access_certificate_issuer == o.secure_access_certificate_issuer &&
      secure_access_cluster_endpoint == o.secure_access_cluster_endpoint &&
      secure_access_dashboard_url == o.secure_access_dashboard_url &&
      secure_access_db_name == o.secure_access_db_name &&
      secure_access_db_schema == o.secure_access_db_schema &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_enforce_hosts_restriction == o.secure_access_enforce_hosts_restriction &&
      secure_access_gateway == o.secure_access_gateway &&
      secure_access_host == o.secure_access_host &&
      secure_access_rd_gateway_server == o.secure_access_rd_gateway_server &&
      secure_access_rdp_domain == o.secure_access_rdp_domain &&
      secure_access_rdp_user == o.secure_access_rdp_user &&
      secure_access_rm_host == o.secure_access_rm_host &&
      secure_access_ssh == o.secure_access_ssh &&
      secure_access_ssh_creds == o.secure_access_ssh_creds &&
      secure_access_ssh_creds_user == o.secure_access_ssh_creds_user &&
      secure_access_url == o.secure_access_url &&
      secure_access_use_internal_bastion == o.secure_access_use_internal_bastion &&
      secure_access_use_internal_ssh_access == o.secure_access_use_internal_ssh_access &&
      secure_access_web_browsing == o.secure_access_web_browsing &&
      secure_access_web_proxy == o.secure_access_web_proxy &&
      target == o.target &&
      token == o.token &&
      uid_token == o.uid_token &&
      usc_tags == o.usc_tags &&
      use_tags_as_filter == o.use_tags_as_filter
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



861
862
863
864
865
866
867
868
869
870
871
872
873
# File 'lib/akeyless/models/update_item.rb', line 861

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


753
754
755
# File 'lib/akeyless/models/update_item.rb', line 753

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



759
760
761
# File 'lib/akeyless/models/update_item.rb', line 759

def hash
  [provider_type, accessibility, add_tag, ara_enabled, cert_file_data, certificate_format, change_event, delete_protection, description, enable_agentic_runtime_authority, enable_ai_quorum, expiration_event_in, gcp_sm_regions, host_provider, input_rule, item_custom_fields, json, lock_during_sra_session, lock_on_read, lock_ttl, max_versions, name, , new_name, output_rule, rm_tag, rotate_after_disconnect, rotate_on_unlock, secure_access_add_host, secure_access_allow_external_user, secure_access_allow_port_forwading, secure_access_api, , secure_access_aws_native_cli, secure_access_aws_region, secure_access_bastion_api, secure_access_bastion_issuer, secure_access_bastion_ssh, secure_access_certificate_issuer, secure_access_cluster_endpoint, secure_access_dashboard_url, secure_access_db_name, secure_access_db_schema, secure_access_enable, secure_access_enforce_hosts_restriction, secure_access_gateway, secure_access_host, secure_access_rd_gateway_server, secure_access_rdp_domain, secure_access_rdp_user, secure_access_rm_host, secure_access_ssh, secure_access_ssh_creds, secure_access_ssh_creds_user, secure_access_url, secure_access_use_internal_bastion, secure_access_use_internal_ssh_access, secure_access_web_browsing, secure_access_web_proxy, target, token, uid_token, usc_tags, use_tags_as_filter].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



662
663
664
665
666
667
668
669
670
# File 'lib/akeyless/models/update_item.rb', line 662

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



837
838
839
# File 'lib/akeyless/models/update_item.rb', line 837

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



843
844
845
846
847
848
849
850
851
852
853
854
855
# File 'lib/akeyless/models/update_item.rb', line 843

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



831
832
833
# File 'lib/akeyless/models/update_item.rb', line 831

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



674
675
676
677
678
# File 'lib/akeyless/models/update_item.rb', line 674

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end