Class: Akeyless::UpdateMcpSecretOAuthClientCreds

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateMcpSecretOAuthClientCreds

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 116

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::UpdateMcpSecretOAuthClientCreds` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::UpdateMcpSecretOAuthClientCreds`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'accessibility')
    self.accessibility = attributes[:'accessibility']
  else
    self.accessibility = 'regular'
  end

  if attributes.key?(:'input_rule')
    if (value = attributes[:'input_rule']).is_a?(Array)
      self.input_rule = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'keep_prev_version')
    self.keep_prev_version = attributes[:'keep_prev_version']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'last_version')
    self.last_version = attributes[:'last_version']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'oauth_client_id')
    self.oauth_client_id = attributes[:'oauth_client_id']
  end

  if attributes.key?(:'oauth_client_secret')
    self.oauth_client_secret = attributes[:'oauth_client_secret']
  end

  if attributes.key?(:'oauth_scopes')
    if (value = attributes[:'oauth_scopes']).is_a?(Array)
      self.oauth_scopes = value
    end
  end

  if attributes.key?(:'oauth_token_url')
    self.oauth_token_url = attributes[:'oauth_token_url']
  end

  if attributes.key?(:'output_rule')
    if (value = attributes[:'output_rule']).is_a?(Array)
      self.output_rule = value
    end
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end
end

Instance Attribute Details

#accessibilityObject

for personal password manager



19
20
21
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 19

def accessibility
  @accessibility
end

#input_ruleObject

Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input)



22
23
24
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 22

def input_rule
  @input_rule
end

#jsonObject

Set output format to JSON



25
26
27
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 25

def json
  @json
end

#keep_prev_versionObject

Whether to keep previous version [true/false]. If not set, use default according to account settings



28
29
30
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 28

def keep_prev_version
  @keep_prev_version
end

#keyObject

Returns the value of attribute key.



30
31
32
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 30

def key
  @key
end

#last_versionObject

Returns the value of attribute last_version.



32
33
34
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 32

def last_version
  @last_version
end

#nameObject

Secret name



35
36
37
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 35

def name
  @name
end

#oauth_client_idObject

OAuth client ID



38
39
40
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 38

def oauth_client_id
  @oauth_client_id
end

#oauth_client_secretObject

OAuth client secret



41
42
43
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 41

def oauth_client_secret
  @oauth_client_secret
end

#oauth_scopesObject

OAuth scopes



44
45
46
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 44

def oauth_scopes
  @oauth_scopes
end

#oauth_token_urlObject

OAuth token URL



47
48
49
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 47

def oauth_token_url
  @oauth_token_url
end

#output_ruleObject

Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)



50
51
52
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 50

def output_rule
  @output_rule
end

#tokenObject

Authentication token (see /auth and /configure)



53
54
55
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 53

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



56
57
58
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 56

def uid_token
  @uid_token
end

#urlObject

URL of the service



59
60
61
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 59

def url
  @url
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 283

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 83

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 62

def self.attribute_map
  {
    :'accessibility' => :'accessibility',
    :'input_rule' => :'input-rule',
    :'json' => :'json',
    :'keep_prev_version' => :'keep-prev-version',
    :'key' => :'key',
    :'last_version' => :'last-version',
    :'name' => :'name',
    :'oauth_client_id' => :'oauth-client-id',
    :'oauth_client_secret' => :'oauth-client-secret',
    :'oauth_scopes' => :'oauth-scopes',
    :'oauth_token_url' => :'oauth-token-url',
    :'output_rule' => :'output-rule',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'url' => :'url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 259

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



109
110
111
112
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 109

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 88

def self.openapi_types
  {
    :'accessibility' => :'String',
    :'input_rule' => :'Array<String>',
    :'json' => :'Boolean',
    :'keep_prev_version' => :'String',
    :'key' => :'String',
    :'last_version' => :'Integer',
    :'name' => :'String',
    :'oauth_client_id' => :'String',
    :'oauth_client_secret' => :'String',
    :'oauth_scopes' => :'Array<String>',
    :'oauth_token_url' => :'String',
    :'output_rule' => :'Array<String>',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 224

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      accessibility == o.accessibility &&
      input_rule == o.input_rule &&
      json == o.json &&
      keep_prev_version == o.keep_prev_version &&
      key == o.key &&
      last_version == o.last_version &&
      name == o.name &&
      oauth_client_id == o.oauth_client_id &&
      oauth_client_secret == o.oauth_client_secret &&
      oauth_scopes == o.oauth_scopes &&
      oauth_token_url == o.oauth_token_url &&
      output_rule == o.output_rule &&
      token == o.token &&
      uid_token == o.uid_token &&
      url == o.url
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 354

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


246
247
248
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 246

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



252
253
254
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 252

def hash
  [accessibility, input_rule, json, keep_prev_version, key, last_version, name, oauth_client_id, oauth_client_secret, oauth_scopes, oauth_token_url, output_rule, token, uid_token, url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



204
205
206
207
208
209
210
211
212
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 204

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



330
331
332
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 330

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 336

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



324
325
326
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 324

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



216
217
218
219
220
# File 'lib/akeyless/models/update_mcp_secret_o_auth_client_creds.rb', line 216

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end