Class: Akeyless::UpdateSSHCertIssuer

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/update_ssh_cert_issuer.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateSSHCertIssuer

Initializes the object



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 148

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::UpdateSSHCertIssuer` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::UpdateSSHCertIssuer`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'add_tag')
    if (value = attributes[:'add_tag']).is_a?(Array)
      self.add_tag = value
    end
  end

  if attributes.key?(:'allowed_users')
    self.allowed_users = attributes[:'allowed_users']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'extensions')
    if (value = attributes[:'extensions']).is_a?(Hash)
      self.extensions = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'principals')
    self.principals = attributes[:'principals']
  end

  if attributes.key?(:'rm_tag')
    if (value = attributes[:'rm_tag']).is_a?(Array)
      self.rm_tag = value
    end
  end

  if attributes.key?(:'secure_access_bastion_api')
    self.secure_access_bastion_api = attributes[:'secure_access_bastion_api']
  end

  if attributes.key?(:'secure_access_bastion_ssh')
    self.secure_access_bastion_ssh = attributes[:'secure_access_bastion_ssh']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_host')
    if (value = attributes[:'secure_access_host']).is_a?(Array)
      self.secure_access_host = value
    end
  end

  if attributes.key?(:'secure_access_ssh_creds_user')
    self.secure_access_ssh_creds_user = attributes[:'secure_access_ssh_creds_user']
  end

  if attributes.key?(:'secure_access_use_internal_bastion')
    self.secure_access_use_internal_bastion = attributes[:'secure_access_use_internal_bastion']
  end

  if attributes.key?(:'signer_key_name')
    self.signer_key_name = attributes[:'signer_key_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'ttl')
    self.ttl = attributes[:'ttl']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end
end

Instance Attribute Details

#add_tagObject

List of the new tags that will be attached to this item



19
20
21
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 19

def add_tag
  @add_tag
end

#allowed_usersObject

Users allowed to fetch the certificate, e.g root,ubuntu



22
23
24
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 22

def allowed_users
  @allowed_users
end

#delete_protectionObject

Protection from accidental deletion of this item [true/false]



25
26
27
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 25

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



28
29
30
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 28

def description
  @description
end

#extensionsObject

Signed certificates with extensions, e.g permit-port-forwarding=\"\"



31
32
33
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 31

def extensions
  @extensions
end

#jsonObject

Set output format to JSON



34
35
36
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 34

def json
  @json
end

#metadataObject

Deprecated - use description



37
38
39
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 37

def 
  
end

#nameObject

SSH certificate issuer name



40
41
42
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 40

def name
  @name
end

#new_nameObject

New item name



43
44
45
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 43

def new_name
  @new_name
end

#principalsObject

Signed certificates with principal, e.g example_role1,example_role2



46
47
48
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 46

def principals
  @principals
end

#rm_tagObject

List of the existent tags that will be removed from this item



49
50
51
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 49

def rm_tag
  @rm_tag
end

#secure_access_bastion_apiObject

Bastion's SSH control API endpoint. E.g. https://my.bastion:9900



52
53
54
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 52

def secure_access_bastion_api
  @secure_access_bastion_api
end

#secure_access_bastion_sshObject

Bastion's SSH server. E.g. my.bastion:22



55
56
57
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 55

def secure_access_bastion_ssh
  @secure_access_bastion_ssh
end

#secure_access_enableObject

Enable/Disable secure remote access [true/false]



58
59
60
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 58

def secure_access_enable
  @secure_access_enable
end

#secure_access_hostObject

Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)



61
62
63
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 61

def secure_access_host
  @secure_access_host
end

#secure_access_ssh_creds_userObject

SSH username to connect to target server, must be in 'Allowed Users' list



64
65
66
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 64

def secure_access_ssh_creds_user
  @secure_access_ssh_creds_user
end

#secure_access_use_internal_bastionObject

Use internal SSH Bastion



67
68
69
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 67

def secure_access_use_internal_bastion
  @secure_access_use_internal_bastion
end

#signer_key_nameObject

A key to sign the certificate with



70
71
72
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 70

def signer_key_name
  @signer_key_name
end

#tokenObject

Authentication token (see /auth and /configure)



73
74
75
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 73

def token
  @token
end

#ttlObject

The requested Time To Live for the certificate, in seconds



76
77
78
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 76

def ttl
  @ttl
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



79
80
81
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 79

def uid_token
  @uid_token
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



109
110
111
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 109

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 82

def self.attribute_map
  {
    :'add_tag' => :'add-tag',
    :'allowed_users' => :'allowed-users',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'extensions' => :'extensions',
    :'json' => :'json',
    :'metadata' => :'metadata',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'principals' => :'principals',
    :'rm_tag' => :'rm-tag',
    :'secure_access_bastion_api' => :'secure-access-bastion-api',
    :'secure_access_bastion_ssh' => :'secure-access-bastion-ssh',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_host' => :'secure-access-host',
    :'secure_access_ssh_creds_user' => :'secure-access-ssh-creds-user',
    :'secure_access_use_internal_bastion' => :'secure-access-use-internal-bastion',
    :'signer_key_name' => :'signer-key-name',
    :'token' => :'token',
    :'ttl' => :'ttl',
    :'uid_token' => :'uid-token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



332
333
334
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 332

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



141
142
143
144
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 141

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 114

def self.openapi_types
  {
    :'add_tag' => :'Array<String>',
    :'allowed_users' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'extensions' => :'Hash<String, String>',
    :'json' => :'Boolean',
    :'metadata' => :'String',
    :'name' => :'String',
    :'new_name' => :'String',
    :'principals' => :'String',
    :'rm_tag' => :'Array<String>',
    :'secure_access_bastion_api' => :'String',
    :'secure_access_bastion_ssh' => :'String',
    :'secure_access_enable' => :'String',
    :'secure_access_host' => :'Array<String>',
    :'secure_access_ssh_creds_user' => :'String',
    :'secure_access_use_internal_bastion' => :'Boolean',
    :'signer_key_name' => :'String',
    :'token' => :'String',
    :'ttl' => :'Integer',
    :'uid_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 291

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      add_tag == o.add_tag &&
      allowed_users == o.allowed_users &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      extensions == o.extensions &&
      json == o.json &&
       == o. &&
      name == o.name &&
      new_name == o.new_name &&
      principals == o.principals &&
      rm_tag == o.rm_tag &&
      secure_access_bastion_api == o.secure_access_bastion_api &&
      secure_access_bastion_ssh == o.secure_access_bastion_ssh &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_host == o.secure_access_host &&
      secure_access_ssh_creds_user == o.secure_access_ssh_creds_user &&
      secure_access_use_internal_bastion == o.secure_access_use_internal_bastion &&
      signer_key_name == o.signer_key_name &&
      token == o.token &&
      ttl == o.ttl &&
      uid_token == o.uid_token
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 363

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



434
435
436
437
438
439
440
441
442
443
444
445
446
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 434

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 339

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


319
320
321
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 319

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



325
326
327
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 325

def hash
  [add_tag, allowed_users, delete_protection, description, extensions, json, , name, new_name, principals, rm_tag, secure_access_bastion_api, secure_access_bastion_ssh, secure_access_enable, secure_access_host, secure_access_ssh_creds_user, secure_access_use_internal_bastion, signer_key_name, token, ttl, uid_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 258

def list_invalid_properties
  invalid_properties = Array.new
  if @allowed_users.nil?
    invalid_properties.push('invalid value for "allowed_users", allowed_users cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @signer_key_name.nil?
    invalid_properties.push('invalid value for "signer_key_name", signer_key_name cannot be nil.')
  end

  if @ttl.nil?
    invalid_properties.push('invalid value for "ttl", ttl cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



410
411
412
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 410

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 416

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



404
405
406
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 404

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



281
282
283
284
285
286
287
# File 'lib/akeyless/models/update_ssh_cert_issuer.rb', line 281

def valid?
  return false if @allowed_users.nil?
  return false if @name.nil?
  return false if @signer_key_name.nil?
  return false if @ttl.nil?
  true
end