Class: Akeyless::UpdateSalesforceTarget

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/update_salesforce_target.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateSalesforceTarget

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/akeyless/models/update_salesforce_target.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::UpdateSalesforceTarget` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::UpdateSalesforceTarget`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ca_cert_data')
    self.ca_cert_data = attributes[:'ca_cert_data']
  end

  if attributes.key?(:'ca_cert_name')
    self.ca_cert_name = attributes[:'ca_cert_name']
  end

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'client_secret')
    self.client_secret = attributes[:'client_secret']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'keep_prev_version')
    self.keep_prev_version = attributes[:'keep_prev_version']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'security_token')
    self.security_token = attributes[:'security_token']
  end

  if attributes.key?(:'tenant_url')
    self.tenant_url = attributes[:'tenant_url']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'update_version')
    self.update_version = attributes[:'update_version']
  end
end

Instance Attribute Details

#ca_cert_dataObject

Base64 encoded PEM cert to use when uploading a new key to Salesforce



19
20
21
# File 'lib/akeyless/models/update_salesforce_target.rb', line 19

def ca_cert_data
  @ca_cert_data
end

#ca_cert_nameObject

name of the certificate in Salesforce tenant to use when uploading new key



22
23
24
# File 'lib/akeyless/models/update_salesforce_target.rb', line 22

def ca_cert_name
  @ca_cert_name
end

#client_idObject

Client ID of the oauth2 app to use for connecting to Salesforce



25
26
27
# File 'lib/akeyless/models/update_salesforce_target.rb', line 25

def client_id
  @client_id
end

#client_secretObject

Client secret of the oauth2 app to use for connecting to Salesforce



28
29
30
# File 'lib/akeyless/models/update_salesforce_target.rb', line 28

def client_secret
  @client_secret
end

#commentObject

Comment about the target



31
32
33
# File 'lib/akeyless/models/update_salesforce_target.rb', line 31

def comment
  @comment
end

#emailObject

The email of the user attached to the oauth2 app used for connecting to Salesforce



34
35
36
# File 'lib/akeyless/models/update_salesforce_target.rb', line 34

def email
  @email
end

#keep_prev_versionObject

Returns the value of attribute keep_prev_version.



36
37
38
# File 'lib/akeyless/models/update_salesforce_target.rb', line 36

def keep_prev_version
  @keep_prev_version
end

#keyObject

The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)



39
40
41
# File 'lib/akeyless/models/update_salesforce_target.rb', line 39

def key
  @key
end

#nameObject

Target name



42
43
44
# File 'lib/akeyless/models/update_salesforce_target.rb', line 42

def name
  @name
end

#new_nameObject

New target name



45
46
47
# File 'lib/akeyless/models/update_salesforce_target.rb', line 45

def new_name
  @new_name
end

#passwordObject

The password of the user attached to the oauth2 app used for connecting to Salesforce



48
49
50
# File 'lib/akeyless/models/update_salesforce_target.rb', line 48

def password
  @password
end

#security_tokenObject

The security token of the user attached to the oauth2 app used for connecting to Salesforce



51
52
53
# File 'lib/akeyless/models/update_salesforce_target.rb', line 51

def security_token
  @security_token
end

#tenant_urlObject

Url of the Salesforce tenant



54
55
56
# File 'lib/akeyless/models/update_salesforce_target.rb', line 54

def tenant_url
  @tenant_url
end

#tokenObject

Authentication token (see /auth and /configure)



57
58
59
# File 'lib/akeyless/models/update_salesforce_target.rb', line 57

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



60
61
62
# File 'lib/akeyless/models/update_salesforce_target.rb', line 60

def uid_token
  @uid_token
end

#update_versionObject

Deprecated



63
64
65
# File 'lib/akeyless/models/update_salesforce_target.rb', line 63

def update_version
  @update_version
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/akeyless/models/update_salesforce_target.rb', line 88

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/akeyless/models/update_salesforce_target.rb', line 66

def self.attribute_map
  {
    :'ca_cert_data' => :'ca-cert-data',
    :'ca_cert_name' => :'ca-cert-name',
    :'client_id' => :'client-id',
    :'client_secret' => :'client-secret',
    :'comment' => :'comment',
    :'email' => :'email',
    :'keep_prev_version' => :'keep-prev-version',
    :'key' => :'key',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'password' => :'password',
    :'security_token' => :'security-token',
    :'tenant_url' => :'tenant-url',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'update_version' => :'update-version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



286
287
288
# File 'lib/akeyless/models/update_salesforce_target.rb', line 286

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
# File 'lib/akeyless/models/update_salesforce_target.rb', line 115

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/akeyless/models/update_salesforce_target.rb', line 93

def self.openapi_types
  {
    :'ca_cert_data' => :'String',
    :'ca_cert_name' => :'String',
    :'client_id' => :'String',
    :'client_secret' => :'String',
    :'comment' => :'String',
    :'email' => :'String',
    :'keep_prev_version' => :'String',
    :'key' => :'String',
    :'name' => :'String',
    :'new_name' => :'String',
    :'password' => :'String',
    :'security_token' => :'String',
    :'tenant_url' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'update_version' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/akeyless/models/update_salesforce_target.rb', line 250

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ca_cert_data == o.ca_cert_data &&
      ca_cert_name == o.ca_cert_name &&
      client_id == o.client_id &&
      client_secret == o.client_secret &&
      comment == o.comment &&
      email == o.email &&
      keep_prev_version == o.keep_prev_version &&
      key == o.key &&
      name == o.name &&
      new_name == o.new_name &&
      password == o.password &&
      security_token == o.security_token &&
      tenant_url == o.tenant_url &&
      token == o.token &&
      uid_token == o.uid_token &&
      update_version == o.update_version
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/akeyless/models/update_salesforce_target.rb', line 317

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/akeyless/models/update_salesforce_target.rb', line 388

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/akeyless/models/update_salesforce_target.rb', line 293

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


273
274
275
# File 'lib/akeyless/models/update_salesforce_target.rb', line 273

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



279
280
281
# File 'lib/akeyless/models/update_salesforce_target.rb', line 279

def hash
  [ca_cert_data, ca_cert_name, client_id, client_secret, comment, email, keep_prev_version, key, name, new_name, password, security_token, tenant_url, token, uid_token, update_version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/akeyless/models/update_salesforce_target.rb', line 202

def list_invalid_properties
  invalid_properties = Array.new
  if @client_id.nil?
    invalid_properties.push('invalid value for "client_id", client_id cannot be nil.')
  end

  if @client_secret.nil?
    invalid_properties.push('invalid value for "client_secret", client_secret cannot be nil.')
  end

  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @password.nil?
    invalid_properties.push('invalid value for "password", password cannot be nil.')
  end

  if @security_token.nil?
    invalid_properties.push('invalid value for "security_token", security_token cannot be nil.')
  end

  if @tenant_url.nil?
    invalid_properties.push('invalid value for "tenant_url", tenant_url cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



364
365
366
# File 'lib/akeyless/models/update_salesforce_target.rb', line 364

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/akeyless/models/update_salesforce_target.rb', line 370

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



358
359
360
# File 'lib/akeyless/models/update_salesforce_target.rb', line 358

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



237
238
239
240
241
242
243
244
245
246
# File 'lib/akeyless/models/update_salesforce_target.rb', line 237

def valid?
  return false if @client_id.nil?
  return false if @client_secret.nil?
  return false if @email.nil?
  return false if @name.nil?
  return false if @password.nil?
  return false if @security_token.nil?
  return false if @tenant_url.nil?
  true
end