Class: Akeyless::UploadPKCS12
- Inherits:
-
Object
- Object
- Akeyless::UploadPKCS12
- Defined in:
- lib/akeyless/models/upload_pkcs12.rb
Instance Attribute Summary collapse
-
#_in ⇒ Object
PKCS#12 input file (private key and certificate only).
-
#customer_frg_id ⇒ Object
The customer fragment ID that will be used to split the key (if empty, the key will be created independently of a customer fragment).
-
#metadata ⇒ Object
A metadata about the key.
-
#name ⇒ Object
Name of key to be created.
-
#passphrase ⇒ Object
Passphrase to unlock the pkcs#12 bundle.
-
#split_level ⇒ Object
The number of fragments that the item will be split into.
-
#tag ⇒ Object
List of the tags attached to this key.
-
#token ⇒ Object
Authentication token (see
/authand/configure). -
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UploadPKCS12
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UploadPKCS12
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::UploadPKCS12` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::UploadPKCS12`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'customer_frg_id') self.customer_frg_id = attributes[:'customer_frg_id'] end if attributes.key?(:'_in') self._in = attributes[:'_in'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'passphrase') self.passphrase = attributes[:'passphrase'] end if attributes.key?(:'split_level') self.split_level = attributes[:'split_level'] else self.split_level = 2 end if attributes.key?(:'tag') if (value = attributes[:'tag']).is_a?(Array) self.tag = value end end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end end |
Instance Attribute Details
#_in ⇒ Object
PKCS#12 input file (private key and certificate only)
22 23 24 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 22 def _in @_in end |
#customer_frg_id ⇒ Object
The customer fragment ID that will be used to split the key (if empty, the key will be created independently of a customer fragment)
19 20 21 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 19 def customer_frg_id @customer_frg_id end |
#metadata ⇒ Object
A metadata about the key
25 26 27 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 25 def @metadata end |
#name ⇒ Object
Name of key to be created
28 29 30 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 28 def name @name end |
#passphrase ⇒ Object
Passphrase to unlock the pkcs#12 bundle
31 32 33 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 31 def passphrase @passphrase end |
#split_level ⇒ Object
The number of fragments that the item will be split into
34 35 36 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 34 def split_level @split_level end |
#tag ⇒ Object
List of the tags attached to this key
37 38 39 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 37 def tag @tag end |
#token ⇒ Object
Authentication token (see /auth and /configure)
40 41 42 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 40 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
43 44 45 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 43 def uid_token @uid_token end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 61 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 46 def self.attribute_map { :'customer_frg_id' => :'customer-frg-id', :'_in' => :'in', :'metadata' => :'metadata', :'name' => :'name', :'passphrase' => :'passphrase', :'split_level' => :'split-level', :'tag' => :'tag', :'token' => :'token', :'uid_token' => :'uid-token' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 201 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 66 def self.openapi_types { :'customer_frg_id' => :'String', :'_in' => :'String', :'metadata' => :'String', :'name' => :'String', :'passphrase' => :'String', :'split_level' => :'Integer', :'tag' => :'Array<String>', :'token' => :'String', :'uid_token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 172 def ==(o) return true if self.equal?(o) self.class == o.class && customer_frg_id == o.customer_frg_id && _in == o._in && == o. && name == o.name && passphrase == o.passphrase && split_level == o.split_level && tag == o.tag && token == o.token && uid_token == o.uid_token end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 232 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 303 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 208 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
188 189 190 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 188 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 194 def hash [customer_frg_id, _in, , name, passphrase, split_level, tag, token, uid_token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 144 def list_invalid_properties invalid_properties = Array.new if @_in.nil? invalid_properties.push('invalid value for "_in", _in cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @passphrase.nil? invalid_properties.push('invalid value for "passphrase", passphrase cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
279 280 281 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 279 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 285 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
273 274 275 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 273 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
163 164 165 166 167 168 |
# File 'lib/akeyless/models/upload_pkcs12.rb', line 163 def valid? return false if @_in.nil? return false if @name.nil? return false if @passphrase.nil? true end |