Class: Akeyless::UscGet
- Inherits:
-
Object
- Object
- Akeyless::UscGet
- Defined in:
- lib/akeyless/models/usc_get.rb
Overview
uscGet is a command that gets the value and internal details of a secret from a Universal Secrets Connector
Instance Attribute Summary collapse
-
#gcp_project_id ⇒ Object
GCP Project ID (Relevant only for GCP targets).
-
#json ⇒ Object
Set output format to JSON.
-
#namespace ⇒ Object
The namespace (relevant for Hashi vault target).
-
#object_type ⇒ Object
Returns the value of attribute object_type.
-
#secret_id ⇒ Object
The secret id (or name, for AWS, Azure, K8s or Hashi vault targets) to get from the Universal Secrets Connector.
-
#selected_repositories ⇒ Object
GitHub selected repositories.
-
#token ⇒ Object
Authentication token (see
/authand/configure). -
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#usc_name ⇒ Object
Name of the Universal Secrets Connector item.
-
#version_id ⇒ Object
The version id (if not specified, will retrieve the last version).
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UscGet
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UscGet
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/akeyless/models/usc_get.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::UscGet` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::UscGet`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'gcp_project_id') self.gcp_project_id = attributes[:'gcp_project_id'] end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'namespace') self.namespace = attributes[:'namespace'] end if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] end if attributes.key?(:'secret_id') self.secret_id = attributes[:'secret_id'] else self.secret_id = nil end if attributes.key?(:'selected_repositories') self.selected_repositories = attributes[:'selected_repositories'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'usc_name') self.usc_name = attributes[:'usc_name'] else self.usc_name = nil end if attributes.key?(:'version_id') self.version_id = attributes[:'version_id'] end end |
Instance Attribute Details
#gcp_project_id ⇒ Object
GCP Project ID (Relevant only for GCP targets)
20 21 22 |
# File 'lib/akeyless/models/usc_get.rb', line 20 def gcp_project_id @gcp_project_id end |
#json ⇒ Object
Set output format to JSON
23 24 25 |
# File 'lib/akeyless/models/usc_get.rb', line 23 def json @json end |
#namespace ⇒ Object
The namespace (relevant for Hashi vault target)
26 27 28 |
# File 'lib/akeyless/models/usc_get.rb', line 26 def namespace @namespace end |
#object_type ⇒ Object
Returns the value of attribute object_type.
28 29 30 |
# File 'lib/akeyless/models/usc_get.rb', line 28 def object_type @object_type end |
#secret_id ⇒ Object
The secret id (or name, for AWS, Azure, K8s or Hashi vault targets) to get from the Universal Secrets Connector
31 32 33 |
# File 'lib/akeyless/models/usc_get.rb', line 31 def secret_id @secret_id end |
#selected_repositories ⇒ Object
GitHub selected repositories. For repository scope: repo name. For repository-environment scope: repo/env (format: repo-name/env-name). Required when multiple repos/envs configured.
34 35 36 |
# File 'lib/akeyless/models/usc_get.rb', line 34 def selected_repositories @selected_repositories end |
#token ⇒ Object
Authentication token (see /auth and /configure)
37 38 39 |
# File 'lib/akeyless/models/usc_get.rb', line 37 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
40 41 42 |
# File 'lib/akeyless/models/usc_get.rb', line 40 def uid_token @uid_token end |
#usc_name ⇒ Object
Name of the Universal Secrets Connector item
43 44 45 |
# File 'lib/akeyless/models/usc_get.rb', line 43 def usc_name @usc_name end |
#version_id ⇒ Object
The version id (if not specified, will retrieve the last version)
46 47 48 |
# File 'lib/akeyless/models/usc_get.rb', line 46 def version_id @version_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/akeyless/models/usc_get.rb', line 234 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/akeyless/models/usc_get.rb', line 65 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/akeyless/models/usc_get.rb', line 49 def self.attribute_map { :'gcp_project_id' => :'gcp-project-id', :'json' => :'json', :'namespace' => :'namespace', :'object_type' => :'object-type', :'secret_id' => :'secret-id', :'selected_repositories' => :'selected-repositories', :'token' => :'token', :'uid_token' => :'uid-token', :'usc_name' => :'usc-name', :'version_id' => :'version-id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/akeyless/models/usc_get.rb', line 210 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/akeyless/models/usc_get.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/akeyless/models/usc_get.rb', line 70 def self.openapi_types { :'gcp_project_id' => :'String', :'json' => :'Boolean', :'namespace' => :'String', :'object_type' => :'String', :'secret_id' => :'String', :'selected_repositories' => :'String', :'token' => :'String', :'uid_token' => :'String', :'usc_name' => :'String', :'version_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/akeyless/models/usc_get.rb', line 180 def ==(o) return true if self.equal?(o) self.class == o.class && gcp_project_id == o.gcp_project_id && json == o.json && namespace == o.namespace && object_type == o.object_type && secret_id == o.secret_id && selected_repositories == o.selected_repositories && token == o.token && uid_token == o.uid_token && usc_name == o.usc_name && version_id == o.version_id end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/akeyless/models/usc_get.rb', line 305 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
197 198 199 |
# File 'lib/akeyless/models/usc_get.rb', line 197 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/akeyless/models/usc_get.rb', line 203 def hash [gcp_project_id, json, namespace, object_type, secret_id, selected_repositories, token, uid_token, usc_name, version_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/akeyless/models/usc_get.rb', line 155 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @secret_id.nil? invalid_properties.push('invalid value for "secret_id", secret_id cannot be nil.') end if @usc_name.nil? invalid_properties.push('invalid value for "usc_name", usc_name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
281 282 283 |
# File 'lib/akeyless/models/usc_get.rb', line 281 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/akeyless/models/usc_get.rb', line 287 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
275 276 277 |
# File 'lib/akeyless/models/usc_get.rb', line 275 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
171 172 173 174 175 176 |
# File 'lib/akeyless/models/usc_get.rb', line 171 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @secret_id.nil? return false if @usc_name.nil? true end |