Class: Akeyless::UscUpdate

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/usc_update.rb

Overview

uscUpdate is a command that updates a secret in a Universal Secrets Connector

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UscUpdate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/akeyless/models/usc_update.rb', line 123

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::UscUpdate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::UscUpdate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'binary_value')
    self.binary_value = attributes[:'binary_value']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'namespace')
    self.namespace = attributes[:'namespace']
  end

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  end

  if attributes.key?(:'pfx_password')
    self.pfx_password = attributes[:'pfx_password']
  end

  if attributes.key?(:'remote_secret_activation_date')
    self.remote_secret_activation_date = attributes[:'remote_secret_activation_date']
  end

  if attributes.key?(:'remote_secret_expires')
    self.remote_secret_expires = attributes[:'remote_secret_expires']
  end

  if attributes.key?(:'secret_id')
    self.secret_id = attributes[:'secret_id']
  else
    self.secret_id = nil
  end

  if attributes.key?(:'selected_repositories')
    self.selected_repositories = attributes[:'selected_repositories']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Hash)
      self.tags = value
    end
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'usc_encryption_key')
    self.usc_encryption_key = attributes[:'usc_encryption_key']
  end

  if attributes.key?(:'usc_name')
    self.usc_name = attributes[:'usc_name']
  else
    self.usc_name = nil
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  else
    self.value = nil
  end
end

Instance Attribute Details

#binary_valueObject

Use this option if the universal secrets value is a base64 encoded binary



20
21
22
# File 'lib/akeyless/models/usc_update.rb', line 20

def binary_value
  @binary_value
end

#descriptionObject

Description of the universal secrets



23
24
25
# File 'lib/akeyless/models/usc_update.rb', line 23

def description
  @description
end

#jsonObject

Set output format to JSON



26
27
28
# File 'lib/akeyless/models/usc_update.rb', line 26

def json
  @json
end

#namespaceObject

The namespace (relevant for Hashi vault target)



29
30
31
# File 'lib/akeyless/models/usc_update.rb', line 29

def namespace
  @namespace
end

#object_typeObject

Returns the value of attribute object_type.



31
32
33
# File 'lib/akeyless/models/usc_update.rb', line 31

def object_type
  @object_type
end

#pfx_passwordObject

Optional, the passphrase that protects the private key within the pfx certificate (Relevant only for Azure KV certificates)



34
35
36
# File 'lib/akeyless/models/usc_update.rb', line 34

def pfx_password
  @pfx_password
end

#remote_secret_activation_dateObject

Activation date for the secret on the remote endpoint, in UTC format: YYYY-MM-DDTHH:MM:SSZ



37
38
39
# File 'lib/akeyless/models/usc_update.rb', line 37

def remote_secret_activation_date
  @remote_secret_activation_date
end

#remote_secret_expiresObject

Expiration time for the secret on the remote endpoint, in UTC format: YYYY-MM-DDTHH:MM:SSZ



40
41
42
# File 'lib/akeyless/models/usc_update.rb', line 40

def remote_secret_expires
  @remote_secret_expires
end

#secret_idObject

The universal secrets id (or name, for AWS, Azure, K8s or Hashi vault targets) to update



43
44
45
# File 'lib/akeyless/models/usc_update.rb', line 43

def secret_id
  @secret_id
end

#selected_repositoriesObject

GitHub selected repositories (required for GitHub USC when repository-access is ‘selected’ or for repository scope) Comma-separated repository names (e.g., "repo1,repo2")



46
47
48
# File 'lib/akeyless/models/usc_update.rb', line 46

def selected_repositories
  @selected_repositories
end

#tagsObject

Tags for the universal secrets



49
50
51
# File 'lib/akeyless/models/usc_update.rb', line 49

def tags
  @tags
end

#tokenObject

Authentication token (see ‘/auth` and `/configure`)



52
53
54
# File 'lib/akeyless/models/usc_update.rb', line 52

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



55
56
57
# File 'lib/akeyless/models/usc_update.rb', line 55

def uid_token
  @uid_token
end

#usc_encryption_keyObject

Optional, The name of the remote key that used to encrypt the secret value (if empty, the default key will be used)



58
59
60
# File 'lib/akeyless/models/usc_update.rb', line 58

def usc_encryption_key
  @usc_encryption_key
end

#usc_nameObject

Name of the Universal Secrets Connector item



61
62
63
# File 'lib/akeyless/models/usc_update.rb', line 61

def usc_name
  @usc_name
end

#valueObject

Value of the universal secrets item, either text or base64 encoded binary



64
65
66
# File 'lib/akeyless/models/usc_update.rb', line 64

def value
  @value
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/akeyless/models/usc_update.rb', line 303

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/akeyless/models/usc_update.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/akeyless/models/usc_update.rb', line 67

def self.attribute_map
  {
    :'binary_value' => :'binary-value',
    :'description' => :'description',
    :'json' => :'json',
    :'namespace' => :'namespace',
    :'object_type' => :'object-type',
    :'pfx_password' => :'pfx-password',
    :'remote_secret_activation_date' => :'remote-secret-activation-date',
    :'remote_secret_expires' => :'remote-secret-expires',
    :'secret_id' => :'secret-id',
    :'selected_repositories' => :'selected-repositories',
    :'tags' => :'tags',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'usc_encryption_key' => :'usc-encryption-key',
    :'usc_name' => :'usc-name',
    :'value' => :'value'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/akeyless/models/usc_update.rb', line 279

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



116
117
118
119
# File 'lib/akeyless/models/usc_update.rb', line 116

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/akeyless/models/usc_update.rb', line 94

def self.openapi_types
  {
    :'binary_value' => :'Boolean',
    :'description' => :'String',
    :'json' => :'Boolean',
    :'namespace' => :'String',
    :'object_type' => :'String',
    :'pfx_password' => :'String',
    :'remote_secret_activation_date' => :'String',
    :'remote_secret_expires' => :'String',
    :'secret_id' => :'String',
    :'selected_repositories' => :'String',
    :'tags' => :'Hash<String, String>',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'usc_encryption_key' => :'String',
    :'usc_name' => :'String',
    :'value' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/akeyless/models/usc_update.rb', line 243

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      binary_value == o.binary_value &&
      description == o.description &&
      json == o.json &&
      namespace == o.namespace &&
      object_type == o.object_type &&
      pfx_password == o.pfx_password &&
      remote_secret_activation_date == o.remote_secret_activation_date &&
      remote_secret_expires == o.remote_secret_expires &&
      secret_id == o.secret_id &&
      selected_repositories == o.selected_repositories &&
      tags == o.tags &&
      token == o.token &&
      uid_token == o.uid_token &&
      usc_encryption_key == o.usc_encryption_key &&
      usc_name == o.usc_name &&
      value == o.value
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/akeyless/models/usc_update.rb', line 374

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


266
267
268
# File 'lib/akeyless/models/usc_update.rb', line 266

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



272
273
274
# File 'lib/akeyless/models/usc_update.rb', line 272

def hash
  [binary_value, description, json, namespace, object_type, pfx_password, remote_secret_activation_date, remote_secret_expires, secret_id, selected_repositories, tags, token, uid_token, usc_encryption_key, usc_name, value].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/akeyless/models/usc_update.rb', line 213

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @secret_id.nil?
    invalid_properties.push('invalid value for "secret_id", secret_id cannot be nil.')
  end

  if @usc_name.nil?
    invalid_properties.push('invalid value for "usc_name", usc_name cannot be nil.')
  end

  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



350
351
352
# File 'lib/akeyless/models/usc_update.rb', line 350

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/akeyless/models/usc_update.rb', line 356

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



344
345
346
# File 'lib/akeyless/models/usc_update.rb', line 344

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



233
234
235
236
237
238
239
# File 'lib/akeyless/models/usc_update.rb', line 233

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @secret_id.nil?
  return false if @usc_name.nil?
  return false if @value.nil?
  true
end