Class: Akeyless::AccountGeneralSettings
- Inherits:
-
Object
- Object
- Akeyless::AccountGeneralSettings
- Defined in:
- lib/akeyless/models/account_general_settings.rb
Overview
AccountGeneralSettings describes general settings for an account
Instance Attribute Summary collapse
-
#account_default_key_item_id ⇒ Object
AccountDefaultKeyItemID is the item ID of the DFC key item configured as the default protection key.
-
#account_default_key_name ⇒ Object
AccountDefaultKeyName is the name of the DFC key item configured as the default key This is here simply for the response to include the item name in addition to the display ID so the client can properly show this to the user.
-
#data_protection_section ⇒ Object
Returns the value of attribute data_protection_section.
-
#enable_request_for_access ⇒ Object
Returns the value of attribute enable_request_for_access.
-
#invalid_characters ⇒ Object
InvalidCharacters is the invalid characters for items/targets/roles/auths/notifier_forwarder naming convention.
-
#password_policy ⇒ Object
Returns the value of attribute password_policy.
-
#protect_items_by_default ⇒ Object
Returns the value of attribute protect_items_by_default.
-
#sharing_policy ⇒ Object
Returns the value of attribute sharing_policy.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountGeneralSettings
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AccountGeneralSettings
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/akeyless/models/account_general_settings.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::AccountGeneralSettings` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::AccountGeneralSettings`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_default_key_item_id') self.account_default_key_item_id = attributes[:'account_default_key_item_id'] end if attributes.key?(:'account_default_key_name') self.account_default_key_name = attributes[:'account_default_key_name'] end if attributes.key?(:'data_protection_section') self.data_protection_section = attributes[:'data_protection_section'] end if attributes.key?(:'enable_request_for_access') self.enable_request_for_access = attributes[:'enable_request_for_access'] end if attributes.key?(:'invalid_characters') self.invalid_characters = attributes[:'invalid_characters'] end if attributes.key?(:'password_policy') self.password_policy = attributes[:'password_policy'] end if attributes.key?(:'protect_items_by_default') self.protect_items_by_default = attributes[:'protect_items_by_default'] end if attributes.key?(:'sharing_policy') self.sharing_policy = attributes[:'sharing_policy'] end end |
Instance Attribute Details
#account_default_key_item_id ⇒ Object
AccountDefaultKeyItemID is the item ID of the DFC key item configured as the default protection key
20 21 22 |
# File 'lib/akeyless/models/account_general_settings.rb', line 20 def account_default_key_item_id @account_default_key_item_id end |
#account_default_key_name ⇒ Object
AccountDefaultKeyName is the name of the DFC key item configured as the default key This is here simply for the response to include the item name in addition to the display ID so the client can properly show this to the user. It will not be saved to the DB, only the AccountDefaultKeyItemID will.
23 24 25 |
# File 'lib/akeyless/models/account_general_settings.rb', line 23 def account_default_key_name @account_default_key_name end |
#data_protection_section ⇒ Object
Returns the value of attribute data_protection_section.
25 26 27 |
# File 'lib/akeyless/models/account_general_settings.rb', line 25 def data_protection_section @data_protection_section end |
#enable_request_for_access ⇒ Object
Returns the value of attribute enable_request_for_access.
27 28 29 |
# File 'lib/akeyless/models/account_general_settings.rb', line 27 def enable_request_for_access @enable_request_for_access end |
#invalid_characters ⇒ Object
InvalidCharacters is the invalid characters for items/targets/roles/auths/notifier_forwarder naming convention
30 31 32 |
# File 'lib/akeyless/models/account_general_settings.rb', line 30 def invalid_characters @invalid_characters end |
#password_policy ⇒ Object
Returns the value of attribute password_policy.
32 33 34 |
# File 'lib/akeyless/models/account_general_settings.rb', line 32 def password_policy @password_policy end |
#protect_items_by_default ⇒ Object
Returns the value of attribute protect_items_by_default.
34 35 36 |
# File 'lib/akeyless/models/account_general_settings.rb', line 34 def protect_items_by_default @protect_items_by_default end |
#sharing_policy ⇒ Object
Returns the value of attribute sharing_policy.
36 37 38 |
# File 'lib/akeyless/models/account_general_settings.rb', line 36 def sharing_policy @sharing_policy end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/akeyless/models/account_general_settings.rb', line 194 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
53 54 55 |
# File 'lib/akeyless/models/account_general_settings.rb', line 53 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/akeyless/models/account_general_settings.rb', line 39 def self.attribute_map { :'account_default_key_item_id' => :'account_default_key_item_id', :'account_default_key_name' => :'account_default_key_name', :'data_protection_section' => :'data_protection_section', :'enable_request_for_access' => :'enable_request_for_access', :'invalid_characters' => :'invalid_characters', :'password_policy' => :'password_policy', :'protect_items_by_default' => :'protect_items_by_default', :'sharing_policy' => :'sharing_policy' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/akeyless/models/account_general_settings.rb', line 170 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/akeyless/models/account_general_settings.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/akeyless/models/account_general_settings.rb', line 58 def self.openapi_types { :'account_default_key_item_id' => :'Integer', :'account_default_key_name' => :'String', :'data_protection_section' => :'DataProtectionSection', :'enable_request_for_access' => :'Boolean', :'invalid_characters' => :'String', :'password_policy' => :'PasswordPolicyInfo', :'protect_items_by_default' => :'Boolean', :'sharing_policy' => :'SharingPolicyInfo' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/akeyless/models/account_general_settings.rb', line 142 def ==(o) return true if self.equal?(o) self.class == o.class && account_default_key_item_id == o.account_default_key_item_id && account_default_key_name == o.account_default_key_name && data_protection_section == o.data_protection_section && enable_request_for_access == o.enable_request_for_access && invalid_characters == o.invalid_characters && password_policy == o.password_policy && protect_items_by_default == o.protect_items_by_default && sharing_policy == o.sharing_policy end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/akeyless/models/account_general_settings.rb', line 265 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
157 158 159 |
# File 'lib/akeyless/models/account_general_settings.rb', line 157 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
163 164 165 |
# File 'lib/akeyless/models/account_general_settings.rb', line 163 def hash [account_default_key_item_id, account_default_key_name, data_protection_section, enable_request_for_access, invalid_characters, password_policy, protect_items_by_default, sharing_policy].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
127 128 129 130 131 |
# File 'lib/akeyless/models/account_general_settings.rb', line 127 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
241 242 243 |
# File 'lib/akeyless/models/account_general_settings.rb', line 241 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/akeyless/models/account_general_settings.rb', line 247 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
235 236 237 |
# File 'lib/akeyless/models/account_general_settings.rb', line 235 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
135 136 137 138 |
# File 'lib/akeyless/models/account_general_settings.rb', line 135 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |