Class: Akeyless::ActiveDirectoryPayload
- Inherits:
-
Object
- Object
- Akeyless::ActiveDirectoryPayload
- Defined in:
- lib/akeyless/models/active_directory_payload.rb
Instance Attribute Summary collapse
-
#active_directory_target_id ⇒ Object
Returns the value of attribute active_directory_target_id.
-
#ai_certificate_discovery ⇒ Object
Returns the value of attribute ai_certificate_discovery.
-
#auto_rotate ⇒ Object
Returns the value of attribute auto_rotate.
-
#auto_rotate_interval_in_days ⇒ Object
Returns the value of attribute auto_rotate_interval_in_days.
-
#auto_rotate_rotation_hour ⇒ Object
Returns the value of attribute auto_rotate_rotation_hour.
-
#certificates_expiration_events ⇒ Object
Returns the value of attribute certificates_expiration_events.
-
#certificates_path_template ⇒ Object
Returns the value of attribute certificates_path_template.
-
#computer_base_dn ⇒ Object
Returns the value of attribute computer_base_dn.
-
#discover_iis_apps ⇒ Object
Returns the value of attribute discover_iis_apps.
-
#discover_local_users ⇒ Object
Deprecated.
-
#discover_services ⇒ Object
Returns the value of attribute discover_services.
-
#discovery_types ⇒ Object
Returns the value of attribute discovery_types.
-
#domain_name ⇒ Object
Returns the value of attribute domain_name.
-
#domain_server_targets_path_template ⇒ Object
Returns the value of attribute domain_server_targets_path_template.
-
#domain_users_rotated_secrets_path_template ⇒ Object
Returns the value of attribute domain_users_rotated_secrets_path_template.
-
#enable_rdp_sra ⇒ Object
Returns the value of attribute enable_rdp_sra.
-
#local_users_ignore_list ⇒ Object
Returns the value of attribute local_users_ignore_list.
-
#local_users_rotated_secrets_path_template ⇒ Object
Returns the value of attribute local_users_rotated_secrets_path_template.
-
#os_filter ⇒ Object
Returns the value of attribute os_filter.
-
#ssh_port ⇒ Object
Returns the value of attribute ssh_port.
-
#target_format ⇒ Object
Returns the value of attribute target_format.
-
#targets_type ⇒ Object
Returns the value of attribute targets_type.
-
#user_base_dn ⇒ Object
Returns the value of attribute user_base_dn.
-
#user_groups ⇒ Object
Returns the value of attribute user_groups.
-
#winrm_over_http ⇒ Object
Returns the value of attribute winrm_over_http.
-
#winrm_port ⇒ Object
Returns the value of attribute winrm_port.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ActiveDirectoryPayload
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ActiveDirectoryPayload
Initializes the object
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 148 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::ActiveDirectoryPayload` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::ActiveDirectoryPayload`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'active_directory_target_id') self.active_directory_target_id = attributes[:'active_directory_target_id'] end if attributes.key?(:'ai_certificate_discovery') self.ai_certificate_discovery = attributes[:'ai_certificate_discovery'] end if attributes.key?(:'auto_rotate') self.auto_rotate = attributes[:'auto_rotate'] end if attributes.key?(:'auto_rotate_interval_in_days') self.auto_rotate_interval_in_days = attributes[:'auto_rotate_interval_in_days'] end if attributes.key?(:'auto_rotate_rotation_hour') self.auto_rotate_rotation_hour = attributes[:'auto_rotate_rotation_hour'] end if attributes.key?(:'certificates_expiration_events') if (value = attributes[:'certificates_expiration_events']).is_a?(Array) self.certificates_expiration_events = value end end if attributes.key?(:'certificates_path_template') self.certificates_path_template = attributes[:'certificates_path_template'] end if attributes.key?(:'computer_base_dn') self.computer_base_dn = attributes[:'computer_base_dn'] end if attributes.key?(:'discover_iis_apps') self.discover_iis_apps = attributes[:'discover_iis_apps'] end if attributes.key?(:'discover_local_users') self.discover_local_users = attributes[:'discover_local_users'] end if attributes.key?(:'discover_services') self.discover_services = attributes[:'discover_services'] end if attributes.key?(:'discovery_types') if (value = attributes[:'discovery_types']).is_a?(Array) self.discovery_types = value end end if attributes.key?(:'domain_name') self.domain_name = attributes[:'domain_name'] end if attributes.key?(:'domain_server_targets_path_template') self.domain_server_targets_path_template = attributes[:'domain_server_targets_path_template'] end if attributes.key?(:'domain_users_rotated_secrets_path_template') self.domain_users_rotated_secrets_path_template = attributes[:'domain_users_rotated_secrets_path_template'] end if attributes.key?(:'enable_rdp_sra') self.enable_rdp_sra = attributes[:'enable_rdp_sra'] end if attributes.key?(:'local_users_ignore_list') if (value = attributes[:'local_users_ignore_list']).is_a?(Hash) self.local_users_ignore_list = value end end if attributes.key?(:'local_users_rotated_secrets_path_template') self.local_users_rotated_secrets_path_template = attributes[:'local_users_rotated_secrets_path_template'] end if attributes.key?(:'os_filter') self.os_filter = attributes[:'os_filter'] end if attributes.key?(:'ssh_port') self.ssh_port = attributes[:'ssh_port'] end if attributes.key?(:'target_format') self.target_format = attributes[:'target_format'] end if attributes.key?(:'targets_type') self.targets_type = attributes[:'targets_type'] end if attributes.key?(:'user_base_dn') self.user_base_dn = attributes[:'user_base_dn'] end if attributes.key?(:'user_groups') if (value = attributes[:'user_groups']).is_a?(Array) self.user_groups = value end end if attributes.key?(:'winrm_over_http') self.winrm_over_http = attributes[:'winrm_over_http'] end if attributes.key?(:'winrm_port') self.winrm_port = attributes[:'winrm_port'] end end |
Instance Attribute Details
#active_directory_target_id ⇒ Object
Returns the value of attribute active_directory_target_id.
18 19 20 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 18 def active_directory_target_id @active_directory_target_id end |
#ai_certificate_discovery ⇒ Object
Returns the value of attribute ai_certificate_discovery.
20 21 22 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 20 def ai_certificate_discovery @ai_certificate_discovery end |
#auto_rotate ⇒ Object
Returns the value of attribute auto_rotate.
22 23 24 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 22 def auto_rotate @auto_rotate end |
#auto_rotate_interval_in_days ⇒ Object
Returns the value of attribute auto_rotate_interval_in_days.
24 25 26 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 24 def auto_rotate_interval_in_days @auto_rotate_interval_in_days end |
#auto_rotate_rotation_hour ⇒ Object
Returns the value of attribute auto_rotate_rotation_hour.
26 27 28 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 26 def auto_rotate_rotation_hour @auto_rotate_rotation_hour end |
#certificates_expiration_events ⇒ Object
Returns the value of attribute certificates_expiration_events.
28 29 30 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 28 def certificates_expiration_events @certificates_expiration_events end |
#certificates_path_template ⇒ Object
Returns the value of attribute certificates_path_template.
30 31 32 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 30 def certificates_path_template @certificates_path_template end |
#computer_base_dn ⇒ Object
Returns the value of attribute computer_base_dn.
32 33 34 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 32 def computer_base_dn @computer_base_dn end |
#discover_iis_apps ⇒ Object
Returns the value of attribute discover_iis_apps.
34 35 36 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 34 def discover_iis_apps @discover_iis_apps end |
#discover_local_users ⇒ Object
Deprecated
37 38 39 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 37 def discover_local_users @discover_local_users end |
#discover_services ⇒ Object
Returns the value of attribute discover_services.
39 40 41 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 39 def discover_services @discover_services end |
#discovery_types ⇒ Object
Returns the value of attribute discovery_types.
41 42 43 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 41 def discovery_types @discovery_types end |
#domain_name ⇒ Object
Returns the value of attribute domain_name.
43 44 45 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 43 def domain_name @domain_name end |
#domain_server_targets_path_template ⇒ Object
Returns the value of attribute domain_server_targets_path_template.
45 46 47 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 45 def domain_server_targets_path_template @domain_server_targets_path_template end |
#domain_users_rotated_secrets_path_template ⇒ Object
Returns the value of attribute domain_users_rotated_secrets_path_template.
47 48 49 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 47 def domain_users_rotated_secrets_path_template @domain_users_rotated_secrets_path_template end |
#enable_rdp_sra ⇒ Object
Returns the value of attribute enable_rdp_sra.
49 50 51 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 49 def enable_rdp_sra @enable_rdp_sra end |
#local_users_ignore_list ⇒ Object
Returns the value of attribute local_users_ignore_list.
51 52 53 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 51 def local_users_ignore_list @local_users_ignore_list end |
#local_users_rotated_secrets_path_template ⇒ Object
Returns the value of attribute local_users_rotated_secrets_path_template.
53 54 55 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 53 def local_users_rotated_secrets_path_template @local_users_rotated_secrets_path_template end |
#os_filter ⇒ Object
Returns the value of attribute os_filter.
55 56 57 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 55 def os_filter @os_filter end |
#ssh_port ⇒ Object
Returns the value of attribute ssh_port.
57 58 59 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 57 def ssh_port @ssh_port end |
#target_format ⇒ Object
Returns the value of attribute target_format.
59 60 61 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 59 def target_format @target_format end |
#targets_type ⇒ Object
Returns the value of attribute targets_type.
61 62 63 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 61 def targets_type @targets_type end |
#user_base_dn ⇒ Object
Returns the value of attribute user_base_dn.
63 64 65 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 63 def user_base_dn @user_base_dn end |
#user_groups ⇒ Object
Returns the value of attribute user_groups.
65 66 67 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 65 def user_groups @user_groups end |
#winrm_over_http ⇒ Object
Returns the value of attribute winrm_over_http.
67 68 69 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 67 def winrm_over_http @winrm_over_http end |
#winrm_port ⇒ Object
Returns the value of attribute winrm_port.
69 70 71 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 69 def winrm_port @winrm_port end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 361 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
104 105 106 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 104 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 72 def self.attribute_map { :'active_directory_target_id' => :'active_directory_target_id', :'ai_certificate_discovery' => :'ai_certificate_discovery', :'auto_rotate' => :'auto_rotate', :'auto_rotate_interval_in_days' => :'auto_rotate_interval_in_days', :'auto_rotate_rotation_hour' => :'auto_rotate_rotation_hour', :'certificates_expiration_events' => :'certificates_expiration_events', :'certificates_path_template' => :'certificates_path_template', :'computer_base_dn' => :'computer_base_dn', :'discover_iis_apps' => :'discover_iis_apps', :'discover_local_users' => :'discover_local_users', :'discover_services' => :'discover_services', :'discovery_types' => :'discovery_types', :'domain_name' => :'domain_name', :'domain_server_targets_path_template' => :'domain_server_targets_path_template', :'domain_users_rotated_secrets_path_template' => :'domain_users_rotated_secrets_path_template', :'enable_rdp_sra' => :'enable_rdp_sra', :'local_users_ignore_list' => :'local_users_ignore_list', :'local_users_rotated_secrets_path_template' => :'local_users_rotated_secrets_path_template', :'os_filter' => :'os_filter', :'ssh_port' => :'ssh_port', :'target_format' => :'target_format', :'targets_type' => :'targets_type', :'user_base_dn' => :'user_base_dn', :'user_groups' => :'user_groups', :'winrm_over_http' => :'winrm_over_http', :'winrm_port' => :'winrm_port' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 337 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
141 142 143 144 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 141 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 109 def self.openapi_types { :'active_directory_target_id' => :'Integer', :'ai_certificate_discovery' => :'Boolean', :'auto_rotate' => :'Boolean', :'auto_rotate_interval_in_days' => :'Integer', :'auto_rotate_rotation_hour' => :'Integer', :'certificates_expiration_events' => :'Array<CertificateExpirationEvent>', :'certificates_path_template' => :'String', :'computer_base_dn' => :'String', :'discover_iis_apps' => :'Boolean', :'discover_local_users' => :'Boolean', :'discover_services' => :'Boolean', :'discovery_types' => :'Array<String>', :'domain_name' => :'String', :'domain_server_targets_path_template' => :'String', :'domain_users_rotated_secrets_path_template' => :'String', :'enable_rdp_sra' => :'Boolean', :'local_users_ignore_list' => :'Hash<String, Boolean>', :'local_users_rotated_secrets_path_template' => :'String', :'os_filter' => :'String', :'ssh_port' => :'String', :'target_format' => :'String', :'targets_type' => :'String', :'user_base_dn' => :'String', :'user_groups' => :'Array<String>', :'winrm_over_http' => :'Boolean', :'winrm_port' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 291 def ==(o) return true if self.equal?(o) self.class == o.class && active_directory_target_id == o.active_directory_target_id && ai_certificate_discovery == o.ai_certificate_discovery && auto_rotate == o.auto_rotate && auto_rotate_interval_in_days == o.auto_rotate_interval_in_days && auto_rotate_rotation_hour == o.auto_rotate_rotation_hour && certificates_expiration_events == o.certificates_expiration_events && certificates_path_template == o.certificates_path_template && computer_base_dn == o.computer_base_dn && discover_iis_apps == o.discover_iis_apps && discover_local_users == o.discover_local_users && discover_services == o.discover_services && discovery_types == o.discovery_types && domain_name == o.domain_name && domain_server_targets_path_template == o.domain_server_targets_path_template && domain_users_rotated_secrets_path_template == o.domain_users_rotated_secrets_path_template && enable_rdp_sra == o.enable_rdp_sra && local_users_ignore_list == o.local_users_ignore_list && local_users_rotated_secrets_path_template == o.local_users_rotated_secrets_path_template && os_filter == o.os_filter && ssh_port == o.ssh_port && target_format == o.target_format && targets_type == o.targets_type && user_base_dn == o.user_base_dn && user_groups == o.user_groups && winrm_over_http == o.winrm_over_http && winrm_port == o.winrm_port end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
432 433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 432 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
324 325 326 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 324 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
330 331 332 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 330 def hash [active_directory_target_id, ai_certificate_discovery, auto_rotate, auto_rotate_interval_in_days, auto_rotate_rotation_hour, certificates_expiration_events, certificates_path_template, computer_base_dn, discover_iis_apps, discover_local_users, discover_services, discovery_types, domain_name, domain_server_targets_path_template, domain_users_rotated_secrets_path_template, enable_rdp_sra, local_users_ignore_list, local_users_rotated_secrets_path_template, os_filter, ssh_port, target_format, targets_type, user_base_dn, user_groups, winrm_over_http, winrm_port].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
276 277 278 279 280 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 276 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
408 409 410 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 408 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 414 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
402 403 404 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 402 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
284 285 286 287 |
# File 'lib/akeyless/models/active_directory_payload.rb', line 284 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |