Class: Akeyless::ActiveDirectoryPayload

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/active_directory_payload.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ActiveDirectoryPayload

Initializes the object



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/akeyless/models/active_directory_payload.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::ActiveDirectoryPayload` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::ActiveDirectoryPayload`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'active_directory_target_id')
    self.active_directory_target_id = attributes[:'active_directory_target_id']
  end

  if attributes.key?(:'auto_rotate')
    self.auto_rotate = attributes[:'auto_rotate']
  end

  if attributes.key?(:'auto_rotate_interval_in_days')
    self.auto_rotate_interval_in_days = attributes[:'auto_rotate_interval_in_days']
  end

  if attributes.key?(:'auto_rotate_rotation_hour')
    self.auto_rotate_rotation_hour = attributes[:'auto_rotate_rotation_hour']
  end

  if attributes.key?(:'computer_base_dn')
    self.computer_base_dn = attributes[:'computer_base_dn']
  end

  if attributes.key?(:'discover_local_users')
    self.discover_local_users = attributes[:'discover_local_users']
  end

  if attributes.key?(:'domain_name')
    self.domain_name = attributes[:'domain_name']
  end

  if attributes.key?(:'domain_server_targets_path_template')
    self.domain_server_targets_path_template = attributes[:'domain_server_targets_path_template']
  end

  if attributes.key?(:'domain_users_rotated_secrets_path_template')
    self.domain_users_rotated_secrets_path_template = attributes[:'domain_users_rotated_secrets_path_template']
  end

  if attributes.key?(:'enable_rdp_sra')
    self.enable_rdp_sra = attributes[:'enable_rdp_sra']
  end

  if attributes.key?(:'local_users_ignore_list')
    if (value = attributes[:'local_users_ignore_list']).is_a?(Hash)
      self.local_users_ignore_list = value
    end
  end

  if attributes.key?(:'local_users_rotated_secrets_path_template')
    self.local_users_rotated_secrets_path_template = attributes[:'local_users_rotated_secrets_path_template']
  end

  if attributes.key?(:'ssh_port')
    self.ssh_port = attributes[:'ssh_port']
  end

  if attributes.key?(:'targets_type')
    self.targets_type = attributes[:'targets_type']
  end

  if attributes.key?(:'user_base_dn')
    self.user_base_dn = attributes[:'user_base_dn']
  end

  if attributes.key?(:'user_groups')
    if (value = attributes[:'user_groups']).is_a?(Array)
      self.user_groups = value
    end
  end

  if attributes.key?(:'winrm_over_http')
    self.winrm_over_http = attributes[:'winrm_over_http']
  end

  if attributes.key?(:'winrm_port')
    self.winrm_port = attributes[:'winrm_port']
  end
end

Instance Attribute Details

#active_directory_target_idObject

Returns the value of attribute active_directory_target_id.



18
19
20
# File 'lib/akeyless/models/active_directory_payload.rb', line 18

def active_directory_target_id
  @active_directory_target_id
end

#auto_rotateObject

Returns the value of attribute auto_rotate.



20
21
22
# File 'lib/akeyless/models/active_directory_payload.rb', line 20

def auto_rotate
  @auto_rotate
end

#auto_rotate_interval_in_daysObject

Returns the value of attribute auto_rotate_interval_in_days.



22
23
24
# File 'lib/akeyless/models/active_directory_payload.rb', line 22

def auto_rotate_interval_in_days
  @auto_rotate_interval_in_days
end

#auto_rotate_rotation_hourObject

Returns the value of attribute auto_rotate_rotation_hour.



24
25
26
# File 'lib/akeyless/models/active_directory_payload.rb', line 24

def auto_rotate_rotation_hour
  @auto_rotate_rotation_hour
end

#computer_base_dnObject

Returns the value of attribute computer_base_dn.



26
27
28
# File 'lib/akeyless/models/active_directory_payload.rb', line 26

def computer_base_dn
  @computer_base_dn
end

#discover_local_usersObject

Returns the value of attribute discover_local_users.



28
29
30
# File 'lib/akeyless/models/active_directory_payload.rb', line 28

def discover_local_users
  @discover_local_users
end

#domain_nameObject

Returns the value of attribute domain_name.



30
31
32
# File 'lib/akeyless/models/active_directory_payload.rb', line 30

def domain_name
  @domain_name
end

#domain_server_targets_path_templateObject

Returns the value of attribute domain_server_targets_path_template.



32
33
34
# File 'lib/akeyless/models/active_directory_payload.rb', line 32

def domain_server_targets_path_template
  @domain_server_targets_path_template
end

#domain_users_rotated_secrets_path_templateObject

Returns the value of attribute domain_users_rotated_secrets_path_template.



34
35
36
# File 'lib/akeyless/models/active_directory_payload.rb', line 34

def domain_users_rotated_secrets_path_template
  @domain_users_rotated_secrets_path_template
end

#enable_rdp_sraObject

Returns the value of attribute enable_rdp_sra.



36
37
38
# File 'lib/akeyless/models/active_directory_payload.rb', line 36

def enable_rdp_sra
  @enable_rdp_sra
end

#local_users_ignore_listObject

Returns the value of attribute local_users_ignore_list.



38
39
40
# File 'lib/akeyless/models/active_directory_payload.rb', line 38

def local_users_ignore_list
  @local_users_ignore_list
end

#local_users_rotated_secrets_path_templateObject

Returns the value of attribute local_users_rotated_secrets_path_template.



40
41
42
# File 'lib/akeyless/models/active_directory_payload.rb', line 40

def local_users_rotated_secrets_path_template
  @local_users_rotated_secrets_path_template
end

#ssh_portObject

Returns the value of attribute ssh_port.



42
43
44
# File 'lib/akeyless/models/active_directory_payload.rb', line 42

def ssh_port
  @ssh_port
end

#targets_typeObject

Returns the value of attribute targets_type.



44
45
46
# File 'lib/akeyless/models/active_directory_payload.rb', line 44

def targets_type
  @targets_type
end

#user_base_dnObject

Returns the value of attribute user_base_dn.



46
47
48
# File 'lib/akeyless/models/active_directory_payload.rb', line 46

def user_base_dn
  @user_base_dn
end

#user_groupsObject

Returns the value of attribute user_groups.



48
49
50
# File 'lib/akeyless/models/active_directory_payload.rb', line 48

def user_groups
  @user_groups
end

#winrm_over_httpObject

Returns the value of attribute winrm_over_http.



50
51
52
# File 'lib/akeyless/models/active_directory_payload.rb', line 50

def winrm_over_http
  @winrm_over_http
end

#winrm_portObject

Returns the value of attribute winrm_port.



52
53
54
# File 'lib/akeyless/models/active_directory_payload.rb', line 52

def winrm_port
  @winrm_port
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/akeyless/models/active_directory_payload.rb', line 284

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/akeyless/models/active_directory_payload.rb', line 79

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/akeyless/models/active_directory_payload.rb', line 55

def self.attribute_map
  {
    :'active_directory_target_id' => :'active_directory_target_id',
    :'auto_rotate' => :'auto_rotate',
    :'auto_rotate_interval_in_days' => :'auto_rotate_interval_in_days',
    :'auto_rotate_rotation_hour' => :'auto_rotate_rotation_hour',
    :'computer_base_dn' => :'computer_base_dn',
    :'discover_local_users' => :'discover_local_users',
    :'domain_name' => :'domain_name',
    :'domain_server_targets_path_template' => :'domain_server_targets_path_template',
    :'domain_users_rotated_secrets_path_template' => :'domain_users_rotated_secrets_path_template',
    :'enable_rdp_sra' => :'enable_rdp_sra',
    :'local_users_ignore_list' => :'local_users_ignore_list',
    :'local_users_rotated_secrets_path_template' => :'local_users_rotated_secrets_path_template',
    :'ssh_port' => :'ssh_port',
    :'targets_type' => :'targets_type',
    :'user_base_dn' => :'user_base_dn',
    :'user_groups' => :'user_groups',
    :'winrm_over_http' => :'winrm_over_http',
    :'winrm_port' => :'winrm_port'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/akeyless/models/active_directory_payload.rb', line 260

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/akeyless/models/active_directory_payload.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/akeyless/models/active_directory_payload.rb', line 84

def self.openapi_types
  {
    :'active_directory_target_id' => :'Integer',
    :'auto_rotate' => :'Boolean',
    :'auto_rotate_interval_in_days' => :'Integer',
    :'auto_rotate_rotation_hour' => :'Integer',
    :'computer_base_dn' => :'String',
    :'discover_local_users' => :'Boolean',
    :'domain_name' => :'String',
    :'domain_server_targets_path_template' => :'String',
    :'domain_users_rotated_secrets_path_template' => :'String',
    :'enable_rdp_sra' => :'Boolean',
    :'local_users_ignore_list' => :'Hash<String, Boolean>',
    :'local_users_rotated_secrets_path_template' => :'String',
    :'ssh_port' => :'String',
    :'targets_type' => :'String',
    :'user_base_dn' => :'String',
    :'user_groups' => :'Array<String>',
    :'winrm_over_http' => :'Boolean',
    :'winrm_port' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/akeyless/models/active_directory_payload.rb', line 222

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      active_directory_target_id == o.active_directory_target_id &&
      auto_rotate == o.auto_rotate &&
      auto_rotate_interval_in_days == o.auto_rotate_interval_in_days &&
      auto_rotate_rotation_hour == o.auto_rotate_rotation_hour &&
      computer_base_dn == o.computer_base_dn &&
      discover_local_users == o.discover_local_users &&
      domain_name == o.domain_name &&
      domain_server_targets_path_template == o.domain_server_targets_path_template &&
      domain_users_rotated_secrets_path_template == o.domain_users_rotated_secrets_path_template &&
      enable_rdp_sra == o.enable_rdp_sra &&
      local_users_ignore_list == o.local_users_ignore_list &&
      local_users_rotated_secrets_path_template == o.local_users_rotated_secrets_path_template &&
      ssh_port == o.ssh_port &&
      targets_type == o.targets_type &&
      user_base_dn == o.user_base_dn &&
      user_groups == o.user_groups &&
      winrm_over_http == o.winrm_over_http &&
      winrm_port == o.winrm_port
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/akeyless/models/active_directory_payload.rb', line 355

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


247
248
249
# File 'lib/akeyless/models/active_directory_payload.rb', line 247

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



253
254
255
# File 'lib/akeyless/models/active_directory_payload.rb', line 253

def hash
  [active_directory_target_id, auto_rotate, auto_rotate_interval_in_days, auto_rotate_rotation_hour, computer_base_dn, discover_local_users, domain_name, domain_server_targets_path_template, domain_users_rotated_secrets_path_template, enable_rdp_sra, local_users_ignore_list, local_users_rotated_secrets_path_template, ssh_port, targets_type, user_base_dn, user_groups, winrm_over_http, winrm_port].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



207
208
209
210
211
# File 'lib/akeyless/models/active_directory_payload.rb', line 207

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



331
332
333
# File 'lib/akeyless/models/active_directory_payload.rb', line 331

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/akeyless/models/active_directory_payload.rb', line 337

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



325
326
327
# File 'lib/akeyless/models/active_directory_payload.rb', line 325

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



215
216
217
218
# File 'lib/akeyless/models/active_directory_payload.rb', line 215

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end