Class: Akeyless::CreateRotatedSecret
- Inherits:
-
Object
- Object
- Akeyless::CreateRotatedSecret
- Defined in:
- lib/akeyless/models/create_rotated_secret.rb
Instance Attribute Summary collapse
-
#api_id ⇒ Object
Returns the value of attribute api_id.
-
#api_key ⇒ Object
Returns the value of attribute api_key.
-
#application_id ⇒ Object
ApplicationId (used in azure).
-
#authentication_credentials ⇒ Object
Returns the value of attribute authentication_credentials.
-
#auto_rotate ⇒ Object
Whether to automatically rotate every --rotation-interval days, or disable existing automatic rotation.
-
#custom_payload ⇒ Object
Returns the value of attribute custom_payload.
-
#key ⇒ Object
The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used).
-
#metadata ⇒ Object
Metadata about the secret.
-
#name ⇒ Object
Secret name.
-
#rotated_password ⇒ Object
Returns the value of attribute rotated_password.
-
#rotated_username ⇒ Object
Returns the value of attribute rotated_username.
-
#rotation_hour ⇒ Object
Returns the value of attribute rotation_hour.
-
#rotation_interval ⇒ Object
The number of days to wait between every automatic key rotation (1-365).
-
#rotator_creds_type ⇒ Object
Returns the value of attribute rotator_creds_type.
-
#rotator_custom_cmd ⇒ Object
Returns the value of attribute rotator_custom_cmd.
-
#rotator_type ⇒ Object
Rotator Type.
-
#ssh_password ⇒ Object
Deprecated: use RotatedPassword.
-
#ssh_username ⇒ Object
Deprecated: use RotatedUser.
-
#tags ⇒ Object
List of the tags attached to this secret.
-
#target_name ⇒ Object
Target name.
-
#token ⇒ Object
Authentication token (see
/authand/configure). -
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#user_attribute ⇒ Object
User Attribute.
-
#user_dn ⇒ Object
User DN.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateRotatedSecret
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateRotatedSecret
Initializes the object
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 154 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::CreateRotatedSecret` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::CreateRotatedSecret`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'api_id') self.api_id = attributes[:'api_id'] end if attributes.key?(:'api_key') self.api_key = attributes[:'api_key'] end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] end if attributes.key?(:'authentication_credentials') self.authentication_credentials = attributes[:'authentication_credentials'] end if attributes.key?(:'auto_rotate') self.auto_rotate = attributes[:'auto_rotate'] end if attributes.key?(:'custom_payload') self.custom_payload = attributes[:'custom_payload'] end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'rotated_password') self.rotated_password = attributes[:'rotated_password'] end if attributes.key?(:'rotated_username') self.rotated_username = attributes[:'rotated_username'] end if attributes.key?(:'rotation_hour') self.rotation_hour = attributes[:'rotation_hour'] end if attributes.key?(:'rotation_interval') self.rotation_interval = attributes[:'rotation_interval'] end if attributes.key?(:'rotator_creds_type') self.rotator_creds_type = attributes[:'rotator_creds_type'] end if attributes.key?(:'rotator_custom_cmd') self.rotator_custom_cmd = attributes[:'rotator_custom_cmd'] end if attributes.key?(:'rotator_type') self.rotator_type = attributes[:'rotator_type'] end if attributes.key?(:'ssh_password') self.ssh_password = attributes[:'ssh_password'] end if attributes.key?(:'ssh_username') self.ssh_username = attributes[:'ssh_username'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'target_name') self.target_name = attributes[:'target_name'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'user_attribute') self.user_attribute = attributes[:'user_attribute'] end if attributes.key?(:'user_dn') self.user_dn = attributes[:'user_dn'] end end |
Instance Attribute Details
#api_id ⇒ Object
Returns the value of attribute api_id.
18 19 20 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 18 def api_id @api_id end |
#api_key ⇒ Object
Returns the value of attribute api_key.
20 21 22 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 20 def api_key @api_key end |
#application_id ⇒ Object
ApplicationId (used in azure)
23 24 25 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 23 def application_id @application_id end |
#authentication_credentials ⇒ Object
Returns the value of attribute authentication_credentials.
25 26 27 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 25 def authentication_credentials @authentication_credentials end |
#auto_rotate ⇒ Object
Whether to automatically rotate every --rotation-interval days, or disable existing automatic rotation
28 29 30 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 28 def auto_rotate @auto_rotate end |
#custom_payload ⇒ Object
Returns the value of attribute custom_payload.
30 31 32 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 30 def custom_payload @custom_payload end |
#key ⇒ Object
The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)
33 34 35 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 33 def key @key end |
#metadata ⇒ Object
Metadata about the secret
36 37 38 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 36 def @metadata end |
#name ⇒ Object
Secret name
39 40 41 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 39 def name @name end |
#rotated_password ⇒ Object
Returns the value of attribute rotated_password.
41 42 43 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 41 def rotated_password @rotated_password end |
#rotated_username ⇒ Object
Returns the value of attribute rotated_username.
43 44 45 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 43 def rotated_username @rotated_username end |
#rotation_hour ⇒ Object
Returns the value of attribute rotation_hour.
45 46 47 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 45 def rotation_hour @rotation_hour end |
#rotation_interval ⇒ Object
The number of days to wait between every automatic key rotation (1-365)
48 49 50 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 48 def rotation_interval @rotation_interval end |
#rotator_creds_type ⇒ Object
Returns the value of attribute rotator_creds_type.
50 51 52 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 50 def rotator_creds_type @rotator_creds_type end |
#rotator_custom_cmd ⇒ Object
Returns the value of attribute rotator_custom_cmd.
52 53 54 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 52 def rotator_custom_cmd @rotator_custom_cmd end |
#rotator_type ⇒ Object
Rotator Type
55 56 57 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 55 def rotator_type @rotator_type end |
#ssh_password ⇒ Object
Deprecated: use RotatedPassword
58 59 60 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 58 def ssh_password @ssh_password end |
#ssh_username ⇒ Object
Deprecated: use RotatedUser
61 62 63 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 61 def ssh_username @ssh_username end |
#tags ⇒ Object
List of the tags attached to this secret
64 65 66 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 64 def @tags end |
#target_name ⇒ Object
Target name
67 68 69 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 67 def target_name @target_name end |
#token ⇒ Object
Authentication token (see /auth and /configure)
70 71 72 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 70 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
73 74 75 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 73 def uid_token @uid_token end |
#user_attribute ⇒ Object
User Attribute
76 77 78 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 76 def user_attribute @user_attribute end |
#user_dn ⇒ Object
User DN
79 80 81 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 79 def user_dn @user_dn end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
112 113 114 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 112 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 82 def self.attribute_map { :'api_id' => :'api-id', :'api_key' => :'api-key', :'application_id' => :'application-id', :'authentication_credentials' => :'authentication-credentials', :'auto_rotate' => :'auto-rotate', :'custom_payload' => :'custom-payload', :'key' => :'key', :'metadata' => :'metadata', :'name' => :'name', :'rotated_password' => :'rotated-password', :'rotated_username' => :'rotated-username', :'rotation_hour' => :'rotation-hour', :'rotation_interval' => :'rotation-interval', :'rotator_creds_type' => :'rotator-creds-type', :'rotator_custom_cmd' => :'rotator-custom-cmd', :'rotator_type' => :'rotator-type', :'ssh_password' => :'ssh-password', :'ssh_username' => :'ssh-username', :'tags' => :'tags', :'target_name' => :'target-name', :'token' => :'token', :'uid_token' => :'uid-token', :'user_attribute' => :'user-attribute', :'user_dn' => :'user-dn' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
340 341 342 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 340 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
147 148 149 150 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 147 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 117 def self.openapi_types { :'api_id' => :'String', :'api_key' => :'String', :'application_id' => :'String', :'authentication_credentials' => :'String', :'auto_rotate' => :'String', :'custom_payload' => :'String', :'key' => :'String', :'metadata' => :'String', :'name' => :'String', :'rotated_password' => :'String', :'rotated_username' => :'String', :'rotation_hour' => :'Integer', :'rotation_interval' => :'String', :'rotator_creds_type' => :'String', :'rotator_custom_cmd' => :'String', :'rotator_type' => :'String', :'ssh_password' => :'String', :'ssh_username' => :'String', :'tags' => :'Array<String>', :'target_name' => :'String', :'token' => :'String', :'uid_token' => :'String', :'user_attribute' => :'String', :'user_dn' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 296 def ==(o) return true if self.equal?(o) self.class == o.class && api_id == o.api_id && api_key == o.api_key && application_id == o.application_id && authentication_credentials == o.authentication_credentials && auto_rotate == o.auto_rotate && custom_payload == o.custom_payload && key == o.key && == o. && name == o.name && rotated_password == o.rotated_password && rotated_username == o.rotated_username && rotation_hour == o.rotation_hour && rotation_interval == o.rotation_interval && rotator_creds_type == o.rotator_creds_type && rotator_custom_cmd == o.rotator_custom_cmd && rotator_type == o.rotator_type && ssh_password == o.ssh_password && ssh_username == o.ssh_username && == o. && target_name == o.target_name && token == o.token && uid_token == o.uid_token && user_attribute == o.user_attribute && user_dn == o.user_dn end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 371 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
442 443 444 445 446 447 448 449 450 451 452 453 454 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 442 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 347 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
327 328 329 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 327 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
333 334 335 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 333 def hash [api_id, api_key, application_id, authentication_credentials, auto_rotate, custom_payload, key, , name, rotated_password, rotated_username, rotation_hour, rotation_interval, rotator_creds_type, rotator_custom_cmd, rotator_type, ssh_password, ssh_username, , target_name, token, uid_token, user_attribute, user_dn].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 268 def list_invalid_properties invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @rotator_type.nil? invalid_properties.push('invalid value for "rotator_type", rotator_type cannot be nil.') end if @target_name.nil? invalid_properties.push('invalid value for "target_name", target_name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
418 419 420 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 418 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
424 425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 424 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
412 413 414 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 412 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
287 288 289 290 291 292 |
# File 'lib/akeyless/models/create_rotated_secret.rb', line 287 def valid? return false if @name.nil? return false if @rotator_type.nil? return false if @target_name.nil? true end |