Class: Akeyless::CreateSSHTarget

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/create_ssh_target.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateSSHTarget

Initializes the object



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/akeyless/models/create_ssh_target.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::CreateSSHTarget` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::CreateSSHTarget`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'host')
    self.host = attributes[:'host']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'port')
    self.port = attributes[:'port']
  end

  if attributes.key?(:'private_key')
    self.private_key = attributes[:'private_key']
  end

  if attributes.key?(:'private_key_password')
    self.private_key_password = attributes[:'private_key_password']
  end

  if attributes.key?(:'ssh_password')
    self.ssh_password = attributes[:'ssh_password']
  end

  if attributes.key?(:'ssh_username')
    self.ssh_username = attributes[:'ssh_username']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end
end

Instance Attribute Details

#commentObject

Comment about the target



19
20
21
# File 'lib/akeyless/models/create_ssh_target.rb', line 19

def comment
  @comment
end

#hostObject

Returns the value of attribute host.



21
22
23
# File 'lib/akeyless/models/create_ssh_target.rb', line 21

def host
  @host
end

#keyObject

The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)



24
25
26
# File 'lib/akeyless/models/create_ssh_target.rb', line 24

def key
  @key
end

#nameObject

Target name



27
28
29
# File 'lib/akeyless/models/create_ssh_target.rb', line 27

def name
  @name
end

#portObject

Returns the value of attribute port.



29
30
31
# File 'lib/akeyless/models/create_ssh_target.rb', line 29

def port
  @port
end

#private_keyObject

Returns the value of attribute private_key.



31
32
33
# File 'lib/akeyless/models/create_ssh_target.rb', line 31

def private_key
  @private_key
end

#private_key_passwordObject

Returns the value of attribute private_key_password.



33
34
35
# File 'lib/akeyless/models/create_ssh_target.rb', line 33

def private_key_password
  @private_key_password
end

#ssh_passwordObject

Returns the value of attribute ssh_password.



35
36
37
# File 'lib/akeyless/models/create_ssh_target.rb', line 35

def ssh_password
  @ssh_password
end

#ssh_usernameObject

Returns the value of attribute ssh_username.



37
38
39
# File 'lib/akeyless/models/create_ssh_target.rb', line 37

def ssh_username
  @ssh_username
end

#tokenObject

Authentication token (see /auth and /configure)



40
41
42
# File 'lib/akeyless/models/create_ssh_target.rb', line 40

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



43
44
45
# File 'lib/akeyless/models/create_ssh_target.rb', line 43

def uid_token
  @uid_token
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/akeyless/models/create_ssh_target.rb', line 63

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/akeyless/models/create_ssh_target.rb', line 46

def self.attribute_map
  {
    :'comment' => :'comment',
    :'host' => :'host',
    :'key' => :'key',
    :'name' => :'name',
    :'port' => :'port',
    :'private_key' => :'private-key',
    :'private_key_password' => :'private-key-password',
    :'ssh_password' => :'ssh-password',
    :'ssh_username' => :'ssh-username',
    :'token' => :'token',
    :'uid_token' => :'uid-token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



201
202
203
# File 'lib/akeyless/models/create_ssh_target.rb', line 201

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
# File 'lib/akeyless/models/create_ssh_target.rb', line 85

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/akeyless/models/create_ssh_target.rb', line 68

def self.openapi_types
  {
    :'comment' => :'String',
    :'host' => :'String',
    :'key' => :'String',
    :'name' => :'String',
    :'port' => :'String',
    :'private_key' => :'String',
    :'private_key_password' => :'String',
    :'ssh_password' => :'String',
    :'ssh_username' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/akeyless/models/create_ssh_target.rb', line 170

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      comment == o.comment &&
      host == o.host &&
      key == o.key &&
      name == o.name &&
      port == o.port &&
      private_key == o.private_key &&
      private_key_password == o.private_key_password &&
      ssh_password == o.ssh_password &&
      ssh_username == o.ssh_username &&
      token == o.token &&
      uid_token == o.uid_token
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/akeyless/models/create_ssh_target.rb', line 232

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/akeyless/models/create_ssh_target.rb', line 303

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/akeyless/models/create_ssh_target.rb', line 208

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


188
189
190
# File 'lib/akeyless/models/create_ssh_target.rb', line 188

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



194
195
196
# File 'lib/akeyless/models/create_ssh_target.rb', line 194

def hash
  [comment, host, key, name, port, private_key, private_key_password, ssh_password, ssh_username, token, uid_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



152
153
154
155
156
157
158
159
# File 'lib/akeyless/models/create_ssh_target.rb', line 152

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



279
280
281
# File 'lib/akeyless/models/create_ssh_target.rb', line 279

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/akeyless/models/create_ssh_target.rb', line 285

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



273
274
275
# File 'lib/akeyless/models/create_ssh_target.rb', line 273

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



163
164
165
166
# File 'lib/akeyless/models/create_ssh_target.rb', line 163

def valid?
  return false if @name.nil?
  true
end