Class: Akeyless::CreateSecret
- Inherits:
-
Object
- Object
- Akeyless::CreateSecret
- Defined in:
- lib/akeyless/models/create_secret.rb
Instance Attribute Summary collapse
-
#accessibility ⇒ Object
for personal password manager.
-
#ara_enabled ⇒ Object
Enable or disable Agentic Runtime Authority rule enforcement for this item.
-
#change_event ⇒ Object
Trigger an event when a secret value changed [true/false] (Relevant only for Static Secret).
-
#custom_field ⇒ Object
For Password Management use, additional fields.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#description ⇒ Object
Description of the object.
-
#enable_agentic_runtime_authority ⇒ Object
EnableAra is the documented spelling of AraEnabled.
-
#enable_ai_quorum ⇒ Object
Turns on AI Quorum checks for this item.
-
#format ⇒ Object
Secret format [text/json/key-value] (relevant only for type 'generic').
-
#host_provider ⇒ Object
Host provider type [explicit/target], Default Host provider is explicit, Relevant only for SRA items.
-
#inject_url ⇒ Object
For Password Management use, reflect the website context.
-
#input_rule ⇒ Object
Agentic input rule in name=...,rule=...
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#lock_during_sra_session ⇒ Object
Lock this secret for read/update while an SRA session is active.
-
#lock_on_read ⇒ Object
Lock this secret after each successful value read.
-
#lock_ttl ⇒ Object
Lock TTL in minutes.
-
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
-
#metadata ⇒ Object
Deprecated - use description.
-
#multiline_value ⇒ Object
The provided value is a multiline value (separated by '\n').
-
#name ⇒ Object
Secret name.
-
#output_rule ⇒ Object
Agentic output rule in name=...,rule=...
-
#password ⇒ Object
For Password Management use, additional fields.
-
#protection_key ⇒ Object
The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used).
-
#provider_type ⇒ Object
Returns the value of attribute provider_type.
-
#secure_access_bastion_issuer ⇒ Object
Deprecated.
-
#secure_access_certificate_issuer ⇒ Object
Path to the SSH Certificate Issuer for your Akeyless Secure Access.
-
#secure_access_enable ⇒ Object
Enable/Disable secure remote access [true/false].
-
#secure_access_enforce_hosts_restriction ⇒ Object
Enforce connections only to allowed SRA hosts.
-
#secure_access_gateway ⇒ Object
Returns the value of attribute secure_access_gateway.
-
#secure_access_host ⇒ Object
Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers).
-
#secure_access_rdp_user ⇒ Object
Remote Desktop Username.
-
#secure_access_ssh_creds ⇒ Object
Static-Secret values contains SSH Credentials, either Private Key or Password [password/private-key].
-
#secure_access_ssh_user ⇒ Object
Override the SSH username as indicated in SSH Certificate Issuer.
-
#secure_access_url ⇒ Object
Destination URL to inject secrets.
-
#secure_access_web_browsing ⇒ Object
Secure browser via Akeyless's Secure Remote Access (SRA).
-
#secure_access_web_proxy ⇒ Object
Web-Proxy via Akeyless's Secure Remote Access (SRA).
-
#tags ⇒ Object
Add tags attached to this object.
-
#target ⇒ Object
A list of targets to be associated with an SRA item, To specify multiple targets use argument multiple times.
-
#token ⇒ Object
Authentication token (see
/authand/configure). -
#type ⇒ Object
The secret sub type [generic/password].
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#username ⇒ Object
For Password Management use.
-
#value ⇒ Object
The secret value (relevant only for type 'generic').
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSecret
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSecret
Initializes the object
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/akeyless/models/create_secret.rb', line 261 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::CreateSecret` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::CreateSecret`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'provider_type') self.provider_type = attributes[:'provider_type'] end if attributes.key?(:'accessibility') self.accessibility = attributes[:'accessibility'] else self.accessibility = 'regular' end if attributes.key?(:'ara_enabled') self.ara_enabled = attributes[:'ara_enabled'] end if attributes.key?(:'change_event') self.change_event = attributes[:'change_event'] end if attributes.key?(:'custom_field') if (value = attributes[:'custom_field']).is_a?(Hash) self.custom_field = value end end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'enable_agentic_runtime_authority') self. = attributes[:'enable_agentic_runtime_authority'] end if attributes.key?(:'enable_ai_quorum') self.enable_ai_quorum = attributes[:'enable_ai_quorum'] end if attributes.key?(:'format') self.format = attributes[:'format'] else self.format = 'text' end if attributes.key?(:'host_provider') self.host_provider = attributes[:'host_provider'] end if attributes.key?(:'inject_url') if (value = attributes[:'inject_url']).is_a?(Array) self.inject_url = value end end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'lock_during_sra_session') self.lock_during_sra_session = attributes[:'lock_during_sra_session'] end if attributes.key?(:'lock_on_read') self.lock_on_read = attributes[:'lock_on_read'] end if attributes.key?(:'lock_ttl') self.lock_ttl = attributes[:'lock_ttl'] end if attributes.key?(:'max_versions') self.max_versions = attributes[:'max_versions'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'multiline_value') self.multiline_value = attributes[:'multiline_value'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'password') self.password = attributes[:'password'] end if attributes.key?(:'protection_key') self.protection_key = attributes[:'protection_key'] end if attributes.key?(:'secure_access_bastion_issuer') self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer'] end if attributes.key?(:'secure_access_certificate_issuer') self.secure_access_certificate_issuer = attributes[:'secure_access_certificate_issuer'] end if attributes.key?(:'secure_access_enable') self.secure_access_enable = attributes[:'secure_access_enable'] end if attributes.key?(:'secure_access_enforce_hosts_restriction') self.secure_access_enforce_hosts_restriction = attributes[:'secure_access_enforce_hosts_restriction'] end if attributes.key?(:'secure_access_gateway') self.secure_access_gateway = attributes[:'secure_access_gateway'] end if attributes.key?(:'secure_access_host') if (value = attributes[:'secure_access_host']).is_a?(Array) self.secure_access_host = value end end if attributes.key?(:'secure_access_rdp_user') self.secure_access_rdp_user = attributes[:'secure_access_rdp_user'] end if attributes.key?(:'secure_access_ssh_creds') self.secure_access_ssh_creds = attributes[:'secure_access_ssh_creds'] end if attributes.key?(:'secure_access_ssh_user') self.secure_access_ssh_user = attributes[:'secure_access_ssh_user'] end if attributes.key?(:'secure_access_url') self.secure_access_url = attributes[:'secure_access_url'] end if attributes.key?(:'secure_access_web_browsing') self.secure_access_web_browsing = attributes[:'secure_access_web_browsing'] else self.secure_access_web_browsing = false end if attributes.key?(:'secure_access_web_proxy') self.secure_access_web_proxy = attributes[:'secure_access_web_proxy'] else self.secure_access_web_proxy = false end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'target') if (value = attributes[:'target']).is_a?(Array) self.target = value end end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = 'generic' end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = nil end end |
Instance Attribute Details
#accessibility ⇒ Object
for personal password manager
21 22 23 |
# File 'lib/akeyless/models/create_secret.rb', line 21 def accessibility @accessibility end |
#ara_enabled ⇒ Object
Enable or disable Agentic Runtime Authority rule enforcement for this item. When false, user-defined input/output rules are stored but not enforced; the base security validation still runs. AraEnabled is tri-state (nil/true/false), not a plain bool: it self-encodes its wire value (see akl.OptionalBool) so an explicit false survives the curl-proxy relay instead of being dropped like a default-false bool flag.
24 25 26 |
# File 'lib/akeyless/models/create_secret.rb', line 24 def ara_enabled @ara_enabled end |
#change_event ⇒ Object
Trigger an event when a secret value changed [true/false] (Relevant only for Static Secret)
27 28 29 |
# File 'lib/akeyless/models/create_secret.rb', line 27 def change_event @change_event end |
#custom_field ⇒ Object
For Password Management use, additional fields
30 31 32 |
# File 'lib/akeyless/models/create_secret.rb', line 30 def custom_field @custom_field end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
33 34 35 |
# File 'lib/akeyless/models/create_secret.rb', line 33 def delete_protection @delete_protection end |
#description ⇒ Object
Description of the object
36 37 38 |
# File 'lib/akeyless/models/create_secret.rb', line 36 def description @description end |
#enable_agentic_runtime_authority ⇒ Object
EnableAra is the documented spelling of AraEnabled. Both set the same field; --ara-enabled shipped first and stays as an undocumented alias so existing scripts and the Terraform provider keep working.
39 40 41 |
# File 'lib/akeyless/models/create_secret.rb', line 39 def @enable_agentic_runtime_authority end |
#enable_ai_quorum ⇒ Object
Turns on AI Quorum checks for this item.
42 43 44 |
# File 'lib/akeyless/models/create_secret.rb', line 42 def enable_ai_quorum @enable_ai_quorum end |
#format ⇒ Object
Secret format [text/json/key-value] (relevant only for type 'generic')
45 46 47 |
# File 'lib/akeyless/models/create_secret.rb', line 45 def format @format end |
#host_provider ⇒ Object
Host provider type [explicit/target], Default Host provider is explicit, Relevant only for SRA items.
48 49 50 |
# File 'lib/akeyless/models/create_secret.rb', line 48 def host_provider @host_provider end |
#inject_url ⇒ Object
For Password Management use, reflect the website context
51 52 53 |
# File 'lib/akeyless/models/create_secret.rb', line 51 def inject_url @inject_url end |
#input_rule ⇒ Object
Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input)
54 55 56 |
# File 'lib/akeyless/models/create_secret.rb', line 54 def input_rule @input_rule end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
57 58 59 |
# File 'lib/akeyless/models/create_secret.rb', line 57 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
60 61 62 |
# File 'lib/akeyless/models/create_secret.rb', line 60 def json @json end |
#lock_during_sra_session ⇒ Object
Lock this secret for read/update while an SRA session is active
63 64 65 |
# File 'lib/akeyless/models/create_secret.rb', line 63 def lock_during_sra_session @lock_during_sra_session end |
#lock_on_read ⇒ Object
Lock this secret after each successful value read
66 67 68 |
# File 'lib/akeyless/models/create_secret.rb', line 66 def lock_on_read @lock_on_read end |
#lock_ttl ⇒ Object
Lock TTL in minutes
69 70 71 |
# File 'lib/akeyless/models/create_secret.rb', line 69 def lock_ttl @lock_ttl end |
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
72 73 74 |
# File 'lib/akeyless/models/create_secret.rb', line 72 def max_versions @max_versions end |
#metadata ⇒ Object
Deprecated - use description
75 76 77 |
# File 'lib/akeyless/models/create_secret.rb', line 75 def @metadata end |
#multiline_value ⇒ Object
The provided value is a multiline value (separated by '\n')
78 79 80 |
# File 'lib/akeyless/models/create_secret.rb', line 78 def multiline_value @multiline_value end |
#name ⇒ Object
Secret name
81 82 83 |
# File 'lib/akeyless/models/create_secret.rb', line 81 def name @name end |
#output_rule ⇒ Object
Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)
84 85 86 |
# File 'lib/akeyless/models/create_secret.rb', line 84 def output_rule @output_rule end |
#password ⇒ Object
For Password Management use, additional fields
87 88 89 |
# File 'lib/akeyless/models/create_secret.rb', line 87 def password @password end |
#protection_key ⇒ Object
The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)
90 91 92 |
# File 'lib/akeyless/models/create_secret.rb', line 90 def protection_key @protection_key end |
#provider_type ⇒ Object
Returns the value of attribute provider_type.
18 19 20 |
# File 'lib/akeyless/models/create_secret.rb', line 18 def provider_type @provider_type end |
#secure_access_bastion_issuer ⇒ Object
Deprecated. use secure-access-certificate-issuer
93 94 95 |
# File 'lib/akeyless/models/create_secret.rb', line 93 def secure_access_bastion_issuer @secure_access_bastion_issuer end |
#secure_access_certificate_issuer ⇒ Object
Path to the SSH Certificate Issuer for your Akeyless Secure Access
96 97 98 |
# File 'lib/akeyless/models/create_secret.rb', line 96 def secure_access_certificate_issuer @secure_access_certificate_issuer end |
#secure_access_enable ⇒ Object
Enable/Disable secure remote access [true/false]
99 100 101 |
# File 'lib/akeyless/models/create_secret.rb', line 99 def secure_access_enable @secure_access_enable end |
#secure_access_enforce_hosts_restriction ⇒ Object
Enforce connections only to allowed SRA hosts
102 103 104 |
# File 'lib/akeyless/models/create_secret.rb', line 102 def secure_access_enforce_hosts_restriction @secure_access_enforce_hosts_restriction end |
#secure_access_gateway ⇒ Object
Returns the value of attribute secure_access_gateway.
104 105 106 |
# File 'lib/akeyless/models/create_secret.rb', line 104 def secure_access_gateway @secure_access_gateway end |
#secure_access_host ⇒ Object
Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)
107 108 109 |
# File 'lib/akeyless/models/create_secret.rb', line 107 def secure_access_host @secure_access_host end |
#secure_access_rdp_user ⇒ Object
Remote Desktop Username
110 111 112 |
# File 'lib/akeyless/models/create_secret.rb', line 110 def secure_access_rdp_user @secure_access_rdp_user end |
#secure_access_ssh_creds ⇒ Object
Static-Secret values contains SSH Credentials, either Private Key or Password [password/private-key]
113 114 115 |
# File 'lib/akeyless/models/create_secret.rb', line 113 def secure_access_ssh_creds @secure_access_ssh_creds end |
#secure_access_ssh_user ⇒ Object
Override the SSH username as indicated in SSH Certificate Issuer
116 117 118 |
# File 'lib/akeyless/models/create_secret.rb', line 116 def secure_access_ssh_user @secure_access_ssh_user end |
#secure_access_url ⇒ Object
Destination URL to inject secrets
119 120 121 |
# File 'lib/akeyless/models/create_secret.rb', line 119 def secure_access_url @secure_access_url end |
#secure_access_web_browsing ⇒ Object
Secure browser via Akeyless's Secure Remote Access (SRA)
122 123 124 |
# File 'lib/akeyless/models/create_secret.rb', line 122 def secure_access_web_browsing @secure_access_web_browsing end |
#secure_access_web_proxy ⇒ Object
Web-Proxy via Akeyless's Secure Remote Access (SRA)
125 126 127 |
# File 'lib/akeyless/models/create_secret.rb', line 125 def secure_access_web_proxy @secure_access_web_proxy end |
#tags ⇒ Object
Add tags attached to this object
128 129 130 |
# File 'lib/akeyless/models/create_secret.rb', line 128 def @tags end |
#target ⇒ Object
A list of targets to be associated with an SRA item, To specify multiple targets use argument multiple times
131 132 133 |
# File 'lib/akeyless/models/create_secret.rb', line 131 def target @target end |
#token ⇒ Object
Authentication token (see /auth and /configure)
134 135 136 |
# File 'lib/akeyless/models/create_secret.rb', line 134 def token @token end |
#type ⇒ Object
The secret sub type [generic/password]
137 138 139 |
# File 'lib/akeyless/models/create_secret.rb', line 137 def type @type end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
140 141 142 |
# File 'lib/akeyless/models/create_secret.rb', line 140 def uid_token @uid_token end |
#username ⇒ Object
For Password Management use
143 144 145 |
# File 'lib/akeyless/models/create_secret.rb', line 143 def username @username end |
#value ⇒ Object
The secret value (relevant only for type 'generic')
146 147 148 |
# File 'lib/akeyless/models/create_secret.rb', line 146 def value @value end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 |
# File 'lib/akeyless/models/create_secret.rb', line 598 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
199 200 201 |
# File 'lib/akeyless/models/create_secret.rb', line 199 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/akeyless/models/create_secret.rb', line 149 def self.attribute_map { :'provider_type' => :'ProviderType', :'accessibility' => :'accessibility', :'ara_enabled' => :'ara-enabled', :'change_event' => :'change-event', :'custom_field' => :'custom-field', :'delete_protection' => :'delete_protection', :'description' => :'description', :'enable_agentic_runtime_authority' => :'enable-agentic-runtime-authority', :'enable_ai_quorum' => :'enable-ai-quorum', :'format' => :'format', :'host_provider' => :'host-provider', :'inject_url' => :'inject-url', :'input_rule' => :'input-rule', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'lock_during_sra_session' => :'lock-during-sra-session', :'lock_on_read' => :'lock-on-read', :'lock_ttl' => :'lock-ttl', :'max_versions' => :'max-versions', :'metadata' => :'metadata', :'multiline_value' => :'multiline_value', :'name' => :'name', :'output_rule' => :'output-rule', :'password' => :'password', :'protection_key' => :'protection_key', :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer', :'secure_access_certificate_issuer' => :'secure-access-certificate-issuer', :'secure_access_enable' => :'secure-access-enable', :'secure_access_enforce_hosts_restriction' => :'secure-access-enforce-hosts-restriction', :'secure_access_gateway' => :'secure-access-gateway', :'secure_access_host' => :'secure-access-host', :'secure_access_rdp_user' => :'secure-access-rdp-user', :'secure_access_ssh_creds' => :'secure-access-ssh-creds', :'secure_access_ssh_user' => :'secure-access-ssh-user', :'secure_access_url' => :'secure-access-url', :'secure_access_web_browsing' => :'secure-access-web-browsing', :'secure_access_web_proxy' => :'secure-access-web-proxy', :'tags' => :'tags', :'target' => :'target', :'token' => :'token', :'type' => :'type', :'uid_token' => :'uid-token', :'username' => :'username', :'value' => :'value' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 |
# File 'lib/akeyless/models/create_secret.rb', line 574 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
254 255 256 257 |
# File 'lib/akeyless/models/create_secret.rb', line 254 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/akeyless/models/create_secret.rb', line 204 def self.openapi_types { :'provider_type' => :'String', :'accessibility' => :'String', :'ara_enabled' => :'Boolean', :'change_event' => :'String', :'custom_field' => :'Hash<String, String>', :'delete_protection' => :'String', :'description' => :'String', :'enable_agentic_runtime_authority' => :'Boolean', :'enable_ai_quorum' => :'Boolean', :'format' => :'String', :'host_provider' => :'String', :'inject_url' => :'Array<String>', :'input_rule' => :'Array<String>', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'lock_during_sra_session' => :'String', :'lock_on_read' => :'String', :'lock_ttl' => :'String', :'max_versions' => :'String', :'metadata' => :'String', :'multiline_value' => :'Boolean', :'name' => :'String', :'output_rule' => :'Array<String>', :'password' => :'String', :'protection_key' => :'String', :'secure_access_bastion_issuer' => :'String', :'secure_access_certificate_issuer' => :'String', :'secure_access_enable' => :'String', :'secure_access_enforce_hosts_restriction' => :'Boolean', :'secure_access_gateway' => :'String', :'secure_access_host' => :'Array<String>', :'secure_access_rdp_user' => :'String', :'secure_access_ssh_creds' => :'String', :'secure_access_ssh_user' => :'String', :'secure_access_url' => :'String', :'secure_access_web_browsing' => :'Boolean', :'secure_access_web_proxy' => :'Boolean', :'tags' => :'Array<String>', :'target' => :'Array<String>', :'token' => :'String', :'type' => :'String', :'uid_token' => :'String', :'username' => :'String', :'value' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 |
# File 'lib/akeyless/models/create_secret.rb', line 510 def ==(o) return true if self.equal?(o) self.class == o.class && provider_type == o.provider_type && accessibility == o.accessibility && ara_enabled == o.ara_enabled && change_event == o.change_event && custom_field == o.custom_field && delete_protection == o.delete_protection && description == o.description && == o. && enable_ai_quorum == o.enable_ai_quorum && format == o.format && host_provider == o.host_provider && inject_url == o.inject_url && input_rule == o.input_rule && item_custom_fields == o.item_custom_fields && json == o.json && lock_during_sra_session == o.lock_during_sra_session && lock_on_read == o.lock_on_read && lock_ttl == o.lock_ttl && max_versions == o.max_versions && == o. && multiline_value == o.multiline_value && name == o.name && output_rule == o.output_rule && password == o.password && protection_key == o.protection_key && secure_access_bastion_issuer == o.secure_access_bastion_issuer && secure_access_certificate_issuer == o.secure_access_certificate_issuer && secure_access_enable == o.secure_access_enable && secure_access_enforce_hosts_restriction == o.secure_access_enforce_hosts_restriction && secure_access_gateway == o.secure_access_gateway && secure_access_host == o.secure_access_host && secure_access_rdp_user == o.secure_access_rdp_user && secure_access_ssh_creds == o.secure_access_ssh_creds && secure_access_ssh_user == o.secure_access_ssh_user && secure_access_url == o.secure_access_url && secure_access_web_browsing == o.secure_access_web_browsing && secure_access_web_proxy == o.secure_access_web_proxy && == o. && target == o.target && token == o.token && type == o.type && uid_token == o.uid_token && username == o.username && value == o.value end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
669 670 671 672 673 674 675 676 677 678 679 680 681 |
# File 'lib/akeyless/models/create_secret.rb', line 669 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
561 562 563 |
# File 'lib/akeyless/models/create_secret.rb', line 561 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
567 568 569 |
# File 'lib/akeyless/models/create_secret.rb', line 567 def hash [provider_type, accessibility, ara_enabled, change_event, custom_field, delete_protection, description, , enable_ai_quorum, format, host_provider, inject_url, input_rule, item_custom_fields, json, lock_during_sra_session, lock_on_read, lock_ttl, max_versions, , multiline_value, name, output_rule, password, protection_key, secure_access_bastion_issuer, secure_access_certificate_issuer, secure_access_enable, secure_access_enforce_hosts_restriction, secure_access_gateway, secure_access_host, secure_access_rdp_user, secure_access_ssh_creds, secure_access_ssh_user, secure_access_url, secure_access_web_browsing, secure_access_web_proxy, , target, token, type, uid_token, username, value].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/akeyless/models/create_secret.rb', line 485 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
645 646 647 |
# File 'lib/akeyless/models/create_secret.rb', line 645 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
651 652 653 654 655 656 657 658 659 660 661 662 663 |
# File 'lib/akeyless/models/create_secret.rb', line 651 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
639 640 641 |
# File 'lib/akeyless/models/create_secret.rb', line 639 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
501 502 503 504 505 506 |
# File 'lib/akeyless/models/create_secret.rb', line 501 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @value.nil? true end |