Class: Akeyless::CreateSecret
- Inherits:
-
Object
- Object
- Akeyless::CreateSecret
- Defined in:
- lib/akeyless/models/create_secret.rb
Instance Attribute Summary collapse
-
#accessibility ⇒ Object
for personal password manager.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this item.
-
#metadata ⇒ Object
Metadata about the secret.
-
#multiline_value ⇒ Object
The provided value is a multiline value (separated by '\n').
-
#name ⇒ Object
Secret name.
-
#password_manager_custom_field ⇒ Object
For Password Management use, additional fields.
-
#password_manager_inject_url ⇒ Object
For Password Management use, reflect the website context.
-
#password_manager_password ⇒ Object
For Password Management use, additional fields.
-
#password_manager_username ⇒ Object
For Password Management use.
-
#protection_key ⇒ Object
The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used).
-
#secure_access_bastion_issuer ⇒ Object
Returns the value of attribute secure_access_bastion_issuer.
-
#secure_access_enable ⇒ Object
Returns the value of attribute secure_access_enable.
-
#secure_access_host ⇒ Object
Returns the value of attribute secure_access_host.
-
#secure_access_ssh_creds ⇒ Object
Returns the value of attribute secure_access_ssh_creds.
-
#secure_access_ssh_user ⇒ Object
Returns the value of attribute secure_access_ssh_user.
-
#secure_access_url ⇒ Object
Returns the value of attribute secure_access_url.
-
#secure_access_web_browsing ⇒ Object
Returns the value of attribute secure_access_web_browsing.
-
#secure_access_web_proxy ⇒ Object
Returns the value of attribute secure_access_web_proxy.
-
#tags ⇒ Object
List of the tags attached to this secret.
-
#token ⇒ Object
Authentication token (see
/authand/configure). -
#type ⇒ Object
For Password Management use, reflect the website context.
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#value ⇒ Object
The secret value.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSecret
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSecret
Initializes the object
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/akeyless/models/create_secret.rb', line 150 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::CreateSecret` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::CreateSecret`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'accessibility') self.accessibility = attributes[:'accessibility'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'multiline_value') self.multiline_value = attributes[:'multiline_value'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'password_manager_custom_field') if (value = attributes[:'password_manager_custom_field']).is_a?(Hash) self.password_manager_custom_field = value end end if attributes.key?(:'password_manager_inject_url') self.password_manager_inject_url = attributes[:'password_manager_inject_url'] end if attributes.key?(:'password_manager_password') self.password_manager_password = attributes[:'password_manager_password'] end if attributes.key?(:'password_manager_username') self.password_manager_username = attributes[:'password_manager_username'] end if attributes.key?(:'protection_key') self.protection_key = attributes[:'protection_key'] end if attributes.key?(:'secure_access_bastion_issuer') self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer'] end if attributes.key?(:'secure_access_enable') self.secure_access_enable = attributes[:'secure_access_enable'] end if attributes.key?(:'secure_access_host') if (value = attributes[:'secure_access_host']).is_a?(Array) self.secure_access_host = value end end if attributes.key?(:'secure_access_ssh_creds') self.secure_access_ssh_creds = attributes[:'secure_access_ssh_creds'] end if attributes.key?(:'secure_access_ssh_user') self.secure_access_ssh_user = attributes[:'secure_access_ssh_user'] end if attributes.key?(:'secure_access_url') self.secure_access_url = attributes[:'secure_access_url'] end if attributes.key?(:'secure_access_web_browsing') self.secure_access_web_browsing = attributes[:'secure_access_web_browsing'] end if attributes.key?(:'secure_access_web_proxy') self.secure_access_web_proxy = attributes[:'secure_access_web_proxy'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'value') self.value = attributes[:'value'] end end |
Instance Attribute Details
#accessibility ⇒ Object
for personal password manager
19 20 21 |
# File 'lib/akeyless/models/create_secret.rb', line 19 def accessibility @accessibility end |
#delete_protection ⇒ Object
Protection from accidental deletion of this item
22 23 24 |
# File 'lib/akeyless/models/create_secret.rb', line 22 def delete_protection @delete_protection end |
#metadata ⇒ Object
Metadata about the secret
25 26 27 |
# File 'lib/akeyless/models/create_secret.rb', line 25 def @metadata end |
#multiline_value ⇒ Object
The provided value is a multiline value (separated by '\n')
28 29 30 |
# File 'lib/akeyless/models/create_secret.rb', line 28 def multiline_value @multiline_value end |
#name ⇒ Object
Secret name
31 32 33 |
# File 'lib/akeyless/models/create_secret.rb', line 31 def name @name end |
#password_manager_custom_field ⇒ Object
For Password Management use, additional fields
34 35 36 |
# File 'lib/akeyless/models/create_secret.rb', line 34 def password_manager_custom_field @password_manager_custom_field end |
#password_manager_inject_url ⇒ Object
For Password Management use, reflect the website context
37 38 39 |
# File 'lib/akeyless/models/create_secret.rb', line 37 def password_manager_inject_url @password_manager_inject_url end |
#password_manager_password ⇒ Object
For Password Management use, additional fields
40 41 42 |
# File 'lib/akeyless/models/create_secret.rb', line 40 def password_manager_password @password_manager_password end |
#password_manager_username ⇒ Object
For Password Management use
43 44 45 |
# File 'lib/akeyless/models/create_secret.rb', line 43 def password_manager_username @password_manager_username end |
#protection_key ⇒ Object
The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)
46 47 48 |
# File 'lib/akeyless/models/create_secret.rb', line 46 def protection_key @protection_key end |
#secure_access_bastion_issuer ⇒ Object
Returns the value of attribute secure_access_bastion_issuer.
48 49 50 |
# File 'lib/akeyless/models/create_secret.rb', line 48 def secure_access_bastion_issuer @secure_access_bastion_issuer end |
#secure_access_enable ⇒ Object
Returns the value of attribute secure_access_enable.
50 51 52 |
# File 'lib/akeyless/models/create_secret.rb', line 50 def secure_access_enable @secure_access_enable end |
#secure_access_host ⇒ Object
Returns the value of attribute secure_access_host.
52 53 54 |
# File 'lib/akeyless/models/create_secret.rb', line 52 def secure_access_host @secure_access_host end |
#secure_access_ssh_creds ⇒ Object
Returns the value of attribute secure_access_ssh_creds.
54 55 56 |
# File 'lib/akeyless/models/create_secret.rb', line 54 def secure_access_ssh_creds @secure_access_ssh_creds end |
#secure_access_ssh_user ⇒ Object
Returns the value of attribute secure_access_ssh_user.
56 57 58 |
# File 'lib/akeyless/models/create_secret.rb', line 56 def secure_access_ssh_user @secure_access_ssh_user end |
#secure_access_url ⇒ Object
Returns the value of attribute secure_access_url.
58 59 60 |
# File 'lib/akeyless/models/create_secret.rb', line 58 def secure_access_url @secure_access_url end |
#secure_access_web_browsing ⇒ Object
Returns the value of attribute secure_access_web_browsing.
60 61 62 |
# File 'lib/akeyless/models/create_secret.rb', line 60 def secure_access_web_browsing @secure_access_web_browsing end |
#secure_access_web_proxy ⇒ Object
Returns the value of attribute secure_access_web_proxy.
62 63 64 |
# File 'lib/akeyless/models/create_secret.rb', line 62 def secure_access_web_proxy @secure_access_web_proxy end |
#tags ⇒ Object
List of the tags attached to this secret
65 66 67 |
# File 'lib/akeyless/models/create_secret.rb', line 65 def @tags end |
#token ⇒ Object
Authentication token (see /auth and /configure)
68 69 70 |
# File 'lib/akeyless/models/create_secret.rb', line 68 def token @token end |
#type ⇒ Object
For Password Management use, reflect the website context
71 72 73 |
# File 'lib/akeyless/models/create_secret.rb', line 71 def type @type end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
74 75 76 |
# File 'lib/akeyless/models/create_secret.rb', line 74 def uid_token @uid_token end |
#value ⇒ Object
The secret value
77 78 79 |
# File 'lib/akeyless/models/create_secret.rb', line 77 def value @value end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
109 110 111 |
# File 'lib/akeyless/models/create_secret.rb', line 109 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/akeyless/models/create_secret.rb', line 80 def self.attribute_map { :'accessibility' => :'accessibility', :'delete_protection' => :'delete_protection', :'metadata' => :'metadata', :'multiline_value' => :'multiline_value', :'name' => :'name', :'password_manager_custom_field' => :'password-manager-custom-field', :'password_manager_inject_url' => :'password-manager-inject-url', :'password_manager_password' => :'password-manager-password', :'password_manager_username' => :'password-manager-username', :'protection_key' => :'protection_key', :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer', :'secure_access_enable' => :'secure-access-enable', :'secure_access_host' => :'secure-access-host', :'secure_access_ssh_creds' => :'secure-access-ssh-creds', :'secure_access_ssh_user' => :'secure-access-ssh-user', :'secure_access_url' => :'secure-access-url', :'secure_access_web_browsing' => :'secure-access-web-browsing', :'secure_access_web_proxy' => :'secure-access-web-proxy', :'tags' => :'tags', :'token' => :'token', :'type' => :'type', :'uid_token' => :'uid-token', :'value' => :'value' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
330 331 332 |
# File 'lib/akeyless/models/create_secret.rb', line 330 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
143 144 145 146 |
# File 'lib/akeyless/models/create_secret.rb', line 143 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/akeyless/models/create_secret.rb', line 114 def self.openapi_types { :'accessibility' => :'String', :'delete_protection' => :'String', :'metadata' => :'String', :'multiline_value' => :'Boolean', :'name' => :'String', :'password_manager_custom_field' => :'Hash<String, String>', :'password_manager_inject_url' => :'String', :'password_manager_password' => :'String', :'password_manager_username' => :'String', :'protection_key' => :'String', :'secure_access_bastion_issuer' => :'String', :'secure_access_enable' => :'String', :'secure_access_host' => :'Array<String>', :'secure_access_ssh_creds' => :'String', :'secure_access_ssh_user' => :'String', :'secure_access_url' => :'String', :'secure_access_web_browsing' => :'Boolean', :'secure_access_web_proxy' => :'Boolean', :'tags' => :'Array<String>', :'token' => :'String', :'type' => :'String', :'uid_token' => :'String', :'value' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/akeyless/models/create_secret.rb', line 287 def ==(o) return true if self.equal?(o) self.class == o.class && accessibility == o.accessibility && delete_protection == o.delete_protection && == o. && multiline_value == o.multiline_value && name == o.name && password_manager_custom_field == o.password_manager_custom_field && password_manager_inject_url == o.password_manager_inject_url && password_manager_password == o.password_manager_password && password_manager_username == o.password_manager_username && protection_key == o.protection_key && secure_access_bastion_issuer == o.secure_access_bastion_issuer && secure_access_enable == o.secure_access_enable && secure_access_host == o.secure_access_host && secure_access_ssh_creds == o.secure_access_ssh_creds && secure_access_ssh_user == o.secure_access_ssh_user && secure_access_url == o.secure_access_url && secure_access_web_browsing == o.secure_access_web_browsing && secure_access_web_proxy == o.secure_access_web_proxy && == o. && token == o.token && type == o.type && uid_token == o.uid_token && value == o.value end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/akeyless/models/create_secret.rb', line 361 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
432 433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/akeyless/models/create_secret.rb', line 432 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/akeyless/models/create_secret.rb', line 337 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
317 318 319 |
# File 'lib/akeyless/models/create_secret.rb', line 317 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
323 324 325 |
# File 'lib/akeyless/models/create_secret.rb', line 323 def hash [accessibility, delete_protection, , multiline_value, name, password_manager_custom_field, password_manager_inject_url, password_manager_password, password_manager_username, protection_key, secure_access_bastion_issuer, secure_access_enable, secure_access_host, secure_access_ssh_creds, secure_access_ssh_user, secure_access_url, secure_access_web_browsing, secure_access_web_proxy, , token, type, uid_token, value].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/akeyless/models/create_secret.rb', line 264 def list_invalid_properties invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
408 409 410 |
# File 'lib/akeyless/models/create_secret.rb', line 408 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/akeyless/models/create_secret.rb', line 414 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
402 403 404 |
# File 'lib/akeyless/models/create_secret.rb', line 402 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
279 280 281 282 283 |
# File 'lib/akeyless/models/create_secret.rb', line 279 def valid? return false if @name.nil? return false if @value.nil? true end |