Class: Akeyless::CreateUSC
- Inherits:
-
Object
- Object
- Akeyless::CreateUSC
- Defined in:
- lib/akeyless/models/create_usc.rb
Overview
CreateUSC is a command that creates a Universal Secrets Connector
Instance Attribute Summary collapse
-
#azure_kv_name ⇒ Object
Azure Key Vault name (Relevant only for Azure targets).
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#description ⇒ Object
Description of the Universal Secrets Connector.
-
#environment_names ⇒ Object
The environments in repo-name/environment-name format, comma-separated (only relevant for: github-scope=repository-environment).
-
#gcp_project_id ⇒ Object
GCP Project ID (Relevant only for GCP targets).
-
#gcp_sm_regions ⇒ Object
GCP Secret Manager regions to query for regional secrets (comma-separated, e.g., us-east1,us-west1).
-
#github_scope ⇒ Object
The scope where secrets will be created, available options: [repository, organization, repository-environment].
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#k8s_namespace ⇒ Object
K8s namespace (Relevant to Kubernetes targets).
-
#name ⇒ Object
Universal Secrets Connector name.
-
#organization_name ⇒ Object
The organization name to create the secret in.
-
#repository_access ⇒ Object
Returns the value of attribute repository_access.
-
#repository_names ⇒ Object
The repository names, comma-separated (only relevant for: github-scope=repository).
-
#tags ⇒ Object
List of the tags attached to this Universal Secrets Connector.
-
#target_to_associate ⇒ Object
Target Universal Secrets Connector to connect.
-
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`).
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#usc_prefix ⇒ Object
Prefix for all secrets created in AWS Secrets Manager.
-
#usc_tags ⇒ Object
Comma-separated list of tags to apply to all secrets created on the remote USC.
-
#use_prefix_as_filter ⇒ Object
Whether to filter the USC secret list using the specified usc-prefix [true/false].
-
#use_tags_as_filter ⇒ Object
Filter the USC secret list by the value(s) of –usc-tags.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateUSC
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateUSC
Initializes the object
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/akeyless/models/create_usc.rb', line 153 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::CreateUSC` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::CreateUSC`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'azure_kv_name') self.azure_kv_name = attributes[:'azure_kv_name'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'environment_names') self.environment_names = attributes[:'environment_names'] end if attributes.key?(:'gcp_project_id') self.gcp_project_id = attributes[:'gcp_project_id'] end if attributes.key?(:'gcp_sm_regions') self.gcp_sm_regions = attributes[:'gcp_sm_regions'] end if attributes.key?(:'github_scope') self.github_scope = attributes[:'github_scope'] else self.github_scope = 'repository' end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'k8s_namespace') self.k8s_namespace = attributes[:'k8s_namespace'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'organization_name') self.organization_name = attributes[:'organization_name'] end if attributes.key?(:'repository_access') self.repository_access = attributes[:'repository_access'] else self.repository_access = 'public' end if attributes.key?(:'repository_names') self.repository_names = attributes[:'repository_names'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'target_to_associate') self.target_to_associate = attributes[:'target_to_associate'] else self.target_to_associate = nil end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'usc_prefix') self.usc_prefix = attributes[:'usc_prefix'] end if attributes.key?(:'usc_tags') self. = attributes[:'usc_tags'] end if attributes.key?(:'use_prefix_as_filter') self.use_prefix_as_filter = attributes[:'use_prefix_as_filter'] else self.use_prefix_as_filter = 'false' end if attributes.key?(:'use_tags_as_filter') self. = attributes[:'use_tags_as_filter'] end end |
Instance Attribute Details
#azure_kv_name ⇒ Object
Azure Key Vault name (Relevant only for Azure targets)
20 21 22 |
# File 'lib/akeyless/models/create_usc.rb', line 20 def azure_kv_name @azure_kv_name end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
23 24 25 |
# File 'lib/akeyless/models/create_usc.rb', line 23 def delete_protection @delete_protection end |
#description ⇒ Object
Description of the Universal Secrets Connector
26 27 28 |
# File 'lib/akeyless/models/create_usc.rb', line 26 def description @description end |
#environment_names ⇒ Object
The environments in repo-name/environment-name format, comma-separated (only relevant for: github-scope=repository-environment)
29 30 31 |
# File 'lib/akeyless/models/create_usc.rb', line 29 def environment_names @environment_names end |
#gcp_project_id ⇒ Object
GCP Project ID (Relevant only for GCP targets)
32 33 34 |
# File 'lib/akeyless/models/create_usc.rb', line 32 def gcp_project_id @gcp_project_id end |
#gcp_sm_regions ⇒ Object
GCP Secret Manager regions to query for regional secrets (comma-separated, e.g., us-east1,us-west1). Max 12 regions. Required when listing with object-type=regional-secrets.
35 36 37 |
# File 'lib/akeyless/models/create_usc.rb', line 35 def gcp_sm_regions @gcp_sm_regions end |
#github_scope ⇒ Object
The scope where secrets will be created, available options: [repository, organization, repository-environment]
38 39 40 |
# File 'lib/akeyless/models/create_usc.rb', line 38 def github_scope @github_scope end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
41 42 43 |
# File 'lib/akeyless/models/create_usc.rb', line 41 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
44 45 46 |
# File 'lib/akeyless/models/create_usc.rb', line 44 def json @json end |
#k8s_namespace ⇒ Object
K8s namespace (Relevant to Kubernetes targets)
47 48 49 |
# File 'lib/akeyless/models/create_usc.rb', line 47 def k8s_namespace @k8s_namespace end |
#name ⇒ Object
Universal Secrets Connector name
50 51 52 |
# File 'lib/akeyless/models/create_usc.rb', line 50 def name @name end |
#organization_name ⇒ Object
The organization name to create the secret in
53 54 55 |
# File 'lib/akeyless/models/create_usc.rb', line 53 def organization_name @organization_name end |
#repository_access ⇒ Object
Returns the value of attribute repository_access.
55 56 57 |
# File 'lib/akeyless/models/create_usc.rb', line 55 def repository_access @repository_access end |
#repository_names ⇒ Object
The repository names, comma-separated (only relevant for: github-scope=repository)
58 59 60 |
# File 'lib/akeyless/models/create_usc.rb', line 58 def repository_names @repository_names end |
#tags ⇒ Object
List of the tags attached to this Universal Secrets Connector
61 62 63 |
# File 'lib/akeyless/models/create_usc.rb', line 61 def @tags end |
#target_to_associate ⇒ Object
Target Universal Secrets Connector to connect
64 65 66 |
# File 'lib/akeyless/models/create_usc.rb', line 64 def target_to_associate @target_to_associate end |
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`)
67 68 69 |
# File 'lib/akeyless/models/create_usc.rb', line 67 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
70 71 72 |
# File 'lib/akeyless/models/create_usc.rb', line 70 def uid_token @uid_token end |
#usc_prefix ⇒ Object
Prefix for all secrets created in AWS Secrets Manager
73 74 75 |
# File 'lib/akeyless/models/create_usc.rb', line 73 def usc_prefix @usc_prefix end |
#usc_tags ⇒ Object
Comma-separated list of tags to apply to all secrets created on the remote USC
76 77 78 |
# File 'lib/akeyless/models/create_usc.rb', line 76 def @usc_tags end |
#use_prefix_as_filter ⇒ Object
Whether to filter the USC secret list using the specified usc-prefix [true/false]
79 80 81 |
# File 'lib/akeyless/models/create_usc.rb', line 79 def use_prefix_as_filter @use_prefix_as_filter end |
#use_tags_as_filter ⇒ Object
Filter the USC secret list by the value(s) of –usc-tags. [true|false]
82 83 84 |
# File 'lib/akeyless/models/create_usc.rb', line 82 def @use_tags_as_filter end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/akeyless/models/create_usc.rb', line 364 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
113 114 115 |
# File 'lib/akeyless/models/create_usc.rb', line 113 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/akeyless/models/create_usc.rb', line 85 def self.attribute_map { :'azure_kv_name' => :'azure-kv-name', :'delete_protection' => :'delete_protection', :'description' => :'description', :'environment_names' => :'environment-names', :'gcp_project_id' => :'gcp-project-id', :'gcp_sm_regions' => :'gcp-sm-regions', :'github_scope' => :'github-scope', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'k8s_namespace' => :'k8s-namespace', :'name' => :'name', :'organization_name' => :'organization-name', :'repository_access' => :'repository-access', :'repository_names' => :'repository-names', :'tags' => :'tags', :'target_to_associate' => :'target-to-associate', :'token' => :'token', :'uid_token' => :'uid-token', :'usc_prefix' => :'usc-prefix', :'usc_tags' => :'usc-tags', :'use_prefix_as_filter' => :'use-prefix-as-filter', :'use_tags_as_filter' => :'use-tags-as-filter' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/akeyless/models/create_usc.rb', line 340 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
146 147 148 149 |
# File 'lib/akeyless/models/create_usc.rb', line 146 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/akeyless/models/create_usc.rb', line 118 def self.openapi_types { :'azure_kv_name' => :'String', :'delete_protection' => :'String', :'description' => :'String', :'environment_names' => :'String', :'gcp_project_id' => :'String', :'gcp_sm_regions' => :'String', :'github_scope' => :'String', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'k8s_namespace' => :'String', :'name' => :'String', :'organization_name' => :'String', :'repository_access' => :'String', :'repository_names' => :'String', :'tags' => :'Array<String>', :'target_to_associate' => :'String', :'token' => :'String', :'uid_token' => :'String', :'usc_prefix' => :'String', :'usc_tags' => :'String', :'use_prefix_as_filter' => :'String', :'use_tags_as_filter' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/akeyless/models/create_usc.rb', line 298 def ==(o) return true if self.equal?(o) self.class == o.class && azure_kv_name == o.azure_kv_name && delete_protection == o.delete_protection && description == o.description && environment_names == o.environment_names && gcp_project_id == o.gcp_project_id && gcp_sm_regions == o.gcp_sm_regions && github_scope == o.github_scope && item_custom_fields == o.item_custom_fields && json == o.json && k8s_namespace == o.k8s_namespace && name == o.name && organization_name == o.organization_name && repository_access == o.repository_access && repository_names == o.repository_names && == o. && target_to_associate == o.target_to_associate && token == o.token && uid_token == o.uid_token && usc_prefix == o.usc_prefix && == o. && use_prefix_as_filter == o.use_prefix_as_filter && == o. end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/akeyless/models/create_usc.rb', line 435 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
327 328 329 |
# File 'lib/akeyless/models/create_usc.rb', line 327 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
333 334 335 |
# File 'lib/akeyless/models/create_usc.rb', line 333 def hash [azure_kv_name, delete_protection, description, environment_names, gcp_project_id, gcp_sm_regions, github_scope, item_custom_fields, json, k8s_namespace, name, organization_name, repository_access, repository_names, , target_to_associate, token, uid_token, usc_prefix, , use_prefix_as_filter, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/akeyless/models/create_usc.rb', line 273 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @target_to_associate.nil? invalid_properties.push('invalid value for "target_to_associate", target_to_associate cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
411 412 413 |
# File 'lib/akeyless/models/create_usc.rb', line 411 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/akeyless/models/create_usc.rb', line 417 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
405 406 407 |
# File 'lib/akeyless/models/create_usc.rb', line 405 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
289 290 291 292 293 294 |
# File 'lib/akeyless/models/create_usc.rb', line 289 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @target_to_associate.nil? true end |