Class: Akeyless::DbTargetDetails
- Inherits:
-
Object
- Object
- Akeyless::DbTargetDetails
- Defined in:
- lib/akeyless/models/db_target_details.rb
Overview
DbTargetDetails
Instance Attribute Summary collapse
-
#db_host_name ⇒ Object
Returns the value of attribute db_host_name.
-
#db_name ⇒ Object
Returns the value of attribute db_name.
-
#db_port ⇒ Object
Returns the value of attribute db_port.
-
#db_private_key ⇒ Object
(Optional) Private Key in PEM format.
-
#db_private_key_passphrase ⇒ Object
Returns the value of attribute db_private_key_passphrase.
-
#db_pwd ⇒ Object
Returns the value of attribute db_pwd.
-
#db_server_certificates ⇒ Object
(Optional) DBServerCertificates defines the set of root certificate authorities that clients use when verifying server certificates.
-
#db_server_name ⇒ Object
(Optional) ServerName is used to verify the hostname on the returned certificates unless InsecureSkipVerify is given.
-
#db_user_name ⇒ Object
Returns the value of attribute db_user_name.
-
#sf_account ⇒ Object
Returns the value of attribute sf_account.
-
#ssl_connection_certificate ⇒ Object
(Optional) SSLConnectionCertificate defines the certificate for SSL connection.
-
#ssl_connection_mode ⇒ Object
(Optional) SSLConnectionMode defines if SSL mode will be used to connect to DB.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DbTargetDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DbTargetDetails
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/akeyless/models/db_target_details.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DbTargetDetails` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DbTargetDetails`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'db_host_name') self.db_host_name = attributes[:'db_host_name'] end if attributes.key?(:'db_name') self.db_name = attributes[:'db_name'] end if attributes.key?(:'db_port') self.db_port = attributes[:'db_port'] end if attributes.key?(:'db_private_key') self.db_private_key = attributes[:'db_private_key'] end if attributes.key?(:'db_private_key_passphrase') self.db_private_key_passphrase = attributes[:'db_private_key_passphrase'] end if attributes.key?(:'db_pwd') self.db_pwd = attributes[:'db_pwd'] end if attributes.key?(:'db_server_certificates') self.db_server_certificates = attributes[:'db_server_certificates'] end if attributes.key?(:'db_server_name') self.db_server_name = attributes[:'db_server_name'] end if attributes.key?(:'db_user_name') self.db_user_name = attributes[:'db_user_name'] end if attributes.key?(:'sf_account') self.sf_account = attributes[:'sf_account'] end if attributes.key?(:'ssl_connection_certificate') self.ssl_connection_certificate = attributes[:'ssl_connection_certificate'] end if attributes.key?(:'ssl_connection_mode') self.ssl_connection_mode = attributes[:'ssl_connection_mode'] end end |
Instance Attribute Details
#db_host_name ⇒ Object
Returns the value of attribute db_host_name.
19 20 21 |
# File 'lib/akeyless/models/db_target_details.rb', line 19 def db_host_name @db_host_name end |
#db_name ⇒ Object
Returns the value of attribute db_name.
21 22 23 |
# File 'lib/akeyless/models/db_target_details.rb', line 21 def db_name @db_name end |
#db_port ⇒ Object
Returns the value of attribute db_port.
23 24 25 |
# File 'lib/akeyless/models/db_target_details.rb', line 23 def db_port @db_port end |
#db_private_key ⇒ Object
(Optional) Private Key in PEM format
26 27 28 |
# File 'lib/akeyless/models/db_target_details.rb', line 26 def db_private_key @db_private_key end |
#db_private_key_passphrase ⇒ Object
Returns the value of attribute db_private_key_passphrase.
28 29 30 |
# File 'lib/akeyless/models/db_target_details.rb', line 28 def db_private_key_passphrase @db_private_key_passphrase end |
#db_pwd ⇒ Object
Returns the value of attribute db_pwd.
30 31 32 |
# File 'lib/akeyless/models/db_target_details.rb', line 30 def db_pwd @db_pwd end |
#db_server_certificates ⇒ Object
(Optional) DBServerCertificates defines the set of root certificate authorities that clients use when verifying server certificates. If DBServerCertificates is empty, TLS uses the host's root CA set.
33 34 35 |
# File 'lib/akeyless/models/db_target_details.rb', line 33 def db_server_certificates @db_server_certificates end |
#db_server_name ⇒ Object
(Optional) ServerName is used to verify the hostname on the returned certificates unless InsecureSkipVerify is given. It is also included in the client's handshake to support virtual hosting unless it is an IP address.
36 37 38 |
# File 'lib/akeyless/models/db_target_details.rb', line 36 def db_server_name @db_server_name end |
#db_user_name ⇒ Object
Returns the value of attribute db_user_name.
38 39 40 |
# File 'lib/akeyless/models/db_target_details.rb', line 38 def db_user_name @db_user_name end |
#sf_account ⇒ Object
Returns the value of attribute sf_account.
40 41 42 |
# File 'lib/akeyless/models/db_target_details.rb', line 40 def sf_account @sf_account end |
#ssl_connection_certificate ⇒ Object
(Optional) SSLConnectionCertificate defines the certificate for SSL connection. Must be base64 certificate loaded by UI using file loader field
43 44 45 |
# File 'lib/akeyless/models/db_target_details.rb', line 43 def ssl_connection_certificate @ssl_connection_certificate end |
#ssl_connection_mode ⇒ Object
(Optional) SSLConnectionMode defines if SSL mode will be used to connect to DB
46 47 48 |
# File 'lib/akeyless/models/db_target_details.rb', line 46 def ssl_connection_mode @ssl_connection_mode end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/akeyless/models/db_target_details.rb', line 232 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/akeyless/models/db_target_details.rb', line 67 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/akeyless/models/db_target_details.rb', line 49 def self.attribute_map { :'db_host_name' => :'db_host_name', :'db_name' => :'db_name', :'db_port' => :'db_port', :'db_private_key' => :'db_private_key', :'db_private_key_passphrase' => :'db_private_key_passphrase', :'db_pwd' => :'db_pwd', :'db_server_certificates' => :'db_server_certificates', :'db_server_name' => :'db_server_name', :'db_user_name' => :'db_user_name', :'sf_account' => :'sf_account', :'ssl_connection_certificate' => :'ssl_connection_certificate', :'ssl_connection_mode' => :'ssl_connection_mode' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/akeyless/models/db_target_details.rb', line 208 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
90 91 92 93 |
# File 'lib/akeyless/models/db_target_details.rb', line 90 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/akeyless/models/db_target_details.rb', line 72 def self.openapi_types { :'db_host_name' => :'String', :'db_name' => :'String', :'db_port' => :'String', :'db_private_key' => :'String', :'db_private_key_passphrase' => :'String', :'db_pwd' => :'String', :'db_server_certificates' => :'String', :'db_server_name' => :'String', :'db_user_name' => :'String', :'sf_account' => :'String', :'ssl_connection_certificate' => :'String', :'ssl_connection_mode' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/akeyless/models/db_target_details.rb', line 176 def ==(o) return true if self.equal?(o) self.class == o.class && db_host_name == o.db_host_name && db_name == o.db_name && db_port == o.db_port && db_private_key == o.db_private_key && db_private_key_passphrase == o.db_private_key_passphrase && db_pwd == o.db_pwd && db_server_certificates == o.db_server_certificates && db_server_name == o.db_server_name && db_user_name == o.db_user_name && sf_account == o.sf_account && ssl_connection_certificate == o.ssl_connection_certificate && ssl_connection_mode == o.ssl_connection_mode end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/akeyless/models/db_target_details.rb', line 303 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
195 196 197 |
# File 'lib/akeyless/models/db_target_details.rb', line 195 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
201 202 203 |
# File 'lib/akeyless/models/db_target_details.rb', line 201 def hash [db_host_name, db_name, db_port, db_private_key, db_private_key_passphrase, db_pwd, db_server_certificates, db_server_name, db_user_name, sf_account, ssl_connection_certificate, ssl_connection_mode].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 |
# File 'lib/akeyless/models/db_target_details.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
279 280 281 |
# File 'lib/akeyless/models/db_target_details.rb', line 279 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/akeyless/models/db_target_details.rb', line 285 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
273 274 275 |
# File 'lib/akeyless/models/db_target_details.rb', line 273 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
169 170 171 172 |
# File 'lib/akeyless/models/db_target_details.rb', line 169 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |