Class: Akeyless::DigiCertTargetDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/digi_cert_target_details.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DigiCertTargetDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DigiCertTargetDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DigiCertTargetDetails`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_key_pem')
    self. = attributes[:'account_key_pem']
  end

  if attributes.key?(:'account_url')
    self. = attributes[:'account_url']
  end

  if attributes.key?(:'challenge_type')
    self.challenge_type = attributes[:'challenge_type']
  end

  if attributes.key?(:'digicert_directory_type')
    self.digicert_directory_type = attributes[:'digicert_directory_type']
  end

  if attributes.key?(:'dns_target_name')
    self.dns_target_name = attributes[:'dns_target_name']
  end

  if attributes.key?(:'dns_target_type')
    self.dns_target_type = attributes[:'dns_target_type']
  end

  if attributes.key?(:'eab_hmac_key')
    self.eab_hmac_key = attributes[:'eab_hmac_key']
  end

  if attributes.key?(:'eab_key_id')
    self.eab_key_id = attributes[:'eab_key_id']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'gcp_project')
    self.gcp_project = attributes[:'gcp_project']
  end

  if attributes.key?(:'hosted_zone')
    self.hosted_zone = attributes[:'hosted_zone']
  end

  if attributes.key?(:'resource_group')
    self.resource_group = attributes[:'resource_group']
  end

  if attributes.key?(:'timeout')
    self.timeout = attributes[:'timeout']
  end
end

Instance Attribute Details

#account_key_pemObject

ACME Account Private Key (PEM-encoded). Supports ECDSA (P-256, P-384, P-521), RSA (2048+), and Ed25519. Auto-generated as ECDSA P-256 during first certificate issuance bootstrap. Stored encrypted, required for certificate operations and revocation.



19
20
21
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 19

def 
  @account_key_pem
end

#account_urlObject

ACME Account URL (returned after registration with DigiCert ACME). Used to retrieve existing account instead of re-registering.



22
23
24
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 22

def 
  @account_url
end

#challenge_typeObject

ACMEChallengeType defines ACME challenge type for Let’s Encrypt



25
26
27
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 25

def challenge_type
  @challenge_type
end

#digicert_directory_typeObject

Returns the value of attribute digicert_directory_type.



27
28
29
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 27

def digicert_directory_type
  @digicert_directory_type
end

#dns_target_nameObject

Name of DNS target (transient field - not stored in DB). Used by CLI to pass DNS target name to SDK for creating target_object_assoc. Retrieved from target_object_assoc when reading target. Required when ChallengeType is dns.



30
31
32
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 30

def dns_target_name
  @dns_target_name
end

#dns_target_typeObject

Returns the value of attribute dns_target_type.



32
33
34
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 32

def dns_target_type
  @dns_target_type
end

#eab_hmac_keyObject

External Account Binding HMAC key. Required until ACME account is bootstrapped on first issuance.



35
36
37
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 35

def eab_hmac_key
  @eab_hmac_key
end

#eab_key_idObject

External Account Binding key identifier. Required until ACME account is bootstrapped on first issuance.



38
39
40
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 38

def eab_key_id
  @eab_key_id
end

#emailObject

Email address for ACME account registration. Required.



41
42
43
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 41

def email
  @email
end

#gcp_projectObject

GCP Cloud DNS: Project ID. Optional - can be derived from service account.



44
45
46
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 44

def gcp_project
  @gcp_project
end

#hosted_zoneObject

AWS Route53: Hosted zone ID. Required when DNSTargetType is AWS.



47
48
49
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 47

def hosted_zone
  @hosted_zone
end

#resource_groupObject

Azure DNS: Resource group name. Required when DNSTargetType is Azure.



50
51
52
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 50

def resource_group
  @resource_group
end

#timeoutObject

A Duration represents the elapsed time between two instants as an int64 nanosecond count. The representation limits the largest representable duration to approximately 290 years.



53
54
55
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 53

def timeout
  @timeout
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 246

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 75

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 56

def self.attribute_map
  {
    :'account_key_pem' => :'account_key_pem',
    :'account_url' => :'account_url',
    :'challenge_type' => :'challenge_type',
    :'digicert_directory_type' => :'digicert_directory_type',
    :'dns_target_name' => :'dns_target_name',
    :'dns_target_type' => :'dns_target_type',
    :'eab_hmac_key' => :'eab_hmac_key',
    :'eab_key_id' => :'eab_key_id',
    :'email' => :'email',
    :'gcp_project' => :'gcp_project',
    :'hosted_zone' => :'hosted_zone',
    :'resource_group' => :'resource_group',
    :'timeout' => :'timeout'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 222

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 99

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 80

def self.openapi_types
  {
    :'account_key_pem' => :'String',
    :'account_url' => :'String',
    :'challenge_type' => :'String',
    :'digicert_directory_type' => :'String',
    :'dns_target_name' => :'String',
    :'dns_target_type' => :'String',
    :'eab_hmac_key' => :'String',
    :'eab_key_id' => :'String',
    :'email' => :'String',
    :'gcp_project' => :'String',
    :'hosted_zone' => :'String',
    :'resource_group' => :'String',
    :'timeout' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 189

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
       == o. &&
      challenge_type == o.challenge_type &&
      digicert_directory_type == o.digicert_directory_type &&
      dns_target_name == o.dns_target_name &&
      dns_target_type == o.dns_target_type &&
      eab_hmac_key == o.eab_hmac_key &&
      eab_key_id == o.eab_key_id &&
      email == o.email &&
      gcp_project == o.gcp_project &&
      hosted_zone == o.hosted_zone &&
      resource_group == o.resource_group &&
      timeout == o.timeout
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 317

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


209
210
211
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 209

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



215
216
217
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 215

def hash
  [, , challenge_type, digicert_directory_type, dns_target_name, dns_target_type, eab_hmac_key, eab_key_id, email, gcp_project, hosted_zone, resource_group, timeout].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



174
175
176
177
178
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 174

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



293
294
295
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 293

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 299

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



287
288
289
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 287

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
185
# File 'lib/akeyless/models/digi_cert_target_details.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end