Class: Akeyless::DynamicSecretUpdateCustom

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/dynamic_secret_update_custom.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DynamicSecretUpdateCustom

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 153

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DynamicSecretUpdateCustom` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DynamicSecretUpdateCustom`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'admin_rotation_interval_days')
    self.admin_rotation_interval_days = attributes[:'admin_rotation_interval_days']
  end

  if attributes.key?(:'ara_enabled')
    self.ara_enabled = attributes[:'ara_enabled']
  end

  if attributes.key?(:'create_sync_url')
    self.create_sync_url = attributes[:'create_sync_url']
  else
    self.create_sync_url = nil
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'enable_admin_rotation')
    self.enable_admin_rotation = attributes[:'enable_admin_rotation']
  else
    self.enable_admin_rotation = false
  end

  if attributes.key?(:'input_rule')
    if (value = attributes[:'input_rule']).is_a?(Array)
      self.input_rule = value
    end
  end

  if attributes.key?(:'item_custom_fields')
    if (value = attributes[:'item_custom_fields']).is_a?(Hash)
      self.item_custom_fields = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'output_rule')
    if (value = attributes[:'output_rule']).is_a?(Array)
      self.output_rule = value
    end
  end

  if attributes.key?(:'payload')
    self.payload = attributes[:'payload']
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'revoke_sync_url')
    self.revoke_sync_url = attributes[:'revoke_sync_url']
  else
    self.revoke_sync_url = nil
  end

  if attributes.key?(:'rotate_sync_url')
    self.rotate_sync_url = attributes[:'rotate_sync_url']
  end

  if attributes.key?(:'skip_dry_run')
    self.skip_dry_run = attributes[:'skip_dry_run']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'timeout_sec')
    self.timeout_sec = attributes[:'timeout_sec']
  else
    self.timeout_sec = 60
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '60m'
  end
end

Instance Attribute Details

#admin_rotation_interval_daysObject

Define rotation interval in days



19
20
21
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 19

def admin_rotation_interval_days
  @admin_rotation_interval_days
end

#ara_enabledObject

Enable or disable Agentic Runtime Authority rule enforcement for this item. Mirrors commands.AgenticRulesParams.AraEnabled.



22
23
24
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 22

def ara_enabled
  @ara_enabled
end

#create_sync_urlObject

URL of an endpoint that implements /sync/create method, for example https://webhook.example.com/sync/create



25
26
27
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 25

def create_sync_url
  @create_sync_url
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



28
29
30
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 28

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



31
32
33
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 31

def description
  @description
end

#enable_admin_rotationObject

Should admin credentials be rotated



34
35
36
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 34

def enable_admin_rotation
  @enable_admin_rotation
end

#input_ruleObject

Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).



37
38
39
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 37

def input_rule
  @input_rule
end

#item_custom_fieldsObject

Additional custom fields to associate with the item



40
41
42
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 40

def item_custom_fields
  @item_custom_fields
end

#jsonObject

Set output format to JSON



43
44
45
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 43

def json
  @json
end

#nameObject

Dynamic secret name



46
47
48
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 46

def name
  @name
end

#new_nameObject

Dynamic secret name



49
50
51
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 49

def new_name
  @new_name
end

#output_ruleObject

Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)



52
53
54
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 52

def output_rule
  @output_rule
end

#payloadObject

Secret payload to be sent with each create/revoke webhook request



55
56
57
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 55

def payload
  @payload
end

#producer_encryption_key_nameObject

Dynamic producer encryption key



58
59
60
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 58

def producer_encryption_key_name
  @producer_encryption_key_name
end

#revoke_sync_urlObject

URL of an endpoint that implements /sync/revoke method, for example https://webhook.example.com/sync/revoke



61
62
63
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 61

def revoke_sync_url
  @revoke_sync_url
end

#rotate_sync_urlObject

URL of an endpoint that implements /sync/rotate method, for example https://webhook.example.com/sync/rotate



64
65
66
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 64

def rotate_sync_url
  @rotate_sync_url
end

#skip_dry_runObject

If set, dry-run will be skipped



67
68
69
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 67

def skip_dry_run
  @skip_dry_run
end

#tagsObject

Add tags attached to this object



70
71
72
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 70

def tags
  @tags
end

#timeout_secObject

Maximum allowed time in seconds for the webhook to return the results



73
74
75
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 73

def timeout_sec
  @timeout_sec
end

#tokenObject

Authentication token (see /auth and /configure)



76
77
78
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 76

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



79
80
81
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 79

def uid_token
  @uid_token
end

#user_ttlObject

User TTL



82
83
84
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 82

def user_ttl
  @user_ttl
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 375

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



113
114
115
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 113

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 85

def self.attribute_map
  {
    :'admin_rotation_interval_days' => :'admin-rotation-interval-days',
    :'ara_enabled' => :'ara-enabled',
    :'create_sync_url' => :'create-sync-url',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'enable_admin_rotation' => :'enable-admin-rotation',
    :'input_rule' => :'input-rule',
    :'item_custom_fields' => :'item-custom-fields',
    :'json' => :'json',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'output_rule' => :'output-rule',
    :'payload' => :'payload',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'revoke_sync_url' => :'revoke-sync-url',
    :'rotate_sync_url' => :'rotate-sync-url',
    :'skip_dry_run' => :'skip_dry_run',
    :'tags' => :'tags',
    :'timeout_sec' => :'timeout-sec',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'user_ttl' => :'user-ttl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 351

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



146
147
148
149
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 146

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 118

def self.openapi_types
  {
    :'admin_rotation_interval_days' => :'Integer',
    :'ara_enabled' => :'Boolean',
    :'create_sync_url' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'enable_admin_rotation' => :'Boolean',
    :'input_rule' => :'Array<String>',
    :'item_custom_fields' => :'Hash<String, String>',
    :'json' => :'Boolean',
    :'name' => :'String',
    :'new_name' => :'String',
    :'output_rule' => :'Array<String>',
    :'payload' => :'String',
    :'producer_encryption_key_name' => :'String',
    :'revoke_sync_url' => :'String',
    :'rotate_sync_url' => :'String',
    :'skip_dry_run' => :'String',
    :'tags' => :'Array<String>',
    :'timeout_sec' => :'Integer',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'user_ttl' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 309

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      admin_rotation_interval_days == o.admin_rotation_interval_days &&
      ara_enabled == o.ara_enabled &&
      create_sync_url == o.create_sync_url &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      enable_admin_rotation == o.enable_admin_rotation &&
      input_rule == o.input_rule &&
      item_custom_fields == o.item_custom_fields &&
      json == o.json &&
      name == o.name &&
      new_name == o.new_name &&
      output_rule == o.output_rule &&
      payload == o.payload &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      revoke_sync_url == o.revoke_sync_url &&
      rotate_sync_url == o.rotate_sync_url &&
      skip_dry_run == o.skip_dry_run &&
      tags == o.tags &&
      timeout_sec == o.timeout_sec &&
      token == o.token &&
      uid_token == o.uid_token &&
      user_ttl == o.user_ttl
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 446

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


338
339
340
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 338

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



344
345
346
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 344

def hash
  [admin_rotation_interval_days, ara_enabled, create_sync_url, delete_protection, description, enable_admin_rotation, input_rule, item_custom_fields, json, name, new_name, output_rule, payload, producer_encryption_key_name, revoke_sync_url, rotate_sync_url, skip_dry_run, tags, timeout_sec, token, uid_token, user_ttl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 279

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @create_sync_url.nil?
    invalid_properties.push('invalid value for "create_sync_url", create_sync_url cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @revoke_sync_url.nil?
    invalid_properties.push('invalid value for "revoke_sync_url", revoke_sync_url cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



422
423
424
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 422

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



428
429
430
431
432
433
434
435
436
437
438
439
440
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 428

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



416
417
418
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 416

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



299
300
301
302
303
304
305
# File 'lib/akeyless/models/dynamic_secret_update_custom.rb', line 299

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @create_sync_url.nil?
  return false if @name.nil?
  return false if @revoke_sync_url.nil?
  true
end