Class: Akeyless::DynamicSecretUpdateRdp
- Inherits:
-
Object
- Object
- Akeyless::DynamicSecretUpdateRdp
- Defined in:
- lib/akeyless/models/dynamic_secret_update_rdp.rb
Overview
dynamicSecretUpdateRdp is a command that updates rdp dynamic secret
Instance Attribute Summary collapse
-
#allow_user_extend_session ⇒ Object
AllowUserExtendSession.
-
#custom_username_template ⇒ Object
Customize how temporary usernames are generated using go template.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#description ⇒ Object
Description of the object.
-
#fixed_user_claim_keyname ⇒ Object
For externally provided users, denotes the key-name of IdP claim to extract the username from (relevant only for fixed-user-only=true).
-
#fixed_user_only ⇒ Object
Allow access using externally (IdP) provided username [true/false].
-
#input_rule ⇒ Object
Agentic input rule in name=…,rule=…
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#name ⇒ Object
Dynamic secret name.
-
#new_name ⇒ Object
Dynamic secret name.
-
#output_rule ⇒ Object
Agentic output rule in name=…,rule=…
-
#password_length ⇒ Object
The length of the password to be generated.
-
#producer_encryption_key_name ⇒ Object
Dynamic producer encryption key.
-
#rdp_admin_name ⇒ Object
RDP Admin Name.
-
#rdp_admin_pwd ⇒ Object
RDP Admin password.
-
#rdp_host_name ⇒ Object
Hostname.
-
#rdp_host_port ⇒ Object
Port.
-
#rdp_user_groups ⇒ Object
Groups.
-
#secure_access_allow_external_user ⇒ Object
Allow providing external user for a domain users.
-
#secure_access_bastion_issuer ⇒ Object
Deprecated.
-
#secure_access_certificate_issuer ⇒ Object
Path to the SSH Certificate Issuer for your Akeyless Secure Access.
-
#secure_access_delay ⇒ Object
The delay duration, in seconds, to wait after generating just-in-time credentials.
-
#secure_access_enable ⇒ Object
Enable/Disable secure remote access [true/false].
-
#secure_access_host ⇒ Object
Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers).
-
#secure_access_rd_gateway_server ⇒ Object
RD Gateway server.
-
#secure_access_rdp_domain ⇒ Object
Required when the Dynamic Secret is used for a domain user.
-
#secure_access_rdp_user ⇒ Object
Override the RDP Domain username.
-
#tags ⇒ Object
Add tags attached to this object.
-
#target_name ⇒ Object
Target name.
-
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`).
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#use_capital_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z).
-
#use_lower_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z).
-
#use_numbers ⇒ Object
Specifies whether the generated temporary password must contain at least one numeric character (0 to 9).
-
#use_special_characters ⇒ Object
Returns the value of attribute use_special_characters.
-
#user_ttl ⇒ Object
User TTL.
-
#warn_user_before_expiration ⇒ Object
WarnBeforeUserExpiration.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DynamicSecretUpdateRdp
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DynamicSecretUpdateRdp
Initializes the object
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 233 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DynamicSecretUpdateRdp` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DynamicSecretUpdateRdp`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'allow_user_extend_session') self.allow_user_extend_session = attributes[:'allow_user_extend_session'] end if attributes.key?(:'custom_username_template') self.custom_username_template = attributes[:'custom_username_template'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'fixed_user_claim_keyname') self.fixed_user_claim_keyname = attributes[:'fixed_user_claim_keyname'] else self.fixed_user_claim_keyname = 'ext_username' end if attributes.key?(:'fixed_user_only') self.fixed_user_only = attributes[:'fixed_user_only'] else self.fixed_user_only = 'false' end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'new_name') self.new_name = attributes[:'new_name'] end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'password_length') self.password_length = attributes[:'password_length'] end if attributes.key?(:'producer_encryption_key_name') self.producer_encryption_key_name = attributes[:'producer_encryption_key_name'] end if attributes.key?(:'rdp_admin_name') self.rdp_admin_name = attributes[:'rdp_admin_name'] end if attributes.key?(:'rdp_admin_pwd') self.rdp_admin_pwd = attributes[:'rdp_admin_pwd'] end if attributes.key?(:'rdp_host_name') self.rdp_host_name = attributes[:'rdp_host_name'] end if attributes.key?(:'rdp_host_port') self.rdp_host_port = attributes[:'rdp_host_port'] else self.rdp_host_port = '22' end if attributes.key?(:'rdp_user_groups') self.rdp_user_groups = attributes[:'rdp_user_groups'] end if attributes.key?(:'secure_access_allow_external_user') self.secure_access_allow_external_user = attributes[:'secure_access_allow_external_user'] else self.secure_access_allow_external_user = false end if attributes.key?(:'secure_access_bastion_issuer') self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer'] end if attributes.key?(:'secure_access_certificate_issuer') self.secure_access_certificate_issuer = attributes[:'secure_access_certificate_issuer'] end if attributes.key?(:'secure_access_delay') self.secure_access_delay = attributes[:'secure_access_delay'] end if attributes.key?(:'secure_access_enable') self.secure_access_enable = attributes[:'secure_access_enable'] end if attributes.key?(:'secure_access_host') if (value = attributes[:'secure_access_host']).is_a?(Array) self.secure_access_host = value end end if attributes.key?(:'secure_access_rd_gateway_server') self.secure_access_rd_gateway_server = attributes[:'secure_access_rd_gateway_server'] end if attributes.key?(:'secure_access_rdp_domain') self.secure_access_rdp_domain = attributes[:'secure_access_rdp_domain'] end if attributes.key?(:'secure_access_rdp_user') self.secure_access_rdp_user = attributes[:'secure_access_rdp_user'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'target_name') self.target_name = attributes[:'target_name'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'use_capital_letters') self.use_capital_letters = attributes[:'use_capital_letters'] end if attributes.key?(:'use_lower_letters') self.use_lower_letters = attributes[:'use_lower_letters'] end if attributes.key?(:'use_numbers') self.use_numbers = attributes[:'use_numbers'] end if attributes.key?(:'use_special_characters') self.use_special_characters = attributes[:'use_special_characters'] end if attributes.key?(:'user_ttl') self.user_ttl = attributes[:'user_ttl'] else self.user_ttl = '60m' end if attributes.key?(:'warn_user_before_expiration') self.warn_user_before_expiration = attributes[:'warn_user_before_expiration'] end end |
Instance Attribute Details
#allow_user_extend_session ⇒ Object
AllowUserExtendSession
20 21 22 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 20 def allow_user_extend_session @allow_user_extend_session end |
#custom_username_template ⇒ Object
Customize how temporary usernames are generated using go template
23 24 25 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 23 def custom_username_template @custom_username_template end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
26 27 28 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 26 def delete_protection @delete_protection end |
#description ⇒ Object
Description of the object
29 30 31 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 29 def description @description end |
#fixed_user_claim_keyname ⇒ Object
For externally provided users, denotes the key-name of IdP claim to extract the username from (relevant only for fixed-user-only=true)
32 33 34 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 32 def fixed_user_claim_keyname @fixed_user_claim_keyname end |
#fixed_user_only ⇒ Object
Allow access using externally (IdP) provided username [true/false]
35 36 37 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 35 def fixed_user_only @fixed_user_only end |
#input_rule ⇒ Object
Agentic input rule in name=…,rule=… format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).
38 39 40 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 38 def input_rule @input_rule end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
41 42 43 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 41 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
44 45 46 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 44 def json @json end |
#name ⇒ Object
Dynamic secret name
47 48 49 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 47 def name @name end |
#new_name ⇒ Object
Dynamic secret name
50 51 52 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 50 def new_name @new_name end |
#output_rule ⇒ Object
Agentic output rule in name=…,rule=… format (e.g. name=rule1,rule=Mask secrets)
53 54 55 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 53 def output_rule @output_rule end |
#password_length ⇒ Object
The length of the password to be generated
56 57 58 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 56 def password_length @password_length end |
#producer_encryption_key_name ⇒ Object
Dynamic producer encryption key
59 60 61 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 59 def producer_encryption_key_name @producer_encryption_key_name end |
#rdp_admin_name ⇒ Object
RDP Admin Name
62 63 64 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 62 def rdp_admin_name @rdp_admin_name end |
#rdp_admin_pwd ⇒ Object
RDP Admin password
65 66 67 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 65 def rdp_admin_pwd @rdp_admin_pwd end |
#rdp_host_name ⇒ Object
Hostname
68 69 70 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 68 def rdp_host_name @rdp_host_name end |
#rdp_host_port ⇒ Object
Port
71 72 73 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 71 def rdp_host_port @rdp_host_port end |
#rdp_user_groups ⇒ Object
Groups
74 75 76 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 74 def rdp_user_groups @rdp_user_groups end |
#secure_access_allow_external_user ⇒ Object
Allow providing external user for a domain users
77 78 79 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 77 def secure_access_allow_external_user @secure_access_allow_external_user end |
#secure_access_bastion_issuer ⇒ Object
Deprecated. use secure-access-certificate-issuer
80 81 82 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 80 def secure_access_bastion_issuer @secure_access_bastion_issuer end |
#secure_access_certificate_issuer ⇒ Object
Path to the SSH Certificate Issuer for your Akeyless Secure Access
83 84 85 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 83 def secure_access_certificate_issuer @secure_access_certificate_issuer end |
#secure_access_delay ⇒ Object
The delay duration, in seconds, to wait after generating just-in-time credentials. Accepted range: 0-120 seconds
86 87 88 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 86 def secure_access_delay @secure_access_delay end |
#secure_access_enable ⇒ Object
Enable/Disable secure remote access [true/false]
89 90 91 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 89 def secure_access_enable @secure_access_enable end |
#secure_access_host ⇒ Object
Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)
92 93 94 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 92 def secure_access_host @secure_access_host end |
#secure_access_rd_gateway_server ⇒ Object
RD Gateway server
95 96 97 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 95 def secure_access_rd_gateway_server @secure_access_rd_gateway_server end |
#secure_access_rdp_domain ⇒ Object
Required when the Dynamic Secret is used for a domain user
98 99 100 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 98 def secure_access_rdp_domain @secure_access_rdp_domain end |
#secure_access_rdp_user ⇒ Object
Override the RDP Domain username
101 102 103 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 101 def secure_access_rdp_user @secure_access_rdp_user end |
#tags ⇒ Object
Add tags attached to this object
104 105 106 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 104 def @tags end |
#target_name ⇒ Object
Target name
107 108 109 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 107 def target_name @target_name end |
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`)
110 111 112 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 110 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
113 114 115 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 113 def uid_token @uid_token end |
#use_capital_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). [true/false]
116 117 118 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 116 def use_capital_letters @use_capital_letters end |
#use_lower_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). [true/false]
119 120 121 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 119 def use_lower_letters @use_lower_letters end |
#use_numbers ⇒ Object
Specifies whether the generated temporary password must contain at least one numeric character (0 to 9). [true/false]
122 123 124 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 122 def use_numbers @use_numbers end |
#use_special_characters ⇒ Object
Returns the value of attribute use_special_characters.
124 125 126 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 124 def use_special_characters @use_special_characters end |
#user_ttl ⇒ Object
User TTL
127 128 129 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 127 def user_ttl @user_ttl end |
#warn_user_before_expiration ⇒ Object
WarnBeforeUserExpiration
130 131 132 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 130 def warn_user_before_expiration @warn_user_before_expiration end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 527 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
177 178 179 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 177 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 133 def self.attribute_map { :'allow_user_extend_session' => :'allow-user-extend-session', :'custom_username_template' => :'custom-username-template', :'delete_protection' => :'delete_protection', :'description' => :'description', :'fixed_user_claim_keyname' => :'fixed-user-claim-keyname', :'fixed_user_only' => :'fixed-user-only', :'input_rule' => :'input-rule', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'name' => :'name', :'new_name' => :'new-name', :'output_rule' => :'output-rule', :'password_length' => :'password-length', :'producer_encryption_key_name' => :'producer-encryption-key-name', :'rdp_admin_name' => :'rdp-admin-name', :'rdp_admin_pwd' => :'rdp-admin-pwd', :'rdp_host_name' => :'rdp-host-name', :'rdp_host_port' => :'rdp-host-port', :'rdp_user_groups' => :'rdp-user-groups', :'secure_access_allow_external_user' => :'secure-access-allow-external-user', :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer', :'secure_access_certificate_issuer' => :'secure-access-certificate-issuer', :'secure_access_delay' => :'secure-access-delay', :'secure_access_enable' => :'secure-access-enable', :'secure_access_host' => :'secure-access-host', :'secure_access_rd_gateway_server' => :'secure-access-rd-gateway-server', :'secure_access_rdp_domain' => :'secure-access-rdp-domain', :'secure_access_rdp_user' => :'secure-access-rdp-user', :'tags' => :'tags', :'target_name' => :'target-name', :'token' => :'token', :'uid_token' => :'uid-token', :'use_capital_letters' => :'use-capital-letters', :'use_lower_letters' => :'use-lower-letters', :'use_numbers' => :'use-numbers', :'use_special_characters' => :'use-special-characters', :'user_ttl' => :'user-ttl', :'warn_user_before_expiration' => :'warn-user-before-expiration' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 503 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
226 227 228 229 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 226 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 182 def self.openapi_types { :'allow_user_extend_session' => :'Integer', :'custom_username_template' => :'String', :'delete_protection' => :'String', :'description' => :'String', :'fixed_user_claim_keyname' => :'String', :'fixed_user_only' => :'String', :'input_rule' => :'Array<String>', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'name' => :'String', :'new_name' => :'String', :'output_rule' => :'Array<String>', :'password_length' => :'String', :'producer_encryption_key_name' => :'String', :'rdp_admin_name' => :'String', :'rdp_admin_pwd' => :'String', :'rdp_host_name' => :'String', :'rdp_host_port' => :'String', :'rdp_user_groups' => :'String', :'secure_access_allow_external_user' => :'Boolean', :'secure_access_bastion_issuer' => :'String', :'secure_access_certificate_issuer' => :'String', :'secure_access_delay' => :'Integer', :'secure_access_enable' => :'String', :'secure_access_host' => :'Array<String>', :'secure_access_rd_gateway_server' => :'String', :'secure_access_rdp_domain' => :'String', :'secure_access_rdp_user' => :'String', :'tags' => :'Array<String>', :'target_name' => :'String', :'token' => :'String', :'uid_token' => :'String', :'use_capital_letters' => :'String', :'use_lower_letters' => :'String', :'use_numbers' => :'String', :'use_special_characters' => :'String', :'user_ttl' => :'String', :'warn_user_before_expiration' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 445 def ==(o) return true if self.equal?(o) self.class == o.class && allow_user_extend_session == o.allow_user_extend_session && custom_username_template == o.custom_username_template && delete_protection == o.delete_protection && description == o.description && fixed_user_claim_keyname == o.fixed_user_claim_keyname && fixed_user_only == o.fixed_user_only && input_rule == o.input_rule && item_custom_fields == o.item_custom_fields && json == o.json && name == o.name && new_name == o.new_name && output_rule == o.output_rule && password_length == o.password_length && producer_encryption_key_name == o.producer_encryption_key_name && rdp_admin_name == o.rdp_admin_name && rdp_admin_pwd == o.rdp_admin_pwd && rdp_host_name == o.rdp_host_name && rdp_host_port == o.rdp_host_port && rdp_user_groups == o.rdp_user_groups && secure_access_allow_external_user == o.secure_access_allow_external_user && secure_access_bastion_issuer == o.secure_access_bastion_issuer && secure_access_certificate_issuer == o.secure_access_certificate_issuer && secure_access_delay == o.secure_access_delay && secure_access_enable == o.secure_access_enable && secure_access_host == o.secure_access_host && secure_access_rd_gateway_server == o.secure_access_rd_gateway_server && secure_access_rdp_domain == o.secure_access_rdp_domain && secure_access_rdp_user == o.secure_access_rdp_user && == o. && target_name == o.target_name && token == o.token && uid_token == o.uid_token && use_capital_letters == o.use_capital_letters && use_lower_letters == o.use_lower_letters && use_numbers == o.use_numbers && use_special_characters == o.use_special_characters && user_ttl == o.user_ttl && warn_user_before_expiration == o.warn_user_before_expiration end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
598 599 600 601 602 603 604 605 606 607 608 609 610 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 598 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
490 491 492 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 490 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
496 497 498 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 496 def hash [allow_user_extend_session, custom_username_template, delete_protection, description, fixed_user_claim_keyname, fixed_user_only, input_rule, item_custom_fields, json, name, new_name, output_rule, password_length, producer_encryption_key_name, rdp_admin_name, rdp_admin_pwd, rdp_host_name, rdp_host_port, rdp_user_groups, secure_access_allow_external_user, secure_access_bastion_issuer, secure_access_certificate_issuer, secure_access_delay, secure_access_enable, secure_access_host, secure_access_rd_gateway_server, secure_access_rdp_domain, secure_access_rdp_user, , target_name, token, uid_token, use_capital_letters, use_lower_letters, use_numbers, use_special_characters, user_ttl, warn_user_before_expiration].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
425 426 427 428 429 430 431 432 433 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 425 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
574 575 576 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 574 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
580 581 582 583 584 585 586 587 588 589 590 591 592 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 580 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
568 569 570 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 568 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
437 438 439 440 441 |
# File 'lib/akeyless/models/dynamic_secret_update_rdp.rb', line 437 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |