Class: Akeyless::DynamicSecretUpdateSnowflake
- Inherits:
-
Object
- Object
- Akeyless::DynamicSecretUpdateSnowflake
- Defined in:
- lib/akeyless/models/dynamic_secret_update_snowflake.rb
Overview
GatewayUpdateProducerSnowflakeCmd is a command that updates a Snowflake dynamic secret
Instance Attribute Summary collapse
-
#account ⇒ Object
Account name.
-
#account_password ⇒ Object
Database Password.
-
#account_username ⇒ Object
Database Username.
-
#auth_mode ⇒ Object
The authentication mode for the temporary user [password/key].
-
#custom_username_template ⇒ Object
Customize how temporary usernames are generated using go template.
-
#db_name ⇒ Object
Database name.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#description ⇒ Object
Description of the object.
-
#input_rule ⇒ Object
Agentic input rule in name=…,rule=…
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#key_algo ⇒ Object
Returns the value of attribute key_algo.
-
#name ⇒ Object
Dynamic secret name.
-
#new_name ⇒ Object
Dynamic secret name.
-
#output_rule ⇒ Object
Agentic output rule in name=…,rule=…
-
#password_length ⇒ Object
The length of the password to be generated.
-
#private_key ⇒ Object
RSA Private key (base64 encoded).
-
#private_key_passphrase ⇒ Object
The Private key passphrase.
-
#role ⇒ Object
User role.
-
#tags ⇒ Object
Add tags attached to this object.
-
#target_name ⇒ Object
Target name.
-
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`).
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#user_ttl ⇒ Object
User TTL.
-
#warehouse ⇒ Object
Warehouse name.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DynamicSecretUpdateSnowflake
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DynamicSecretUpdateSnowflake
Initializes the object
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 168 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::DynamicSecretUpdateSnowflake` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::DynamicSecretUpdateSnowflake`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account') self.account = attributes[:'account'] end if attributes.key?(:'account_password') self.account_password = attributes[:'account_password'] end if attributes.key?(:'account_username') self.account_username = attributes[:'account_username'] end if attributes.key?(:'auth_mode') self.auth_mode = attributes[:'auth_mode'] else self.auth_mode = 'password' end if attributes.key?(:'custom_username_template') self.custom_username_template = attributes[:'custom_username_template'] end if attributes.key?(:'db_name') self.db_name = attributes[:'db_name'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'key_algo') self.key_algo = attributes[:'key_algo'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'new_name') self.new_name = attributes[:'new_name'] end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'password_length') self.password_length = attributes[:'password_length'] end if attributes.key?(:'private_key') self.private_key = attributes[:'private_key'] end if attributes.key?(:'private_key_passphrase') self.private_key_passphrase = attributes[:'private_key_passphrase'] end if attributes.key?(:'role') self.role = attributes[:'role'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'target_name') self.target_name = attributes[:'target_name'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'user_ttl') self.user_ttl = attributes[:'user_ttl'] else self.user_ttl = '24h' end if attributes.key?(:'warehouse') self.warehouse = attributes[:'warehouse'] end end |
Instance Attribute Details
#account ⇒ Object
Account name
20 21 22 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 20 def account @account end |
#account_password ⇒ Object
Database Password
23 24 25 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 23 def account_password @account_password end |
#account_username ⇒ Object
Database Username
26 27 28 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 26 def account_username @account_username end |
#auth_mode ⇒ Object
The authentication mode for the temporary user [password/key]
29 30 31 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 29 def auth_mode @auth_mode end |
#custom_username_template ⇒ Object
Customize how temporary usernames are generated using go template
32 33 34 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 32 def custom_username_template @custom_username_template end |
#db_name ⇒ Object
Database name
35 36 37 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 35 def db_name @db_name end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
38 39 40 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 38 def delete_protection @delete_protection end |
#description ⇒ Object
Description of the object
41 42 43 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 41 def description @description end |
#input_rule ⇒ Object
Agentic input rule in name=…,rule=… format (e.g. name=rule1,rule=Sanitize input) Mirrors commands.AgenticRulesParams — kept separate because ResourceDS cannot embed it (different package, different struct layout).
44 45 46 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 44 def input_rule @input_rule end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
47 48 49 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 47 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
50 51 52 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 50 def json @json end |
#key_algo ⇒ Object
Returns the value of attribute key_algo.
52 53 54 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 52 def key_algo @key_algo end |
#name ⇒ Object
Dynamic secret name
55 56 57 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 55 def name @name end |
#new_name ⇒ Object
Dynamic secret name
58 59 60 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 58 def new_name @new_name end |
#output_rule ⇒ Object
Agentic output rule in name=…,rule=… format (e.g. name=rule1,rule=Mask secrets)
61 62 63 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 61 def output_rule @output_rule end |
#password_length ⇒ Object
The length of the password to be generated
64 65 66 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 64 def password_length @password_length end |
#private_key ⇒ Object
RSA Private key (base64 encoded)
67 68 69 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 67 def private_key @private_key end |
#private_key_passphrase ⇒ Object
The Private key passphrase
70 71 72 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 70 def private_key_passphrase @private_key_passphrase end |
#role ⇒ Object
User role
73 74 75 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 73 def role @role end |
#tags ⇒ Object
Add tags attached to this object
76 77 78 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 76 def @tags end |
#target_name ⇒ Object
Target name
79 80 81 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 79 def target_name @target_name end |
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`)
82 83 84 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 82 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
85 86 87 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 85 def uid_token @uid_token end |
#user_ttl ⇒ Object
User TTL
88 89 90 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 88 def user_ttl @user_ttl end |
#warehouse ⇒ Object
Warehouse name
91 92 93 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 91 def warehouse @warehouse end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 389 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
125 126 127 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 125 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 94 def self.attribute_map { :'account' => :'account', :'account_password' => :'account-password', :'account_username' => :'account-username', :'auth_mode' => :'auth-mode', :'custom_username_template' => :'custom-username-template', :'db_name' => :'db-name', :'delete_protection' => :'delete_protection', :'description' => :'description', :'input_rule' => :'input-rule', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'key_algo' => :'key-algo', :'name' => :'name', :'new_name' => :'new-name', :'output_rule' => :'output-rule', :'password_length' => :'password-length', :'private_key' => :'private-key', :'private_key_passphrase' => :'private-key-passphrase', :'role' => :'role', :'tags' => :'tags', :'target_name' => :'target-name', :'token' => :'token', :'uid_token' => :'uid-token', :'user_ttl' => :'user-ttl', :'warehouse' => :'warehouse' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 365 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
161 162 163 164 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 161 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 130 def self.openapi_types { :'account' => :'String', :'account_password' => :'String', :'account_username' => :'String', :'auth_mode' => :'String', :'custom_username_template' => :'String', :'db_name' => :'String', :'delete_protection' => :'String', :'description' => :'String', :'input_rule' => :'Array<String>', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'key_algo' => :'String', :'name' => :'String', :'new_name' => :'String', :'output_rule' => :'Array<String>', :'password_length' => :'String', :'private_key' => :'String', :'private_key_passphrase' => :'String', :'role' => :'String', :'tags' => :'Array<String>', :'target_name' => :'String', :'token' => :'String', :'uid_token' => :'String', :'user_ttl' => :'String', :'warehouse' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 320 def ==(o) return true if self.equal?(o) self.class == o.class && account == o.account && account_password == o.account_password && account_username == o.account_username && auth_mode == o.auth_mode && custom_username_template == o.custom_username_template && db_name == o.db_name && delete_protection == o.delete_protection && description == o.description && input_rule == o.input_rule && item_custom_fields == o.item_custom_fields && json == o.json && key_algo == o.key_algo && name == o.name && new_name == o.new_name && output_rule == o.output_rule && password_length == o.password_length && private_key == o.private_key && private_key_passphrase == o.private_key_passphrase && role == o.role && == o. && target_name == o.target_name && token == o.token && uid_token == o.uid_token && user_ttl == o.user_ttl && warehouse == o.warehouse end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 460 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
352 353 354 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 352 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
358 359 360 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 358 def hash [account, account_password, account_username, auth_mode, custom_username_template, db_name, delete_protection, description, input_rule, item_custom_fields, json, key_algo, name, new_name, output_rule, password_length, private_key, private_key_passphrase, role, , target_name, token, uid_token, user_ttl, warehouse].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
300 301 302 303 304 305 306 307 308 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 300 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
436 437 438 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 436 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
442 443 444 445 446 447 448 449 450 451 452 453 454 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 442 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
430 431 432 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 430 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
312 313 314 315 316 |
# File 'lib/akeyless/models/dynamic_secret_update_snowflake.rb', line 312 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |