Class: Akeyless::GatewayUpdateProducerAzure

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/gateway_update_producer_azure.rb

Overview

gatewayUpdateProducerAzure is a command that updates azure producer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GatewayUpdateProducerAzure

Initializes the object



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 155

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayUpdateProducerAzure` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayUpdateProducerAzure`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'app_obj_id')
    self.app_obj_id = attributes[:'app_obj_id']
  end

  if attributes.key?(:'azure_client_id')
    self.azure_client_id = attributes[:'azure_client_id']
  end

  if attributes.key?(:'azure_client_secret')
    self.azure_client_secret = attributes[:'azure_client_secret']
  end

  if attributes.key?(:'azure_tenant_id')
    self.azure_tenant_id = attributes[:'azure_tenant_id']
  end

  if attributes.key?(:'fixed_user_claim_keyname')
    self.fixed_user_claim_keyname = attributes[:'fixed_user_claim_keyname']
  else
    self.fixed_user_claim_keyname = 'false'
  end

  if attributes.key?(:'fixed_user_only')
    self.fixed_user_only = attributes[:'fixed_user_only']
  else
    self.fixed_user_only = false
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'producer_encryption_key_name')
    self.producer_encryption_key_name = attributes[:'producer_encryption_key_name']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_web')
    self.secure_access_web = attributes[:'secure_access_web']
  end

  if attributes.key?(:'secure_access_web_browsing')
    self.secure_access_web_browsing = attributes[:'secure_access_web_browsing']
  end

  if attributes.key?(:'secure_access_web_proxy')
    self.secure_access_web_proxy = attributes[:'secure_access_web_proxy']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'user_group_obj_id')
    self.user_group_obj_id = attributes[:'user_group_obj_id']
  end

  if attributes.key?(:'user_portal_access')
    self.user_portal_access = attributes[:'user_portal_access']
  else
    self.user_portal_access = false
  end

  if attributes.key?(:'user_principal_name')
    self.user_principal_name = attributes[:'user_principal_name']
  end

  if attributes.key?(:'user_programmatic_access')
    self.user_programmatic_access = attributes[:'user_programmatic_access']
  else
    self.user_programmatic_access = false
  end

  if attributes.key?(:'user_role_template_id')
    self.user_role_template_id = attributes[:'user_role_template_id']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '60m'
  end
end

Instance Attribute Details

#app_obj_idObject

Azure App Object Id



20
21
22
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 20

def app_obj_id
  @app_obj_id
end

#azure_client_idObject

Azure Client ID



23
24
25
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 23

def azure_client_id
  @azure_client_id
end

#azure_client_secretObject

Azure Client Secret



26
27
28
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 26

def azure_client_secret
  @azure_client_secret
end

#azure_tenant_idObject

Azure Tenant ID



29
30
31
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 29

def azure_tenant_id
  @azure_tenant_id
end

#fixed_user_claim_keynameObject

FixedUserClaimKeyname



32
33
34
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 32

def fixed_user_claim_keyname
  @fixed_user_claim_keyname
end

#fixed_user_onlyObject

Fixed user



35
36
37
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 35

def fixed_user_only
  @fixed_user_only
end

#nameObject

Producer name



38
39
40
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 38

def name
  @name
end

#new_nameObject

Producer name



41
42
43
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 41

def new_name
  @new_name
end

#producer_encryption_key_nameObject

Dynamic producer encryption key



44
45
46
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 44

def producer_encryption_key_name
  @producer_encryption_key_name
end

#secure_access_enableObject

Returns the value of attribute secure_access_enable.



46
47
48
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 46

def secure_access_enable
  @secure_access_enable
end

#secure_access_webObject

Returns the value of attribute secure_access_web.



48
49
50
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 48

def secure_access_web
  @secure_access_web
end

#secure_access_web_browsingObject

Returns the value of attribute secure_access_web_browsing.



50
51
52
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 50

def secure_access_web_browsing
  @secure_access_web_browsing
end

#secure_access_web_proxyObject

Returns the value of attribute secure_access_web_proxy.



52
53
54
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 52

def secure_access_web_proxy
  @secure_access_web_proxy
end

#tagsObject

List of the tags attached to this secret



55
56
57
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 55

def tags
  @tags
end

#target_nameObject

Target name



58
59
60
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 58

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



61
62
63
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 61

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



64
65
66
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 64

def uid_token
  @uid_token
end

#user_group_obj_idObject

User Group Object Id



67
68
69
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 67

def user_group_obj_id
  @user_group_obj_id
end

#user_portal_accessObject

Azure User portal access



70
71
72
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 70

def user_portal_access
  @user_portal_access
end

#user_principal_nameObject

User Principal Name



73
74
75
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 73

def user_principal_name
  @user_principal_name
end

#user_programmatic_accessObject

Azure User programmatic access



76
77
78
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 76

def user_programmatic_access
  @user_programmatic_access
end

#user_role_template_idObject

User Role Template Id



79
80
81
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 79

def user_role_template_id
  @user_role_template_id
end

#user_ttlObject

User TTL



82
83
84
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 82

def user_ttl
  @user_ttl
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



114
115
116
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 114

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 85

def self.attribute_map
  {
    :'app_obj_id' => :'app-obj-id',
    :'azure_client_id' => :'azure-client-id',
    :'azure_client_secret' => :'azure-client-secret',
    :'azure_tenant_id' => :'azure-tenant-id',
    :'fixed_user_claim_keyname' => :'fixed-user-claim-keyname',
    :'fixed_user_only' => :'fixed-user-only',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'producer_encryption_key_name' => :'producer-encryption-key-name',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_web' => :'secure-access-web',
    :'secure_access_web_browsing' => :'secure-access-web-browsing',
    :'secure_access_web_proxy' => :'secure-access-web-proxy',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'user_group_obj_id' => :'user-group-obj-id',
    :'user_portal_access' => :'user-portal-access',
    :'user_principal_name' => :'user-principal-name',
    :'user_programmatic_access' => :'user-programmatic-access',
    :'user_role_template_id' => :'user-role-template-id',
    :'user_ttl' => :'user-ttl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



336
337
338
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 336

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



148
149
150
151
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 148

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 119

def self.openapi_types
  {
    :'app_obj_id' => :'String',
    :'azure_client_id' => :'String',
    :'azure_client_secret' => :'String',
    :'azure_tenant_id' => :'String',
    :'fixed_user_claim_keyname' => :'String',
    :'fixed_user_only' => :'Boolean',
    :'name' => :'String',
    :'new_name' => :'String',
    :'producer_encryption_key_name' => :'String',
    :'secure_access_enable' => :'String',
    :'secure_access_web' => :'Boolean',
    :'secure_access_web_browsing' => :'Boolean',
    :'secure_access_web_proxy' => :'Boolean',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'user_group_obj_id' => :'String',
    :'user_portal_access' => :'Boolean',
    :'user_principal_name' => :'String',
    :'user_programmatic_access' => :'Boolean',
    :'user_role_template_id' => :'String',
    :'user_ttl' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 293

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      app_obj_id == o.app_obj_id &&
      azure_client_id == o.azure_client_id &&
      azure_client_secret == o.azure_client_secret &&
      azure_tenant_id == o.azure_tenant_id &&
      fixed_user_claim_keyname == o.fixed_user_claim_keyname &&
      fixed_user_only == o.fixed_user_only &&
      name == o.name &&
      new_name == o.new_name &&
      producer_encryption_key_name == o.producer_encryption_key_name &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_web == o.secure_access_web &&
      secure_access_web_browsing == o.secure_access_web_browsing &&
      secure_access_web_proxy == o.secure_access_web_proxy &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      user_group_obj_id == o.user_group_obj_id &&
      user_portal_access == o.user_portal_access &&
      user_principal_name == o.user_principal_name &&
      user_programmatic_access == o.user_programmatic_access &&
      user_role_template_id == o.user_role_template_id &&
      user_ttl == o.user_ttl
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 367

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 438

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 343

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


323
324
325
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 323

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



329
330
331
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 329

def hash
  [app_obj_id, azure_client_id, azure_client_secret, azure_tenant_id, fixed_user_claim_keyname, fixed_user_only, name, new_name, producer_encryption_key_name, secure_access_enable, secure_access_web, secure_access_web_browsing, secure_access_web_proxy, tags, target_name, token, uid_token, user_group_obj_id, user_portal_access, user_principal_name, user_programmatic_access, user_role_template_id, user_ttl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



275
276
277
278
279
280
281
282
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 275

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



414
415
416
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 414

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 420

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



408
409
410
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 408

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



286
287
288
289
# File 'lib/akeyless/models/gateway_update_producer_azure.rb', line 286

def valid?
  return false if @name.nil?
  true
end