Class: Akeyless::GatewayUpdateProducerGithub

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/gateway_update_producer_github.rb

Overview

gatewayUpdateProducerGithub is a command that updates github producer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GatewayUpdateProducerGithub

Initializes the object



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayUpdateProducerGithub` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayUpdateProducerGithub`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'github_app_id')
    self.github_app_id = attributes[:'github_app_id']
  end

  if attributes.key?(:'github_app_private_key')
    self.github_app_private_key = attributes[:'github_app_private_key']
  end

  if attributes.key?(:'github_base_url')
    self.github_base_url = attributes[:'github_base_url']
  end

  if attributes.key?(:'installation_id')
    self.installation_id = attributes[:'installation_id']
  end

  if attributes.key?(:'installation_repository')
    self.installation_repository = attributes[:'installation_repository']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'token_permissions')
    if (value = attributes[:'token_permissions']).is_a?(Array)
      self.token_permissions = value
    end
  end

  if attributes.key?(:'token_repositories')
    if (value = attributes[:'token_repositories']).is_a?(Array)
      self.token_repositories = value
    end
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end
end

Instance Attribute Details

#github_app_idObject

Github app id



20
21
22
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 20

def github_app_id
  @github_app_id
end

#github_app_private_keyObject

App private key



23
24
25
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 23

def github_app_private_key
  @github_app_private_key
end

#github_base_urlObject

Base URL



26
27
28
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 26

def github_base_url
  @github_base_url
end

#installation_idObject

Github app installation id



29
30
31
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 29

def installation_id
  @installation_id
end

#installation_repositoryObject

Repository that the app installation has access to



32
33
34
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 32

def installation_repository
  @installation_repository
end

#nameObject

Producer name



35
36
37
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 35

def name
  @name
end

#new_nameObject

Producer name



38
39
40
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 38

def new_name
  @new_name
end

#target_nameObject

Target name



41
42
43
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 41

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



44
45
46
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 44

def token
  @token
end

#token_permissionsObject

Optional - installation token's allowed permissions



47
48
49
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 47

def token_permissions
  @token_permissions
end

#token_repositoriesObject

Optional - installation token's allowed repositories



50
51
52
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 50

def token_repositories
  @token_repositories
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



53
54
55
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 53

def uid_token
  @uid_token
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 74

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 56

def self.attribute_map
  {
    :'github_app_id' => :'github-app-id',
    :'github_app_private_key' => :'github-app-private-key',
    :'github_base_url' => :'github-base-url',
    :'installation_id' => :'installation-id',
    :'installation_repository' => :'installation-repository',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'token_permissions' => :'token-permissions',
    :'token_repositories' => :'token-repositories',
    :'uid_token' => :'uid-token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



222
223
224
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 222

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 79

def self.openapi_types
  {
    :'github_app_id' => :'Integer',
    :'github_app_private_key' => :'String',
    :'github_base_url' => :'String',
    :'installation_id' => :'Integer',
    :'installation_repository' => :'String',
    :'name' => :'String',
    :'new_name' => :'String',
    :'target_name' => :'String',
    :'token' => :'String',
    :'token_permissions' => :'Array<String>',
    :'token_repositories' => :'Array<String>',
    :'uid_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 190

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      github_app_id == o.github_app_id &&
      github_app_private_key == o.github_app_private_key &&
      github_base_url == o.github_base_url &&
      installation_id == o.installation_id &&
      installation_repository == o.installation_repository &&
      name == o.name &&
      new_name == o.new_name &&
      target_name == o.target_name &&
      token == o.token &&
      token_permissions == o.token_permissions &&
      token_repositories == o.token_repositories &&
      uid_token == o.uid_token
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 253

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 324

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 229

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


209
210
211
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 209

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



215
216
217
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 215

def hash
  [github_app_id, github_app_private_key, github_base_url, installation_id, installation_repository, name, new_name, target_name, token, token_permissions, token_repositories, uid_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



172
173
174
175
176
177
178
179
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 172

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



300
301
302
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 300

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 306

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



294
295
296
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 294

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



183
184
185
186
# File 'lib/akeyless/models/gateway_update_producer_github.rb', line 183

def valid?
  return false if @name.nil?
  true
end