Class: Akeyless::GatewayUpdateProducerSnowflake

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/gateway_update_producer_snowflake.rb

Overview

gatewayUpdateProducerSnowflakeCmd is a command that updates a Snowflake producer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ GatewayUpdateProducerSnowflake

Initializes the object



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::GatewayUpdateProducerSnowflake` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::GatewayUpdateProducerSnowflake`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account')
    self. = attributes[:'account']
  end

  if attributes.key?(:'account_password')
    self. = attributes[:'account_password']
  end

  if attributes.key?(:'account_username')
    self. = attributes[:'account_username']
  end

  if attributes.key?(:'db_name')
    self.db_name = attributes[:'db_name']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'user_ttl')
    self.user_ttl = attributes[:'user_ttl']
  else
    self.user_ttl = '24h'
  end

  if attributes.key?(:'warehouse')
    self.warehouse = attributes[:'warehouse']
  end
end

Instance Attribute Details

#accountObject

Account name



20
21
22
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 20

def 
  @account
end

#account_passwordObject

Database Password



23
24
25
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 23

def 
  @account_password
end

#account_usernameObject

Database Username



26
27
28
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 26

def 
  @account_username
end

#db_nameObject

Database name



29
30
31
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 29

def db_name
  @db_name
end

#nameObject

Producer name



32
33
34
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 32

def name
  @name
end

#new_nameObject

Producer name



35
36
37
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 35

def new_name
  @new_name
end

#roleObject

User role



38
39
40
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 38

def role
  @role
end

#tagsObject

List of the tags attached to this secret



41
42
43
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 41

def tags
  @tags
end

#target_nameObject

Target name



44
45
46
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 44

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



47
48
49
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 47

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



50
51
52
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 50

def uid_token
  @uid_token
end

#user_ttlObject

User TTL



53
54
55
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 53

def user_ttl
  @user_ttl
end

#warehouseObject

Warehouse name



56
57
58
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 56

def warehouse
  @warehouse
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 78

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 59

def self.attribute_map
  {
    :'account' => :'account',
    :'account_password' => :'account-password',
    :'account_username' => :'account-username',
    :'db_name' => :'db-name',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'role' => :'role',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'user_ttl' => :'user-ttl',
    :'warehouse' => :'warehouse'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



232
233
234
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 232

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 83

def self.openapi_types
  {
    :'account' => :'String',
    :'account_password' => :'String',
    :'account_username' => :'String',
    :'db_name' => :'String',
    :'name' => :'String',
    :'new_name' => :'String',
    :'role' => :'String',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'user_ttl' => :'String',
    :'warehouse' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 199

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
       == o. &&
       == o. &&
      db_name == o.db_name &&
      name == o.name &&
      new_name == o.new_name &&
      role == o.role &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      user_ttl == o.user_ttl &&
      warehouse == o.warehouse
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 263

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 334

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 239

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


219
220
221
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 219

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



225
226
227
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 225

def hash
  [, , , db_name, name, new_name, role, tags, target_name, token, uid_token, user_ttl, warehouse].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



181
182
183
184
185
186
187
188
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 181

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



310
311
312
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 310

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 316

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



304
305
306
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 304

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



192
193
194
195
# File 'lib/akeyless/models/gateway_update_producer_snowflake.rb', line 192

def valid?
  return false if @name.nil?
  true
end