Class: Akeyless::Item

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/item.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Item

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/akeyless/models/item.rb', line 180

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::Item` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::Item`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'access_date')
    self.access_date = attributes[:'access_date']
  end

  if attributes.key?(:'auto_rotate')
    self.auto_rotate = attributes[:'auto_rotate']
  end

  if attributes.key?(:'cert_issuer_signer_key_name')
    self.cert_issuer_signer_key_name = attributes[:'cert_issuer_signer_key_name']
  end

  if attributes.key?(:'certificate_issue_details')
    self.certificate_issue_details = attributes[:'certificate_issue_details']
  end

  if attributes.key?(:'certificates')
    self.certificates = attributes[:'certificates']
  end

  if attributes.key?(:'client_permissions')
    if (value = attributes[:'client_permissions']).is_a?(Array)
      self.client_permissions = value
    end
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  end

  if attributes.key?(:'customer_fragment_id')
    self.customer_fragment_id = attributes[:'customer_fragment_id']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'deletion_date')
    self.deletion_date = attributes[:'deletion_date']
  end

  if attributes.key?(:'display_id')
    self.display_id = attributes[:'display_id']
  end

  if attributes.key?(:'is_enabled')
    self.is_enabled = attributes[:'is_enabled']
  end

  if attributes.key?(:'item_accessibility')
    self.item_accessibility = attributes[:'item_accessibility']
  end

  if attributes.key?(:'item_general_info')
    self.item_general_info = attributes[:'item_general_info']
  end

  if attributes.key?(:'item_id')
    self.item_id = attributes[:'item_id']
  end

  if attributes.key?(:'item_metadata')
    self. = attributes[:'item_metadata']
  end

  if attributes.key?(:'item_name')
    self.item_name = attributes[:'item_name']
  end

  if attributes.key?(:'item_size')
    self.item_size = attributes[:'item_size']
  end

  if attributes.key?(:'item_state')
    self.item_state = attributes[:'item_state']
  end

  if attributes.key?(:'item_sub_type')
    self.item_sub_type = attributes[:'item_sub_type']
  end

  if attributes.key?(:'item_tags')
    if (value = attributes[:'item_tags']).is_a?(Array)
      self.item_tags = value
    end
  end

  if attributes.key?(:'item_targets_assoc')
    if (value = attributes[:'item_targets_assoc']).is_a?(Array)
      self.item_targets_assoc = value
    end
  end

  if attributes.key?(:'item_type')
    self.item_type = attributes[:'item_type']
  end

  if attributes.key?(:'item_versions')
    if (value = attributes[:'item_versions']).is_a?(Array)
      self.item_versions = value
    end
  end

  if attributes.key?(:'last_version')
    self.last_version = attributes[:'last_version']
  end

  if attributes.key?(:'modification_date')
    self.modification_date = attributes[:'modification_date']
  end

  if attributes.key?(:'next_rotation_date')
    self.next_rotation_date = attributes[:'next_rotation_date']
  end

  if attributes.key?(:'protection_key_name')
    self.protection_key_name = attributes[:'protection_key_name']
  end

  if attributes.key?(:'protection_key_type')
    self.protection_key_type = attributes[:'protection_key_type']
  end

  if attributes.key?(:'public_value')
    self.public_value = attributes[:'public_value']
  end

  if attributes.key?(:'rotation_interval')
    self.rotation_interval = attributes[:'rotation_interval']
  end

  if attributes.key?(:'shared_by')
    self.shared_by = attributes[:'shared_by']
  end

  if attributes.key?(:'target_versions')
    if (value = attributes[:'target_versions']).is_a?(Array)
      self.target_versions = value
    end
  end

  if attributes.key?(:'with_customer_fragment')
    self.with_customer_fragment = attributes[:'with_customer_fragment']
  end
end

Instance Attribute Details

#access_dateObject

Returns the value of attribute access_date.



18
19
20
# File 'lib/akeyless/models/item.rb', line 18

def access_date
  @access_date
end

#auto_rotateObject

Returns the value of attribute auto_rotate.



20
21
22
# File 'lib/akeyless/models/item.rb', line 20

def auto_rotate
  @auto_rotate
end

#cert_issuer_signer_key_nameObject

Returns the value of attribute cert_issuer_signer_key_name.



22
23
24
# File 'lib/akeyless/models/item.rb', line 22

def cert_issuer_signer_key_name
  @cert_issuer_signer_key_name
end

#certificate_issue_detailsObject

Returns the value of attribute certificate_issue_details.



24
25
26
# File 'lib/akeyless/models/item.rb', line 24

def certificate_issue_details
  @certificate_issue_details
end

#certificatesObject

Returns the value of attribute certificates.



26
27
28
# File 'lib/akeyless/models/item.rb', line 26

def certificates
  @certificates
end

#client_permissionsObject

Returns the value of attribute client_permissions.



28
29
30
# File 'lib/akeyless/models/item.rb', line 28

def client_permissions
  @client_permissions
end

#creation_dateObject

Returns the value of attribute creation_date.



30
31
32
# File 'lib/akeyless/models/item.rb', line 30

def creation_date
  @creation_date
end

#customer_fragment_idObject

Returns the value of attribute customer_fragment_id.



32
33
34
# File 'lib/akeyless/models/item.rb', line 32

def customer_fragment_id
  @customer_fragment_id
end

#delete_protectionObject

Returns the value of attribute delete_protection.



34
35
36
# File 'lib/akeyless/models/item.rb', line 34

def delete_protection
  @delete_protection
end

#deletion_dateObject

Returns the value of attribute deletion_date.



36
37
38
# File 'lib/akeyless/models/item.rb', line 36

def deletion_date
  @deletion_date
end

#display_idObject

Returns the value of attribute display_id.



38
39
40
# File 'lib/akeyless/models/item.rb', line 38

def display_id
  @display_id
end

#is_enabledObject

Returns the value of attribute is_enabled.



40
41
42
# File 'lib/akeyless/models/item.rb', line 40

def is_enabled
  @is_enabled
end

#item_accessibilityObject

Returns the value of attribute item_accessibility.



42
43
44
# File 'lib/akeyless/models/item.rb', line 42

def item_accessibility
  @item_accessibility
end

#item_general_infoObject

Returns the value of attribute item_general_info.



44
45
46
# File 'lib/akeyless/models/item.rb', line 44

def item_general_info
  @item_general_info
end

#item_idObject

Returns the value of attribute item_id.



46
47
48
# File 'lib/akeyless/models/item.rb', line 46

def item_id
  @item_id
end

#item_metadataObject

Returns the value of attribute item_metadata.



48
49
50
# File 'lib/akeyless/models/item.rb', line 48

def 
  @item_metadata
end

#item_nameObject

Returns the value of attribute item_name.



50
51
52
# File 'lib/akeyless/models/item.rb', line 50

def item_name
  @item_name
end

#item_sizeObject

Returns the value of attribute item_size.



52
53
54
# File 'lib/akeyless/models/item.rb', line 52

def item_size
  @item_size
end

#item_stateObject

ItemState defines the different states an Item can be in



55
56
57
# File 'lib/akeyless/models/item.rb', line 55

def item_state
  @item_state
end

#item_sub_typeObject

Returns the value of attribute item_sub_type.



57
58
59
# File 'lib/akeyless/models/item.rb', line 57

def item_sub_type
  @item_sub_type
end

#item_tagsObject

Returns the value of attribute item_tags.



59
60
61
# File 'lib/akeyless/models/item.rb', line 59

def item_tags
  @item_tags
end

#item_targets_assocObject

Returns the value of attribute item_targets_assoc.



61
62
63
# File 'lib/akeyless/models/item.rb', line 61

def item_targets_assoc
  @item_targets_assoc
end

#item_typeObject

Returns the value of attribute item_type.



63
64
65
# File 'lib/akeyless/models/item.rb', line 63

def item_type
  @item_type
end

#item_versionsObject

Returns the value of attribute item_versions.



65
66
67
# File 'lib/akeyless/models/item.rb', line 65

def item_versions
  @item_versions
end

#last_versionObject

Returns the value of attribute last_version.



67
68
69
# File 'lib/akeyless/models/item.rb', line 67

def last_version
  @last_version
end

#modification_dateObject

Returns the value of attribute modification_date.



69
70
71
# File 'lib/akeyless/models/item.rb', line 69

def modification_date
  @modification_date
end

#next_rotation_dateObject

Returns the value of attribute next_rotation_date.



71
72
73
# File 'lib/akeyless/models/item.rb', line 71

def next_rotation_date
  @next_rotation_date
end

#protection_key_nameObject

Returns the value of attribute protection_key_name.



73
74
75
# File 'lib/akeyless/models/item.rb', line 73

def protection_key_name
  @protection_key_name
end

#protection_key_typeObject

Returns the value of attribute protection_key_type.



75
76
77
# File 'lib/akeyless/models/item.rb', line 75

def protection_key_type
  @protection_key_type
end

#public_valueObject

Returns the value of attribute public_value.



77
78
79
# File 'lib/akeyless/models/item.rb', line 77

def public_value
  @public_value
end

#rotation_intervalObject

Returns the value of attribute rotation_interval.



79
80
81
# File 'lib/akeyless/models/item.rb', line 79

def rotation_interval
  @rotation_interval
end

#shared_byObject

Returns the value of attribute shared_by.



81
82
83
# File 'lib/akeyless/models/item.rb', line 81

def shared_by
  @shared_by
end

#target_versionsObject

Returns the value of attribute target_versions.



83
84
85
# File 'lib/akeyless/models/item.rb', line 83

def target_versions
  @target_versions
end

#with_customer_fragmentObject

Returns the value of attribute with_customer_fragment.



85
86
87
# File 'lib/akeyless/models/item.rb', line 85

def with_customer_fragment
  @with_customer_fragment
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



128
129
130
# File 'lib/akeyless/models/item.rb', line 128

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/akeyless/models/item.rb', line 88

def self.attribute_map
  {
    :'access_date' => :'access_date',
    :'auto_rotate' => :'auto_rotate',
    :'cert_issuer_signer_key_name' => :'cert_issuer_signer_key_name',
    :'certificate_issue_details' => :'certificate_issue_details',
    :'certificates' => :'certificates',
    :'client_permissions' => :'client_permissions',
    :'creation_date' => :'creation_date',
    :'customer_fragment_id' => :'customer_fragment_id',
    :'delete_protection' => :'delete_protection',
    :'deletion_date' => :'deletion_date',
    :'display_id' => :'display_id',
    :'is_enabled' => :'is_enabled',
    :'item_accessibility' => :'item_accessibility',
    :'item_general_info' => :'item_general_info',
    :'item_id' => :'item_id',
    :'item_metadata' => :'item_metadata',
    :'item_name' => :'item_name',
    :'item_size' => :'item_size',
    :'item_state' => :'item_state',
    :'item_sub_type' => :'item_sub_type',
    :'item_tags' => :'item_tags',
    :'item_targets_assoc' => :'item_targets_assoc',
    :'item_type' => :'item_type',
    :'item_versions' => :'item_versions',
    :'last_version' => :'last_version',
    :'modification_date' => :'modification_date',
    :'next_rotation_date' => :'next_rotation_date',
    :'protection_key_name' => :'protection_key_name',
    :'protection_key_type' => :'protection_key_type',
    :'public_value' => :'public_value',
    :'rotation_interval' => :'rotation_interval',
    :'shared_by' => :'shared_by',
    :'target_versions' => :'target_versions',
    :'with_customer_fragment' => :'with_customer_fragment'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



409
410
411
# File 'lib/akeyless/models/item.rb', line 409

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



173
174
175
176
# File 'lib/akeyless/models/item.rb', line 173

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/akeyless/models/item.rb', line 133

def self.openapi_types
  {
    :'access_date' => :'Time',
    :'auto_rotate' => :'Boolean',
    :'cert_issuer_signer_key_name' => :'String',
    :'certificate_issue_details' => :'CertificateIssueInfo',
    :'certificates' => :'String',
    :'client_permissions' => :'Array<String>',
    :'creation_date' => :'Time',
    :'customer_fragment_id' => :'String',
    :'delete_protection' => :'Boolean',
    :'deletion_date' => :'Time',
    :'display_id' => :'String',
    :'is_enabled' => :'Boolean',
    :'item_accessibility' => :'Integer',
    :'item_general_info' => :'ItemGeneralInfo',
    :'item_id' => :'Integer',
    :'item_metadata' => :'String',
    :'item_name' => :'String',
    :'item_size' => :'Integer',
    :'item_state' => :'String',
    :'item_sub_type' => :'String',
    :'item_tags' => :'Array<String>',
    :'item_targets_assoc' => :'Array<ItemTargetAssociation>',
    :'item_type' => :'String',
    :'item_versions' => :'Array<ItemVersion>',
    :'last_version' => :'Integer',
    :'modification_date' => :'Time',
    :'next_rotation_date' => :'Time',
    :'protection_key_name' => :'String',
    :'protection_key_type' => :'String',
    :'public_value' => :'String',
    :'rotation_interval' => :'Integer',
    :'shared_by' => :'RuleAssigner',
    :'target_versions' => :'Array<TargetItemVersion>',
    :'with_customer_fragment' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/akeyless/models/item.rb', line 355

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      access_date == o.access_date &&
      auto_rotate == o.auto_rotate &&
      cert_issuer_signer_key_name == o.cert_issuer_signer_key_name &&
      certificate_issue_details == o.certificate_issue_details &&
      certificates == o.certificates &&
      client_permissions == o.client_permissions &&
      creation_date == o.creation_date &&
      customer_fragment_id == o.customer_fragment_id &&
      delete_protection == o.delete_protection &&
      deletion_date == o.deletion_date &&
      display_id == o.display_id &&
      is_enabled == o.is_enabled &&
      item_accessibility == o.item_accessibility &&
      item_general_info == o.item_general_info &&
      item_id == o.item_id &&
       == o. &&
      item_name == o.item_name &&
      item_size == o.item_size &&
      item_state == o.item_state &&
      item_sub_type == o.item_sub_type &&
      item_tags == o.item_tags &&
      item_targets_assoc == o.item_targets_assoc &&
      item_type == o.item_type &&
      item_versions == o.item_versions &&
      last_version == o.last_version &&
      modification_date == o.modification_date &&
      next_rotation_date == o.next_rotation_date &&
      protection_key_name == o.protection_key_name &&
      protection_key_type == o.protection_key_type &&
      public_value == o.public_value &&
      rotation_interval == o.rotation_interval &&
      shared_by == o.shared_by &&
      target_versions == o.target_versions &&
      with_customer_fragment == o.with_customer_fragment
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/akeyless/models/item.rb', line 440

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



511
512
513
514
515
516
517
518
519
520
521
522
523
# File 'lib/akeyless/models/item.rb', line 511

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/akeyless/models/item.rb', line 416

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


396
397
398
# File 'lib/akeyless/models/item.rb', line 396

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



402
403
404
# File 'lib/akeyless/models/item.rb', line 402

def hash
  [access_date, auto_rotate, cert_issuer_signer_key_name, certificate_issue_details, certificates, client_permissions, creation_date, customer_fragment_id, delete_protection, deletion_date, display_id, is_enabled, item_accessibility, item_general_info, item_id, , item_name, item_size, item_state, item_sub_type, item_tags, item_targets_assoc, item_type, item_versions, last_version, modification_date, next_rotation_date, protection_key_name, protection_key_type, public_value, rotation_interval, shared_by, target_versions, with_customer_fragment].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



342
343
344
345
# File 'lib/akeyless/models/item.rb', line 342

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



487
488
489
# File 'lib/akeyless/models/item.rb', line 487

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/akeyless/models/item.rb', line 493

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



481
482
483
# File 'lib/akeyless/models/item.rb', line 481

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



349
350
351
# File 'lib/akeyless/models/item.rb', line 349

def valid?
  true
end