Class: Akeyless::ListItems

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/list_items.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ListItems

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/akeyless/models/list_items.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::ListItems` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::ListItems`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'accessibility')
    self.accessibility = attributes[:'accessibility']
  else
    self.accessibility = 'regular'
  end

  if attributes.key?(:'filter')
    self.filter = attributes[:'filter']
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'minimal_view')
    self.minimal_view = attributes[:'minimal_view']
  end

  if attributes.key?(:'pagination')
    self.pagination = attributes[:'pagination']
  else
    self.pagination = 'enabled'
  end

  if attributes.key?(:'pagination_token')
    self.pagination_token = attributes[:'pagination_token']
  end

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  end

  if attributes.key?(:'sra_only')
    self.sra_only = attributes[:'sra_only']
  else
    self.sra_only = false
  end

  if attributes.key?(:'sub_types')
    if (value = attributes[:'sub_types']).is_a?(Array)
      self.sub_types = value
    end
  end

  if attributes.key?(:'tag')
    self.tag = attributes[:'tag']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'type')
    if (value = attributes[:'type']).is_a?(Array)
      self.type = value
    end
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end
end

Instance Attribute Details

#accessibilityObject

for personal password manager



19
20
21
# File 'lib/akeyless/models/list_items.rb', line 19

def accessibility
  @accessibility
end

#filterObject

Filter by item name or part of it



22
23
24
# File 'lib/akeyless/models/list_items.rb', line 22

def filter
  @filter
end

#jsonObject

Set output format to JSON



25
26
27
# File 'lib/akeyless/models/list_items.rb', line 25

def json
  @json
end

#minimal_viewObject

Returns the value of attribute minimal_view.



27
28
29
# File 'lib/akeyless/models/list_items.rb', line 27

def minimal_view
  @minimal_view
end

#paginationObject

Retrieve items with pagination



30
31
32
# File 'lib/akeyless/models/list_items.rb', line 30

def pagination
  @pagination
end

#pagination_tokenObject

Next page reference



33
34
35
# File 'lib/akeyless/models/list_items.rb', line 33

def pagination_token
  @pagination_token
end

#pathObject

Path to folder



36
37
38
# File 'lib/akeyless/models/list_items.rb', line 36

def path
  @path
end

#sra_onlyObject

Filter by items with SRA functionality enabled



39
40
41
# File 'lib/akeyless/models/list_items.rb', line 39

def sra_only
  @sra_only
end

#sub_typesObject

Returns the value of attribute sub_types.



41
42
43
# File 'lib/akeyless/models/list_items.rb', line 41

def sub_types
  @sub_types
end

#tagObject

Filter by item tag



44
45
46
# File 'lib/akeyless/models/list_items.rb', line 44

def tag
  @tag
end

#tokenObject

Authentication token (see /auth and /configure)



47
48
49
# File 'lib/akeyless/models/list_items.rb', line 47

def token
  @token
end

#typeObject

The item types list of the requested items. In case it is empty, all types of items will be returned. options: [key, static-secret, dynamic-secret, classic-key]



50
51
52
# File 'lib/akeyless/models/list_items.rb', line 50

def type
  @type
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



53
54
55
# File 'lib/akeyless/models/list_items.rb', line 53

def uid_token
  @uid_token
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/akeyless/models/list_items.rb', line 75

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/akeyless/models/list_items.rb', line 56

def self.attribute_map
  {
    :'accessibility' => :'accessibility',
    :'filter' => :'filter',
    :'json' => :'json',
    :'minimal_view' => :'minimal-view',
    :'pagination' => :'pagination',
    :'pagination_token' => :'pagination-token',
    :'path' => :'path',
    :'sra_only' => :'sra-only',
    :'sub_types' => :'sub_types',
    :'tag' => :'tag',
    :'token' => :'token',
    :'type' => :'type',
    :'uid_token' => :'uid-token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



232
233
234
# File 'lib/akeyless/models/list_items.rb', line 232

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
# File 'lib/akeyless/models/list_items.rb', line 99

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/akeyless/models/list_items.rb', line 80

def self.openapi_types
  {
    :'accessibility' => :'String',
    :'filter' => :'String',
    :'json' => :'Boolean',
    :'minimal_view' => :'Boolean',
    :'pagination' => :'String',
    :'pagination_token' => :'String',
    :'path' => :'String',
    :'sra_only' => :'Boolean',
    :'sub_types' => :'Array<String>',
    :'tag' => :'String',
    :'token' => :'String',
    :'type' => :'Array<String>',
    :'uid_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/akeyless/models/list_items.rb', line 199

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      accessibility == o.accessibility &&
      filter == o.filter &&
      json == o.json &&
      minimal_view == o.minimal_view &&
      pagination == o.pagination &&
      pagination_token == o.pagination_token &&
      path == o.path &&
      sra_only == o.sra_only &&
      sub_types == o.sub_types &&
      tag == o.tag &&
      token == o.token &&
      type == o.type &&
      uid_token == o.uid_token
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/akeyless/models/list_items.rb', line 263

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/akeyless/models/list_items.rb', line 334

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/akeyless/models/list_items.rb', line 239

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


219
220
221
# File 'lib/akeyless/models/list_items.rb', line 219

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



225
226
227
# File 'lib/akeyless/models/list_items.rb', line 225

def hash
  [accessibility, filter, json, minimal_view, pagination, pagination_token, path, sra_only, sub_types, tag, token, type, uid_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



186
187
188
189
# File 'lib/akeyless/models/list_items.rb', line 186

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



310
311
312
# File 'lib/akeyless/models/list_items.rb', line 310

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/akeyless/models/list_items.rb', line 316

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



304
305
306
# File 'lib/akeyless/models/list_items.rb', line 304

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



193
194
195
# File 'lib/akeyless/models/list_items.rb', line 193

def valid?
  true
end