Class: Akeyless::RotatedSecretCreateSsh

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/rotated_secret_create_ssh.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RotatedSecretCreateSsh

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 302

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::RotatedSecretCreateSsh` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::RotatedSecretCreateSsh`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'provider_type')
    self.provider_type = attributes[:'provider_type']
  end

  if attributes.key?(:'ara_enabled')
    self.ara_enabled = attributes[:'ara_enabled']
  end

  if attributes.key?(:'authentication_credentials')
    self.authentication_credentials = attributes[:'authentication_credentials']
  else
    self.authentication_credentials = 'use-user-creds'
  end

  if attributes.key?(:'auto_rotate')
    self.auto_rotate = attributes[:'auto_rotate']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'host_provider')
    self.host_provider = attributes[:'host_provider']
  end

  if attributes.key?(:'input_rule')
    if (value = attributes[:'input_rule']).is_a?(Array)
      self.input_rule = value
    end
  end

  if attributes.key?(:'item_custom_fields')
    if (value = attributes[:'item_custom_fields']).is_a?(Hash)
      self.item_custom_fields = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'key_algorithm')
    self.key_algorithm = attributes[:'key_algorithm']
  end

  if attributes.key?(:'key_data_base64')
    self.key_data_base64 = attributes[:'key_data_base64']
  end

  if attributes.key?(:'lock_during_sra_session')
    self.lock_during_sra_session = attributes[:'lock_during_sra_session']
  end

  if attributes.key?(:'max_versions')
    self.max_versions = attributes[:'max_versions']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'output_rule')
    if (value = attributes[:'output_rule']).is_a?(Array)
      self.output_rule = value
    end
  end

  if attributes.key?(:'password_length')
    self.password_length = attributes[:'password_length']
  end

  if attributes.key?(:'public_key_remote_path')
    self.public_key_remote_path = attributes[:'public_key_remote_path']
  end

  if attributes.key?(:'rotate_after_disconnect')
    self.rotate_after_disconnect = attributes[:'rotate_after_disconnect']
  end

  if attributes.key?(:'rotated_password')
    self.rotated_password = attributes[:'rotated_password']
  end

  if attributes.key?(:'rotated_username')
    self.rotated_username = attributes[:'rotated_username']
  end

  if attributes.key?(:'rotation_event_in')
    if (value = attributes[:'rotation_event_in']).is_a?(Array)
      self.rotation_event_in = value
    end
  end

  if attributes.key?(:'rotation_hour')
    self.rotation_hour = attributes[:'rotation_hour']
  end

  if attributes.key?(:'rotation_interval')
    self.rotation_interval = attributes[:'rotation_interval']
  end

  if attributes.key?(:'rotator_custom_cmd')
    self.rotator_custom_cmd = attributes[:'rotator_custom_cmd']
  end

  if attributes.key?(:'rotator_type')
    self.rotator_type = attributes[:'rotator_type']
  else
    self.rotator_type = nil
  end

  if attributes.key?(:'same_password')
    self.same_password = attributes[:'same_password']
  end

  if attributes.key?(:'secure_access_allow_external_user')
    self.secure_access_allow_external_user = attributes[:'secure_access_allow_external_user']
  else
    self.secure_access_allow_external_user = false
  end

  if attributes.key?(:'secure_access_bastion_issuer')
    self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer']
  end

  if attributes.key?(:'secure_access_certificate_issuer')
    self.secure_access_certificate_issuer = attributes[:'secure_access_certificate_issuer']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_enforce_hosts_restriction')
    self.secure_access_enforce_hosts_restriction = attributes[:'secure_access_enforce_hosts_restriction']
  end

  if attributes.key?(:'secure_access_host')
    if (value = attributes[:'secure_access_host']).is_a?(Array)
      self.secure_access_host = value
    end
  end

  if attributes.key?(:'secure_access_rdp_domain')
    self.secure_access_rdp_domain = attributes[:'secure_access_rdp_domain']
  end

  if attributes.key?(:'secure_access_rdp_user')
    self.secure_access_rdp_user = attributes[:'secure_access_rdp_user']
  end

  if attributes.key?(:'secure_access_ssh_creds')
    self.secure_access_ssh_creds = attributes[:'secure_access_ssh_creds']
  end

  if attributes.key?(:'secure_access_ssh_user')
    self.secure_access_ssh_user = attributes[:'secure_access_ssh_user']
  end

  if attributes.key?(:'secure_access_target_type')
    self.secure_access_target_type = attributes[:'secure_access_target_type']
  else
    self.secure_access_target_type = 'false'
  end

  if attributes.key?(:'secure_access_url')
    self.secure_access_url = attributes[:'secure_access_url']
  end

  if attributes.key?(:'secure_access_web')
    self.secure_access_web = attributes[:'secure_access_web']
  else
    self.secure_access_web = true
  end

  if attributes.key?(:'secure_access_web_browsing')
    self.secure_access_web_browsing = attributes[:'secure_access_web_browsing']
  else
    self.secure_access_web_browsing = false
  end

  if attributes.key?(:'secure_access_web_proxy')
    self.secure_access_web_proxy = attributes[:'secure_access_web_proxy']
  else
    self.secure_access_web_proxy = false
  end

  if attributes.key?(:'skip_dry_run')
    self.skip_dry_run = attributes[:'skip_dry_run']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target')
    if (value = attributes[:'target']).is_a?(Array)
      self.target = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  else
    self.target_name = nil
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'use_capital_letters')
    self.use_capital_letters = attributes[:'use_capital_letters']
  end

  if attributes.key?(:'use_lower_letters')
    self.use_lower_letters = attributes[:'use_lower_letters']
  end

  if attributes.key?(:'use_numbers')
    self.use_numbers = attributes[:'use_numbers']
  end

  if attributes.key?(:'use_special_characters')
    self.use_special_characters = attributes[:'use_special_characters']
  end
end

Instance Attribute Details

#ara_enabledObject

Enable or disable Agentic Runtime Authority rule enforcement for this item. When false, user-defined input/output rules are stored but not enforced; the base security validation still runs. AraEnabled is tri-state (nil/true/false), not a plain bool: it self-encodes its wire value (see akl.OptionalBool) so an explicit false survives the curl-proxy relay instead of being dropped like a default-false bool flag.



21
22
23
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 21

def ara_enabled
  @ara_enabled
end

#authentication_credentialsObject

The credentials to connect with use-user-creds/use-target-creds



24
25
26
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 24

def authentication_credentials
  @authentication_credentials
end

#auto_rotateObject

Returns the value of attribute auto_rotate.



26
27
28
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 26

def auto_rotate
  @auto_rotate
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



29
30
31
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 29

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



32
33
34
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 32

def description
  @description
end

#host_providerObject

Host provider type [explicit/target], Default Host provider is explicit, Relevant only for SRA items.



35
36
37
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 35

def host_provider
  @host_provider
end

#input_ruleObject

Agentic input rule in name=...,rule=... format (e.g. name=rule1,rule=Sanitize input)



38
39
40
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 38

def input_rule
  @input_rule
end

#item_custom_fieldsObject

Additional custom fields to associate with the item



41
42
43
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 41

def item_custom_fields
  @item_custom_fields
end

#jsonObject

Set output format to JSON



44
45
46
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 44

def json
  @json
end

#keyObject

Returns the value of attribute key.



46
47
48
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 46

def key
  @key
end

#key_algorithmObject

The key algorithm to generate with when no private key is supplied. options: [ED25519/RSA2048/RSA3072/RSA4096/ECDSA256/ECDSA384/ECDSA521]



49
50
51
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 49

def key_algorithm
  @key_algorithm
end

#key_data_base64Object

Private key file contents encoded using base64



52
53
54
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 52

def key_data_base64
  @key_data_base64
end

#lock_during_sra_sessionObject

Lock this secret for read/update while an SRA session is active



55
56
57
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 55

def lock_during_sra_session
  @lock_during_sra_session
end

#max_versionsObject

Set the maximum number of versions, limited by the account settings defaults.



58
59
60
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 58

def max_versions
  @max_versions
end

#nameObject

Rotated secret name



61
62
63
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 61

def name
  @name
end

#output_ruleObject

Agentic output rule in name=...,rule=... format (e.g. name=rule1,rule=Mask secrets)



64
65
66
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 64

def output_rule
  @output_rule
end

#password_lengthObject

The length of the password to be generated



67
68
69
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 67

def password_length
  @password_length
end

#provider_typeObject

Returns the value of attribute provider_type.



18
19
20
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 18

def provider_type
  @provider_type
end

#public_key_remote_pathObject

The path to the public key that will be rotated on the server



70
71
72
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 70

def public_key_remote_path
  @public_key_remote_path
end

#rotate_after_disconnectObject

StringOrBool accepts JSON strings, booleans, and numbers for backward compatibility with older SDK versions that send boolean values for rotate-after-disconnect.



73
74
75
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 73

def rotate_after_disconnect
  @rotate_after_disconnect
end

#rotated_passwordObject

rotated-username password (relevant only for rotator-type=password)



76
77
78
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 76

def rotated_password
  @rotated_password
end

#rotated_usernameObject

username to be rotated, if selected use-self-creds at rotator-creds-type, this username will try to rotate it's own password, if use-target-creds is selected, target credentials will be use to rotate the rotated-password (relevant only for rotator-type=password)



79
80
81
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 79

def rotated_username
  @rotated_username
end

#rotation_event_inObject

How many days before the rotation of the item would you like to be notified



82
83
84
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 82

def rotation_event_in
  @rotation_event_in
end

#rotation_hourObject

Returns the value of attribute rotation_hour.



84
85
86
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 84

def rotation_hour
  @rotation_hour
end

#rotation_intervalObject

Returns the value of attribute rotation_interval.



86
87
88
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 86

def rotation_interval
  @rotation_interval
end

#rotator_custom_cmdObject

Custom rotation command



89
90
91
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 89

def rotator_custom_cmd
  @rotator_custom_cmd
end

#rotator_typeObject

The rotator type. options: [target/password/key]



92
93
94
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 92

def rotator_type
  @rotator_type
end

#same_passwordObject

Rotate same password for each host from the Linked Target (relevant only for Linked Target)



95
96
97
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 95

def same_password
  @same_password
end

#secure_access_allow_external_userObject

Allow providing external user for a domain users



98
99
100
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 98

def secure_access_allow_external_user
  @secure_access_allow_external_user
end

#secure_access_bastion_issuerObject

Deprecated. use secure-access-certificate-issuer



101
102
103
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 101

def secure_access_bastion_issuer
  @secure_access_bastion_issuer
end

#secure_access_certificate_issuerObject

Path to the SSH Certificate Issuer for your Akeyless Secure Access



104
105
106
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 104

def secure_access_certificate_issuer
  @secure_access_certificate_issuer
end

#secure_access_enableObject

Enable/Disable secure remote access [true/false]



107
108
109
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 107

def secure_access_enable
  @secure_access_enable
end

#secure_access_enforce_hosts_restrictionObject

Enforce connections only to allowed SRA hosts



110
111
112
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 110

def secure_access_enforce_hosts_restriction
  @secure_access_enforce_hosts_restriction
end

#secure_access_hostObject

Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)



113
114
115
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 113

def secure_access_host
  @secure_access_host
end

#secure_access_rdp_domainObject

Default domain name server. i.e. microsoft.com



116
117
118
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 116

def secure_access_rdp_domain
  @secure_access_rdp_domain
end

#secure_access_rdp_userObject

Override the RDP Domain username



119
120
121
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 119

def secure_access_rdp_user
  @secure_access_rdp_user
end

#secure_access_ssh_credsObject

Secret values contains SSH Credentials, either Private Key or Password [password/private-key] (relevant only for Static-Secret or Rotated-secret)



122
123
124
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 122

def secure_access_ssh_creds
  @secure_access_ssh_creds
end

#secure_access_ssh_userObject

Override the SSH username as indicated in SSH Certificate Issuer



125
126
127
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 125

def secure_access_ssh_user
  @secure_access_ssh_user
end

#secure_access_target_typeObject

Specify target type. Options are ssh or rdp



128
129
130
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 128

def secure_access_target_type
  @secure_access_target_type
end

#secure_access_urlObject

Destination URL to inject secrets



131
132
133
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 131

def secure_access_url
  @secure_access_url
end

#secure_access_webObject

Enable Web Secure Remote Access



134
135
136
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 134

def secure_access_web
  @secure_access_web
end

#secure_access_web_browsingObject

Secure browser via Akeyless's Secure Remote Access (SRA)



137
138
139
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 137

def secure_access_web_browsing
  @secure_access_web_browsing
end

#secure_access_web_proxyObject

Web-Proxy via Akeyless's Secure Remote Access (SRA)



140
141
142
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 140

def secure_access_web_proxy
  @secure_access_web_proxy
end

#skip_dry_runObject

If set, dry-run will be skipped



143
144
145
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 143

def skip_dry_run
  @skip_dry_run
end

#tagsObject

Add tags attached to this object



146
147
148
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 146

def tags
  @tags
end

#targetObject

A list of targets to be associated with an SRA item, To specify multiple targets use argument multiple times



149
150
151
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 149

def target
  @target
end

#target_nameObject

The target name to associate



152
153
154
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 152

def target_name
  @target_name
end

#tokenObject

Authentication token (see /auth and /configure)



155
156
157
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 155

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



158
159
160
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 158

def uid_token
  @uid_token
end

#use_capital_lettersObject

Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). [true/false]



161
162
163
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 161

def use_capital_letters
  @use_capital_letters
end

#use_lower_lettersObject

Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). [true/false]



164
165
166
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 164

def use_lower_letters
  @use_lower_letters
end

#use_numbersObject

Specifies whether the generated temporary password must contain at least one numeric character (0 to 9). [true/false]



167
168
169
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 167

def use_numbers
  @use_numbers
end

#use_special_charactersObject

Returns the value of attribute use_special_characters.



169
170
171
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 169

def use_special_characters
  @use_special_characters
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 691

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



231
232
233
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 231

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 172

def self.attribute_map
  {
    :'provider_type' => :'ProviderType',
    :'ara_enabled' => :'ara-enabled',
    :'authentication_credentials' => :'authentication-credentials',
    :'auto_rotate' => :'auto-rotate',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'host_provider' => :'host-provider',
    :'input_rule' => :'input-rule',
    :'item_custom_fields' => :'item-custom-fields',
    :'json' => :'json',
    :'key' => :'key',
    :'key_algorithm' => :'key-algorithm',
    :'key_data_base64' => :'key-data-base64',
    :'lock_during_sra_session' => :'lock-during-sra-session',
    :'max_versions' => :'max-versions',
    :'name' => :'name',
    :'output_rule' => :'output-rule',
    :'password_length' => :'password-length',
    :'public_key_remote_path' => :'public-key-remote-path',
    :'rotate_after_disconnect' => :'rotate-after-disconnect',
    :'rotated_password' => :'rotated-password',
    :'rotated_username' => :'rotated-username',
    :'rotation_event_in' => :'rotation-event-in',
    :'rotation_hour' => :'rotation-hour',
    :'rotation_interval' => :'rotation-interval',
    :'rotator_custom_cmd' => :'rotator-custom-cmd',
    :'rotator_type' => :'rotator-type',
    :'same_password' => :'same-password',
    :'secure_access_allow_external_user' => :'secure-access-allow-external-user',
    :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer',
    :'secure_access_certificate_issuer' => :'secure-access-certificate-issuer',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_enforce_hosts_restriction' => :'secure-access-enforce-hosts-restriction',
    :'secure_access_host' => :'secure-access-host',
    :'secure_access_rdp_domain' => :'secure-access-rdp-domain',
    :'secure_access_rdp_user' => :'secure-access-rdp-user',
    :'secure_access_ssh_creds' => :'secure-access-ssh-creds',
    :'secure_access_ssh_user' => :'secure-access-ssh-user',
    :'secure_access_target_type' => :'secure-access-target-type',
    :'secure_access_url' => :'secure-access-url',
    :'secure_access_web' => :'secure-access-web',
    :'secure_access_web_browsing' => :'secure-access-web-browsing',
    :'secure_access_web_proxy' => :'secure-access-web-proxy',
    :'skip_dry_run' => :'skip_dry_run',
    :'tags' => :'tags',
    :'target' => :'target',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'use_capital_letters' => :'use-capital-letters',
    :'use_lower_letters' => :'use-lower-letters',
    :'use_numbers' => :'use-numbers',
    :'use_special_characters' => :'use-special-characters'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 667

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



295
296
297
298
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 295

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 236

def self.openapi_types
  {
    :'provider_type' => :'String',
    :'ara_enabled' => :'Boolean',
    :'authentication_credentials' => :'String',
    :'auto_rotate' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'host_provider' => :'String',
    :'input_rule' => :'Array<String>',
    :'item_custom_fields' => :'Hash<String, String>',
    :'json' => :'Boolean',
    :'key' => :'String',
    :'key_algorithm' => :'String',
    :'key_data_base64' => :'String',
    :'lock_during_sra_session' => :'String',
    :'max_versions' => :'String',
    :'name' => :'String',
    :'output_rule' => :'Array<String>',
    :'password_length' => :'String',
    :'public_key_remote_path' => :'String',
    :'rotate_after_disconnect' => :'String',
    :'rotated_password' => :'String',
    :'rotated_username' => :'String',
    :'rotation_event_in' => :'Array<String>',
    :'rotation_hour' => :'Integer',
    :'rotation_interval' => :'String',
    :'rotator_custom_cmd' => :'String',
    :'rotator_type' => :'String',
    :'same_password' => :'String',
    :'secure_access_allow_external_user' => :'Boolean',
    :'secure_access_bastion_issuer' => :'String',
    :'secure_access_certificate_issuer' => :'String',
    :'secure_access_enable' => :'String',
    :'secure_access_enforce_hosts_restriction' => :'Boolean',
    :'secure_access_host' => :'Array<String>',
    :'secure_access_rdp_domain' => :'String',
    :'secure_access_rdp_user' => :'String',
    :'secure_access_ssh_creds' => :'String',
    :'secure_access_ssh_user' => :'String',
    :'secure_access_target_type' => :'String',
    :'secure_access_url' => :'String',
    :'secure_access_web' => :'Boolean',
    :'secure_access_web_browsing' => :'Boolean',
    :'secure_access_web_proxy' => :'Boolean',
    :'skip_dry_run' => :'String',
    :'tags' => :'Array<String>',
    :'target' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'use_capital_letters' => :'String',
    :'use_lower_letters' => :'String',
    :'use_numbers' => :'String',
    :'use_special_characters' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 594

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      provider_type == o.provider_type &&
      ara_enabled == o.ara_enabled &&
      authentication_credentials == o.authentication_credentials &&
      auto_rotate == o.auto_rotate &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      host_provider == o.host_provider &&
      input_rule == o.input_rule &&
      item_custom_fields == o.item_custom_fields &&
      json == o.json &&
      key == o.key &&
      key_algorithm == o.key_algorithm &&
      key_data_base64 == o.key_data_base64 &&
      lock_during_sra_session == o.lock_during_sra_session &&
      max_versions == o.max_versions &&
      name == o.name &&
      output_rule == o.output_rule &&
      password_length == o.password_length &&
      public_key_remote_path == o.public_key_remote_path &&
      rotate_after_disconnect == o.rotate_after_disconnect &&
      rotated_password == o.rotated_password &&
      rotated_username == o.rotated_username &&
      rotation_event_in == o.rotation_event_in &&
      rotation_hour == o.rotation_hour &&
      rotation_interval == o.rotation_interval &&
      rotator_custom_cmd == o.rotator_custom_cmd &&
      rotator_type == o.rotator_type &&
      same_password == o.same_password &&
      secure_access_allow_external_user == o.secure_access_allow_external_user &&
      secure_access_bastion_issuer == o.secure_access_bastion_issuer &&
      secure_access_certificate_issuer == o.secure_access_certificate_issuer &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_enforce_hosts_restriction == o.secure_access_enforce_hosts_restriction &&
      secure_access_host == o.secure_access_host &&
      secure_access_rdp_domain == o.secure_access_rdp_domain &&
      secure_access_rdp_user == o.secure_access_rdp_user &&
      secure_access_ssh_creds == o.secure_access_ssh_creds &&
      secure_access_ssh_user == o.secure_access_ssh_user &&
      secure_access_target_type == o.secure_access_target_type &&
      secure_access_url == o.secure_access_url &&
      secure_access_web == o.secure_access_web &&
      secure_access_web_browsing == o.secure_access_web_browsing &&
      secure_access_web_proxy == o.secure_access_web_proxy &&
      skip_dry_run == o.skip_dry_run &&
      tags == o.tags &&
      target == o.target &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      use_capital_letters == o.use_capital_letters &&
      use_lower_letters == o.use_lower_letters &&
      use_numbers == o.use_numbers &&
      use_special_characters == o.use_special_characters
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



762
763
764
765
766
767
768
769
770
771
772
773
774
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 762

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


654
655
656
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 654

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



660
661
662
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 660

def hash
  [provider_type, ara_enabled, authentication_credentials, auto_rotate, delete_protection, description, host_provider, input_rule, item_custom_fields, json, key, key_algorithm, key_data_base64, lock_during_sra_session, max_versions, name, output_rule, password_length, public_key_remote_path, rotate_after_disconnect, rotated_password, rotated_username, rotation_event_in, rotation_hour, rotation_interval, rotator_custom_cmd, rotator_type, same_password, secure_access_allow_external_user, secure_access_bastion_issuer, secure_access_certificate_issuer, secure_access_enable, secure_access_enforce_hosts_restriction, secure_access_host, secure_access_rdp_domain, secure_access_rdp_user, secure_access_ssh_creds, secure_access_ssh_user, secure_access_target_type, secure_access_url, secure_access_web, secure_access_web_browsing, secure_access_web_proxy, skip_dry_run, tags, target, target_name, token, uid_token, use_capital_letters, use_lower_letters, use_numbers, use_special_characters].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 564

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @rotator_type.nil?
    invalid_properties.push('invalid value for "rotator_type", rotator_type cannot be nil.')
  end

  if @target_name.nil?
    invalid_properties.push('invalid value for "target_name", target_name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



738
739
740
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 738

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



744
745
746
747
748
749
750
751
752
753
754
755
756
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 744

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



732
733
734
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 732

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



584
585
586
587
588
589
590
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 584

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @rotator_type.nil?
  return false if @target_name.nil?
  true
end