Class: Akeyless::RotatedSecretCreateSsh

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/rotated_secret_create_ssh.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RotatedSecretCreateSsh

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 243

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::RotatedSecretCreateSsh` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::RotatedSecretCreateSsh`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'authentication_credentials')
    self.authentication_credentials = attributes[:'authentication_credentials']
  else
    self.authentication_credentials = 'use-user-creds'
  end

  if attributes.key?(:'auto_rotate')
    self.auto_rotate = attributes[:'auto_rotate']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'input_rule')
    if (value = attributes[:'input_rule']).is_a?(Array)
      self.input_rule = value
    end
  end

  if attributes.key?(:'item_custom_fields')
    if (value = attributes[:'item_custom_fields']).is_a?(Hash)
      self.item_custom_fields = value
    end
  end

  if attributes.key?(:'json')
    self.json = attributes[:'json']
  else
    self.json = false
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'key_data_base64')
    self.key_data_base64 = attributes[:'key_data_base64']
  end

  if attributes.key?(:'lock_during_sra_session')
    self.lock_during_sra_session = attributes[:'lock_during_sra_session']
  end

  if attributes.key?(:'max_versions')
    self.max_versions = attributes[:'max_versions']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'output_rule')
    if (value = attributes[:'output_rule']).is_a?(Array)
      self.output_rule = value
    end
  end

  if attributes.key?(:'password_length')
    self.password_length = attributes[:'password_length']
  end

  if attributes.key?(:'public_key_remote_path')
    self.public_key_remote_path = attributes[:'public_key_remote_path']
  end

  if attributes.key?(:'rotate_after_disconnect')
    self.rotate_after_disconnect = attributes[:'rotate_after_disconnect']
  end

  if attributes.key?(:'rotated_password')
    self.rotated_password = attributes[:'rotated_password']
  end

  if attributes.key?(:'rotated_username')
    self.rotated_username = attributes[:'rotated_username']
  end

  if attributes.key?(:'rotation_event_in')
    if (value = attributes[:'rotation_event_in']).is_a?(Array)
      self.rotation_event_in = value
    end
  end

  if attributes.key?(:'rotation_hour')
    self.rotation_hour = attributes[:'rotation_hour']
  end

  if attributes.key?(:'rotation_interval')
    self.rotation_interval = attributes[:'rotation_interval']
  end

  if attributes.key?(:'rotator_custom_cmd')
    self.rotator_custom_cmd = attributes[:'rotator_custom_cmd']
  end

  if attributes.key?(:'rotator_type')
    self.rotator_type = attributes[:'rotator_type']
  else
    self.rotator_type = nil
  end

  if attributes.key?(:'same_password')
    self.same_password = attributes[:'same_password']
  end

  if attributes.key?(:'secure_access_allow_external_user')
    self.secure_access_allow_external_user = attributes[:'secure_access_allow_external_user']
  else
    self.secure_access_allow_external_user = false
  end

  if attributes.key?(:'secure_access_bastion_issuer')
    self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer']
  end

  if attributes.key?(:'secure_access_certificate_issuer')
    self.secure_access_certificate_issuer = attributes[:'secure_access_certificate_issuer']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_host')
    if (value = attributes[:'secure_access_host']).is_a?(Array)
      self.secure_access_host = value
    end
  end

  if attributes.key?(:'secure_access_rdp_domain')
    self.secure_access_rdp_domain = attributes[:'secure_access_rdp_domain']
  end

  if attributes.key?(:'secure_access_rdp_user')
    self.secure_access_rdp_user = attributes[:'secure_access_rdp_user']
  end

  if attributes.key?(:'secure_access_ssh_user')
    self.secure_access_ssh_user = attributes[:'secure_access_ssh_user']
  end

  if attributes.key?(:'secure_access_target_type')
    self.secure_access_target_type = attributes[:'secure_access_target_type']
  else
    self.secure_access_target_type = 'false'
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'target_name')
    self.target_name = attributes[:'target_name']
  else
    self.target_name = nil
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'use_capital_letters')
    self.use_capital_letters = attributes[:'use_capital_letters']
  end

  if attributes.key?(:'use_lower_letters')
    self.use_lower_letters = attributes[:'use_lower_letters']
  end

  if attributes.key?(:'use_numbers')
    self.use_numbers = attributes[:'use_numbers']
  end

  if attributes.key?(:'use_special_characters')
    self.use_special_characters = attributes[:'use_special_characters']
  end
end

Instance Attribute Details

#authentication_credentialsObject

The credentials to connect with use-user-creds/use-target-creds



19
20
21
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 19

def authentication_credentials
  @authentication_credentials
end

#auto_rotateObject

Returns the value of attribute auto_rotate.



21
22
23
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 21

def auto_rotate
  @auto_rotate
end

#delete_protectionObject

Protection from accidental deletion of this object [true/false]



24
25
26
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 24

def delete_protection
  @delete_protection
end

#descriptionObject

Description of the object



27
28
29
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 27

def description
  @description
end

#input_ruleObject

Agentic input rule in name=…,rule=… format (e.g. name=rule1,rule=Sanitize input)



30
31
32
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 30

def input_rule
  @input_rule
end

#item_custom_fieldsObject

Additional custom fields to associate with the item



33
34
35
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 33

def item_custom_fields
  @item_custom_fields
end

#jsonObject

Set output format to JSON



36
37
38
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 36

def json
  @json
end

#keyObject

Returns the value of attribute key.



38
39
40
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 38

def key
  @key
end

#key_data_base64Object

Private key file contents encoded using base64



41
42
43
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 41

def key_data_base64
  @key_data_base64
end

#lock_during_sra_sessionObject

Lock this secret for read/update while an SRA session is active



44
45
46
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 44

def lock_during_sra_session
  @lock_during_sra_session
end

#max_versionsObject

Set the maximum number of versions, limited by the account settings defaults.



47
48
49
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 47

def max_versions
  @max_versions
end

#nameObject

Rotated secret name



50
51
52
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 50

def name
  @name
end

#output_ruleObject

Agentic output rule in name=…,rule=… format (e.g. name=rule1,rule=Mask secrets)



53
54
55
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 53

def output_rule
  @output_rule
end

#password_lengthObject

The length of the password to be generated



56
57
58
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 56

def password_length
  @password_length
end

#public_key_remote_pathObject

The path to the public key that will be rotated on the server



59
60
61
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 59

def public_key_remote_path
  @public_key_remote_path
end

#rotate_after_disconnectObject

StringOrBool accepts JSON strings, booleans, and numbers for backward compatibility with older SDK versions that send boolean values for rotate-after-disconnect.



62
63
64
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 62

def rotate_after_disconnect
  @rotate_after_disconnect
end

#rotated_passwordObject

rotated-username password (relevant only for rotator-type=password)



65
66
67
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 65

def rotated_password
  @rotated_password
end

#rotated_usernameObject

username to be rotated, if selected use-self-creds at rotator-creds-type, this username will try to rotate it’s own password, if use-target-creds is selected, target credentials will be use to rotate the rotated-password (relevant only for rotator-type=password)



68
69
70
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 68

def rotated_username
  @rotated_username
end

#rotation_event_inObject

How many days before the rotation of the item would you like to be notified



71
72
73
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 71

def rotation_event_in
  @rotation_event_in
end

#rotation_hourObject

Returns the value of attribute rotation_hour.



73
74
75
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 73

def rotation_hour
  @rotation_hour
end

#rotation_intervalObject

Returns the value of attribute rotation_interval.



75
76
77
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 75

def rotation_interval
  @rotation_interval
end

#rotator_custom_cmdObject

Custom rotation command



78
79
80
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 78

def rotator_custom_cmd
  @rotator_custom_cmd
end

#rotator_typeObject

The rotator type. options: [target/password/key]



81
82
83
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 81

def rotator_type
  @rotator_type
end

#same_passwordObject

Rotate same password for each host from the Linked Target (relevant only for Linked Target)



84
85
86
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 84

def same_password
  @same_password
end

#secure_access_allow_external_userObject

Allow providing external user for a domain users



87
88
89
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 87

def secure_access_allow_external_user
  @secure_access_allow_external_user
end

#secure_access_bastion_issuerObject

Deprecated. use secure-access-certificate-issuer



90
91
92
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 90

def secure_access_bastion_issuer
  @secure_access_bastion_issuer
end

#secure_access_certificate_issuerObject

Path to the SSH Certificate Issuer for your Akeyless Secure Access



93
94
95
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 93

def secure_access_certificate_issuer
  @secure_access_certificate_issuer
end

#secure_access_enableObject

Enable/Disable secure remote access [true/false]



96
97
98
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 96

def secure_access_enable
  @secure_access_enable
end

#secure_access_hostObject

Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)



99
100
101
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 99

def secure_access_host
  @secure_access_host
end

#secure_access_rdp_domainObject

Default domain name server. i.e. microsoft.com



102
103
104
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 102

def secure_access_rdp_domain
  @secure_access_rdp_domain
end

#secure_access_rdp_userObject

Override the RDP Domain username



105
106
107
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 105

def secure_access_rdp_user
  @secure_access_rdp_user
end

#secure_access_ssh_userObject

Override the SSH username as indicated in SSH Certificate Issuer



108
109
110
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 108

def secure_access_ssh_user
  @secure_access_ssh_user
end

#secure_access_target_typeObject

Specify target type. Options are ssh or rdp



111
112
113
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 111

def secure_access_target_type
  @secure_access_target_type
end

#tagsObject

Add tags attached to this object



114
115
116
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 114

def tags
  @tags
end

#target_nameObject

The target name to associate



117
118
119
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 117

def target_name
  @target_name
end

#tokenObject

Authentication token (see ‘/auth` and `/configure`)



120
121
122
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 120

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



123
124
125
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 123

def uid_token
  @uid_token
end

#use_capital_lettersObject

Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). [true/false]



126
127
128
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 126

def use_capital_letters
  @use_capital_letters
end

#use_lower_lettersObject

Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). [true/false]



129
130
131
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 129

def use_lower_letters
  @use_lower_letters
end

#use_numbersObject

Specifies whether the generated temporary password must contain at least one numeric character (0 to 9). [true/false]



132
133
134
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 132

def use_numbers
  @use_numbers
end

#use_special_charactersObject

Returns the value of attribute use_special_characters.



134
135
136
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 134

def use_special_characters
  @use_special_characters
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 564

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



184
185
186
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 184

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 137

def self.attribute_map
  {
    :'authentication_credentials' => :'authentication-credentials',
    :'auto_rotate' => :'auto-rotate',
    :'delete_protection' => :'delete_protection',
    :'description' => :'description',
    :'input_rule' => :'input-rule',
    :'item_custom_fields' => :'item-custom-fields',
    :'json' => :'json',
    :'key' => :'key',
    :'key_data_base64' => :'key-data-base64',
    :'lock_during_sra_session' => :'lock-during-sra-session',
    :'max_versions' => :'max-versions',
    :'name' => :'name',
    :'output_rule' => :'output-rule',
    :'password_length' => :'password-length',
    :'public_key_remote_path' => :'public-key-remote-path',
    :'rotate_after_disconnect' => :'rotate-after-disconnect',
    :'rotated_password' => :'rotated-password',
    :'rotated_username' => :'rotated-username',
    :'rotation_event_in' => :'rotation-event-in',
    :'rotation_hour' => :'rotation-hour',
    :'rotation_interval' => :'rotation-interval',
    :'rotator_custom_cmd' => :'rotator-custom-cmd',
    :'rotator_type' => :'rotator-type',
    :'same_password' => :'same-password',
    :'secure_access_allow_external_user' => :'secure-access-allow-external-user',
    :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer',
    :'secure_access_certificate_issuer' => :'secure-access-certificate-issuer',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_host' => :'secure-access-host',
    :'secure_access_rdp_domain' => :'secure-access-rdp-domain',
    :'secure_access_rdp_user' => :'secure-access-rdp-user',
    :'secure_access_ssh_user' => :'secure-access-ssh-user',
    :'secure_access_target_type' => :'secure-access-target-type',
    :'tags' => :'tags',
    :'target_name' => :'target-name',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'use_capital_letters' => :'use-capital-letters',
    :'use_lower_letters' => :'use-lower-letters',
    :'use_numbers' => :'use-numbers',
    :'use_special_characters' => :'use-special-characters'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 540

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



236
237
238
239
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 236

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 189

def self.openapi_types
  {
    :'authentication_credentials' => :'String',
    :'auto_rotate' => :'String',
    :'delete_protection' => :'String',
    :'description' => :'String',
    :'input_rule' => :'Array<String>',
    :'item_custom_fields' => :'Hash<String, String>',
    :'json' => :'Boolean',
    :'key' => :'String',
    :'key_data_base64' => :'String',
    :'lock_during_sra_session' => :'String',
    :'max_versions' => :'String',
    :'name' => :'String',
    :'output_rule' => :'Array<String>',
    :'password_length' => :'String',
    :'public_key_remote_path' => :'String',
    :'rotate_after_disconnect' => :'String',
    :'rotated_password' => :'String',
    :'rotated_username' => :'String',
    :'rotation_event_in' => :'Array<String>',
    :'rotation_hour' => :'Integer',
    :'rotation_interval' => :'String',
    :'rotator_custom_cmd' => :'String',
    :'rotator_type' => :'String',
    :'same_password' => :'String',
    :'secure_access_allow_external_user' => :'Boolean',
    :'secure_access_bastion_issuer' => :'String',
    :'secure_access_certificate_issuer' => :'String',
    :'secure_access_enable' => :'String',
    :'secure_access_host' => :'Array<String>',
    :'secure_access_rdp_domain' => :'String',
    :'secure_access_rdp_user' => :'String',
    :'secure_access_ssh_user' => :'String',
    :'secure_access_target_type' => :'String',
    :'tags' => :'Array<String>',
    :'target_name' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'use_capital_letters' => :'String',
    :'use_lower_letters' => :'String',
    :'use_numbers' => :'String',
    :'use_special_characters' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 479

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      authentication_credentials == o.authentication_credentials &&
      auto_rotate == o.auto_rotate &&
      delete_protection == o.delete_protection &&
      description == o.description &&
      input_rule == o.input_rule &&
      item_custom_fields == o.item_custom_fields &&
      json == o.json &&
      key == o.key &&
      key_data_base64 == o.key_data_base64 &&
      lock_during_sra_session == o.lock_during_sra_session &&
      max_versions == o.max_versions &&
      name == o.name &&
      output_rule == o.output_rule &&
      password_length == o.password_length &&
      public_key_remote_path == o.public_key_remote_path &&
      rotate_after_disconnect == o.rotate_after_disconnect &&
      rotated_password == o.rotated_password &&
      rotated_username == o.rotated_username &&
      rotation_event_in == o.rotation_event_in &&
      rotation_hour == o.rotation_hour &&
      rotation_interval == o.rotation_interval &&
      rotator_custom_cmd == o.rotator_custom_cmd &&
      rotator_type == o.rotator_type &&
      same_password == o.same_password &&
      secure_access_allow_external_user == o.secure_access_allow_external_user &&
      secure_access_bastion_issuer == o.secure_access_bastion_issuer &&
      secure_access_certificate_issuer == o.secure_access_certificate_issuer &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_host == o.secure_access_host &&
      secure_access_rdp_domain == o.secure_access_rdp_domain &&
      secure_access_rdp_user == o.secure_access_rdp_user &&
      secure_access_ssh_user == o.secure_access_ssh_user &&
      secure_access_target_type == o.secure_access_target_type &&
      tags == o.tags &&
      target_name == o.target_name &&
      token == o.token &&
      uid_token == o.uid_token &&
      use_capital_letters == o.use_capital_letters &&
      use_lower_letters == o.use_lower_letters &&
      use_numbers == o.use_numbers &&
      use_special_characters == o.use_special_characters
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



635
636
637
638
639
640
641
642
643
644
645
646
647
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 635

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


527
528
529
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 527

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



533
534
535
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 533

def hash
  [authentication_credentials, auto_rotate, delete_protection, description, input_rule, item_custom_fields, json, key, key_data_base64, lock_during_sra_session, max_versions, name, output_rule, password_length, public_key_remote_path, rotate_after_disconnect, rotated_password, rotated_username, rotation_event_in, rotation_hour, rotation_interval, rotator_custom_cmd, rotator_type, same_password, secure_access_allow_external_user, secure_access_bastion_issuer, secure_access_certificate_issuer, secure_access_enable, secure_access_host, secure_access_rdp_domain, secure_access_rdp_user, secure_access_ssh_user, secure_access_target_type, tags, target_name, token, uid_token, use_capital_letters, use_lower_letters, use_numbers, use_special_characters].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 449

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @rotator_type.nil?
    invalid_properties.push('invalid value for "rotator_type", rotator_type cannot be nil.')
  end

  if @target_name.nil?
    invalid_properties.push('invalid value for "target_name", target_name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



611
612
613
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 611

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



617
618
619
620
621
622
623
624
625
626
627
628
629
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 617

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



605
606
607
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 605

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



469
470
471
472
473
474
475
# File 'lib/akeyless/models/rotated_secret_create_ssh.rb', line 469

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @rotator_type.nil?
  return false if @target_name.nil?
  true
end