Class: Akeyless::RotatedSecretUpdateLdap
- Inherits:
-
Object
- Object
- Akeyless::RotatedSecretUpdateLdap
- Defined in:
- lib/akeyless/models/rotated_secret_update_ldap.rb
Instance Attribute Summary collapse
-
#add_tag ⇒ Object
List of the new tags that will be attached to this item.
-
#authentication_credentials ⇒ Object
The credentials to connect with use-user-creds/use-target-creds.
-
#auto_rotate ⇒ Object
Whether to automatically rotate every –rotation-interval days, or disable existing automatic rotation [true/false].
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#description ⇒ Object
Description of the object.
-
#host_provider ⇒ Object
Host provider type [explicit/target], Default Host provider is explicit, Relevant only for Secure Remote Access of ssh cert issuer, ldap rotated secret and ldap dynamic secret.
-
#input_rule ⇒ Object
Agentic input rule in name=…,rule=…
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#keep_prev_version ⇒ Object
Whether to keep previous version [true/false].
-
#key ⇒ Object
The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used).
-
#lock_during_sra_session ⇒ Object
Lock this secret for read/update while an SRA session is active.
-
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
-
#name ⇒ Object
Rotated secret name.
-
#new_name ⇒ Object
New item name.
-
#output_rule ⇒ Object
Agentic output rule in name=…,rule=…
-
#password_length ⇒ Object
The length of the password to be generated.
-
#provider_type ⇒ Object
Returns the value of attribute provider_type.
-
#rm_tag ⇒ Object
List of the existent tags that will be removed from this item.
-
#rotate_after_disconnect ⇒ Object
StringOrBool accepts JSON strings, booleans, and numbers for backward compatibility with older SDK versions that send boolean values for rotate-after-disconnect.
-
#rotated_password ⇒ Object
rotated-username password (relevant only for rotator-type=ldap).
-
#rotated_username ⇒ Object
username to be rotated, if selected use-self-creds at rotator-creds-type, this username will try to rotate it’s own password, if use-target-creds is selected, target credentials will be use to rotate the rotated-password (relevant only for rotator-type=ldap).
-
#rotation_event_in ⇒ Object
How many days before the rotation of the item would you like to be notified.
-
#rotation_hour ⇒ Object
The Hour of the rotation in UTC.
-
#rotation_interval ⇒ Object
The number of days to wait between every automatic key rotation (1-365).
-
#secure_access_bastion_issuer ⇒ Object
Deprecated.
-
#secure_access_certificate_issuer ⇒ Object
Path to the SSH Certificate Issuer for your Akeyless Secure Access.
-
#secure_access_enable ⇒ Object
Enable/Disable secure remote access [true/false].
-
#secure_access_host ⇒ Object
Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers).
-
#secure_access_rdp_domain ⇒ Object
Default domain name server.
-
#secure_access_url ⇒ Object
Destination URL to inject secrets.
-
#secure_access_web ⇒ Object
Enable Web Secure Remote Access.
-
#secure_access_web_browsing ⇒ Object
Secure browser via Akeyless’s Secure Remote Access (SRA).
-
#secure_access_web_proxy ⇒ Object
Web-Proxy via Akeyless’s Secure Remote Access (SRA).
-
#target ⇒ Object
A list of linked targets to be associated, Relevant only for Secure Remote Access for ssh cert issuer, ldap rotated secret and ldap dynamic secret, To specify multiple targets use argument multiple times.
-
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`).
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#user_attribute ⇒ Object
LDAP User Attribute, Default value "cn".
-
#user_dn ⇒ Object
Base DN to Perform User Search.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RotatedSecretUpdateLdap
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RotatedSecretUpdateLdap
Initializes the object
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 237 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::RotatedSecretUpdateLdap` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::RotatedSecretUpdateLdap`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'provider_type') self.provider_type = attributes[:'provider_type'] end if attributes.key?(:'add_tag') if (value = attributes[:'add_tag']).is_a?(Array) self.add_tag = value end end if attributes.key?(:'authentication_credentials') self.authentication_credentials = attributes[:'authentication_credentials'] else self.authentication_credentials = 'use-user-creds' end if attributes.key?(:'auto_rotate') self.auto_rotate = attributes[:'auto_rotate'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = 'default_metadata' end if attributes.key?(:'host_provider') self.host_provider = attributes[:'host_provider'] end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'keep_prev_version') self.keep_prev_version = attributes[:'keep_prev_version'] end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'lock_during_sra_session') self.lock_during_sra_session = attributes[:'lock_during_sra_session'] end if attributes.key?(:'max_versions') self.max_versions = attributes[:'max_versions'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'new_name') self.new_name = attributes[:'new_name'] end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'password_length') self.password_length = attributes[:'password_length'] end if attributes.key?(:'rm_tag') if (value = attributes[:'rm_tag']).is_a?(Array) self.rm_tag = value end end if attributes.key?(:'rotate_after_disconnect') self.rotate_after_disconnect = attributes[:'rotate_after_disconnect'] end if attributes.key?(:'rotated_password') self.rotated_password = attributes[:'rotated_password'] end if attributes.key?(:'rotated_username') self.rotated_username = attributes[:'rotated_username'] end if attributes.key?(:'rotation_event_in') if (value = attributes[:'rotation_event_in']).is_a?(Array) self.rotation_event_in = value end end if attributes.key?(:'rotation_hour') self.rotation_hour = attributes[:'rotation_hour'] end if attributes.key?(:'rotation_interval') self.rotation_interval = attributes[:'rotation_interval'] end if attributes.key?(:'secure_access_bastion_issuer') self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer'] end if attributes.key?(:'secure_access_certificate_issuer') self.secure_access_certificate_issuer = attributes[:'secure_access_certificate_issuer'] end if attributes.key?(:'secure_access_enable') self.secure_access_enable = attributes[:'secure_access_enable'] end if attributes.key?(:'secure_access_host') if (value = attributes[:'secure_access_host']).is_a?(Array) self.secure_access_host = value end end if attributes.key?(:'secure_access_rdp_domain') self.secure_access_rdp_domain = attributes[:'secure_access_rdp_domain'] end if attributes.key?(:'secure_access_url') self.secure_access_url = attributes[:'secure_access_url'] end if attributes.key?(:'secure_access_web') self.secure_access_web = attributes[:'secure_access_web'] else self.secure_access_web = false end if attributes.key?(:'secure_access_web_browsing') self.secure_access_web_browsing = attributes[:'secure_access_web_browsing'] else self.secure_access_web_browsing = false end if attributes.key?(:'secure_access_web_proxy') self.secure_access_web_proxy = attributes[:'secure_access_web_proxy'] else self.secure_access_web_proxy = false end if attributes.key?(:'target') if (value = attributes[:'target']).is_a?(Array) self.target = value end end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'user_attribute') self.user_attribute = attributes[:'user_attribute'] else self.user_attribute = 'cn' end if attributes.key?(:'user_dn') self.user_dn = attributes[:'user_dn'] end end |
Instance Attribute Details
#add_tag ⇒ Object
List of the new tags that will be attached to this item
21 22 23 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 21 def add_tag @add_tag end |
#authentication_credentials ⇒ Object
The credentials to connect with use-user-creds/use-target-creds
24 25 26 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 24 def authentication_credentials @authentication_credentials end |
#auto_rotate ⇒ Object
Whether to automatically rotate every –rotation-interval days, or disable existing automatic rotation [true/false]
27 28 29 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 27 def auto_rotate @auto_rotate end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
30 31 32 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 30 def delete_protection @delete_protection end |
#description ⇒ Object
Description of the object
33 34 35 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 33 def description @description end |
#host_provider ⇒ Object
Host provider type [explicit/target], Default Host provider is explicit, Relevant only for Secure Remote Access of ssh cert issuer, ldap rotated secret and ldap dynamic secret
36 37 38 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 36 def host_provider @host_provider end |
#input_rule ⇒ Object
Agentic input rule in name=…,rule=… format (e.g. name=rule1,rule=Sanitize input)
39 40 41 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 39 def input_rule @input_rule end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
42 43 44 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 42 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
45 46 47 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 45 def json @json end |
#keep_prev_version ⇒ Object
Whether to keep previous version [true/false]. If not set, use default according to account settings
48 49 50 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 48 def keep_prev_version @keep_prev_version end |
#key ⇒ Object
The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)
51 52 53 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 51 def key @key end |
#lock_during_sra_session ⇒ Object
Lock this secret for read/update while an SRA session is active
54 55 56 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 54 def lock_during_sra_session @lock_during_sra_session end |
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
57 58 59 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 57 def max_versions @max_versions end |
#name ⇒ Object
Rotated secret name
60 61 62 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 60 def name @name end |
#new_name ⇒ Object
New item name
63 64 65 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 63 def new_name @new_name end |
#output_rule ⇒ Object
Agentic output rule in name=…,rule=… format (e.g. name=rule1,rule=Mask secrets)
66 67 68 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 66 def output_rule @output_rule end |
#password_length ⇒ Object
The length of the password to be generated
69 70 71 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 69 def password_length @password_length end |
#provider_type ⇒ Object
Returns the value of attribute provider_type.
18 19 20 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 18 def provider_type @provider_type end |
#rm_tag ⇒ Object
List of the existent tags that will be removed from this item
72 73 74 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 72 def rm_tag @rm_tag end |
#rotate_after_disconnect ⇒ Object
StringOrBool accepts JSON strings, booleans, and numbers for backward compatibility with older SDK versions that send boolean values for rotate-after-disconnect.
75 76 77 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 75 def rotate_after_disconnect @rotate_after_disconnect end |
#rotated_password ⇒ Object
rotated-username password (relevant only for rotator-type=ldap)
78 79 80 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 78 def rotated_password @rotated_password end |
#rotated_username ⇒ Object
username to be rotated, if selected use-self-creds at rotator-creds-type, this username will try to rotate it’s own password, if use-target-creds is selected, target credentials will be use to rotate the rotated-password (relevant only for rotator-type=ldap)
81 82 83 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 81 def rotated_username @rotated_username end |
#rotation_event_in ⇒ Object
How many days before the rotation of the item would you like to be notified
84 85 86 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 84 def rotation_event_in @rotation_event_in end |
#rotation_hour ⇒ Object
The Hour of the rotation in UTC
87 88 89 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 87 def rotation_hour @rotation_hour end |
#rotation_interval ⇒ Object
The number of days to wait between every automatic key rotation (1-365)
90 91 92 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 90 def rotation_interval @rotation_interval end |
#secure_access_bastion_issuer ⇒ Object
Deprecated. use secure-access-certificate-issuer
93 94 95 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 93 def secure_access_bastion_issuer @secure_access_bastion_issuer end |
#secure_access_certificate_issuer ⇒ Object
Path to the SSH Certificate Issuer for your Akeyless Secure Access
96 97 98 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 96 def secure_access_certificate_issuer @secure_access_certificate_issuer end |
#secure_access_enable ⇒ Object
Enable/Disable secure remote access [true/false]
99 100 101 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 99 def secure_access_enable @secure_access_enable end |
#secure_access_host ⇒ Object
Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)
102 103 104 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 102 def secure_access_host @secure_access_host end |
#secure_access_rdp_domain ⇒ Object
Default domain name server. i.e. microsoft.com
105 106 107 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 105 def secure_access_rdp_domain @secure_access_rdp_domain end |
#secure_access_url ⇒ Object
Destination URL to inject secrets
108 109 110 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 108 def secure_access_url @secure_access_url end |
#secure_access_web ⇒ Object
Enable Web Secure Remote Access
111 112 113 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 111 def secure_access_web @secure_access_web end |
#secure_access_web_browsing ⇒ Object
Secure browser via Akeyless’s Secure Remote Access (SRA)
114 115 116 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 114 def secure_access_web_browsing @secure_access_web_browsing end |
#secure_access_web_proxy ⇒ Object
Web-Proxy via Akeyless’s Secure Remote Access (SRA)
117 118 119 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 117 def secure_access_web_proxy @secure_access_web_proxy end |
#target ⇒ Object
A list of linked targets to be associated, Relevant only for Secure Remote Access for ssh cert issuer, ldap rotated secret and ldap dynamic secret, To specify multiple targets use argument multiple times
120 121 122 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 120 def target @target end |
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`)
123 124 125 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 123 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
126 127 128 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 126 def uid_token @uid_token end |
#user_attribute ⇒ Object
LDAP User Attribute, Default value "cn"
129 130 131 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 129 def user_attribute @user_attribute end |
#user_dn ⇒ Object
Base DN to Perform User Search
132 133 134 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 132 def user_dn @user_dn end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 544 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
180 181 182 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 180 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 135 def self.attribute_map { :'provider_type' => :'ProviderType', :'add_tag' => :'add-tag', :'authentication_credentials' => :'authentication-credentials', :'auto_rotate' => :'auto-rotate', :'delete_protection' => :'delete_protection', :'description' => :'description', :'host_provider' => :'host-provider', :'input_rule' => :'input-rule', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'keep_prev_version' => :'keep-prev-version', :'key' => :'key', :'lock_during_sra_session' => :'lock-during-sra-session', :'max_versions' => :'max-versions', :'name' => :'name', :'new_name' => :'new-name', :'output_rule' => :'output-rule', :'password_length' => :'password-length', :'rm_tag' => :'rm-tag', :'rotate_after_disconnect' => :'rotate-after-disconnect', :'rotated_password' => :'rotated-password', :'rotated_username' => :'rotated-username', :'rotation_event_in' => :'rotation-event-in', :'rotation_hour' => :'rotation-hour', :'rotation_interval' => :'rotation-interval', :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer', :'secure_access_certificate_issuer' => :'secure-access-certificate-issuer', :'secure_access_enable' => :'secure-access-enable', :'secure_access_host' => :'secure-access-host', :'secure_access_rdp_domain' => :'secure-access-rdp-domain', :'secure_access_url' => :'secure-access-url', :'secure_access_web' => :'secure-access-web', :'secure_access_web_browsing' => :'secure-access-web-browsing', :'secure_access_web_proxy' => :'secure-access-web-proxy', :'target' => :'target', :'token' => :'token', :'uid_token' => :'uid-token', :'user_attribute' => :'user-attribute', :'user_dn' => :'user-dn' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 520 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
230 231 232 233 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 230 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 185 def self.openapi_types { :'provider_type' => :'String', :'add_tag' => :'Array<String>', :'authentication_credentials' => :'String', :'auto_rotate' => :'String', :'delete_protection' => :'String', :'description' => :'String', :'host_provider' => :'String', :'input_rule' => :'Array<String>', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'keep_prev_version' => :'String', :'key' => :'String', :'lock_during_sra_session' => :'String', :'max_versions' => :'String', :'name' => :'String', :'new_name' => :'String', :'output_rule' => :'Array<String>', :'password_length' => :'String', :'rm_tag' => :'Array<String>', :'rotate_after_disconnect' => :'String', :'rotated_password' => :'String', :'rotated_username' => :'String', :'rotation_event_in' => :'Array<String>', :'rotation_hour' => :'Integer', :'rotation_interval' => :'String', :'secure_access_bastion_issuer' => :'String', :'secure_access_certificate_issuer' => :'String', :'secure_access_enable' => :'String', :'secure_access_host' => :'Array<String>', :'secure_access_rdp_domain' => :'String', :'secure_access_url' => :'String', :'secure_access_web' => :'Boolean', :'secure_access_web_browsing' => :'Boolean', :'secure_access_web_proxy' => :'Boolean', :'target' => :'Array<String>', :'token' => :'String', :'uid_token' => :'String', :'user_attribute' => :'String', :'user_dn' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 461 def ==(o) return true if self.equal?(o) self.class == o.class && provider_type == o.provider_type && add_tag == o.add_tag && authentication_credentials == o.authentication_credentials && auto_rotate == o.auto_rotate && delete_protection == o.delete_protection && description == o.description && host_provider == o.host_provider && input_rule == o.input_rule && item_custom_fields == o.item_custom_fields && json == o.json && keep_prev_version == o.keep_prev_version && key == o.key && lock_during_sra_session == o.lock_during_sra_session && max_versions == o.max_versions && name == o.name && new_name == o.new_name && output_rule == o.output_rule && password_length == o.password_length && rm_tag == o.rm_tag && rotate_after_disconnect == o.rotate_after_disconnect && rotated_password == o.rotated_password && rotated_username == o.rotated_username && rotation_event_in == o.rotation_event_in && rotation_hour == o.rotation_hour && rotation_interval == o.rotation_interval && secure_access_bastion_issuer == o.secure_access_bastion_issuer && secure_access_certificate_issuer == o.secure_access_certificate_issuer && secure_access_enable == o.secure_access_enable && secure_access_host == o.secure_access_host && secure_access_rdp_domain == o.secure_access_rdp_domain && secure_access_url == o.secure_access_url && secure_access_web == o.secure_access_web && secure_access_web_browsing == o.secure_access_web_browsing && secure_access_web_proxy == o.secure_access_web_proxy && target == o.target && token == o.token && uid_token == o.uid_token && user_attribute == o.user_attribute && user_dn == o.user_dn end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
615 616 617 618 619 620 621 622 623 624 625 626 627 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 615 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
507 508 509 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 507 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
513 514 515 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 513 def hash [provider_type, add_tag, authentication_credentials, auto_rotate, delete_protection, description, host_provider, input_rule, item_custom_fields, json, keep_prev_version, key, lock_during_sra_session, max_versions, name, new_name, output_rule, password_length, rm_tag, rotate_after_disconnect, rotated_password, rotated_username, rotation_event_in, rotation_hour, rotation_interval, secure_access_bastion_issuer, secure_access_certificate_issuer, secure_access_enable, secure_access_host, secure_access_rdp_domain, secure_access_url, secure_access_web, secure_access_web_browsing, secure_access_web_proxy, target, token, uid_token, user_attribute, user_dn].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
441 442 443 444 445 446 447 448 449 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 441 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
591 592 593 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 591 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
597 598 599 600 601 602 603 604 605 606 607 608 609 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 597 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
585 586 587 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 585 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
453 454 455 456 457 |
# File 'lib/akeyless/models/rotated_secret_update_ldap.rb', line 453 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |