Class: Akeyless::RotatedSecretUpdateSsh
- Inherits:
-
Object
- Object
- Akeyless::RotatedSecretUpdateSsh
- Defined in:
- lib/akeyless/models/rotated_secret_update_ssh.rb
Instance Attribute Summary collapse
-
#add_tag ⇒ Object
List of the new tags that will be attached to this item.
-
#authentication_credentials ⇒ Object
The credentials to connect with use-user-creds/use-target-creds.
-
#auto_rotate ⇒ Object
Returns the value of attribute auto_rotate.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#description ⇒ Object
Description of the object.
-
#input_rule ⇒ Object
Agentic input rule in name=…,rule=…
-
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item.
-
#json ⇒ Object
Set output format to JSON.
-
#keep_prev_version ⇒ Object
Whether to keep previous version [true/false].
-
#key ⇒ Object
Returns the value of attribute key.
-
#key_data_base64 ⇒ Object
Private key file contents encoded using base64.
-
#lock_during_sra_session ⇒ Object
Lock this secret for read/update while an SRA session is active.
-
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
-
#name ⇒ Object
Rotated secret name.
-
#new_name ⇒ Object
New item name.
-
#output_rule ⇒ Object
Agentic output rule in name=…,rule=…
-
#password_length ⇒ Object
The length of the password to be generated.
-
#public_key_remote_path ⇒ Object
The path to the public key that will be rotated on the server.
-
#rm_tag ⇒ Object
List of the existent tags that will be removed from this item.
-
#rotate_after_disconnect ⇒ Object
StringOrBool accepts JSON strings, booleans, and numbers for backward compatibility with older SDK versions that send boolean values for rotate-after-disconnect.
-
#rotated_password ⇒ Object
rotated-username password (relevant only for rotator-type=password).
-
#rotated_username ⇒ Object
username to be rotated, if selected use-self-creds at rotator-creds-type, this username will try to rotate it’s own password, if use-target-creds is selected, target credentials will be use to rotate the rotated-password (relevant only for rotator-type=password).
-
#rotation_event_in ⇒ Object
How many days before the rotation of the item would you like to be notified.
-
#rotation_hour ⇒ Object
Returns the value of attribute rotation_hour.
-
#rotation_interval ⇒ Object
Returns the value of attribute rotation_interval.
-
#rotator_custom_cmd ⇒ Object
Custom rotation command.
-
#rotator_type ⇒ Object
The rotator type.
-
#same_password ⇒ Object
Rotate same password for each host from the Linked Target (relevant only for Linked Target).
-
#secure_access_allow_external_user ⇒ Object
Allow providing external user for a domain users.
-
#secure_access_bastion_issuer ⇒ Object
Deprecated.
-
#secure_access_certificate_issuer ⇒ Object
Path to the SSH Certificate Issuer for your Akeyless Secure Access.
-
#secure_access_enable ⇒ Object
Enable/Disable secure remote access [true/false].
-
#secure_access_host ⇒ Object
Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers).
-
#secure_access_rdp_domain ⇒ Object
Default domain name server.
-
#secure_access_rdp_user ⇒ Object
Override the RDP Domain username.
-
#secure_access_ssh_user ⇒ Object
Override the SSH username as indicated in SSH Certificate Issuer.
-
#secure_access_target_type ⇒ Object
Specify target type.
-
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`).
-
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#use_capital_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z).
-
#use_lower_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z).
-
#use_numbers ⇒ Object
Specifies whether the generated temporary password must contain at least one numeric character (0 to 9).
-
#use_special_characters ⇒ Object
Returns the value of attribute use_special_characters.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RotatedSecretUpdateSsh
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RotatedSecretUpdateSsh
Initializes the object
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 253 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::RotatedSecretUpdateSsh` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::RotatedSecretUpdateSsh`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'add_tag') if (value = attributes[:'add_tag']).is_a?(Array) self.add_tag = value end end if attributes.key?(:'authentication_credentials') self.authentication_credentials = attributes[:'authentication_credentials'] else self.authentication_credentials = 'use-user-creds' end if attributes.key?(:'auto_rotate') self.auto_rotate = attributes[:'auto_rotate'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = 'default_metadata' end if attributes.key?(:'input_rule') if (value = attributes[:'input_rule']).is_a?(Array) self.input_rule = value end end if attributes.key?(:'item_custom_fields') if (value = attributes[:'item_custom_fields']).is_a?(Hash) self.item_custom_fields = value end end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'keep_prev_version') self.keep_prev_version = attributes[:'keep_prev_version'] end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'key_data_base64') self.key_data_base64 = attributes[:'key_data_base64'] end if attributes.key?(:'lock_during_sra_session') self.lock_during_sra_session = attributes[:'lock_during_sra_session'] end if attributes.key?(:'max_versions') self.max_versions = attributes[:'max_versions'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'new_name') self.new_name = attributes[:'new_name'] end if attributes.key?(:'output_rule') if (value = attributes[:'output_rule']).is_a?(Array) self.output_rule = value end end if attributes.key?(:'password_length') self.password_length = attributes[:'password_length'] end if attributes.key?(:'public_key_remote_path') self.public_key_remote_path = attributes[:'public_key_remote_path'] end if attributes.key?(:'rm_tag') if (value = attributes[:'rm_tag']).is_a?(Array) self.rm_tag = value end end if attributes.key?(:'rotate_after_disconnect') self.rotate_after_disconnect = attributes[:'rotate_after_disconnect'] end if attributes.key?(:'rotated_password') self.rotated_password = attributes[:'rotated_password'] end if attributes.key?(:'rotated_username') self.rotated_username = attributes[:'rotated_username'] end if attributes.key?(:'rotation_event_in') if (value = attributes[:'rotation_event_in']).is_a?(Array) self.rotation_event_in = value end end if attributes.key?(:'rotation_hour') self.rotation_hour = attributes[:'rotation_hour'] end if attributes.key?(:'rotation_interval') self.rotation_interval = attributes[:'rotation_interval'] end if attributes.key?(:'rotator_custom_cmd') self.rotator_custom_cmd = attributes[:'rotator_custom_cmd'] end if attributes.key?(:'rotator_type') self.rotator_type = attributes[:'rotator_type'] else self.rotator_type = nil end if attributes.key?(:'same_password') self.same_password = attributes[:'same_password'] end if attributes.key?(:'secure_access_allow_external_user') self.secure_access_allow_external_user = attributes[:'secure_access_allow_external_user'] else self.secure_access_allow_external_user = false end if attributes.key?(:'secure_access_bastion_issuer') self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer'] end if attributes.key?(:'secure_access_certificate_issuer') self.secure_access_certificate_issuer = attributes[:'secure_access_certificate_issuer'] end if attributes.key?(:'secure_access_enable') self.secure_access_enable = attributes[:'secure_access_enable'] end if attributes.key?(:'secure_access_host') if (value = attributes[:'secure_access_host']).is_a?(Array) self.secure_access_host = value end end if attributes.key?(:'secure_access_rdp_domain') self.secure_access_rdp_domain = attributes[:'secure_access_rdp_domain'] end if attributes.key?(:'secure_access_rdp_user') self.secure_access_rdp_user = attributes[:'secure_access_rdp_user'] end if attributes.key?(:'secure_access_ssh_user') self.secure_access_ssh_user = attributes[:'secure_access_ssh_user'] end if attributes.key?(:'secure_access_target_type') self.secure_access_target_type = attributes[:'secure_access_target_type'] else self.secure_access_target_type = 'false' end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'use_capital_letters') self.use_capital_letters = attributes[:'use_capital_letters'] end if attributes.key?(:'use_lower_letters') self.use_lower_letters = attributes[:'use_lower_letters'] end if attributes.key?(:'use_numbers') self.use_numbers = attributes[:'use_numbers'] end if attributes.key?(:'use_special_characters') self.use_special_characters = attributes[:'use_special_characters'] end end |
Instance Attribute Details
#add_tag ⇒ Object
List of the new tags that will be attached to this item
19 20 21 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 19 def add_tag @add_tag end |
#authentication_credentials ⇒ Object
The credentials to connect with use-user-creds/use-target-creds
22 23 24 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 22 def authentication_credentials @authentication_credentials end |
#auto_rotate ⇒ Object
Returns the value of attribute auto_rotate.
24 25 26 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 24 def auto_rotate @auto_rotate end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
27 28 29 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 27 def delete_protection @delete_protection end |
#description ⇒ Object
Description of the object
30 31 32 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 30 def description @description end |
#input_rule ⇒ Object
Agentic input rule in name=…,rule=… format (e.g. name=rule1,rule=Sanitize input)
33 34 35 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 33 def input_rule @input_rule end |
#item_custom_fields ⇒ Object
Additional custom fields to associate with the item
36 37 38 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 36 def item_custom_fields @item_custom_fields end |
#json ⇒ Object
Set output format to JSON
39 40 41 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 39 def json @json end |
#keep_prev_version ⇒ Object
Whether to keep previous version [true/false]. If not set, use default according to account settings
42 43 44 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 42 def keep_prev_version @keep_prev_version end |
#key ⇒ Object
Returns the value of attribute key.
44 45 46 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 44 def key @key end |
#key_data_base64 ⇒ Object
Private key file contents encoded using base64
47 48 49 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 47 def key_data_base64 @key_data_base64 end |
#lock_during_sra_session ⇒ Object
Lock this secret for read/update while an SRA session is active
50 51 52 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 50 def lock_during_sra_session @lock_during_sra_session end |
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
53 54 55 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 53 def max_versions @max_versions end |
#name ⇒ Object
Rotated secret name
56 57 58 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 56 def name @name end |
#new_name ⇒ Object
New item name
59 60 61 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 59 def new_name @new_name end |
#output_rule ⇒ Object
Agentic output rule in name=…,rule=… format (e.g. name=rule1,rule=Mask secrets)
62 63 64 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 62 def output_rule @output_rule end |
#password_length ⇒ Object
The length of the password to be generated
65 66 67 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 65 def password_length @password_length end |
#public_key_remote_path ⇒ Object
The path to the public key that will be rotated on the server
68 69 70 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 68 def public_key_remote_path @public_key_remote_path end |
#rm_tag ⇒ Object
List of the existent tags that will be removed from this item
71 72 73 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 71 def rm_tag @rm_tag end |
#rotate_after_disconnect ⇒ Object
StringOrBool accepts JSON strings, booleans, and numbers for backward compatibility with older SDK versions that send boolean values for rotate-after-disconnect.
74 75 76 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 74 def rotate_after_disconnect @rotate_after_disconnect end |
#rotated_password ⇒ Object
rotated-username password (relevant only for rotator-type=password)
77 78 79 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 77 def rotated_password @rotated_password end |
#rotated_username ⇒ Object
username to be rotated, if selected use-self-creds at rotator-creds-type, this username will try to rotate it’s own password, if use-target-creds is selected, target credentials will be use to rotate the rotated-password (relevant only for rotator-type=password)
80 81 82 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 80 def rotated_username @rotated_username end |
#rotation_event_in ⇒ Object
How many days before the rotation of the item would you like to be notified
83 84 85 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 83 def rotation_event_in @rotation_event_in end |
#rotation_hour ⇒ Object
Returns the value of attribute rotation_hour.
85 86 87 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 85 def rotation_hour @rotation_hour end |
#rotation_interval ⇒ Object
Returns the value of attribute rotation_interval.
87 88 89 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 87 def rotation_interval @rotation_interval end |
#rotator_custom_cmd ⇒ Object
Custom rotation command
90 91 92 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 90 def rotator_custom_cmd @rotator_custom_cmd end |
#rotator_type ⇒ Object
The rotator type. options: [target/password/key]
93 94 95 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 93 def rotator_type @rotator_type end |
#same_password ⇒ Object
Rotate same password for each host from the Linked Target (relevant only for Linked Target)
96 97 98 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 96 def same_password @same_password end |
#secure_access_allow_external_user ⇒ Object
Allow providing external user for a domain users
99 100 101 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 99 def secure_access_allow_external_user @secure_access_allow_external_user end |
#secure_access_bastion_issuer ⇒ Object
Deprecated. use secure-access-certificate-issuer
102 103 104 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 102 def secure_access_bastion_issuer @secure_access_bastion_issuer end |
#secure_access_certificate_issuer ⇒ Object
Path to the SSH Certificate Issuer for your Akeyless Secure Access
105 106 107 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 105 def secure_access_certificate_issuer @secure_access_certificate_issuer end |
#secure_access_enable ⇒ Object
Enable/Disable secure remote access [true/false]
108 109 110 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 108 def secure_access_enable @secure_access_enable end |
#secure_access_host ⇒ Object
Target servers for connections (In case of Linked Target association, host(s) will inherit Linked Target hosts - Relevant only for Dynamic Secrets/producers)
111 112 113 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 111 def secure_access_host @secure_access_host end |
#secure_access_rdp_domain ⇒ Object
Default domain name server. i.e. microsoft.com
114 115 116 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 114 def secure_access_rdp_domain @secure_access_rdp_domain end |
#secure_access_rdp_user ⇒ Object
Override the RDP Domain username
117 118 119 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 117 def secure_access_rdp_user @secure_access_rdp_user end |
#secure_access_ssh_user ⇒ Object
Override the SSH username as indicated in SSH Certificate Issuer
120 121 122 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 120 def secure_access_ssh_user @secure_access_ssh_user end |
#secure_access_target_type ⇒ Object
Specify target type. Options are ssh or rdp
123 124 125 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 123 def secure_access_target_type @secure_access_target_type end |
#token ⇒ Object
Authentication token (see ‘/auth` and `/configure`)
126 127 128 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 126 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
129 130 131 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 129 def uid_token @uid_token end |
#use_capital_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one uppercase character from the ISO basic Latin alphabet (A to Z). [true/false]
132 133 134 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 132 def use_capital_letters @use_capital_letters end |
#use_lower_letters ⇒ Object
Specifies whether the generated temporary password must contain at least one lowercase character from the ISO basic Latin alphabet (a to z). [true/false]
135 136 137 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 135 def use_lower_letters @use_lower_letters end |
#use_numbers ⇒ Object
Specifies whether the generated temporary password must contain at least one numeric character (0 to 9). [true/false]
138 139 140 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 138 def use_numbers @use_numbers end |
#use_special_characters ⇒ Object
Returns the value of attribute use_special_characters.
140 141 142 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 140 def use_special_characters @use_special_characters end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 581 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
192 193 194 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 192 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 143 def self.attribute_map { :'add_tag' => :'add-tag', :'authentication_credentials' => :'authentication-credentials', :'auto_rotate' => :'auto-rotate', :'delete_protection' => :'delete_protection', :'description' => :'description', :'input_rule' => :'input-rule', :'item_custom_fields' => :'item-custom-fields', :'json' => :'json', :'keep_prev_version' => :'keep-prev-version', :'key' => :'key', :'key_data_base64' => :'key-data-base64', :'lock_during_sra_session' => :'lock-during-sra-session', :'max_versions' => :'max-versions', :'name' => :'name', :'new_name' => :'new-name', :'output_rule' => :'output-rule', :'password_length' => :'password-length', :'public_key_remote_path' => :'public-key-remote-path', :'rm_tag' => :'rm-tag', :'rotate_after_disconnect' => :'rotate-after-disconnect', :'rotated_password' => :'rotated-password', :'rotated_username' => :'rotated-username', :'rotation_event_in' => :'rotation-event-in', :'rotation_hour' => :'rotation-hour', :'rotation_interval' => :'rotation-interval', :'rotator_custom_cmd' => :'rotator-custom-cmd', :'rotator_type' => :'rotator-type', :'same_password' => :'same-password', :'secure_access_allow_external_user' => :'secure-access-allow-external-user', :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer', :'secure_access_certificate_issuer' => :'secure-access-certificate-issuer', :'secure_access_enable' => :'secure-access-enable', :'secure_access_host' => :'secure-access-host', :'secure_access_rdp_domain' => :'secure-access-rdp-domain', :'secure_access_rdp_user' => :'secure-access-rdp-user', :'secure_access_ssh_user' => :'secure-access-ssh-user', :'secure_access_target_type' => :'secure-access-target-type', :'token' => :'token', :'uid_token' => :'uid-token', :'use_capital_letters' => :'use-capital-letters', :'use_lower_letters' => :'use-lower-letters', :'use_numbers' => :'use-numbers', :'use_special_characters' => :'use-special-characters' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 557 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
246 247 248 249 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 246 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 197 def self.openapi_types { :'add_tag' => :'Array<String>', :'authentication_credentials' => :'String', :'auto_rotate' => :'String', :'delete_protection' => :'String', :'description' => :'String', :'input_rule' => :'Array<String>', :'item_custom_fields' => :'Hash<String, String>', :'json' => :'Boolean', :'keep_prev_version' => :'String', :'key' => :'String', :'key_data_base64' => :'String', :'lock_during_sra_session' => :'String', :'max_versions' => :'String', :'name' => :'String', :'new_name' => :'String', :'output_rule' => :'Array<String>', :'password_length' => :'String', :'public_key_remote_path' => :'String', :'rm_tag' => :'Array<String>', :'rotate_after_disconnect' => :'String', :'rotated_password' => :'String', :'rotated_username' => :'String', :'rotation_event_in' => :'Array<String>', :'rotation_hour' => :'Integer', :'rotation_interval' => :'String', :'rotator_custom_cmd' => :'String', :'rotator_type' => :'String', :'same_password' => :'String', :'secure_access_allow_external_user' => :'Boolean', :'secure_access_bastion_issuer' => :'String', :'secure_access_certificate_issuer' => :'String', :'secure_access_enable' => :'String', :'secure_access_host' => :'Array<String>', :'secure_access_rdp_domain' => :'String', :'secure_access_rdp_user' => :'String', :'secure_access_ssh_user' => :'String', :'secure_access_target_type' => :'String', :'token' => :'String', :'uid_token' => :'String', :'use_capital_letters' => :'String', :'use_lower_letters' => :'String', :'use_numbers' => :'String', :'use_special_characters' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 494 def ==(o) return true if self.equal?(o) self.class == o.class && add_tag == o.add_tag && authentication_credentials == o.authentication_credentials && auto_rotate == o.auto_rotate && delete_protection == o.delete_protection && description == o.description && input_rule == o.input_rule && item_custom_fields == o.item_custom_fields && json == o.json && keep_prev_version == o.keep_prev_version && key == o.key && key_data_base64 == o.key_data_base64 && lock_during_sra_session == o.lock_during_sra_session && max_versions == o.max_versions && name == o.name && new_name == o.new_name && output_rule == o.output_rule && password_length == o.password_length && public_key_remote_path == o.public_key_remote_path && rm_tag == o.rm_tag && rotate_after_disconnect == o.rotate_after_disconnect && rotated_password == o.rotated_password && rotated_username == o.rotated_username && rotation_event_in == o.rotation_event_in && rotation_hour == o.rotation_hour && rotation_interval == o.rotation_interval && rotator_custom_cmd == o.rotator_custom_cmd && rotator_type == o.rotator_type && same_password == o.same_password && secure_access_allow_external_user == o.secure_access_allow_external_user && secure_access_bastion_issuer == o.secure_access_bastion_issuer && secure_access_certificate_issuer == o.secure_access_certificate_issuer && secure_access_enable == o.secure_access_enable && secure_access_host == o.secure_access_host && secure_access_rdp_domain == o.secure_access_rdp_domain && secure_access_rdp_user == o.secure_access_rdp_user && secure_access_ssh_user == o.secure_access_ssh_user && secure_access_target_type == o.secure_access_target_type && token == o.token && uid_token == o.uid_token && use_capital_letters == o.use_capital_letters && use_lower_letters == o.use_lower_letters && use_numbers == o.use_numbers && use_special_characters == o.use_special_characters end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
652 653 654 655 656 657 658 659 660 661 662 663 664 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 652 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
544 545 546 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 544 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
550 551 552 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 550 def hash [add_tag, authentication_credentials, auto_rotate, delete_protection, description, input_rule, item_custom_fields, json, keep_prev_version, key, key_data_base64, lock_during_sra_session, max_versions, name, new_name, output_rule, password_length, public_key_remote_path, rm_tag, rotate_after_disconnect, rotated_password, rotated_username, rotation_event_in, rotation_hour, rotation_interval, rotator_custom_cmd, rotator_type, same_password, secure_access_allow_external_user, secure_access_bastion_issuer, secure_access_certificate_issuer, secure_access_enable, secure_access_host, secure_access_rdp_domain, secure_access_rdp_user, secure_access_ssh_user, secure_access_target_type, token, uid_token, use_capital_letters, use_lower_letters, use_numbers, use_special_characters].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 469 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @rotator_type.nil? invalid_properties.push('invalid value for "rotator_type", rotator_type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
628 629 630 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 628 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
634 635 636 637 638 639 640 641 642 643 644 645 646 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 634 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
622 623 624 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 622 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
485 486 487 488 489 490 |
# File 'lib/akeyless/models/rotated_secret_update_ssh.rb', line 485 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @rotator_type.nil? true end |