Class: Akeyless::SecretInfo

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/secret_info.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SecretInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/akeyless/models/secret_info.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::SecretInfo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::SecretInfo`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'activation_date')
    self.activation_date = attributes[:'activation_date']
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'expiration')
    self.expiration = attributes[:'expiration']
  end

  if attributes.key?(:'github')
    self.github = attributes[:'github']
  end

  if attributes.key?(:'key_id')
    self.key_id = attributes[:'key_id']
  end

  if attributes.key?(:'last_retrieved')
    self.last_retrieved = attributes[:'last_retrieved']
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'namespace')
    self.namespace = attributes[:'namespace']
  end

  if attributes.key?(:'region')
    self.region = attributes[:'region']
  end

  if attributes.key?(:'secret_id')
    self.secret_id = attributes[:'secret_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Hash)
      self.tags = value
    end
  end

  if attributes.key?(:'thumbprint')
    self.thumbprint = attributes[:'thumbprint']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'version_id')
    self.version_id = attributes[:'version_id']
  end

  if attributes.key?(:'version_ids')
    if (value = attributes[:'version_ids']).is_a?(Array)
      self.version_ids = value
    end
  end
end

Instance Attribute Details

#activation_dateObject

Returns the value of attribute activation_date.



18
19
20
# File 'lib/akeyless/models/secret_info.rb', line 18

def activation_date
  @activation_date
end

#createdObject

Returns the value of attribute created.



20
21
22
# File 'lib/akeyless/models/secret_info.rb', line 20

def created
  @created
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/akeyless/models/secret_info.rb', line 22

def description
  @description
end

#expirationObject

Returns the value of attribute expiration.



24
25
26
# File 'lib/akeyless/models/secret_info.rb', line 24

def expiration
  @expiration
end

#githubObject

Returns the value of attribute github.



26
27
28
# File 'lib/akeyless/models/secret_info.rb', line 26

def github
  @github
end

#key_idObject

Returns the value of attribute key_id.



28
29
30
# File 'lib/akeyless/models/secret_info.rb', line 28

def key_id
  @key_id
end

#last_retrievedObject

Returns the value of attribute last_retrieved.



30
31
32
# File 'lib/akeyless/models/secret_info.rb', line 30

def last_retrieved
  @last_retrieved
end

#locationObject

Returns the value of attribute location.



32
33
34
# File 'lib/akeyless/models/secret_info.rb', line 32

def location
  @location
end

#nameObject

Returns the value of attribute name.



34
35
36
# File 'lib/akeyless/models/secret_info.rb', line 34

def name
  @name
end

#namespaceObject

Returns the value of attribute namespace.



36
37
38
# File 'lib/akeyless/models/secret_info.rb', line 36

def namespace
  @namespace
end

#regionObject

Returns the value of attribute region.



38
39
40
# File 'lib/akeyless/models/secret_info.rb', line 38

def region
  @region
end

#secret_idObject

Returns the value of attribute secret_id.



40
41
42
# File 'lib/akeyless/models/secret_info.rb', line 40

def secret_id
  @secret_id
end

#statusObject

Returns the value of attribute status.



42
43
44
# File 'lib/akeyless/models/secret_info.rb', line 42

def status
  @status
end

#tagsObject

Returns the value of attribute tags.



44
45
46
# File 'lib/akeyless/models/secret_info.rb', line 44

def tags
  @tags
end

#thumbprintObject

Returns the value of attribute thumbprint.



46
47
48
# File 'lib/akeyless/models/secret_info.rb', line 46

def thumbprint
  @thumbprint
end

#typeObject

Returns the value of attribute type.



48
49
50
# File 'lib/akeyless/models/secret_info.rb', line 48

def type
  @type
end

#versionObject

Returns the value of attribute version.



50
51
52
# File 'lib/akeyless/models/secret_info.rb', line 50

def version
  @version
end

#version_idObject

Returns the value of attribute version_id.



52
53
54
# File 'lib/akeyless/models/secret_info.rb', line 52

def version_id
  @version_id
end

#version_idsObject

Returns the value of attribute version_ids.



54
55
56
# File 'lib/akeyless/models/secret_info.rb', line 54

def version_ids
  @version_ids
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/akeyless/models/secret_info.rb', line 294

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/akeyless/models/secret_info.rb', line 82

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/akeyless/models/secret_info.rb', line 57

def self.attribute_map
  {
    :'activation_date' => :'activation_date',
    :'created' => :'created',
    :'description' => :'description',
    :'expiration' => :'expiration',
    :'github' => :'github',
    :'key_id' => :'key_id',
    :'last_retrieved' => :'last_retrieved',
    :'location' => :'location',
    :'name' => :'name',
    :'namespace' => :'namespace',
    :'region' => :'region',
    :'secret_id' => :'secret_id',
    :'status' => :'status',
    :'tags' => :'tags',
    :'thumbprint' => :'thumbprint',
    :'type' => :'type',
    :'version' => :'version',
    :'version_id' => :'version_id',
    :'version_ids' => :'version_ids'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/akeyless/models/secret_info.rb', line 270

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
116
# File 'lib/akeyless/models/secret_info.rb', line 112

def self.openapi_nullable
  Set.new([
    :'location',
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/akeyless/models/secret_info.rb', line 87

def self.openapi_types
  {
    :'activation_date' => :'Time',
    :'created' => :'Time',
    :'description' => :'String',
    :'expiration' => :'Time',
    :'github' => :'GithubMetadata',
    :'key_id' => :'String',
    :'last_retrieved' => :'Time',
    :'location' => :'Object',
    :'name' => :'String',
    :'namespace' => :'String',
    :'region' => :'String',
    :'secret_id' => :'String',
    :'status' => :'Boolean',
    :'tags' => :'Hash<String, String>',
    :'thumbprint' => :'String',
    :'type' => :'String',
    :'version' => :'Integer',
    :'version_id' => :'String',
    :'version_ids' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/akeyless/models/secret_info.rb', line 231

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      activation_date == o.activation_date &&
      created == o.created &&
      description == o.description &&
      expiration == o.expiration &&
      github == o.github &&
      key_id == o.key_id &&
      last_retrieved == o.last_retrieved &&
      location == o.location &&
      name == o.name &&
      namespace == o.namespace &&
      region == o.region &&
      secret_id == o.secret_id &&
      status == o.status &&
      tags == o.tags &&
      thumbprint == o.thumbprint &&
      type == o.type &&
      version == o.version &&
      version_id == o.version_id &&
      version_ids == o.version_ids
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/akeyless/models/secret_info.rb', line 365

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


257
258
259
# File 'lib/akeyless/models/secret_info.rb', line 257

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



263
264
265
# File 'lib/akeyless/models/secret_info.rb', line 263

def hash
  [activation_date, created, description, expiration, github, key_id, last_retrieved, location, name, namespace, region, secret_id, status, tags, thumbprint, type, version, version_id, version_ids].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



216
217
218
219
220
# File 'lib/akeyless/models/secret_info.rb', line 216

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



341
342
343
# File 'lib/akeyless/models/secret_info.rb', line 341

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/akeyless/models/secret_info.rb', line 347

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



335
336
337
# File 'lib/akeyless/models/secret_info.rb', line 335

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



224
225
226
227
# File 'lib/akeyless/models/secret_info.rb', line 224

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end