Class: Akeyless::TargetTypeDetailsInput
- Inherits:
-
Object
- Object
- Akeyless::TargetTypeDetailsInput
- Defined in:
- lib/akeyless/models/target_type_details_input.rb
Instance Attribute Summary collapse
-
#anthropic_target_details ⇒ Object
Returns the value of attribute anthropic_target_details.
-
#artifactory_target_details ⇒ Object
Returns the value of attribute artifactory_target_details.
-
#aws_target_details ⇒ Object
Returns the value of attribute aws_target_details.
-
#azure_target_details ⇒ Object
Returns the value of attribute azure_target_details.
-
#bedrock_target_details ⇒ Object
Returns the value of attribute bedrock_target_details.
-
#chef_target_details ⇒ Object
Returns the value of attribute chef_target_details.
-
#cloudflare_target_details ⇒ Object
Returns the value of attribute cloudflare_target_details.
-
#custom_dns_target_details ⇒ Object
Returns the value of attribute custom_dns_target_details.
-
#custom_target_details ⇒ Object
Returns the value of attribute custom_target_details.
-
#db_target_details ⇒ Object
Returns the value of attribute db_target_details.
-
#digicert_target_details ⇒ Object
Returns the value of attribute digicert_target_details.
-
#dockerhub_target_details ⇒ Object
Returns the value of attribute dockerhub_target_details.
-
#eks_target_details ⇒ Object
Returns the value of attribute eks_target_details.
-
#gcp_target_details ⇒ Object
Returns the value of attribute gcp_target_details.
-
#gemini_target_details ⇒ Object
Returns the value of attribute gemini_target_details.
-
#github_target_details ⇒ Object
Returns the value of attribute github_target_details.
-
#gitlab_target_details ⇒ Object
Returns the value of attribute gitlab_target_details.
-
#gke_target_details ⇒ Object
Returns the value of attribute gke_target_details.
-
#globalsign_atlas_target_details ⇒ Object
Returns the value of attribute globalsign_atlas_target_details.
-
#globalsign_target_details ⇒ Object
Returns the value of attribute globalsign_target_details.
-
#godaddy_target_details ⇒ Object
Returns the value of attribute godaddy_target_details.
-
#google_trust_target_details ⇒ Object
Returns the value of attribute google_trust_target_details.
-
#grok_target_details ⇒ Object
Returns the value of attribute grok_target_details.
-
#hashi_vault_target_details ⇒ Object
Returns the value of attribute hashi_vault_target_details.
-
#keycloak_target_details ⇒ Object
Returns the value of attribute keycloak_target_details.
-
#ldap_target_details ⇒ Object
Returns the value of attribute ldap_target_details.
-
#letsencrypt_target_details ⇒ Object
Returns the value of attribute letsencrypt_target_details.
-
#linked_target_details ⇒ Object
Returns the value of attribute linked_target_details.
-
#mongo_db_target_details ⇒ Object
Returns the value of attribute mongo_db_target_details.
-
#native_k8s_target_details ⇒ Object
Returns the value of attribute native_k8s_target_details.
-
#okta_target_details ⇒ Object
Returns the value of attribute okta_target_details.
-
#openai_target_details ⇒ Object
Returns the value of attribute openai_target_details.
-
#ping_target_details ⇒ Object
Returns the value of attribute ping_target_details.
-
#rabbit_mq_target_details ⇒ Object
Returns the value of attribute rabbit_mq_target_details.
-
#salesforce_target_details ⇒ Object
Returns the value of attribute salesforce_target_details.
-
#sectigo_target_details ⇒ Object
Returns the value of attribute sectigo_target_details.
-
#splunk_target_details ⇒ Object
Returns the value of attribute splunk_target_details.
-
#ssh_target_details ⇒ Object
Returns the value of attribute ssh_target_details.
-
#venafi_target_details ⇒ Object
Returns the value of attribute venafi_target_details.
-
#web_target_details ⇒ Object
Returns the value of attribute web_target_details.
-
#windows_target_details ⇒ Object
Returns the value of attribute windows_target_details.
-
#zerossl_target_details ⇒ Object
Returns the value of attribute zerossl_target_details.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TargetTypeDetailsInput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TargetTypeDetailsInput
Initializes the object
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 211 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::TargetTypeDetailsInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::TargetTypeDetailsInput`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'anthropic_target_details') self.anthropic_target_details = attributes[:'anthropic_target_details'] end if attributes.key?(:'artifactory_target_details') self.artifactory_target_details = attributes[:'artifactory_target_details'] end if attributes.key?(:'aws_target_details') self.aws_target_details = attributes[:'aws_target_details'] end if attributes.key?(:'azure_target_details') self.azure_target_details = attributes[:'azure_target_details'] end if attributes.key?(:'bedrock_target_details') self.bedrock_target_details = attributes[:'bedrock_target_details'] end if attributes.key?(:'chef_target_details') self.chef_target_details = attributes[:'chef_target_details'] end if attributes.key?(:'cloudflare_target_details') self.cloudflare_target_details = attributes[:'cloudflare_target_details'] end if attributes.key?(:'custom_dns_target_details') self.custom_dns_target_details = attributes[:'custom_dns_target_details'] end if attributes.key?(:'custom_target_details') self.custom_target_details = attributes[:'custom_target_details'] end if attributes.key?(:'db_target_details') self.db_target_details = attributes[:'db_target_details'] end if attributes.key?(:'digicert_target_details') self.digicert_target_details = attributes[:'digicert_target_details'] end if attributes.key?(:'dockerhub_target_details') self.dockerhub_target_details = attributes[:'dockerhub_target_details'] end if attributes.key?(:'eks_target_details') self.eks_target_details = attributes[:'eks_target_details'] end if attributes.key?(:'gcp_target_details') self.gcp_target_details = attributes[:'gcp_target_details'] end if attributes.key?(:'gemini_target_details') self.gemini_target_details = attributes[:'gemini_target_details'] end if attributes.key?(:'github_target_details') self.github_target_details = attributes[:'github_target_details'] end if attributes.key?(:'gitlab_target_details') self.gitlab_target_details = attributes[:'gitlab_target_details'] end if attributes.key?(:'gke_target_details') self.gke_target_details = attributes[:'gke_target_details'] end if attributes.key?(:'globalsign_atlas_target_details') self.globalsign_atlas_target_details = attributes[:'globalsign_atlas_target_details'] end if attributes.key?(:'globalsign_target_details') self.globalsign_target_details = attributes[:'globalsign_target_details'] end if attributes.key?(:'godaddy_target_details') self.godaddy_target_details = attributes[:'godaddy_target_details'] end if attributes.key?(:'google_trust_target_details') self.google_trust_target_details = attributes[:'google_trust_target_details'] end if attributes.key?(:'grok_target_details') self.grok_target_details = attributes[:'grok_target_details'] end if attributes.key?(:'hashi_vault_target_details') self.hashi_vault_target_details = attributes[:'hashi_vault_target_details'] end if attributes.key?(:'keycloak_target_details') self.keycloak_target_details = attributes[:'keycloak_target_details'] end if attributes.key?(:'ldap_target_details') self.ldap_target_details = attributes[:'ldap_target_details'] end if attributes.key?(:'letsencrypt_target_details') self.letsencrypt_target_details = attributes[:'letsencrypt_target_details'] end if attributes.key?(:'linked_target_details') self.linked_target_details = attributes[:'linked_target_details'] end if attributes.key?(:'mongo_db_target_details') self.mongo_db_target_details = attributes[:'mongo_db_target_details'] end if attributes.key?(:'native_k8s_target_details') self.native_k8s_target_details = attributes[:'native_k8s_target_details'] end if attributes.key?(:'okta_target_details') self.okta_target_details = attributes[:'okta_target_details'] end if attributes.key?(:'openai_target_details') self.openai_target_details = attributes[:'openai_target_details'] end if attributes.key?(:'ping_target_details') self.ping_target_details = attributes[:'ping_target_details'] end if attributes.key?(:'rabbit_mq_target_details') self.rabbit_mq_target_details = attributes[:'rabbit_mq_target_details'] end if attributes.key?(:'salesforce_target_details') self.salesforce_target_details = attributes[:'salesforce_target_details'] end if attributes.key?(:'sectigo_target_details') self.sectigo_target_details = attributes[:'sectigo_target_details'] end if attributes.key?(:'splunk_target_details') self.splunk_target_details = attributes[:'splunk_target_details'] end if attributes.key?(:'ssh_target_details') self.ssh_target_details = attributes[:'ssh_target_details'] end if attributes.key?(:'venafi_target_details') self.venafi_target_details = attributes[:'venafi_target_details'] end if attributes.key?(:'web_target_details') self.web_target_details = attributes[:'web_target_details'] end if attributes.key?(:'windows_target_details') self.windows_target_details = attributes[:'windows_target_details'] end if attributes.key?(:'zerossl_target_details') self.zerossl_target_details = attributes[:'zerossl_target_details'] end end |
Instance Attribute Details
#anthropic_target_details ⇒ Object
Returns the value of attribute anthropic_target_details.
18 19 20 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 18 def anthropic_target_details @anthropic_target_details end |
#artifactory_target_details ⇒ Object
Returns the value of attribute artifactory_target_details.
20 21 22 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 20 def artifactory_target_details @artifactory_target_details end |
#aws_target_details ⇒ Object
Returns the value of attribute aws_target_details.
22 23 24 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 22 def aws_target_details @aws_target_details end |
#azure_target_details ⇒ Object
Returns the value of attribute azure_target_details.
24 25 26 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 24 def azure_target_details @azure_target_details end |
#bedrock_target_details ⇒ Object
Returns the value of attribute bedrock_target_details.
26 27 28 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 26 def bedrock_target_details @bedrock_target_details end |
#chef_target_details ⇒ Object
Returns the value of attribute chef_target_details.
28 29 30 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 28 def chef_target_details @chef_target_details end |
#cloudflare_target_details ⇒ Object
Returns the value of attribute cloudflare_target_details.
30 31 32 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 30 def cloudflare_target_details @cloudflare_target_details end |
#custom_dns_target_details ⇒ Object
Returns the value of attribute custom_dns_target_details.
32 33 34 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 32 def custom_dns_target_details @custom_dns_target_details end |
#custom_target_details ⇒ Object
Returns the value of attribute custom_target_details.
34 35 36 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 34 def custom_target_details @custom_target_details end |
#db_target_details ⇒ Object
Returns the value of attribute db_target_details.
36 37 38 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 36 def db_target_details @db_target_details end |
#digicert_target_details ⇒ Object
Returns the value of attribute digicert_target_details.
38 39 40 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 38 def digicert_target_details @digicert_target_details end |
#dockerhub_target_details ⇒ Object
Returns the value of attribute dockerhub_target_details.
40 41 42 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 40 def dockerhub_target_details @dockerhub_target_details end |
#eks_target_details ⇒ Object
Returns the value of attribute eks_target_details.
42 43 44 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 42 def eks_target_details @eks_target_details end |
#gcp_target_details ⇒ Object
Returns the value of attribute gcp_target_details.
44 45 46 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 44 def gcp_target_details @gcp_target_details end |
#gemini_target_details ⇒ Object
Returns the value of attribute gemini_target_details.
46 47 48 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 46 def gemini_target_details @gemini_target_details end |
#github_target_details ⇒ Object
Returns the value of attribute github_target_details.
48 49 50 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 48 def github_target_details @github_target_details end |
#gitlab_target_details ⇒ Object
Returns the value of attribute gitlab_target_details.
50 51 52 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 50 def gitlab_target_details @gitlab_target_details end |
#gke_target_details ⇒ Object
Returns the value of attribute gke_target_details.
52 53 54 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 52 def gke_target_details @gke_target_details end |
#globalsign_atlas_target_details ⇒ Object
Returns the value of attribute globalsign_atlas_target_details.
54 55 56 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 54 def globalsign_atlas_target_details @globalsign_atlas_target_details end |
#globalsign_target_details ⇒ Object
Returns the value of attribute globalsign_target_details.
56 57 58 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 56 def globalsign_target_details @globalsign_target_details end |
#godaddy_target_details ⇒ Object
Returns the value of attribute godaddy_target_details.
58 59 60 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 58 def godaddy_target_details @godaddy_target_details end |
#google_trust_target_details ⇒ Object
Returns the value of attribute google_trust_target_details.
60 61 62 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 60 def google_trust_target_details @google_trust_target_details end |
#grok_target_details ⇒ Object
Returns the value of attribute grok_target_details.
62 63 64 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 62 def grok_target_details @grok_target_details end |
#hashi_vault_target_details ⇒ Object
Returns the value of attribute hashi_vault_target_details.
64 65 66 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 64 def hashi_vault_target_details @hashi_vault_target_details end |
#keycloak_target_details ⇒ Object
Returns the value of attribute keycloak_target_details.
66 67 68 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 66 def keycloak_target_details @keycloak_target_details end |
#ldap_target_details ⇒ Object
Returns the value of attribute ldap_target_details.
68 69 70 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 68 def ldap_target_details @ldap_target_details end |
#letsencrypt_target_details ⇒ Object
Returns the value of attribute letsencrypt_target_details.
70 71 72 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 70 def letsencrypt_target_details @letsencrypt_target_details end |
#linked_target_details ⇒ Object
Returns the value of attribute linked_target_details.
72 73 74 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 72 def linked_target_details @linked_target_details end |
#mongo_db_target_details ⇒ Object
Returns the value of attribute mongo_db_target_details.
74 75 76 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 74 def mongo_db_target_details @mongo_db_target_details end |
#native_k8s_target_details ⇒ Object
Returns the value of attribute native_k8s_target_details.
76 77 78 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 76 def native_k8s_target_details @native_k8s_target_details end |
#okta_target_details ⇒ Object
Returns the value of attribute okta_target_details.
78 79 80 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 78 def okta_target_details @okta_target_details end |
#openai_target_details ⇒ Object
Returns the value of attribute openai_target_details.
80 81 82 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 80 def openai_target_details @openai_target_details end |
#ping_target_details ⇒ Object
Returns the value of attribute ping_target_details.
82 83 84 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 82 def ping_target_details @ping_target_details end |
#rabbit_mq_target_details ⇒ Object
Returns the value of attribute rabbit_mq_target_details.
84 85 86 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 84 def rabbit_mq_target_details @rabbit_mq_target_details end |
#salesforce_target_details ⇒ Object
Returns the value of attribute salesforce_target_details.
86 87 88 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 86 def salesforce_target_details @salesforce_target_details end |
#sectigo_target_details ⇒ Object
Returns the value of attribute sectigo_target_details.
88 89 90 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 88 def sectigo_target_details @sectigo_target_details end |
#splunk_target_details ⇒ Object
Returns the value of attribute splunk_target_details.
90 91 92 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 90 def splunk_target_details @splunk_target_details end |
#ssh_target_details ⇒ Object
Returns the value of attribute ssh_target_details.
92 93 94 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 92 def ssh_target_details @ssh_target_details end |
#venafi_target_details ⇒ Object
Returns the value of attribute venafi_target_details.
94 95 96 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 94 def venafi_target_details @venafi_target_details end |
#web_target_details ⇒ Object
Returns the value of attribute web_target_details.
96 97 98 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 96 def web_target_details @web_target_details end |
#windows_target_details ⇒ Object
Returns the value of attribute windows_target_details.
98 99 100 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 98 def windows_target_details @windows_target_details end |
#zerossl_target_details ⇒ Object
Returns the value of attribute zerossl_target_details.
100 101 102 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 100 def zerossl_target_details @zerossl_target_details end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 496 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
151 152 153 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 151 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 103 def self.attribute_map { :'anthropic_target_details' => :'anthropic_target_details', :'artifactory_target_details' => :'artifactory_target_details', :'aws_target_details' => :'aws_target_details', :'azure_target_details' => :'azure_target_details', :'bedrock_target_details' => :'bedrock_target_details', :'chef_target_details' => :'chef_target_details', :'cloudflare_target_details' => :'cloudflare_target_details', :'custom_dns_target_details' => :'custom_dns_target_details', :'custom_target_details' => :'custom_target_details', :'db_target_details' => :'db_target_details', :'digicert_target_details' => :'digicert_target_details', :'dockerhub_target_details' => :'dockerhub_target_details', :'eks_target_details' => :'eks_target_details', :'gcp_target_details' => :'gcp_target_details', :'gemini_target_details' => :'gemini_target_details', :'github_target_details' => :'github_target_details', :'gitlab_target_details' => :'gitlab_target_details', :'gke_target_details' => :'gke_target_details', :'globalsign_atlas_target_details' => :'globalsign_atlas_target_details', :'globalsign_target_details' => :'globalsign_target_details', :'godaddy_target_details' => :'godaddy_target_details', :'google_trust_target_details' => :'google_trust_target_details', :'grok_target_details' => :'grok_target_details', :'hashi_vault_target_details' => :'hashi_vault_target_details', :'keycloak_target_details' => :'keycloak_target_details', :'ldap_target_details' => :'ldap_target_details', :'letsencrypt_target_details' => :'letsencrypt_target_details', :'linked_target_details' => :'linked_target_details', :'mongo_db_target_details' => :'mongo_db_target_details', :'native_k8s_target_details' => :'native_k8s_target_details', :'okta_target_details' => :'okta_target_details', :'openai_target_details' => :'openai_target_details', :'ping_target_details' => :'ping_target_details', :'rabbit_mq_target_details' => :'rabbit_mq_target_details', :'salesforce_target_details' => :'salesforce_target_details', :'sectigo_target_details' => :'sectigo_target_details', :'splunk_target_details' => :'splunk_target_details', :'ssh_target_details' => :'ssh_target_details', :'venafi_target_details' => :'venafi_target_details', :'web_target_details' => :'web_target_details', :'windows_target_details' => :'windows_target_details', :'zerossl_target_details' => :'zerossl_target_details' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 472 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
204 205 206 207 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 204 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 156 def self.openapi_types { :'anthropic_target_details' => :'AnthropicTargetDetails', :'artifactory_target_details' => :'ArtifactoryTargetDetails', :'aws_target_details' => :'AWSTargetDetails', :'azure_target_details' => :'AzureTargetDetails', :'bedrock_target_details' => :'BedrockTargetDetails', :'chef_target_details' => :'ChefTargetDetails', :'cloudflare_target_details' => :'CloudflareTargetDetails', :'custom_dns_target_details' => :'CustomDnsTargetDetails', :'custom_target_details' => :'CustomTargetDetails', :'db_target_details' => :'DbTargetDetails', :'digicert_target_details' => :'DigiCertTargetDetails', :'dockerhub_target_details' => :'DockerhubTargetDetails', :'eks_target_details' => :'EKSTargetDetails', :'gcp_target_details' => :'GcpTargetDetails', :'gemini_target_details' => :'GeminiTargetDetails', :'github_target_details' => :'GithubTargetDetails', :'gitlab_target_details' => :'GitlabTargetDetails', :'gke_target_details' => :'GKETargetDetails', :'globalsign_atlas_target_details' => :'GlobalSignAtlasTargetDetails', :'globalsign_target_details' => :'GlobalSignGCCTargetDetails', :'godaddy_target_details' => :'GodaddyTargetDetails', :'google_trust_target_details' => :'GoogleTrustTargetDetails', :'grok_target_details' => :'GrokTargetDetails', :'hashi_vault_target_details' => :'HashiVaultTargetDetails', :'keycloak_target_details' => :'KeycloakTargetDetails', :'ldap_target_details' => :'LdapTargetDetails', :'letsencrypt_target_details' => :'LetsEncryptTargetDetails', :'linked_target_details' => :'LinkedTargetDetails', :'mongo_db_target_details' => :'MongoDBTargetDetails', :'native_k8s_target_details' => :'NativeK8sTargetDetails', :'okta_target_details' => :'OktaTargetDetails', :'openai_target_details' => :'OpenAITargetDetails', :'ping_target_details' => :'PingTargetDetails', :'rabbit_mq_target_details' => :'RabbitMQTargetDetails', :'salesforce_target_details' => :'SalesforceTargetDetails', :'sectigo_target_details' => :'SectigoTargetDetails', :'splunk_target_details' => :'SplunkTargetDetails', :'ssh_target_details' => :'SSHTargetDetails', :'venafi_target_details' => :'VenafiTargetDetails', :'web_target_details' => :'WebTargetDetails', :'windows_target_details' => :'WindowsTargetDetails', :'zerossl_target_details' => :'ZeroSSLTargetDetails' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 410 def ==(o) return true if self.equal?(o) self.class == o.class && anthropic_target_details == o.anthropic_target_details && artifactory_target_details == o.artifactory_target_details && aws_target_details == o.aws_target_details && azure_target_details == o.azure_target_details && bedrock_target_details == o.bedrock_target_details && chef_target_details == o.chef_target_details && cloudflare_target_details == o.cloudflare_target_details && custom_dns_target_details == o.custom_dns_target_details && custom_target_details == o.custom_target_details && db_target_details == o.db_target_details && digicert_target_details == o.digicert_target_details && dockerhub_target_details == o.dockerhub_target_details && eks_target_details == o.eks_target_details && gcp_target_details == o.gcp_target_details && gemini_target_details == o.gemini_target_details && github_target_details == o.github_target_details && gitlab_target_details == o.gitlab_target_details && gke_target_details == o.gke_target_details && globalsign_atlas_target_details == o.globalsign_atlas_target_details && globalsign_target_details == o.globalsign_target_details && godaddy_target_details == o.godaddy_target_details && google_trust_target_details == o.google_trust_target_details && grok_target_details == o.grok_target_details && hashi_vault_target_details == o.hashi_vault_target_details && keycloak_target_details == o.keycloak_target_details && ldap_target_details == o.ldap_target_details && letsencrypt_target_details == o.letsencrypt_target_details && linked_target_details == o.linked_target_details && mongo_db_target_details == o.mongo_db_target_details && native_k8s_target_details == o.native_k8s_target_details && okta_target_details == o.okta_target_details && openai_target_details == o.openai_target_details && ping_target_details == o.ping_target_details && rabbit_mq_target_details == o.rabbit_mq_target_details && salesforce_target_details == o.salesforce_target_details && sectigo_target_details == o.sectigo_target_details && splunk_target_details == o.splunk_target_details && ssh_target_details == o.ssh_target_details && venafi_target_details == o.venafi_target_details && web_target_details == o.web_target_details && windows_target_details == o.windows_target_details && zerossl_target_details == o.zerossl_target_details end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
567 568 569 570 571 572 573 574 575 576 577 578 579 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 567 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
459 460 461 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 459 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
465 466 467 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 465 def hash [anthropic_target_details, artifactory_target_details, aws_target_details, azure_target_details, bedrock_target_details, chef_target_details, cloudflare_target_details, custom_dns_target_details, custom_target_details, db_target_details, digicert_target_details, dockerhub_target_details, eks_target_details, gcp_target_details, gemini_target_details, github_target_details, gitlab_target_details, gke_target_details, globalsign_atlas_target_details, globalsign_target_details, godaddy_target_details, google_trust_target_details, grok_target_details, hashi_vault_target_details, keycloak_target_details, ldap_target_details, letsencrypt_target_details, linked_target_details, mongo_db_target_details, native_k8s_target_details, okta_target_details, openai_target_details, ping_target_details, rabbit_mq_target_details, salesforce_target_details, sectigo_target_details, splunk_target_details, ssh_target_details, venafi_target_details, web_target_details, windows_target_details, zerossl_target_details].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
395 396 397 398 399 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 395 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
543 544 545 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 543 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
549 550 551 552 553 554 555 556 557 558 559 560 561 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 549 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
537 538 539 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 537 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
403 404 405 406 |
# File 'lib/akeyless/models/target_type_details_input.rb', line 403 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |