Class: Akeyless::TargetTypeDetailsInput

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/target_type_details_input.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TargetTypeDetailsInput

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
# File 'lib/akeyless/models/target_type_details_input.rb', line 436

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::TargetTypeDetailsInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::TargetTypeDetailsInput`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'app_private_key')
    if (value = attributes[:'app_private_key']).is_a?(Array)
      self.app_private_key = value
    end
  end

  if attributes.key?(:'artifactory_admin_apikey')
    self.artifactory_admin_apikey = attributes[:'artifactory_admin_apikey']
  end

  if attributes.key?(:'artifactory_admin_username')
    self.artifactory_admin_username = attributes[:'artifactory_admin_username']
  end

  if attributes.key?(:'artifactory_base_url')
    self.artifactory_base_url = attributes[:'artifactory_base_url']
  end

  if attributes.key?(:'auth_flow')
    self.auth_flow = attributes[:'auth_flow']
  end

  if attributes.key?(:'aws_access_key_id')
    self.aws_access_key_id = attributes[:'aws_access_key_id']
  end

  if attributes.key?(:'aws_region')
    self.aws_region = attributes[:'aws_region']
  end

  if attributes.key?(:'aws_secret_access_key')
    self.aws_secret_access_key = attributes[:'aws_secret_access_key']
  end

  if attributes.key?(:'aws_session_token')
    self.aws_session_token = attributes[:'aws_session_token']
  end

  if attributes.key?(:'azure_client_id')
    self.azure_client_id = attributes[:'azure_client_id']
  end

  if attributes.key?(:'azure_client_secret')
    self.azure_client_secret = attributes[:'azure_client_secret']
  end

  if attributes.key?(:'azure_resource_group_name')
    self.azure_resource_group_name = attributes[:'azure_resource_group_name']
  end

  if attributes.key?(:'azure_resource_name')
    self.azure_resource_name = attributes[:'azure_resource_name']
  end

  if attributes.key?(:'azure_subscription_id')
    self.azure_subscription_id = attributes[:'azure_subscription_id']
  end

  if attributes.key?(:'azure_tenant_id')
    self.azure_tenant_id = attributes[:'azure_tenant_id']
  end

  if attributes.key?(:'ca_cert_data')
    if (value = attributes[:'ca_cert_data']).is_a?(Array)
      self.ca_cert_data = value
    end
  end

  if attributes.key?(:'ca_cert_name')
    self.ca_cert_name = attributes[:'ca_cert_name']
  end

  if attributes.key?(:'chef_server_host_name')
    self.chef_server_host_name = attributes[:'chef_server_host_name']
  end

  if attributes.key?(:'chef_server_key')
    self.chef_server_key = attributes[:'chef_server_key']
  end

  if attributes.key?(:'chef_server_port')
    self.chef_server_port = attributes[:'chef_server_port']
  end

  if attributes.key?(:'chef_server_url')
    self.chef_server_url = attributes[:'chef_server_url']
  end

  if attributes.key?(:'chef_server_username')
    self.chef_server_username = attributes[:'chef_server_username']
  end

  if attributes.key?(:'chef_skip_ssl')
    self.chef_skip_ssl = attributes[:'chef_skip_ssl']
  end

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'client_secret')
    self.client_secret = attributes[:'client_secret']
  end

  if attributes.key?(:'db_host_name')
    self.db_host_name = attributes[:'db_host_name']
  end

  if attributes.key?(:'db_name')
    self.db_name = attributes[:'db_name']
  end

  if attributes.key?(:'db_port')
    self.db_port = attributes[:'db_port']
  end

  if attributes.key?(:'db_private_key')
    self.db_private_key = attributes[:'db_private_key']
  end

  if attributes.key?(:'db_private_key_passphrase')
    self.db_private_key_passphrase = attributes[:'db_private_key_passphrase']
  end

  if attributes.key?(:'db_pwd')
    self.db_pwd = attributes[:'db_pwd']
  end

  if attributes.key?(:'db_server_certificates')
    self.db_server_certificates = attributes[:'db_server_certificates']
  end

  if attributes.key?(:'db_server_name')
    self.db_server_name = attributes[:'db_server_name']
  end

  if attributes.key?(:'db_user_name')
    self.db_user_name = attributes[:'db_user_name']
  end

  if attributes.key?(:'eks_access_key_id')
    self.eks_access_key_id = attributes[:'eks_access_key_id']
  end

  if attributes.key?(:'eks_cluster_ca_certificate')
    self.eks_cluster_ca_certificate = attributes[:'eks_cluster_ca_certificate']
  end

  if attributes.key?(:'eks_cluster_endpoint')
    self.eks_cluster_endpoint = attributes[:'eks_cluster_endpoint']
  end

  if attributes.key?(:'eks_cluster_name')
    self.eks_cluster_name = attributes[:'eks_cluster_name']
  end

  if attributes.key?(:'eks_region')
    self.eks_region = attributes[:'eks_region']
  end

  if attributes.key?(:'eks_secret_access_key')
    self.eks_secret_access_key = attributes[:'eks_secret_access_key']
  end

  if attributes.key?(:'gcp_service_account_email')
    self. = attributes[:'gcp_service_account_email']
  end

  if attributes.key?(:'gcp_service_account_key')
    self. = attributes[:'gcp_service_account_key']
  end

  if attributes.key?(:'github_app_id')
    self.github_app_id = attributes[:'github_app_id']
  end

  if attributes.key?(:'github_app_private_key')
    self.github_app_private_key = attributes[:'github_app_private_key']
  end

  if attributes.key?(:'github_base_url')
    self.github_base_url = attributes[:'github_base_url']
  end

  if attributes.key?(:'gke_cluster_ca_certificate')
    self.gke_cluster_ca_certificate = attributes[:'gke_cluster_ca_certificate']
  end

  if attributes.key?(:'gke_cluster_endpoint')
    self.gke_cluster_endpoint = attributes[:'gke_cluster_endpoint']
  end

  if attributes.key?(:'gke_cluster_name')
    self.gke_cluster_name = attributes[:'gke_cluster_name']
  end

  if attributes.key?(:'gke_service_account_key')
    self. = attributes[:'gke_service_account_key']
  end

  if attributes.key?(:'gke_service_account_name')
    self. = attributes[:'gke_service_account_name']
  end

  if attributes.key?(:'host')
    self.host = attributes[:'host']
  end

  if attributes.key?(:'implementation_type')
    self.implementation_type = attributes[:'implementation_type']
  end

  if attributes.key?(:'k8s_bearer_token')
    self.k8s_bearer_token = attributes[:'k8s_bearer_token']
  end

  if attributes.key?(:'k8s_cluster_ca_certificate')
    self.k8s_cluster_ca_certificate = attributes[:'k8s_cluster_ca_certificate']
  end

  if attributes.key?(:'k8s_cluster_endpoint')
    self.k8s_cluster_endpoint = attributes[:'k8s_cluster_endpoint']
  end

  if attributes.key?(:'ldap_audience')
    self.ldap_audience = attributes[:'ldap_audience']
  end

  if attributes.key?(:'ldap_bind_dn')
    self.ldap_bind_dn = attributes[:'ldap_bind_dn']
  end

  if attributes.key?(:'ldap_bind_password')
    self.ldap_bind_password = attributes[:'ldap_bind_password']
  end

  if attributes.key?(:'ldap_certificate')
    self.ldap_certificate = attributes[:'ldap_certificate']
  end

  if attributes.key?(:'ldap_token_expiration')
    self.ldap_token_expiration = attributes[:'ldap_token_expiration']
  end

  if attributes.key?(:'ldap_url')
    self.ldap_url = attributes[:'ldap_url']
  end

  if attributes.key?(:'mongodb_atlas_api_private_key')
    self.mongodb_atlas_api_private_key = attributes[:'mongodb_atlas_api_private_key']
  end

  if attributes.key?(:'mongodb_atlas_api_public_key')
    self.mongodb_atlas_api_public_key = attributes[:'mongodb_atlas_api_public_key']
  end

  if attributes.key?(:'mongodb_atlas_project_id')
    self.mongodb_atlas_project_id = attributes[:'mongodb_atlas_project_id']
  end

  if attributes.key?(:'mongodb_db_name')
    self.mongodb_db_name = attributes[:'mongodb_db_name']
  end

  if attributes.key?(:'mongodb_default_auth_db')
    self.mongodb_default_auth_db = attributes[:'mongodb_default_auth_db']
  end

  if attributes.key?(:'mongodb_host_port')
    self.mongodb_host_port = attributes[:'mongodb_host_port']
  end

  if attributes.key?(:'mongodb_is_atlas')
    self.mongodb_is_atlas = attributes[:'mongodb_is_atlas']
  end

  if attributes.key?(:'mongodb_password')
    self.mongodb_password = attributes[:'mongodb_password']
  end

  if attributes.key?(:'mongodb_uri_connection')
    self.mongodb_uri_connection = attributes[:'mongodb_uri_connection']
  end

  if attributes.key?(:'mongodb_uri_options')
    self.mongodb_uri_options = attributes[:'mongodb_uri_options']
  end

  if attributes.key?(:'mongodb_username')
    self.mongodb_username = attributes[:'mongodb_username']
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'payload')
    self.payload = attributes[:'payload']
  end

  if attributes.key?(:'port')
    self.port = attributes[:'port']
  end

  if attributes.key?(:'private_key')
    self.private_key = attributes[:'private_key']
  end

  if attributes.key?(:'private_key_password')
    self.private_key_password = attributes[:'private_key_password']
  end

  if attributes.key?(:'rabbitmq_server_password')
    self.rabbitmq_server_password = attributes[:'rabbitmq_server_password']
  end

  if attributes.key?(:'rabbitmq_server_uri')
    self.rabbitmq_server_uri = attributes[:'rabbitmq_server_uri']
  end

  if attributes.key?(:'rabbitmq_server_user')
    self.rabbitmq_server_user = attributes[:'rabbitmq_server_user']
  end

  if attributes.key?(:'security_token')
    self.security_token = attributes[:'security_token']
  end

  if attributes.key?(:'sf_account')
    self. = attributes[:'sf_account']
  end

  if attributes.key?(:'ssl_connection_certificate')
    self.ssl_connection_certificate = attributes[:'ssl_connection_certificate']
  end

  if attributes.key?(:'ssl_connection_mode')
    self.ssl_connection_mode = attributes[:'ssl_connection_mode']
  end

  if attributes.key?(:'tenant_url')
    self.tenant_url = attributes[:'tenant_url']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'use_gw_cloud_identity')
    self.use_gw_cloud_identity = attributes[:'use_gw_cloud_identity']
  end

  if attributes.key?(:'user_name')
    self.user_name = attributes[:'user_name']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'venafi_api_key')
    self.venafi_api_key = attributes[:'venafi_api_key']
  end

  if attributes.key?(:'venafi_base_url')
    self.venafi_base_url = attributes[:'venafi_base_url']
  end

  if attributes.key?(:'venafi_tpp_password')
    self.venafi_tpp_password = attributes[:'venafi_tpp_password']
  end

  if attributes.key?(:'venafi_tpp_username')
    self.venafi_tpp_username = attributes[:'venafi_tpp_username']
  end

  if attributes.key?(:'venafi_use_tpp')
    self.venafi_use_tpp = attributes[:'venafi_use_tpp']
  end

  if attributes.key?(:'venafi_zone')
    self.venafi_zone = attributes[:'venafi_zone']
  end
end

Instance Attribute Details

#app_private_keyObject

params needed for jwt auth AppPrivateKey is the rsa private key in PEM format



19
20
21
# File 'lib/akeyless/models/target_type_details_input.rb', line 19

def app_private_key
  @app_private_key
end

#artifactory_admin_apikeyObject

Returns the value of attribute artifactory_admin_apikey.



21
22
23
# File 'lib/akeyless/models/target_type_details_input.rb', line 21

def artifactory_admin_apikey
  @artifactory_admin_apikey
end

#artifactory_admin_usernameObject

Returns the value of attribute artifactory_admin_username.



23
24
25
# File 'lib/akeyless/models/target_type_details_input.rb', line 23

def artifactory_admin_username
  @artifactory_admin_username
end

#artifactory_base_urlObject

Returns the value of attribute artifactory_base_url.



25
26
27
# File 'lib/akeyless/models/target_type_details_input.rb', line 25

def artifactory_base_url
  @artifactory_base_url
end

#auth_flowObject

Returns the value of attribute auth_flow.



27
28
29
# File 'lib/akeyless/models/target_type_details_input.rb', line 27

def auth_flow
  @auth_flow
end

#aws_access_key_idObject

Returns the value of attribute aws_access_key_id.



29
30
31
# File 'lib/akeyless/models/target_type_details_input.rb', line 29

def aws_access_key_id
  @aws_access_key_id
end

#aws_regionObject

Returns the value of attribute aws_region.



31
32
33
# File 'lib/akeyless/models/target_type_details_input.rb', line 31

def aws_region
  @aws_region
end

#aws_secret_access_keyObject

Returns the value of attribute aws_secret_access_key.



33
34
35
# File 'lib/akeyless/models/target_type_details_input.rb', line 33

def aws_secret_access_key
  @aws_secret_access_key
end

#aws_session_tokenObject

Returns the value of attribute aws_session_token.



35
36
37
# File 'lib/akeyless/models/target_type_details_input.rb', line 35

def aws_session_token
  @aws_session_token
end

#azure_client_idObject

Returns the value of attribute azure_client_id.



37
38
39
# File 'lib/akeyless/models/target_type_details_input.rb', line 37

def azure_client_id
  @azure_client_id
end

#azure_client_secretObject

Returns the value of attribute azure_client_secret.



39
40
41
# File 'lib/akeyless/models/target_type_details_input.rb', line 39

def azure_client_secret
  @azure_client_secret
end

#azure_resource_group_nameObject

Returns the value of attribute azure_resource_group_name.



41
42
43
# File 'lib/akeyless/models/target_type_details_input.rb', line 41

def azure_resource_group_name
  @azure_resource_group_name
end

#azure_resource_nameObject

Returns the value of attribute azure_resource_name.



43
44
45
# File 'lib/akeyless/models/target_type_details_input.rb', line 43

def azure_resource_name
  @azure_resource_name
end

#azure_subscription_idObject

Returns the value of attribute azure_subscription_id.



45
46
47
# File 'lib/akeyless/models/target_type_details_input.rb', line 45

def azure_subscription_id
  @azure_subscription_id
end

#azure_tenant_idObject

Returns the value of attribute azure_tenant_id.



47
48
49
# File 'lib/akeyless/models/target_type_details_input.rb', line 47

def azure_tenant_id
  @azure_tenant_id
end

#ca_cert_dataObject

CACertData is the rsa 4096 certificate data in PEM format



50
51
52
# File 'lib/akeyless/models/target_type_details_input.rb', line 50

def ca_cert_data
  @ca_cert_data
end

#ca_cert_nameObject

CACertName is the name of the certificate in SalesForce tenant



53
54
55
# File 'lib/akeyless/models/target_type_details_input.rb', line 53

def ca_cert_name
  @ca_cert_name
end

#chef_server_host_nameObject

Returns the value of attribute chef_server_host_name.



55
56
57
# File 'lib/akeyless/models/target_type_details_input.rb', line 55

def chef_server_host_name
  @chef_server_host_name
end

#chef_server_keyObject

Returns the value of attribute chef_server_key.



57
58
59
# File 'lib/akeyless/models/target_type_details_input.rb', line 57

def chef_server_key
  @chef_server_key
end

#chef_server_portObject

Returns the value of attribute chef_server_port.



59
60
61
# File 'lib/akeyless/models/target_type_details_input.rb', line 59

def chef_server_port
  @chef_server_port
end

#chef_server_urlObject

Returns the value of attribute chef_server_url.



61
62
63
# File 'lib/akeyless/models/target_type_details_input.rb', line 61

def chef_server_url
  @chef_server_url
end

#chef_server_usernameObject

Returns the value of attribute chef_server_username.



63
64
65
# File 'lib/akeyless/models/target_type_details_input.rb', line 63

def chef_server_username
  @chef_server_username
end

#chef_skip_sslObject

Returns the value of attribute chef_skip_ssl.



65
66
67
# File 'lib/akeyless/models/target_type_details_input.rb', line 65

def chef_skip_ssl
  @chef_skip_ssl
end

#client_idObject

Returns the value of attribute client_id.



67
68
69
# File 'lib/akeyless/models/target_type_details_input.rb', line 67

def client_id
  @client_id
end

#client_secretObject

params needed for password auth



70
71
72
# File 'lib/akeyless/models/target_type_details_input.rb', line 70

def client_secret
  @client_secret
end

#db_host_nameObject

Returns the value of attribute db_host_name.



72
73
74
# File 'lib/akeyless/models/target_type_details_input.rb', line 72

def db_host_name
  @db_host_name
end

#db_nameObject

Returns the value of attribute db_name.



74
75
76
# File 'lib/akeyless/models/target_type_details_input.rb', line 74

def db_name
  @db_name
end

#db_portObject

Returns the value of attribute db_port.



76
77
78
# File 'lib/akeyless/models/target_type_details_input.rb', line 76

def db_port
  @db_port
end

#db_private_keyObject

(Optional) Private Key in PEM format



79
80
81
# File 'lib/akeyless/models/target_type_details_input.rb', line 79

def db_private_key
  @db_private_key
end

#db_private_key_passphraseObject

Returns the value of attribute db_private_key_passphrase.



81
82
83
# File 'lib/akeyless/models/target_type_details_input.rb', line 81

def db_private_key_passphrase
  @db_private_key_passphrase
end

#db_pwdObject

Returns the value of attribute db_pwd.



83
84
85
# File 'lib/akeyless/models/target_type_details_input.rb', line 83

def db_pwd
  @db_pwd
end

#db_server_certificatesObject

(Optional) DBServerCertificates defines the set of root certificate authorities that clients use when verifying server certificates. If DBServerCertificates is empty, TLS uses the host's root CA set.



86
87
88
# File 'lib/akeyless/models/target_type_details_input.rb', line 86

def db_server_certificates
  @db_server_certificates
end

#db_server_nameObject

(Optional) ServerName is used to verify the hostname on the returned certificates unless InsecureSkipVerify is given. It is also included in the client's handshake to support virtual hosting unless it is an IP address.



89
90
91
# File 'lib/akeyless/models/target_type_details_input.rb', line 89

def db_server_name
  @db_server_name
end

#db_user_nameObject

Returns the value of attribute db_user_name.



91
92
93
# File 'lib/akeyless/models/target_type_details_input.rb', line 91

def db_user_name
  @db_user_name
end

#eks_access_key_idObject

Returns the value of attribute eks_access_key_id.



93
94
95
# File 'lib/akeyless/models/target_type_details_input.rb', line 93

def eks_access_key_id
  @eks_access_key_id
end

#eks_cluster_ca_certificateObject

Returns the value of attribute eks_cluster_ca_certificate.



95
96
97
# File 'lib/akeyless/models/target_type_details_input.rb', line 95

def eks_cluster_ca_certificate
  @eks_cluster_ca_certificate
end

#eks_cluster_endpointObject

Returns the value of attribute eks_cluster_endpoint.



97
98
99
# File 'lib/akeyless/models/target_type_details_input.rb', line 97

def eks_cluster_endpoint
  @eks_cluster_endpoint
end

#eks_cluster_nameObject

Returns the value of attribute eks_cluster_name.



99
100
101
# File 'lib/akeyless/models/target_type_details_input.rb', line 99

def eks_cluster_name
  @eks_cluster_name
end

#eks_regionObject

Returns the value of attribute eks_region.



101
102
103
# File 'lib/akeyless/models/target_type_details_input.rb', line 101

def eks_region
  @eks_region
end

#eks_secret_access_keyObject

Returns the value of attribute eks_secret_access_key.



103
104
105
# File 'lib/akeyless/models/target_type_details_input.rb', line 103

def eks_secret_access_key
  @eks_secret_access_key
end

#gcp_service_account_emailObject

deprecated



106
107
108
# File 'lib/akeyless/models/target_type_details_input.rb', line 106

def 
  
end

#gcp_service_account_keyObject

Returns the value of attribute gcp_service_account_key.



108
109
110
# File 'lib/akeyless/models/target_type_details_input.rb', line 108

def 
  
end

#github_app_idObject

Returns the value of attribute github_app_id.



110
111
112
# File 'lib/akeyless/models/target_type_details_input.rb', line 110

def github_app_id
  @github_app_id
end

#github_app_private_keyObject

Returns the value of attribute github_app_private_key.



112
113
114
# File 'lib/akeyless/models/target_type_details_input.rb', line 112

def github_app_private_key
  @github_app_private_key
end

#github_base_urlObject

Returns the value of attribute github_base_url.



114
115
116
# File 'lib/akeyless/models/target_type_details_input.rb', line 114

def github_base_url
  @github_base_url
end

#gke_cluster_ca_certificateObject

Returns the value of attribute gke_cluster_ca_certificate.



116
117
118
# File 'lib/akeyless/models/target_type_details_input.rb', line 116

def gke_cluster_ca_certificate
  @gke_cluster_ca_certificate
end

#gke_cluster_endpointObject

Returns the value of attribute gke_cluster_endpoint.



118
119
120
# File 'lib/akeyless/models/target_type_details_input.rb', line 118

def gke_cluster_endpoint
  @gke_cluster_endpoint
end

#gke_cluster_nameObject

Returns the value of attribute gke_cluster_name.



120
121
122
# File 'lib/akeyless/models/target_type_details_input.rb', line 120

def gke_cluster_name
  @gke_cluster_name
end

#gke_service_account_keyObject

Returns the value of attribute gke_service_account_key.



122
123
124
# File 'lib/akeyless/models/target_type_details_input.rb', line 122

def 
  
end

#gke_service_account_nameObject

Returns the value of attribute gke_service_account_name.



124
125
126
# File 'lib/akeyless/models/target_type_details_input.rb', line 124

def 
  
end

#hostObject

Returns the value of attribute host.



126
127
128
# File 'lib/akeyless/models/target_type_details_input.rb', line 126

def host
  @host
end

#implementation_typeObject

Returns the value of attribute implementation_type.



128
129
130
# File 'lib/akeyless/models/target_type_details_input.rb', line 128

def implementation_type
  @implementation_type
end

#k8s_bearer_tokenObject

Returns the value of attribute k8s_bearer_token.



130
131
132
# File 'lib/akeyless/models/target_type_details_input.rb', line 130

def k8s_bearer_token
  @k8s_bearer_token
end

#k8s_cluster_ca_certificateObject

Returns the value of attribute k8s_cluster_ca_certificate.



132
133
134
# File 'lib/akeyless/models/target_type_details_input.rb', line 132

def k8s_cluster_ca_certificate
  @k8s_cluster_ca_certificate
end

#k8s_cluster_endpointObject

Returns the value of attribute k8s_cluster_endpoint.



134
135
136
# File 'lib/akeyless/models/target_type_details_input.rb', line 134

def k8s_cluster_endpoint
  @k8s_cluster_endpoint
end

#ldap_audienceObject

Returns the value of attribute ldap_audience.



136
137
138
# File 'lib/akeyless/models/target_type_details_input.rb', line 136

def ldap_audience
  @ldap_audience
end

#ldap_bind_dnObject

Returns the value of attribute ldap_bind_dn.



138
139
140
# File 'lib/akeyless/models/target_type_details_input.rb', line 138

def ldap_bind_dn
  @ldap_bind_dn
end

#ldap_bind_passwordObject

Returns the value of attribute ldap_bind_password.



140
141
142
# File 'lib/akeyless/models/target_type_details_input.rb', line 140

def ldap_bind_password
  @ldap_bind_password
end

#ldap_certificateObject

Returns the value of attribute ldap_certificate.



142
143
144
# File 'lib/akeyless/models/target_type_details_input.rb', line 142

def ldap_certificate
  @ldap_certificate
end

#ldap_token_expirationObject

Returns the value of attribute ldap_token_expiration.



144
145
146
# File 'lib/akeyless/models/target_type_details_input.rb', line 144

def ldap_token_expiration
  @ldap_token_expiration
end

#ldap_urlObject

Returns the value of attribute ldap_url.



146
147
148
# File 'lib/akeyless/models/target_type_details_input.rb', line 146

def ldap_url
  @ldap_url
end

#mongodb_atlas_api_private_keyObject

Returns the value of attribute mongodb_atlas_api_private_key.



148
149
150
# File 'lib/akeyless/models/target_type_details_input.rb', line 148

def mongodb_atlas_api_private_key
  @mongodb_atlas_api_private_key
end

#mongodb_atlas_api_public_keyObject

Returns the value of attribute mongodb_atlas_api_public_key.



150
151
152
# File 'lib/akeyless/models/target_type_details_input.rb', line 150

def mongodb_atlas_api_public_key
  @mongodb_atlas_api_public_key
end

#mongodb_atlas_project_idObject

mongodb atlas fields



153
154
155
# File 'lib/akeyless/models/target_type_details_input.rb', line 153

def mongodb_atlas_project_id
  @mongodb_atlas_project_id
end

#mongodb_db_nameObject

common fields



156
157
158
# File 'lib/akeyless/models/target_type_details_input.rb', line 156

def mongodb_db_name
  @mongodb_db_name
end

#mongodb_default_auth_dbObject

Returns the value of attribute mongodb_default_auth_db.



158
159
160
# File 'lib/akeyless/models/target_type_details_input.rb', line 158

def mongodb_default_auth_db
  @mongodb_default_auth_db
end

#mongodb_host_portObject

Returns the value of attribute mongodb_host_port.



160
161
162
# File 'lib/akeyless/models/target_type_details_input.rb', line 160

def mongodb_host_port
  @mongodb_host_port
end

#mongodb_is_atlasObject

Returns the value of attribute mongodb_is_atlas.



162
163
164
# File 'lib/akeyless/models/target_type_details_input.rb', line 162

def mongodb_is_atlas
  @mongodb_is_atlas
end

#mongodb_passwordObject

Returns the value of attribute mongodb_password.



164
165
166
# File 'lib/akeyless/models/target_type_details_input.rb', line 164

def mongodb_password
  @mongodb_password
end

#mongodb_uri_connectionObject

mongodb fields



167
168
169
# File 'lib/akeyless/models/target_type_details_input.rb', line 167

def mongodb_uri_connection
  @mongodb_uri_connection
end

#mongodb_uri_optionsObject

Returns the value of attribute mongodb_uri_options.



169
170
171
# File 'lib/akeyless/models/target_type_details_input.rb', line 169

def mongodb_uri_options
  @mongodb_uri_options
end

#mongodb_usernameObject

Returns the value of attribute mongodb_username.



171
172
173
# File 'lib/akeyless/models/target_type_details_input.rb', line 171

def mongodb_username
  @mongodb_username
end

#passwordObject

Returns the value of attribute password.



173
174
175
# File 'lib/akeyless/models/target_type_details_input.rb', line 173

def password
  @password
end

#payloadObject

Returns the value of attribute payload.



175
176
177
# File 'lib/akeyless/models/target_type_details_input.rb', line 175

def payload
  @payload
end

#portObject

Returns the value of attribute port.



177
178
179
# File 'lib/akeyless/models/target_type_details_input.rb', line 177

def port
  @port
end

#private_keyObject

Returns the value of attribute private_key.



179
180
181
# File 'lib/akeyless/models/target_type_details_input.rb', line 179

def private_key
  @private_key
end

#private_key_passwordObject

Returns the value of attribute private_key_password.



181
182
183
# File 'lib/akeyless/models/target_type_details_input.rb', line 181

def private_key_password
  @private_key_password
end

#rabbitmq_server_passwordObject

Returns the value of attribute rabbitmq_server_password.



183
184
185
# File 'lib/akeyless/models/target_type_details_input.rb', line 183

def rabbitmq_server_password
  @rabbitmq_server_password
end

#rabbitmq_server_uriObject

Returns the value of attribute rabbitmq_server_uri.



185
186
187
# File 'lib/akeyless/models/target_type_details_input.rb', line 185

def rabbitmq_server_uri
  @rabbitmq_server_uri
end

#rabbitmq_server_userObject

Returns the value of attribute rabbitmq_server_user.



187
188
189
# File 'lib/akeyless/models/target_type_details_input.rb', line 187

def rabbitmq_server_user
  @rabbitmq_server_user
end

#security_tokenObject

Returns the value of attribute security_token.



189
190
191
# File 'lib/akeyless/models/target_type_details_input.rb', line 189

def security_token
  @security_token
end

#sf_accountObject

Returns the value of attribute sf_account.



191
192
193
# File 'lib/akeyless/models/target_type_details_input.rb', line 191

def 
  
end

#ssl_connection_certificateObject

(Optional) SSLConnectionCertificate defines the certificate for SSL connection. Must be base64 certificate loaded by UI using file loader field



194
195
196
# File 'lib/akeyless/models/target_type_details_input.rb', line 194

def ssl_connection_certificate
  @ssl_connection_certificate
end

#ssl_connection_modeObject

(Optional) SSLConnectionMode defines if SSL mode will be used to connect to DB



197
198
199
# File 'lib/akeyless/models/target_type_details_input.rb', line 197

def ssl_connection_mode
  @ssl_connection_mode
end

#tenant_urlObject

Returns the value of attribute tenant_url.



199
200
201
# File 'lib/akeyless/models/target_type_details_input.rb', line 199

def tenant_url
  @tenant_url
end

#urlObject

Returns the value of attribute url.



201
202
203
# File 'lib/akeyless/models/target_type_details_input.rb', line 201

def url
  @url
end

#use_gw_cloud_identityObject

Returns the value of attribute use_gw_cloud_identity.



203
204
205
# File 'lib/akeyless/models/target_type_details_input.rb', line 203

def use_gw_cloud_identity
  @use_gw_cloud_identity
end

#user_nameObject

Returns the value of attribute user_name.



205
206
207
# File 'lib/akeyless/models/target_type_details_input.rb', line 205

def user_name
  @user_name
end

#usernameObject

Returns the value of attribute username.



207
208
209
# File 'lib/akeyless/models/target_type_details_input.rb', line 207

def username
  @username
end

#venafi_api_keyObject

Returns the value of attribute venafi_api_key.



209
210
211
# File 'lib/akeyless/models/target_type_details_input.rb', line 209

def venafi_api_key
  @venafi_api_key
end

#venafi_base_urlObject

Returns the value of attribute venafi_base_url.



211
212
213
# File 'lib/akeyless/models/target_type_details_input.rb', line 211

def venafi_base_url
  @venafi_base_url
end

#venafi_tpp_passwordObject

Returns the value of attribute venafi_tpp_password.



213
214
215
# File 'lib/akeyless/models/target_type_details_input.rb', line 213

def venafi_tpp_password
  @venafi_tpp_password
end

#venafi_tpp_usernameObject

Returns the value of attribute venafi_tpp_username.



215
216
217
# File 'lib/akeyless/models/target_type_details_input.rb', line 215

def venafi_tpp_username
  @venafi_tpp_username
end

#venafi_use_tppObject

Returns the value of attribute venafi_use_tpp.



217
218
219
# File 'lib/akeyless/models/target_type_details_input.rb', line 217

def venafi_use_tpp
  @venafi_use_tpp
end

#venafi_zoneObject

Returns the value of attribute venafi_zone.



219
220
221
# File 'lib/akeyless/models/target_type_details_input.rb', line 219

def venafi_zone
  @venafi_zone
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



323
324
325
# File 'lib/akeyless/models/target_type_details_input.rb', line 323

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/akeyless/models/target_type_details_input.rb', line 222

def self.attribute_map
  {
    :'app_private_key' => :'app_private_key',
    :'artifactory_admin_apikey' => :'artifactory_admin_apikey',
    :'artifactory_admin_username' => :'artifactory_admin_username',
    :'artifactory_base_url' => :'artifactory_base_url',
    :'auth_flow' => :'auth_flow',
    :'aws_access_key_id' => :'aws_access_key_id',
    :'aws_region' => :'aws_region',
    :'aws_secret_access_key' => :'aws_secret_access_key',
    :'aws_session_token' => :'aws_session_token',
    :'azure_client_id' => :'azure_client_id',
    :'azure_client_secret' => :'azure_client_secret',
    :'azure_resource_group_name' => :'azure_resource_group_name',
    :'azure_resource_name' => :'azure_resource_name',
    :'azure_subscription_id' => :'azure_subscription_id',
    :'azure_tenant_id' => :'azure_tenant_id',
    :'ca_cert_data' => :'ca_cert_data',
    :'ca_cert_name' => :'ca_cert_name',
    :'chef_server_host_name' => :'chef_server_host_name',
    :'chef_server_key' => :'chef_server_key',
    :'chef_server_port' => :'chef_server_port',
    :'chef_server_url' => :'chef_server_url',
    :'chef_server_username' => :'chef_server_username',
    :'chef_skip_ssl' => :'chef_skip_ssl',
    :'client_id' => :'client_id',
    :'client_secret' => :'client_secret',
    :'db_host_name' => :'db_host_name',
    :'db_name' => :'db_name',
    :'db_port' => :'db_port',
    :'db_private_key' => :'db_private_key',
    :'db_private_key_passphrase' => :'db_private_key_passphrase',
    :'db_pwd' => :'db_pwd',
    :'db_server_certificates' => :'db_server_certificates',
    :'db_server_name' => :'db_server_name',
    :'db_user_name' => :'db_user_name',
    :'eks_access_key_id' => :'eks_access_key_id',
    :'eks_cluster_ca_certificate' => :'eks_cluster_ca_certificate',
    :'eks_cluster_endpoint' => :'eks_cluster_endpoint',
    :'eks_cluster_name' => :'eks_cluster_name',
    :'eks_region' => :'eks_region',
    :'eks_secret_access_key' => :'eks_secret_access_key',
    :'gcp_service_account_email' => :'gcp_service_account_email',
    :'gcp_service_account_key' => :'gcp_service_account_key',
    :'github_app_id' => :'github_app_id',
    :'github_app_private_key' => :'github_app_private_key',
    :'github_base_url' => :'github_base_url',
    :'gke_cluster_ca_certificate' => :'gke_cluster_ca_certificate',
    :'gke_cluster_endpoint' => :'gke_cluster_endpoint',
    :'gke_cluster_name' => :'gke_cluster_name',
    :'gke_service_account_key' => :'gke_service_account_key',
    :'gke_service_account_name' => :'gke_service_account_name',
    :'host' => :'host',
    :'implementation_type' => :'implementation_type',
    :'k8s_bearer_token' => :'k8s_bearer_token',
    :'k8s_cluster_ca_certificate' => :'k8s_cluster_ca_certificate',
    :'k8s_cluster_endpoint' => :'k8s_cluster_endpoint',
    :'ldap_audience' => :'ldap_audience',
    :'ldap_bind_dn' => :'ldap_bind_dn',
    :'ldap_bind_password' => :'ldap_bind_password',
    :'ldap_certificate' => :'ldap_certificate',
    :'ldap_token_expiration' => :'ldap_token_expiration',
    :'ldap_url' => :'ldap_url',
    :'mongodb_atlas_api_private_key' => :'mongodb_atlas_api_private_key',
    :'mongodb_atlas_api_public_key' => :'mongodb_atlas_api_public_key',
    :'mongodb_atlas_project_id' => :'mongodb_atlas_project_id',
    :'mongodb_db_name' => :'mongodb_db_name',
    :'mongodb_default_auth_db' => :'mongodb_default_auth_db',
    :'mongodb_host_port' => :'mongodb_host_port',
    :'mongodb_is_atlas' => :'mongodb_is_atlas',
    :'mongodb_password' => :'mongodb_password',
    :'mongodb_uri_connection' => :'mongodb_uri_connection',
    :'mongodb_uri_options' => :'mongodb_uri_options',
    :'mongodb_username' => :'mongodb_username',
    :'password' => :'password',
    :'payload' => :'payload',
    :'port' => :'port',
    :'private_key' => :'private_key',
    :'private_key_password' => :'private_key_password',
    :'rabbitmq_server_password' => :'rabbitmq_server_password',
    :'rabbitmq_server_uri' => :'rabbitmq_server_uri',
    :'rabbitmq_server_user' => :'rabbitmq_server_user',
    :'security_token' => :'security_token',
    :'sf_account' => :'sf_account',
    :'ssl_connection_certificate' => :'ssl_connection_certificate',
    :'ssl_connection_mode' => :'ssl_connection_mode',
    :'tenant_url' => :'tenant_url',
    :'url' => :'url',
    :'use_gw_cloud_identity' => :'use_gw_cloud_identity',
    :'user_name' => :'user_name',
    :'username' => :'username',
    :'venafi_api_key' => :'venafi_api_key',
    :'venafi_base_url' => :'venafi_base_url',
    :'venafi_tpp_password' => :'venafi_tpp_password',
    :'venafi_tpp_username' => :'venafi_tpp_username',
    :'venafi_use_tpp' => :'venafi_use_tpp',
    :'venafi_zone' => :'venafi_zone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



964
965
966
# File 'lib/akeyless/models/target_type_details_input.rb', line 964

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



429
430
431
432
# File 'lib/akeyless/models/target_type_details_input.rb', line 429

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
# File 'lib/akeyless/models/target_type_details_input.rb', line 328

def self.openapi_types
  {
    :'app_private_key' => :'Array<Integer>',
    :'artifactory_admin_apikey' => :'String',
    :'artifactory_admin_username' => :'String',
    :'artifactory_base_url' => :'String',
    :'auth_flow' => :'String',
    :'aws_access_key_id' => :'String',
    :'aws_region' => :'String',
    :'aws_secret_access_key' => :'String',
    :'aws_session_token' => :'String',
    :'azure_client_id' => :'String',
    :'azure_client_secret' => :'String',
    :'azure_resource_group_name' => :'String',
    :'azure_resource_name' => :'String',
    :'azure_subscription_id' => :'String',
    :'azure_tenant_id' => :'String',
    :'ca_cert_data' => :'Array<Integer>',
    :'ca_cert_name' => :'String',
    :'chef_server_host_name' => :'String',
    :'chef_server_key' => :'String',
    :'chef_server_port' => :'String',
    :'chef_server_url' => :'String',
    :'chef_server_username' => :'String',
    :'chef_skip_ssl' => :'Boolean',
    :'client_id' => :'String',
    :'client_secret' => :'String',
    :'db_host_name' => :'String',
    :'db_name' => :'String',
    :'db_port' => :'String',
    :'db_private_key' => :'String',
    :'db_private_key_passphrase' => :'String',
    :'db_pwd' => :'String',
    :'db_server_certificates' => :'String',
    :'db_server_name' => :'String',
    :'db_user_name' => :'String',
    :'eks_access_key_id' => :'String',
    :'eks_cluster_ca_certificate' => :'String',
    :'eks_cluster_endpoint' => :'String',
    :'eks_cluster_name' => :'String',
    :'eks_region' => :'String',
    :'eks_secret_access_key' => :'String',
    :'gcp_service_account_email' => :'String',
    :'gcp_service_account_key' => :'String',
    :'github_app_id' => :'Integer',
    :'github_app_private_key' => :'String',
    :'github_base_url' => :'String',
    :'gke_cluster_ca_certificate' => :'String',
    :'gke_cluster_endpoint' => :'String',
    :'gke_cluster_name' => :'String',
    :'gke_service_account_key' => :'String',
    :'gke_service_account_name' => :'String',
    :'host' => :'String',
    :'implementation_type' => :'String',
    :'k8s_bearer_token' => :'String',
    :'k8s_cluster_ca_certificate' => :'String',
    :'k8s_cluster_endpoint' => :'String',
    :'ldap_audience' => :'String',
    :'ldap_bind_dn' => :'String',
    :'ldap_bind_password' => :'String',
    :'ldap_certificate' => :'String',
    :'ldap_token_expiration' => :'String',
    :'ldap_url' => :'String',
    :'mongodb_atlas_api_private_key' => :'String',
    :'mongodb_atlas_api_public_key' => :'String',
    :'mongodb_atlas_project_id' => :'String',
    :'mongodb_db_name' => :'String',
    :'mongodb_default_auth_db' => :'String',
    :'mongodb_host_port' => :'String',
    :'mongodb_is_atlas' => :'Boolean',
    :'mongodb_password' => :'String',
    :'mongodb_uri_connection' => :'String',
    :'mongodb_uri_options' => :'String',
    :'mongodb_username' => :'String',
    :'password' => :'String',
    :'payload' => :'String',
    :'port' => :'String',
    :'private_key' => :'String',
    :'private_key_password' => :'String',
    :'rabbitmq_server_password' => :'String',
    :'rabbitmq_server_uri' => :'String',
    :'rabbitmq_server_user' => :'String',
    :'security_token' => :'String',
    :'sf_account' => :'String',
    :'ssl_connection_certificate' => :'String',
    :'ssl_connection_mode' => :'Boolean',
    :'tenant_url' => :'String',
    :'url' => :'String',
    :'use_gw_cloud_identity' => :'Boolean',
    :'user_name' => :'String',
    :'username' => :'String',
    :'venafi_api_key' => :'String',
    :'venafi_base_url' => :'String',
    :'venafi_tpp_password' => :'String',
    :'venafi_tpp_username' => :'String',
    :'venafi_use_tpp' => :'Boolean',
    :'venafi_zone' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
# File 'lib/akeyless/models/target_type_details_input.rb', line 849

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      app_private_key == o.app_private_key &&
      artifactory_admin_apikey == o.artifactory_admin_apikey &&
      artifactory_admin_username == o.artifactory_admin_username &&
      artifactory_base_url == o.artifactory_base_url &&
      auth_flow == o.auth_flow &&
      aws_access_key_id == o.aws_access_key_id &&
      aws_region == o.aws_region &&
      aws_secret_access_key == o.aws_secret_access_key &&
      aws_session_token == o.aws_session_token &&
      azure_client_id == o.azure_client_id &&
      azure_client_secret == o.azure_client_secret &&
      azure_resource_group_name == o.azure_resource_group_name &&
      azure_resource_name == o.azure_resource_name &&
      azure_subscription_id == o.azure_subscription_id &&
      azure_tenant_id == o.azure_tenant_id &&
      ca_cert_data == o.ca_cert_data &&
      ca_cert_name == o.ca_cert_name &&
      chef_server_host_name == o.chef_server_host_name &&
      chef_server_key == o.chef_server_key &&
      chef_server_port == o.chef_server_port &&
      chef_server_url == o.chef_server_url &&
      chef_server_username == o.chef_server_username &&
      chef_skip_ssl == o.chef_skip_ssl &&
      client_id == o.client_id &&
      client_secret == o.client_secret &&
      db_host_name == o.db_host_name &&
      db_name == o.db_name &&
      db_port == o.db_port &&
      db_private_key == o.db_private_key &&
      db_private_key_passphrase == o.db_private_key_passphrase &&
      db_pwd == o.db_pwd &&
      db_server_certificates == o.db_server_certificates &&
      db_server_name == o.db_server_name &&
      db_user_name == o.db_user_name &&
      eks_access_key_id == o.eks_access_key_id &&
      eks_cluster_ca_certificate == o.eks_cluster_ca_certificate &&
      eks_cluster_endpoint == o.eks_cluster_endpoint &&
      eks_cluster_name == o.eks_cluster_name &&
      eks_region == o.eks_region &&
      eks_secret_access_key == o.eks_secret_access_key &&
       == o. &&
       == o. &&
      github_app_id == o.github_app_id &&
      github_app_private_key == o.github_app_private_key &&
      github_base_url == o.github_base_url &&
      gke_cluster_ca_certificate == o.gke_cluster_ca_certificate &&
      gke_cluster_endpoint == o.gke_cluster_endpoint &&
      gke_cluster_name == o.gke_cluster_name &&
       == o. &&
       == o. &&
      host == o.host &&
      implementation_type == o.implementation_type &&
      k8s_bearer_token == o.k8s_bearer_token &&
      k8s_cluster_ca_certificate == o.k8s_cluster_ca_certificate &&
      k8s_cluster_endpoint == o.k8s_cluster_endpoint &&
      ldap_audience == o.ldap_audience &&
      ldap_bind_dn == o.ldap_bind_dn &&
      ldap_bind_password == o.ldap_bind_password &&
      ldap_certificate == o.ldap_certificate &&
      ldap_token_expiration == o.ldap_token_expiration &&
      ldap_url == o.ldap_url &&
      mongodb_atlas_api_private_key == o.mongodb_atlas_api_private_key &&
      mongodb_atlas_api_public_key == o.mongodb_atlas_api_public_key &&
      mongodb_atlas_project_id == o.mongodb_atlas_project_id &&
      mongodb_db_name == o.mongodb_db_name &&
      mongodb_default_auth_db == o.mongodb_default_auth_db &&
      mongodb_host_port == o.mongodb_host_port &&
      mongodb_is_atlas == o.mongodb_is_atlas &&
      mongodb_password == o.mongodb_password &&
      mongodb_uri_connection == o.mongodb_uri_connection &&
      mongodb_uri_options == o.mongodb_uri_options &&
      mongodb_username == o.mongodb_username &&
      password == o.password &&
      payload == o.payload &&
      port == o.port &&
      private_key == o.private_key &&
      private_key_password == o.private_key_password &&
      rabbitmq_server_password == o.rabbitmq_server_password &&
      rabbitmq_server_uri == o.rabbitmq_server_uri &&
      rabbitmq_server_user == o.rabbitmq_server_user &&
      security_token == o.security_token &&
       == o. &&
      ssl_connection_certificate == o.ssl_connection_certificate &&
      ssl_connection_mode == o.ssl_connection_mode &&
      tenant_url == o.tenant_url &&
      url == o.url &&
      use_gw_cloud_identity == o.use_gw_cloud_identity &&
      user_name == o.user_name &&
      username == o.username &&
      venafi_api_key == o.venafi_api_key &&
      venafi_base_url == o.venafi_base_url &&
      venafi_tpp_password == o.venafi_tpp_password &&
      venafi_tpp_username == o.venafi_tpp_username &&
      venafi_use_tpp == o.venafi_use_tpp &&
      venafi_zone == o.venafi_zone
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • type Data type

  • value Value to be deserialized

Returns:

  • Deserialized data



995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
# File 'lib/akeyless/models/target_type_details_input.rb', line 995

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • Any valid value

Returns:

  • Returns the value in the form of hash



1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/akeyless/models/target_type_details_input.rb', line 1066

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
# File 'lib/akeyless/models/target_type_details_input.rb', line 971

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


951
952
953
# File 'lib/akeyless/models/target_type_details_input.rb', line 951

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



957
958
959
# File 'lib/akeyless/models/target_type_details_input.rb', line 957

def hash
  [app_private_key, artifactory_admin_apikey, artifactory_admin_username, artifactory_base_url, auth_flow, aws_access_key_id, aws_region, aws_secret_access_key, aws_session_token, azure_client_id, azure_client_secret, azure_resource_group_name, azure_resource_name, azure_subscription_id, azure_tenant_id, ca_cert_data, ca_cert_name, chef_server_host_name, chef_server_key, chef_server_port, chef_server_url, chef_server_username, chef_skip_ssl, client_id, client_secret, db_host_name, db_name, db_port, db_private_key, db_private_key_passphrase, db_pwd, db_server_certificates, db_server_name, db_user_name, eks_access_key_id, eks_cluster_ca_certificate, eks_cluster_endpoint, eks_cluster_name, eks_region, eks_secret_access_key, , , github_app_id, github_app_private_key, github_base_url, gke_cluster_ca_certificate, gke_cluster_endpoint, gke_cluster_name, , , host, implementation_type, k8s_bearer_token, k8s_cluster_ca_certificate, k8s_cluster_endpoint, ldap_audience, ldap_bind_dn, ldap_bind_password, ldap_certificate, ldap_token_expiration, ldap_url, mongodb_atlas_api_private_key, mongodb_atlas_api_public_key, mongodb_atlas_project_id, mongodb_db_name, mongodb_default_auth_db, mongodb_host_port, mongodb_is_atlas, mongodb_password, mongodb_uri_connection, mongodb_uri_options, mongodb_username, password, payload, port, private_key, private_key_password, rabbitmq_server_password, rabbitmq_server_uri, rabbitmq_server_user, security_token, , ssl_connection_certificate, ssl_connection_mode, tenant_url, url, use_gw_cloud_identity, user_name, username, venafi_api_key, venafi_base_url, venafi_tpp_password, venafi_tpp_username, venafi_use_tpp, venafi_zone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



836
837
838
839
# File 'lib/akeyless/models/target_type_details_input.rb', line 836

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • Returns the object in the form of hash



1042
1043
1044
# File 'lib/akeyless/models/target_type_details_input.rb', line 1042

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
# File 'lib/akeyless/models/target_type_details_input.rb', line 1048

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



1036
1037
1038
# File 'lib/akeyless/models/target_type_details_input.rb', line 1036

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



843
844
845
# File 'lib/akeyless/models/target_type_details_input.rb', line 843

def valid?
  true
end