Class: Akeyless::TargetTypeDetailsInput

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/target_type_details_input.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TargetTypeDetailsInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
# File 'lib/akeyless/models/target_type_details_input.rb', line 400

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::TargetTypeDetailsInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::TargetTypeDetailsInput`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'artifactory_admin_apikey')
    self.artifactory_admin_apikey = attributes[:'artifactory_admin_apikey']
  end

  if attributes.key?(:'artifactory_admin_username')
    self.artifactory_admin_username = attributes[:'artifactory_admin_username']
  end

  if attributes.key?(:'artifactory_base_url')
    self.artifactory_base_url = attributes[:'artifactory_base_url']
  end

  if attributes.key?(:'aws_access_key_id')
    self.aws_access_key_id = attributes[:'aws_access_key_id']
  end

  if attributes.key?(:'aws_region')
    self.aws_region = attributes[:'aws_region']
  end

  if attributes.key?(:'aws_secret_access_key')
    self.aws_secret_access_key = attributes[:'aws_secret_access_key']
  end

  if attributes.key?(:'aws_session_token')
    self.aws_session_token = attributes[:'aws_session_token']
  end

  if attributes.key?(:'azure_client_id')
    self.azure_client_id = attributes[:'azure_client_id']
  end

  if attributes.key?(:'azure_client_secret')
    self.azure_client_secret = attributes[:'azure_client_secret']
  end

  if attributes.key?(:'azure_tenant_id')
    self.azure_tenant_id = attributes[:'azure_tenant_id']
  end

  if attributes.key?(:'ca_cert_data')
    if (value = attributes[:'ca_cert_data']).is_a?(Array)
      self.ca_cert_data = value
    end
  end

  if attributes.key?(:'ca_cert_name')
    self.ca_cert_name = attributes[:'ca_cert_name']
  end

  if attributes.key?(:'chef_server_host_name')
    self.chef_server_host_name = attributes[:'chef_server_host_name']
  end

  if attributes.key?(:'chef_server_key')
    self.chef_server_key = attributes[:'chef_server_key']
  end

  if attributes.key?(:'chef_server_port')
    self.chef_server_port = attributes[:'chef_server_port']
  end

  if attributes.key?(:'chef_server_url')
    self.chef_server_url = attributes[:'chef_server_url']
  end

  if attributes.key?(:'chef_server_username')
    self.chef_server_username = attributes[:'chef_server_username']
  end

  if attributes.key?(:'chef_skip_ssl')
    self.chef_skip_ssl = attributes[:'chef_skip_ssl']
  end

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'client_secret')
    self.client_secret = attributes[:'client_secret']
  end

  if attributes.key?(:'db_host_name')
    self.db_host_name = attributes[:'db_host_name']
  end

  if attributes.key?(:'db_name')
    self.db_name = attributes[:'db_name']
  end

  if attributes.key?(:'db_port')
    self.db_port = attributes[:'db_port']
  end

  if attributes.key?(:'db_pwd')
    self.db_pwd = attributes[:'db_pwd']
  end

  if attributes.key?(:'db_server_certificates')
    self.db_server_certificates = attributes[:'db_server_certificates']
  end

  if attributes.key?(:'db_server_name')
    self.db_server_name = attributes[:'db_server_name']
  end

  if attributes.key?(:'db_user_name')
    self.db_user_name = attributes[:'db_user_name']
  end

  if attributes.key?(:'eks_access_key_id')
    self.eks_access_key_id = attributes[:'eks_access_key_id']
  end

  if attributes.key?(:'eks_cluster_ca_certificate')
    self.eks_cluster_ca_certificate = attributes[:'eks_cluster_ca_certificate']
  end

  if attributes.key?(:'eks_cluster_endpoint')
    self.eks_cluster_endpoint = attributes[:'eks_cluster_endpoint']
  end

  if attributes.key?(:'eks_cluster_name')
    self.eks_cluster_name = attributes[:'eks_cluster_name']
  end

  if attributes.key?(:'eks_region')
    self.eks_region = attributes[:'eks_region']
  end

  if attributes.key?(:'eks_secret_access_key')
    self.eks_secret_access_key = attributes[:'eks_secret_access_key']
  end

  if attributes.key?(:'gcp_service_account_email')
    self. = attributes[:'gcp_service_account_email']
  end

  if attributes.key?(:'gcp_service_account_key')
    self. = attributes[:'gcp_service_account_key']
  end

  if attributes.key?(:'github_app_id')
    self.github_app_id = attributes[:'github_app_id']
  end

  if attributes.key?(:'github_app_private_key')
    self.github_app_private_key = attributes[:'github_app_private_key']
  end

  if attributes.key?(:'github_base_url')
    self.github_base_url = attributes[:'github_base_url']
  end

  if attributes.key?(:'gke_cluster_ca_certificate')
    self.gke_cluster_ca_certificate = attributes[:'gke_cluster_ca_certificate']
  end

  if attributes.key?(:'gke_cluster_endpoint')
    self.gke_cluster_endpoint = attributes[:'gke_cluster_endpoint']
  end

  if attributes.key?(:'gke_cluster_name')
    self.gke_cluster_name = attributes[:'gke_cluster_name']
  end

  if attributes.key?(:'gke_service_account_key')
    self. = attributes[:'gke_service_account_key']
  end

  if attributes.key?(:'gke_service_account_name')
    self. = attributes[:'gke_service_account_name']
  end

  if attributes.key?(:'host')
    self.host = attributes[:'host']
  end

  if attributes.key?(:'k8s_bearer_token')
    self.k8s_bearer_token = attributes[:'k8s_bearer_token']
  end

  if attributes.key?(:'k8s_cluster_ca_certificate')
    self.k8s_cluster_ca_certificate = attributes[:'k8s_cluster_ca_certificate']
  end

  if attributes.key?(:'k8s_cluster_endpoint')
    self.k8s_cluster_endpoint = attributes[:'k8s_cluster_endpoint']
  end

  if attributes.key?(:'ldap_audience')
    self.ldap_audience = attributes[:'ldap_audience']
  end

  if attributes.key?(:'ldap_bind_dn')
    self.ldap_bind_dn = attributes[:'ldap_bind_dn']
  end

  if attributes.key?(:'ldap_bind_password')
    self.ldap_bind_password = attributes[:'ldap_bind_password']
  end

  if attributes.key?(:'ldap_certificate')
    self.ldap_certificate = attributes[:'ldap_certificate']
  end

  if attributes.key?(:'ldap_token_expiration')
    self.ldap_token_expiration = attributes[:'ldap_token_expiration']
  end

  if attributes.key?(:'ldap_url')
    self.ldap_url = attributes[:'ldap_url']
  end

  if attributes.key?(:'mongodb_atlas_api_private_key')
    self.mongodb_atlas_api_private_key = attributes[:'mongodb_atlas_api_private_key']
  end

  if attributes.key?(:'mongodb_atlas_api_public_key')
    self.mongodb_atlas_api_public_key = attributes[:'mongodb_atlas_api_public_key']
  end

  if attributes.key?(:'mongodb_atlas_project_id')
    self.mongodb_atlas_project_id = attributes[:'mongodb_atlas_project_id']
  end

  if attributes.key?(:'mongodb_db_name')
    self.mongodb_db_name = attributes[:'mongodb_db_name']
  end

  if attributes.key?(:'mongodb_default_auth_db')
    self.mongodb_default_auth_db = attributes[:'mongodb_default_auth_db']
  end

  if attributes.key?(:'mongodb_host_port')
    self.mongodb_host_port = attributes[:'mongodb_host_port']
  end

  if attributes.key?(:'mongodb_is_atlas')
    self.mongodb_is_atlas = attributes[:'mongodb_is_atlas']
  end

  if attributes.key?(:'mongodb_password')
    self.mongodb_password = attributes[:'mongodb_password']
  end

  if attributes.key?(:'mongodb_uri_connection')
    self.mongodb_uri_connection = attributes[:'mongodb_uri_connection']
  end

  if attributes.key?(:'mongodb_uri_options')
    self.mongodb_uri_options = attributes[:'mongodb_uri_options']
  end

  if attributes.key?(:'mongodb_username')
    self.mongodb_username = attributes[:'mongodb_username']
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'payload')
    self.payload = attributes[:'payload']
  end

  if attributes.key?(:'port')
    self.port = attributes[:'port']
  end

  if attributes.key?(:'private_key')
    self.private_key = attributes[:'private_key']
  end

  if attributes.key?(:'private_key_password')
    self.private_key_password = attributes[:'private_key_password']
  end

  if attributes.key?(:'rabbitmq_server_password')
    self.rabbitmq_server_password = attributes[:'rabbitmq_server_password']
  end

  if attributes.key?(:'rabbitmq_server_uri')
    self.rabbitmq_server_uri = attributes[:'rabbitmq_server_uri']
  end

  if attributes.key?(:'rabbitmq_server_user')
    self.rabbitmq_server_user = attributes[:'rabbitmq_server_user']
  end

  if attributes.key?(:'security_token')
    self.security_token = attributes[:'security_token']
  end

  if attributes.key?(:'sf_account')
    self. = attributes[:'sf_account']
  end

  if attributes.key?(:'ssl_connection_certificate')
    self.ssl_connection_certificate = attributes[:'ssl_connection_certificate']
  end

  if attributes.key?(:'ssl_connection_mode')
    self.ssl_connection_mode = attributes[:'ssl_connection_mode']
  end

  if attributes.key?(:'tenant_url')
    self.tenant_url = attributes[:'tenant_url']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'use_gw_cloud_identity')
    self.use_gw_cloud_identity = attributes[:'use_gw_cloud_identity']
  end

  if attributes.key?(:'user_name')
    self.user_name = attributes[:'user_name']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'venafi_api_key')
    self.venafi_api_key = attributes[:'venafi_api_key']
  end

  if attributes.key?(:'venafi_base_url')
    self.venafi_base_url = attributes[:'venafi_base_url']
  end

  if attributes.key?(:'venafi_tpp_password')
    self.venafi_tpp_password = attributes[:'venafi_tpp_password']
  end

  if attributes.key?(:'venafi_tpp_username')
    self.venafi_tpp_username = attributes[:'venafi_tpp_username']
  end

  if attributes.key?(:'venafi_use_tpp')
    self.venafi_use_tpp = attributes[:'venafi_use_tpp']
  end

  if attributes.key?(:'venafi_zone')
    self.venafi_zone = attributes[:'venafi_zone']
  end
end

Instance Attribute Details

#artifactory_admin_apikey ⇒ Object

Returns the value of attribute artifactory_admin_apikey.



18
19
20
# File 'lib/akeyless/models/target_type_details_input.rb', line 18

def artifactory_admin_apikey
  @artifactory_admin_apikey
end

#artifactory_admin_username ⇒ Object

Returns the value of attribute artifactory_admin_username.



20
21
22
# File 'lib/akeyless/models/target_type_details_input.rb', line 20

def artifactory_admin_username
  @artifactory_admin_username
end

#artifactory_base_url ⇒ Object

Returns the value of attribute artifactory_base_url.



22
23
24
# File 'lib/akeyless/models/target_type_details_input.rb', line 22

def artifactory_base_url
  @artifactory_base_url
end

#aws_access_key_id ⇒ Object

Returns the value of attribute aws_access_key_id.



24
25
26
# File 'lib/akeyless/models/target_type_details_input.rb', line 24

def aws_access_key_id
  @aws_access_key_id
end

#aws_region ⇒ Object

Returns the value of attribute aws_region.



26
27
28
# File 'lib/akeyless/models/target_type_details_input.rb', line 26

def aws_region
  @aws_region
end

#aws_secret_access_key ⇒ Object

Returns the value of attribute aws_secret_access_key.



28
29
30
# File 'lib/akeyless/models/target_type_details_input.rb', line 28

def aws_secret_access_key
  @aws_secret_access_key
end

#aws_session_token ⇒ Object

Returns the value of attribute aws_session_token.



30
31
32
# File 'lib/akeyless/models/target_type_details_input.rb', line 30

def aws_session_token
  @aws_session_token
end

#azure_client_id ⇒ Object

Returns the value of attribute azure_client_id.



32
33
34
# File 'lib/akeyless/models/target_type_details_input.rb', line 32

def azure_client_id
  @azure_client_id
end

#azure_client_secret ⇒ Object

Returns the value of attribute azure_client_secret.



34
35
36
# File 'lib/akeyless/models/target_type_details_input.rb', line 34

def azure_client_secret
  @azure_client_secret
end

#azure_tenant_id ⇒ Object

Returns the value of attribute azure_tenant_id.



36
37
38
# File 'lib/akeyless/models/target_type_details_input.rb', line 36

def azure_tenant_id
  @azure_tenant_id
end

#ca_cert_data ⇒ Object

CACertData is the rsa 4096 certificate data in PEM format



39
40
41
# File 'lib/akeyless/models/target_type_details_input.rb', line 39

def ca_cert_data
  @ca_cert_data
end

#ca_cert_name ⇒ Object

CACertName is the name of the certificate in SalesForce tenant



42
43
44
# File 'lib/akeyless/models/target_type_details_input.rb', line 42

def ca_cert_name
  @ca_cert_name
end

#chef_server_host_name ⇒ Object

Returns the value of attribute chef_server_host_name.



44
45
46
# File 'lib/akeyless/models/target_type_details_input.rb', line 44

def chef_server_host_name
  @chef_server_host_name
end

#chef_server_key ⇒ Object

Returns the value of attribute chef_server_key.



46
47
48
# File 'lib/akeyless/models/target_type_details_input.rb', line 46

def chef_server_key
  @chef_server_key
end

#chef_server_port ⇒ Object

Returns the value of attribute chef_server_port.



48
49
50
# File 'lib/akeyless/models/target_type_details_input.rb', line 48

def chef_server_port
  @chef_server_port
end

#chef_server_url ⇒ Object

Returns the value of attribute chef_server_url.



50
51
52
# File 'lib/akeyless/models/target_type_details_input.rb', line 50

def chef_server_url
  @chef_server_url
end

#chef_server_username ⇒ Object

Returns the value of attribute chef_server_username.



52
53
54
# File 'lib/akeyless/models/target_type_details_input.rb', line 52

def chef_server_username
  @chef_server_username
end

#chef_skip_ssl ⇒ Object

Returns the value of attribute chef_skip_ssl.



54
55
56
# File 'lib/akeyless/models/target_type_details_input.rb', line 54

def chef_skip_ssl
  @chef_skip_ssl
end

#client_id ⇒ Object

Returns the value of attribute client_id.



56
57
58
# File 'lib/akeyless/models/target_type_details_input.rb', line 56

def client_id
  @client_id
end

#client_secret ⇒ Object

Returns the value of attribute client_secret.



58
59
60
# File 'lib/akeyless/models/target_type_details_input.rb', line 58

def client_secret
  @client_secret
end

#db_host_name ⇒ Object

Returns the value of attribute db_host_name.



60
61
62
# File 'lib/akeyless/models/target_type_details_input.rb', line 60

def db_host_name
  @db_host_name
end

#db_name ⇒ Object

Returns the value of attribute db_name.



62
63
64
# File 'lib/akeyless/models/target_type_details_input.rb', line 62

def db_name
  @db_name
end

#db_port ⇒ Object

Returns the value of attribute db_port.



64
65
66
# File 'lib/akeyless/models/target_type_details_input.rb', line 64

def db_port
  @db_port
end

#db_pwd ⇒ Object

Returns the value of attribute db_pwd.



66
67
68
# File 'lib/akeyless/models/target_type_details_input.rb', line 66

def db_pwd
  @db_pwd
end

#db_server_certificates ⇒ Object

(Optional) DBServerCertificates defines the set of root certificate authorities that clients use when verifying server certificates. If DBServerCertificates is empty, TLS uses the host's root CA set.



69
70
71
# File 'lib/akeyless/models/target_type_details_input.rb', line 69

def db_server_certificates
  @db_server_certificates
end

#db_server_name ⇒ Object

(Optional) ServerName is used to verify the hostname on the returned certificates unless InsecureSkipVerify is given. It is also included in the client's handshake to support virtual hosting unless it is an IP address.



72
73
74
# File 'lib/akeyless/models/target_type_details_input.rb', line 72

def db_server_name
  @db_server_name
end

#db_user_name ⇒ Object

Returns the value of attribute db_user_name.



74
75
76
# File 'lib/akeyless/models/target_type_details_input.rb', line 74

def db_user_name
  @db_user_name
end

#eks_access_key_id ⇒ Object

Returns the value of attribute eks_access_key_id.



76
77
78
# File 'lib/akeyless/models/target_type_details_input.rb', line 76

def eks_access_key_id
  @eks_access_key_id
end

#eks_cluster_ca_certificate ⇒ Object

Returns the value of attribute eks_cluster_ca_certificate.



78
79
80
# File 'lib/akeyless/models/target_type_details_input.rb', line 78

def eks_cluster_ca_certificate
  @eks_cluster_ca_certificate
end

#eks_cluster_endpoint ⇒ Object

Returns the value of attribute eks_cluster_endpoint.



80
81
82
# File 'lib/akeyless/models/target_type_details_input.rb', line 80

def eks_cluster_endpoint
  @eks_cluster_endpoint
end

#eks_cluster_name ⇒ Object

Returns the value of attribute eks_cluster_name.



82
83
84
# File 'lib/akeyless/models/target_type_details_input.rb', line 82

def eks_cluster_name
  @eks_cluster_name
end

#eks_region ⇒ Object

Returns the value of attribute eks_region.



84
85
86
# File 'lib/akeyless/models/target_type_details_input.rb', line 84

def eks_region
  @eks_region
end

#eks_secret_access_key ⇒ Object

Returns the value of attribute eks_secret_access_key.



86
87
88
# File 'lib/akeyless/models/target_type_details_input.rb', line 86

def eks_secret_access_key
  @eks_secret_access_key
end

#gcp_service_account_email ⇒ Object

Returns the value of attribute gcp_service_account_email.



88
89
90
# File 'lib/akeyless/models/target_type_details_input.rb', line 88

def 
  @gcp_service_account_email
end

#gcp_service_account_key ⇒ Object

Returns the value of attribute gcp_service_account_key.



90
91
92
# File 'lib/akeyless/models/target_type_details_input.rb', line 90

def 
  @gcp_service_account_key
end

#github_app_id ⇒ Object

Returns the value of attribute github_app_id.



92
93
94
# File 'lib/akeyless/models/target_type_details_input.rb', line 92

def github_app_id
  @github_app_id
end

#github_app_private_key ⇒ Object

Returns the value of attribute github_app_private_key.



94
95
96
# File 'lib/akeyless/models/target_type_details_input.rb', line 94

def github_app_private_key
  @github_app_private_key
end

#github_base_url ⇒ Object

Returns the value of attribute github_base_url.



96
97
98
# File 'lib/akeyless/models/target_type_details_input.rb', line 96

def github_base_url
  @github_base_url
end

#gke_cluster_ca_certificate ⇒ Object

Returns the value of attribute gke_cluster_ca_certificate.



98
99
100
# File 'lib/akeyless/models/target_type_details_input.rb', line 98

def gke_cluster_ca_certificate
  @gke_cluster_ca_certificate
end

#gke_cluster_endpoint ⇒ Object

Returns the value of attribute gke_cluster_endpoint.



100
101
102
# File 'lib/akeyless/models/target_type_details_input.rb', line 100

def gke_cluster_endpoint
  @gke_cluster_endpoint
end

#gke_cluster_name ⇒ Object

Returns the value of attribute gke_cluster_name.



102
103
104
# File 'lib/akeyless/models/target_type_details_input.rb', line 102

def gke_cluster_name
  @gke_cluster_name
end

#gke_service_account_key ⇒ Object

Returns the value of attribute gke_service_account_key.



104
105
106
# File 'lib/akeyless/models/target_type_details_input.rb', line 104

def 
  @gke_service_account_key
end

#gke_service_account_name ⇒ Object

Returns the value of attribute gke_service_account_name.



106
107
108
# File 'lib/akeyless/models/target_type_details_input.rb', line 106

def 
  @gke_service_account_name
end

#host ⇒ Object

Returns the value of attribute host.



108
109
110
# File 'lib/akeyless/models/target_type_details_input.rb', line 108

def host
  @host
end

#k8s_bearer_token ⇒ Object

Returns the value of attribute k8s_bearer_token.



110
111
112
# File 'lib/akeyless/models/target_type_details_input.rb', line 110

def k8s_bearer_token
  @k8s_bearer_token
end

#k8s_cluster_ca_certificate ⇒ Object

Returns the value of attribute k8s_cluster_ca_certificate.



112
113
114
# File 'lib/akeyless/models/target_type_details_input.rb', line 112

def k8s_cluster_ca_certificate
  @k8s_cluster_ca_certificate
end

#k8s_cluster_endpoint ⇒ Object

Returns the value of attribute k8s_cluster_endpoint.



114
115
116
# File 'lib/akeyless/models/target_type_details_input.rb', line 114

def k8s_cluster_endpoint
  @k8s_cluster_endpoint
end

#ldap_audience ⇒ Object

Returns the value of attribute ldap_audience.



116
117
118
# File 'lib/akeyless/models/target_type_details_input.rb', line 116

def ldap_audience
  @ldap_audience
end

#ldap_bind_dn ⇒ Object

Returns the value of attribute ldap_bind_dn.



118
119
120
# File 'lib/akeyless/models/target_type_details_input.rb', line 118

def ldap_bind_dn
  @ldap_bind_dn
end

#ldap_bind_password ⇒ Object

Returns the value of attribute ldap_bind_password.



120
121
122
# File 'lib/akeyless/models/target_type_details_input.rb', line 120

def ldap_bind_password
  @ldap_bind_password
end

#ldap_certificate ⇒ Object

Returns the value of attribute ldap_certificate.



122
123
124
# File 'lib/akeyless/models/target_type_details_input.rb', line 122

def ldap_certificate
  @ldap_certificate
end

#ldap_token_expiration ⇒ Object

Returns the value of attribute ldap_token_expiration.



124
125
126
# File 'lib/akeyless/models/target_type_details_input.rb', line 124

def ldap_token_expiration
  @ldap_token_expiration
end

#ldap_url ⇒ Object

Returns the value of attribute ldap_url.



126
127
128
# File 'lib/akeyless/models/target_type_details_input.rb', line 126

def ldap_url
  @ldap_url
end

#mongodb_atlas_api_private_key ⇒ Object

Returns the value of attribute mongodb_atlas_api_private_key.



128
129
130
# File 'lib/akeyless/models/target_type_details_input.rb', line 128

def mongodb_atlas_api_private_key
  @mongodb_atlas_api_private_key
end

#mongodb_atlas_api_public_key ⇒ Object

Returns the value of attribute mongodb_atlas_api_public_key.



130
131
132
# File 'lib/akeyless/models/target_type_details_input.rb', line 130

def mongodb_atlas_api_public_key
  @mongodb_atlas_api_public_key
end

#mongodb_atlas_project_id ⇒ Object

mongodb atlas fields



133
134
135
# File 'lib/akeyless/models/target_type_details_input.rb', line 133

def mongodb_atlas_project_id
  @mongodb_atlas_project_id
end

#mongodb_db_name ⇒ Object

common fields



136
137
138
# File 'lib/akeyless/models/target_type_details_input.rb', line 136

def mongodb_db_name
  @mongodb_db_name
end

#mongodb_default_auth_db ⇒ Object

Returns the value of attribute mongodb_default_auth_db.



138
139
140
# File 'lib/akeyless/models/target_type_details_input.rb', line 138

def mongodb_default_auth_db
  @mongodb_default_auth_db
end

#mongodb_host_port ⇒ Object

Returns the value of attribute mongodb_host_port.



140
141
142
# File 'lib/akeyless/models/target_type_details_input.rb', line 140

def mongodb_host_port
  @mongodb_host_port
end

#mongodb_is_atlas ⇒ Object

Returns the value of attribute mongodb_is_atlas.



142
143
144
# File 'lib/akeyless/models/target_type_details_input.rb', line 142

def mongodb_is_atlas
  @mongodb_is_atlas
end

#mongodb_password ⇒ Object

Returns the value of attribute mongodb_password.



144
145
146
# File 'lib/akeyless/models/target_type_details_input.rb', line 144

def mongodb_password
  @mongodb_password
end

#mongodb_uri_connection ⇒ Object

mongodb fields



147
148
149
# File 'lib/akeyless/models/target_type_details_input.rb', line 147

def mongodb_uri_connection
  @mongodb_uri_connection
end

#mongodb_uri_options ⇒ Object

Returns the value of attribute mongodb_uri_options.



149
150
151
# File 'lib/akeyless/models/target_type_details_input.rb', line 149

def mongodb_uri_options
  @mongodb_uri_options
end

#mongodb_username ⇒ Object

Returns the value of attribute mongodb_username.



151
152
153
# File 'lib/akeyless/models/target_type_details_input.rb', line 151

def mongodb_username
  @mongodb_username
end

#password ⇒ Object

Returns the value of attribute password.



153
154
155
# File 'lib/akeyless/models/target_type_details_input.rb', line 153

def password
  @password
end

#payload ⇒ Object

Returns the value of attribute payload.



155
156
157
# File 'lib/akeyless/models/target_type_details_input.rb', line 155

def payload
  @payload
end

#port ⇒ Object

Returns the value of attribute port.



157
158
159
# File 'lib/akeyless/models/target_type_details_input.rb', line 157

def port
  @port
end

#private_key ⇒ Object

Returns the value of attribute private_key.



159
160
161
# File 'lib/akeyless/models/target_type_details_input.rb', line 159

def private_key
  @private_key
end

#private_key_password ⇒ Object

Returns the value of attribute private_key_password.



161
162
163
# File 'lib/akeyless/models/target_type_details_input.rb', line 161

def private_key_password
  @private_key_password
end

#rabbitmq_server_password ⇒ Object

Returns the value of attribute rabbitmq_server_password.



163
164
165
# File 'lib/akeyless/models/target_type_details_input.rb', line 163

def rabbitmq_server_password
  @rabbitmq_server_password
end

#rabbitmq_server_uri ⇒ Object

Returns the value of attribute rabbitmq_server_uri.



165
166
167
# File 'lib/akeyless/models/target_type_details_input.rb', line 165

def rabbitmq_server_uri
  @rabbitmq_server_uri
end

#rabbitmq_server_user ⇒ Object

Returns the value of attribute rabbitmq_server_user.



167
168
169
# File 'lib/akeyless/models/target_type_details_input.rb', line 167

def rabbitmq_server_user
  @rabbitmq_server_user
end

#security_token ⇒ Object

Returns the value of attribute security_token.



169
170
171
# File 'lib/akeyless/models/target_type_details_input.rb', line 169

def security_token
  @security_token
end

#sf_account ⇒ Object

Returns the value of attribute sf_account.



171
172
173
# File 'lib/akeyless/models/target_type_details_input.rb', line 171

def 
  @sf_account
end

#ssl_connection_certificate ⇒ Object

(Optional) SSLConnectionCertificate defines the certificate for SSL connection. Must be base64 certificate loaded by UI using file loader field



174
175
176
# File 'lib/akeyless/models/target_type_details_input.rb', line 174

def ssl_connection_certificate
  @ssl_connection_certificate
end

#ssl_connection_mode ⇒ Object

(Optional) SSLConnectionMode defines if SSL mode will be used to connect to DB



177
178
179
# File 'lib/akeyless/models/target_type_details_input.rb', line 177

def ssl_connection_mode
  @ssl_connection_mode
end

#tenant_url ⇒ Object

Returns the value of attribute tenant_url.



179
180
181
# File 'lib/akeyless/models/target_type_details_input.rb', line 179

def tenant_url
  @tenant_url
end

#url ⇒ Object

Returns the value of attribute url.



181
182
183
# File 'lib/akeyless/models/target_type_details_input.rb', line 181

def url
  @url
end

#use_gw_cloud_identity ⇒ Object

Returns the value of attribute use_gw_cloud_identity.



183
184
185
# File 'lib/akeyless/models/target_type_details_input.rb', line 183

def use_gw_cloud_identity
  @use_gw_cloud_identity
end

#user_name ⇒ Object

Returns the value of attribute user_name.



185
186
187
# File 'lib/akeyless/models/target_type_details_input.rb', line 185

def user_name
  @user_name
end

#username ⇒ Object

Returns the value of attribute username.



187
188
189
# File 'lib/akeyless/models/target_type_details_input.rb', line 187

def username
  @username
end

#venafi_api_key ⇒ Object

Returns the value of attribute venafi_api_key.



189
190
191
# File 'lib/akeyless/models/target_type_details_input.rb', line 189

def venafi_api_key
  @venafi_api_key
end

#venafi_base_url ⇒ Object

Returns the value of attribute venafi_base_url.



191
192
193
# File 'lib/akeyless/models/target_type_details_input.rb', line 191

def venafi_base_url
  @venafi_base_url
end

#venafi_tpp_password ⇒ Object

Returns the value of attribute venafi_tpp_password.



193
194
195
# File 'lib/akeyless/models/target_type_details_input.rb', line 193

def venafi_tpp_password
  @venafi_tpp_password
end

#venafi_tpp_username ⇒ Object

Returns the value of attribute venafi_tpp_username.



195
196
197
# File 'lib/akeyless/models/target_type_details_input.rb', line 195

def venafi_tpp_username
  @venafi_tpp_username
end

#venafi_use_tpp ⇒ Object

Returns the value of attribute venafi_use_tpp.



197
198
199
# File 'lib/akeyless/models/target_type_details_input.rb', line 197

def venafi_use_tpp
  @venafi_use_tpp
end

#venafi_zone ⇒ Object

Returns the value of attribute venafi_zone.



199
200
201
# File 'lib/akeyless/models/target_type_details_input.rb', line 199

def venafi_zone
  @venafi_zone
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



295
296
297
# File 'lib/akeyless/models/target_type_details_input.rb', line 295

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/akeyless/models/target_type_details_input.rb', line 202

def self.attribute_map
  {
    :'artifactory_admin_apikey' => :'artifactory_admin_apikey',
    :'artifactory_admin_username' => :'artifactory_admin_username',
    :'artifactory_base_url' => :'artifactory_base_url',
    :'aws_access_key_id' => :'aws_access_key_id',
    :'aws_region' => :'aws_region',
    :'aws_secret_access_key' => :'aws_secret_access_key',
    :'aws_session_token' => :'aws_session_token',
    :'azure_client_id' => :'azure_client_id',
    :'azure_client_secret' => :'azure_client_secret',
    :'azure_tenant_id' => :'azure_tenant_id',
    :'ca_cert_data' => :'ca_cert_data',
    :'ca_cert_name' => :'ca_cert_name',
    :'chef_server_host_name' => :'chef_server_host_name',
    :'chef_server_key' => :'chef_server_key',
    :'chef_server_port' => :'chef_server_port',
    :'chef_server_url' => :'chef_server_url',
    :'chef_server_username' => :'chef_server_username',
    :'chef_skip_ssl' => :'chef_skip_ssl',
    :'client_id' => :'client_id',
    :'client_secret' => :'client_secret',
    :'db_host_name' => :'db_host_name',
    :'db_name' => :'db_name',
    :'db_port' => :'db_port',
    :'db_pwd' => :'db_pwd',
    :'db_server_certificates' => :'db_server_certificates',
    :'db_server_name' => :'db_server_name',
    :'db_user_name' => :'db_user_name',
    :'eks_access_key_id' => :'eks_access_key_id',
    :'eks_cluster_ca_certificate' => :'eks_cluster_ca_certificate',
    :'eks_cluster_endpoint' => :'eks_cluster_endpoint',
    :'eks_cluster_name' => :'eks_cluster_name',
    :'eks_region' => :'eks_region',
    :'eks_secret_access_key' => :'eks_secret_access_key',
    :'gcp_service_account_email' => :'gcp_service_account_email',
    :'gcp_service_account_key' => :'gcp_service_account_key',
    :'github_app_id' => :'github_app_id',
    :'github_app_private_key' => :'github_app_private_key',
    :'github_base_url' => :'github_base_url',
    :'gke_cluster_ca_certificate' => :'gke_cluster_ca_certificate',
    :'gke_cluster_endpoint' => :'gke_cluster_endpoint',
    :'gke_cluster_name' => :'gke_cluster_name',
    :'gke_service_account_key' => :'gke_service_account_key',
    :'gke_service_account_name' => :'gke_service_account_name',
    :'host' => :'host',
    :'k8s_bearer_token' => :'k8s_bearer_token',
    :'k8s_cluster_ca_certificate' => :'k8s_cluster_ca_certificate',
    :'k8s_cluster_endpoint' => :'k8s_cluster_endpoint',
    :'ldap_audience' => :'ldap_audience',
    :'ldap_bind_dn' => :'ldap_bind_dn',
    :'ldap_bind_password' => :'ldap_bind_password',
    :'ldap_certificate' => :'ldap_certificate',
    :'ldap_token_expiration' => :'ldap_token_expiration',
    :'ldap_url' => :'ldap_url',
    :'mongodb_atlas_api_private_key' => :'mongodb_atlas_api_private_key',
    :'mongodb_atlas_api_public_key' => :'mongodb_atlas_api_public_key',
    :'mongodb_atlas_project_id' => :'mongodb_atlas_project_id',
    :'mongodb_db_name' => :'mongodb_db_name',
    :'mongodb_default_auth_db' => :'mongodb_default_auth_db',
    :'mongodb_host_port' => :'mongodb_host_port',
    :'mongodb_is_atlas' => :'mongodb_is_atlas',
    :'mongodb_password' => :'mongodb_password',
    :'mongodb_uri_connection' => :'mongodb_uri_connection',
    :'mongodb_uri_options' => :'mongodb_uri_options',
    :'mongodb_username' => :'mongodb_username',
    :'password' => :'password',
    :'payload' => :'payload',
    :'port' => :'port',
    :'private_key' => :'private_key',
    :'private_key_password' => :'private_key_password',
    :'rabbitmq_server_password' => :'rabbitmq_server_password',
    :'rabbitmq_server_uri' => :'rabbitmq_server_uri',
    :'rabbitmq_server_user' => :'rabbitmq_server_user',
    :'security_token' => :'security_token',
    :'sf_account' => :'sf_account',
    :'ssl_connection_certificate' => :'ssl_connection_certificate',
    :'ssl_connection_mode' => :'ssl_connection_mode',
    :'tenant_url' => :'tenant_url',
    :'url' => :'url',
    :'use_gw_cloud_identity' => :'use_gw_cloud_identity',
    :'user_name' => :'user_name',
    :'username' => :'username',
    :'venafi_api_key' => :'venafi_api_key',
    :'venafi_base_url' => :'venafi_base_url',
    :'venafi_tpp_password' => :'venafi_tpp_password',
    :'venafi_tpp_username' => :'venafi_tpp_username',
    :'venafi_use_tpp' => :'venafi_use_tpp',
    :'venafi_zone' => :'venafi_zone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



886
887
888
# File 'lib/akeyless/models/target_type_details_input.rb', line 886

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



393
394
395
396
# File 'lib/akeyless/models/target_type_details_input.rb', line 393

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/akeyless/models/target_type_details_input.rb', line 300

def self.openapi_types
  {
    :'artifactory_admin_apikey' => :'String',
    :'artifactory_admin_username' => :'String',
    :'artifactory_base_url' => :'String',
    :'aws_access_key_id' => :'String',
    :'aws_region' => :'String',
    :'aws_secret_access_key' => :'String',
    :'aws_session_token' => :'String',
    :'azure_client_id' => :'String',
    :'azure_client_secret' => :'String',
    :'azure_tenant_id' => :'String',
    :'ca_cert_data' => :'Array<Integer>',
    :'ca_cert_name' => :'String',
    :'chef_server_host_name' => :'String',
    :'chef_server_key' => :'String',
    :'chef_server_port' => :'String',
    :'chef_server_url' => :'String',
    :'chef_server_username' => :'String',
    :'chef_skip_ssl' => :'Boolean',
    :'client_id' => :'String',
    :'client_secret' => :'String',
    :'db_host_name' => :'String',
    :'db_name' => :'String',
    :'db_port' => :'String',
    :'db_pwd' => :'String',
    :'db_server_certificates' => :'String',
    :'db_server_name' => :'String',
    :'db_user_name' => :'String',
    :'eks_access_key_id' => :'String',
    :'eks_cluster_ca_certificate' => :'String',
    :'eks_cluster_endpoint' => :'String',
    :'eks_cluster_name' => :'String',
    :'eks_region' => :'String',
    :'eks_secret_access_key' => :'String',
    :'gcp_service_account_email' => :'String',
    :'gcp_service_account_key' => :'String',
    :'github_app_id' => :'Integer',
    :'github_app_private_key' => :'String',
    :'github_base_url' => :'String',
    :'gke_cluster_ca_certificate' => :'String',
    :'gke_cluster_endpoint' => :'String',
    :'gke_cluster_name' => :'String',
    :'gke_service_account_key' => :'String',
    :'gke_service_account_name' => :'String',
    :'host' => :'String',
    :'k8s_bearer_token' => :'String',
    :'k8s_cluster_ca_certificate' => :'String',
    :'k8s_cluster_endpoint' => :'String',
    :'ldap_audience' => :'String',
    :'ldap_bind_dn' => :'String',
    :'ldap_bind_password' => :'String',
    :'ldap_certificate' => :'String',
    :'ldap_token_expiration' => :'String',
    :'ldap_url' => :'String',
    :'mongodb_atlas_api_private_key' => :'String',
    :'mongodb_atlas_api_public_key' => :'String',
    :'mongodb_atlas_project_id' => :'String',
    :'mongodb_db_name' => :'String',
    :'mongodb_default_auth_db' => :'String',
    :'mongodb_host_port' => :'String',
    :'mongodb_is_atlas' => :'Boolean',
    :'mongodb_password' => :'String',
    :'mongodb_uri_connection' => :'String',
    :'mongodb_uri_options' => :'String',
    :'mongodb_username' => :'String',
    :'password' => :'String',
    :'payload' => :'String',
    :'port' => :'String',
    :'private_key' => :'String',
    :'private_key_password' => :'String',
    :'rabbitmq_server_password' => :'String',
    :'rabbitmq_server_uri' => :'String',
    :'rabbitmq_server_user' => :'String',
    :'security_token' => :'String',
    :'sf_account' => :'String',
    :'ssl_connection_certificate' => :'String',
    :'ssl_connection_mode' => :'Boolean',
    :'tenant_url' => :'String',
    :'url' => :'String',
    :'use_gw_cloud_identity' => :'Boolean',
    :'user_name' => :'String',
    :'username' => :'String',
    :'venafi_api_key' => :'String',
    :'venafi_base_url' => :'String',
    :'venafi_tpp_password' => :'String',
    :'venafi_tpp_username' => :'String',
    :'venafi_use_tpp' => :'Boolean',
    :'venafi_zone' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
# File 'lib/akeyless/models/target_type_details_input.rb', line 779

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      artifactory_admin_apikey == o.artifactory_admin_apikey &&
      artifactory_admin_username == o.artifactory_admin_username &&
      artifactory_base_url == o.artifactory_base_url &&
      aws_access_key_id == o.aws_access_key_id &&
      aws_region == o.aws_region &&
      aws_secret_access_key == o.aws_secret_access_key &&
      aws_session_token == o.aws_session_token &&
      azure_client_id == o.azure_client_id &&
      azure_client_secret == o.azure_client_secret &&
      azure_tenant_id == o.azure_tenant_id &&
      ca_cert_data == o.ca_cert_data &&
      ca_cert_name == o.ca_cert_name &&
      chef_server_host_name == o.chef_server_host_name &&
      chef_server_key == o.chef_server_key &&
      chef_server_port == o.chef_server_port &&
      chef_server_url == o.chef_server_url &&
      chef_server_username == o.chef_server_username &&
      chef_skip_ssl == o.chef_skip_ssl &&
      client_id == o.client_id &&
      client_secret == o.client_secret &&
      db_host_name == o.db_host_name &&
      db_name == o.db_name &&
      db_port == o.db_port &&
      db_pwd == o.db_pwd &&
      db_server_certificates == o.db_server_certificates &&
      db_server_name == o.db_server_name &&
      db_user_name == o.db_user_name &&
      eks_access_key_id == o.eks_access_key_id &&
      eks_cluster_ca_certificate == o.eks_cluster_ca_certificate &&
      eks_cluster_endpoint == o.eks_cluster_endpoint &&
      eks_cluster_name == o.eks_cluster_name &&
      eks_region == o.eks_region &&
      eks_secret_access_key == o.eks_secret_access_key &&
       == o. &&
       == o. &&
      github_app_id == o.github_app_id &&
      github_app_private_key == o.github_app_private_key &&
      github_base_url == o.github_base_url &&
      gke_cluster_ca_certificate == o.gke_cluster_ca_certificate &&
      gke_cluster_endpoint == o.gke_cluster_endpoint &&
      gke_cluster_name == o.gke_cluster_name &&
       == o. &&
       == o. &&
      host == o.host &&
      k8s_bearer_token == o.k8s_bearer_token &&
      k8s_cluster_ca_certificate == o.k8s_cluster_ca_certificate &&
      k8s_cluster_endpoint == o.k8s_cluster_endpoint &&
      ldap_audience == o.ldap_audience &&
      ldap_bind_dn == o.ldap_bind_dn &&
      ldap_bind_password == o.ldap_bind_password &&
      ldap_certificate == o.ldap_certificate &&
      ldap_token_expiration == o.ldap_token_expiration &&
      ldap_url == o.ldap_url &&
      mongodb_atlas_api_private_key == o.mongodb_atlas_api_private_key &&
      mongodb_atlas_api_public_key == o.mongodb_atlas_api_public_key &&
      mongodb_atlas_project_id == o.mongodb_atlas_project_id &&
      mongodb_db_name == o.mongodb_db_name &&
      mongodb_default_auth_db == o.mongodb_default_auth_db &&
      mongodb_host_port == o.mongodb_host_port &&
      mongodb_is_atlas == o.mongodb_is_atlas &&
      mongodb_password == o.mongodb_password &&
      mongodb_uri_connection == o.mongodb_uri_connection &&
      mongodb_uri_options == o.mongodb_uri_options &&
      mongodb_username == o.mongodb_username &&
      password == o.password &&
      payload == o.payload &&
      port == o.port &&
      private_key == o.private_key &&
      private_key_password == o.private_key_password &&
      rabbitmq_server_password == o.rabbitmq_server_password &&
      rabbitmq_server_uri == o.rabbitmq_server_uri &&
      rabbitmq_server_user == o.rabbitmq_server_user &&
      security_token == o.security_token &&
       == o. &&
      ssl_connection_certificate == o.ssl_connection_certificate &&
      ssl_connection_mode == o.ssl_connection_mode &&
      tenant_url == o.tenant_url &&
      url == o.url &&
      use_gw_cloud_identity == o.use_gw_cloud_identity &&
      user_name == o.user_name &&
      username == o.username &&
      venafi_api_key == o.venafi_api_key &&
      venafi_base_url == o.venafi_base_url &&
      venafi_tpp_password == o.venafi_tpp_password &&
      venafi_tpp_username == o.venafi_tpp_username &&
      venafi_use_tpp == o.venafi_use_tpp &&
      venafi_zone == o.venafi_zone
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
# File 'lib/akeyless/models/target_type_details_input.rb', line 917

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



988
989
990
991
992
993
994
995
996
997
998
999
1000
# File 'lib/akeyless/models/target_type_details_input.rb', line 988

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
# File 'lib/akeyless/models/target_type_details_input.rb', line 893

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


873
874
875
# File 'lib/akeyless/models/target_type_details_input.rb', line 873

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



879
880
881
# File 'lib/akeyless/models/target_type_details_input.rb', line 879

def hash
  [artifactory_admin_apikey, artifactory_admin_username, artifactory_base_url, aws_access_key_id, aws_region, aws_secret_access_key, aws_session_token, azure_client_id, azure_client_secret, azure_tenant_id, ca_cert_data, ca_cert_name, chef_server_host_name, chef_server_key, chef_server_port, chef_server_url, chef_server_username, chef_skip_ssl, client_id, client_secret, db_host_name, db_name, db_port, db_pwd, db_server_certificates, db_server_name, db_user_name, eks_access_key_id, eks_cluster_ca_certificate, eks_cluster_endpoint, eks_cluster_name, eks_region, eks_secret_access_key, , , github_app_id, github_app_private_key, github_base_url, gke_cluster_ca_certificate, gke_cluster_endpoint, gke_cluster_name, , , host, k8s_bearer_token, k8s_cluster_ca_certificate, k8s_cluster_endpoint, ldap_audience, ldap_bind_dn, ldap_bind_password, ldap_certificate, ldap_token_expiration, ldap_url, mongodb_atlas_api_private_key, mongodb_atlas_api_public_key, mongodb_atlas_project_id, mongodb_db_name, mongodb_default_auth_db, mongodb_host_port, mongodb_is_atlas, mongodb_password, mongodb_uri_connection, mongodb_uri_options, mongodb_username, password, payload, port, private_key, private_key_password, rabbitmq_server_password, rabbitmq_server_uri, rabbitmq_server_user, security_token, , ssl_connection_certificate, ssl_connection_mode, tenant_url, url, use_gw_cloud_identity, user_name, username, venafi_api_key, venafi_base_url, venafi_tpp_password, venafi_tpp_username, venafi_use_tpp, venafi_zone].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



766
767
768
769
# File 'lib/akeyless/models/target_type_details_input.rb', line 766

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



964
965
966
# File 'lib/akeyless/models/target_type_details_input.rb', line 964

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



970
971
972
973
974
975
976
977
978
979
980
981
982
# File 'lib/akeyless/models/target_type_details_input.rb', line 970

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



958
959
960
# File 'lib/akeyless/models/target_type_details_input.rb', line 958

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



773
774
775
# File 'lib/akeyless/models/target_type_details_input.rb', line 773

def valid?
  true
end