Class: Akeyless::TargetUpdateAerospike
- Inherits:
-
Object
- Object
- Akeyless::TargetUpdateAerospike
- Defined in:
- lib/akeyless/models/target_update_aerospike.rb
Instance Attribute Summary collapse
-
#admin_username ⇒ Object
Username of an account with the user-admin role.
-
#aerospike_client_id ⇒ Object
Client ID for Aerospike Cloud authentication (relevant only for Aerospike Cloud).
-
#aerospike_client_secret ⇒ Object
Client secret for Aerospike Cloud authentication (relevant only for Aerospike Cloud).
-
#aerospike_cloud ⇒ Object
Set to 'true' for Aerospike Cloud deployments.
-
#aerospike_cluster_id ⇒ Object
Cloud cluster ID (relevant only for Aerospike Cloud).
-
#client_certificate ⇒ Object
Client certificate for mTLS (mTLS only).
-
#client_private_key ⇒ Object
Client private key for mTLS (mTLS only).
-
#db_server_name ⇒ Object
TLS server name used to verify the certificate hostname.
-
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false].
-
#description ⇒ Object
Description of the object.
-
#enable_mtls ⇒ Object
Enable mutual TLS authentication - requires --ssl=true (true/false).
-
#hostname ⇒ Object
Aerospike host address and port (e.g. url.to.aerospike.db).
-
#json ⇒ Object
Set output format to JSON.
-
#keep_prev_version ⇒ Object
Whether to keep previous version [true/false].
-
#key ⇒ Object
The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used).
-
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
-
#name ⇒ Object
Target name.
-
#namespace ⇒ Object
Namespace name (relevant only for Aerospike db).
-
#new_comment ⇒ Object
Deprecated - use description.
-
#new_name ⇒ Object
New target name.
-
#password ⇒ Object
Password for the admin user.
-
#port ⇒ Object
Database connection port.
-
#skip_server_name_validation ⇒ Object
Skip server name verification while still validating the certificate chain (true/false).
-
#ssl ⇒ Object
Enable SSL encryption (true/false).
-
#ssl_certificate ⇒ Object
Base64-encoded SSL CA certificate from a trusted Certificate Authority (CA).
-
#token ⇒ Object
Authentication token (see
/authand/configure). -
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TargetUpdateAerospike
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TargetUpdateAerospike
Initializes the object
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 178 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::TargetUpdateAerospike` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::TargetUpdateAerospike`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'admin_username') self.admin_username = attributes[:'admin_username'] end if attributes.key?(:'aerospike_client_id') self.aerospike_client_id = attributes[:'aerospike_client_id'] end if attributes.key?(:'aerospike_client_secret') self.aerospike_client_secret = attributes[:'aerospike_client_secret'] end if attributes.key?(:'aerospike_cloud') self.aerospike_cloud = attributes[:'aerospike_cloud'] end if attributes.key?(:'aerospike_cluster_id') self.aerospike_cluster_id = attributes[:'aerospike_cluster_id'] end if attributes.key?(:'client_certificate') self.client_certificate = attributes[:'client_certificate'] end if attributes.key?(:'client_private_key') self.client_private_key = attributes[:'client_private_key'] end if attributes.key?(:'db_server_name') self.db_server_name = attributes[:'db_server_name'] end if attributes.key?(:'delete_protection') self.delete_protection = attributes[:'delete_protection'] end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = 'default_comment' end if attributes.key?(:'enable_mtls') self.enable_mtls = attributes[:'enable_mtls'] end if attributes.key?(:'hostname') self.hostname = attributes[:'hostname'] end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'keep_prev_version') self.keep_prev_version = attributes[:'keep_prev_version'] end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'max_versions') self.max_versions = attributes[:'max_versions'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'namespace') self.namespace = attributes[:'namespace'] end if attributes.key?(:'new_comment') self.new_comment = attributes[:'new_comment'] else self.new_comment = 'default_comment' end if attributes.key?(:'new_name') self.new_name = attributes[:'new_name'] end if attributes.key?(:'password') self.password = attributes[:'password'] end if attributes.key?(:'port') self.port = attributes[:'port'] end if attributes.key?(:'skip_server_name_validation') self.skip_server_name_validation = attributes[:'skip_server_name_validation'] end if attributes.key?(:'ssl') self.ssl = attributes[:'ssl'] end if attributes.key?(:'ssl_certificate') self.ssl_certificate = attributes[:'ssl_certificate'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end end |
Instance Attribute Details
#admin_username ⇒ Object
Username of an account with the user-admin role
19 20 21 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 19 def admin_username @admin_username end |
#aerospike_client_id ⇒ Object
Client ID for Aerospike Cloud authentication (relevant only for Aerospike Cloud)
22 23 24 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 22 def aerospike_client_id @aerospike_client_id end |
#aerospike_client_secret ⇒ Object
Client secret for Aerospike Cloud authentication (relevant only for Aerospike Cloud)
25 26 27 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 25 def aerospike_client_secret @aerospike_client_secret end |
#aerospike_cloud ⇒ Object
Set to 'true' for Aerospike Cloud deployments
28 29 30 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 28 def aerospike_cloud @aerospike_cloud end |
#aerospike_cluster_id ⇒ Object
Cloud cluster ID (relevant only for Aerospike Cloud)
31 32 33 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 31 def aerospike_cluster_id @aerospike_cluster_id end |
#client_certificate ⇒ Object
Client certificate for mTLS (mTLS only)
34 35 36 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 34 def client_certificate @client_certificate end |
#client_private_key ⇒ Object
Client private key for mTLS (mTLS only)
37 38 39 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 37 def client_private_key @client_private_key end |
#db_server_name ⇒ Object
TLS server name used to verify the certificate hostname. If empty, the Aerospike hostname is used.
40 41 42 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 40 def db_server_name @db_server_name end |
#delete_protection ⇒ Object
Protection from accidental deletion of this object [true/false]
43 44 45 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 43 def delete_protection @delete_protection end |
#description ⇒ Object
Description of the object
46 47 48 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 46 def description @description end |
#enable_mtls ⇒ Object
Enable mutual TLS authentication - requires --ssl=true (true/false)
49 50 51 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 49 def enable_mtls @enable_mtls end |
#hostname ⇒ Object
Aerospike host address and port (e.g. url.to.aerospike.db)
52 53 54 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 52 def hostname @hostname end |
#json ⇒ Object
Set output format to JSON
55 56 57 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 55 def json @json end |
#keep_prev_version ⇒ Object
Whether to keep previous version [true/false]. If not set, use default according to account settings
58 59 60 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 58 def keep_prev_version @keep_prev_version end |
#key ⇒ Object
The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
61 62 63 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 61 def key @key end |
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
64 65 66 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 64 def max_versions @max_versions end |
#name ⇒ Object
Target name
67 68 69 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 67 def name @name end |
#namespace ⇒ Object
Namespace name (relevant only for Aerospike db)
70 71 72 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 70 def namespace @namespace end |
#new_comment ⇒ Object
Deprecated - use description
73 74 75 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 73 def new_comment @new_comment end |
#new_name ⇒ Object
New target name
76 77 78 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 76 def new_name @new_name end |
#password ⇒ Object
Password for the admin user
79 80 81 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 79 def password @password end |
#port ⇒ Object
Database connection port
82 83 84 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 82 def port @port end |
#skip_server_name_validation ⇒ Object
Skip server name verification while still validating the certificate chain (true/false). Empty means do not skip.
85 86 87 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 85 def skip_server_name_validation @skip_server_name_validation end |
#ssl ⇒ Object
Enable SSL encryption (true/false)
88 89 90 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 88 def ssl @ssl end |
#ssl_certificate ⇒ Object
Base64-encoded SSL CA certificate from a trusted Certificate Authority (CA)
91 92 93 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 91 def ssl_certificate @ssl_certificate end |
#token ⇒ Object
Authentication token (see /auth and /configure)
94 95 96 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 94 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
97 98 99 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 97 def uid_token @uid_token end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 401 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
133 134 135 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 133 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 100 def self.attribute_map { :'admin_username' => :'admin-username', :'aerospike_client_id' => :'aerospike-client-id', :'aerospike_client_secret' => :'aerospike-client-secret', :'aerospike_cloud' => :'aerospike-cloud', :'aerospike_cluster_id' => :'aerospike-cluster-id', :'client_certificate' => :'client-certificate', :'client_private_key' => :'client-private-key', :'db_server_name' => :'db-server-name', :'delete_protection' => :'delete_protection', :'description' => :'description', :'enable_mtls' => :'enable-mtls', :'hostname' => :'hostname', :'json' => :'json', :'keep_prev_version' => :'keep-prev-version', :'key' => :'key', :'max_versions' => :'max-versions', :'name' => :'name', :'namespace' => :'namespace', :'new_comment' => :'new-comment', :'new_name' => :'new-name', :'password' => :'password', :'port' => :'port', :'skip_server_name_validation' => :'skip-server-name-validation', :'ssl' => :'ssl', :'ssl_certificate' => :'ssl-certificate', :'token' => :'token', :'uid_token' => :'uid-token' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 377 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
171 172 173 174 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 171 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 138 def self.openapi_types { :'admin_username' => :'String', :'aerospike_client_id' => :'String', :'aerospike_client_secret' => :'String', :'aerospike_cloud' => :'Boolean', :'aerospike_cluster_id' => :'String', :'client_certificate' => :'String', :'client_private_key' => :'String', :'db_server_name' => :'String', :'delete_protection' => :'String', :'description' => :'String', :'enable_mtls' => :'Boolean', :'hostname' => :'String', :'json' => :'Boolean', :'keep_prev_version' => :'String', :'key' => :'String', :'max_versions' => :'String', :'name' => :'String', :'namespace' => :'String', :'new_comment' => :'String', :'new_name' => :'String', :'password' => :'String', :'port' => :'String', :'skip_server_name_validation' => :'String', :'ssl' => :'Boolean', :'ssl_certificate' => :'String', :'token' => :'String', :'uid_token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 330 def ==(o) return true if self.equal?(o) self.class == o.class && admin_username == o.admin_username && aerospike_client_id == o.aerospike_client_id && aerospike_client_secret == o.aerospike_client_secret && aerospike_cloud == o.aerospike_cloud && aerospike_cluster_id == o.aerospike_cluster_id && client_certificate == o.client_certificate && client_private_key == o.client_private_key && db_server_name == o.db_server_name && delete_protection == o.delete_protection && description == o.description && enable_mtls == o.enable_mtls && hostname == o.hostname && json == o.json && keep_prev_version == o.keep_prev_version && key == o.key && max_versions == o.max_versions && name == o.name && namespace == o.namespace && new_comment == o.new_comment && new_name == o.new_name && password == o.password && port == o.port && skip_server_name_validation == o.skip_server_name_validation && ssl == o.ssl && ssl_certificate == o.ssl_certificate && token == o.token && uid_token == o.uid_token end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
472 473 474 475 476 477 478 479 480 481 482 483 484 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 472 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
364 365 366 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 364 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
370 371 372 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 370 def hash [admin_username, aerospike_client_id, aerospike_client_secret, aerospike_cloud, aerospike_cluster_id, client_certificate, client_private_key, db_server_name, delete_protection, description, enable_mtls, hostname, json, keep_prev_version, key, max_versions, name, namespace, new_comment, new_name, password, port, skip_server_name_validation, ssl, ssl_certificate, token, uid_token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
310 311 312 313 314 315 316 317 318 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 310 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
448 449 450 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 448 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
454 455 456 457 458 459 460 461 462 463 464 465 466 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 454 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
442 443 444 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 442 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
322 323 324 325 326 |
# File 'lib/akeyless/models/target_update_aerospike.rb', line 322 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |