Class: Akeyless::TargetUpdateLetsEncrypt
- Inherits:
-
Object
- Object
- Akeyless::TargetUpdateLetsEncrypt
- Defined in:
- lib/akeyless/models/target_update_lets_encrypt.rb
Overview
targetUpdateLetsEncrypt is a command that updates an existing Let’s Encrypt target
Instance Attribute Summary collapse
-
#acme_challenge ⇒ Object
Returns the value of attribute acme_challenge.
-
#description ⇒ Object
Description of the object.
-
#dns_target_creds ⇒ Object
Name of existing cloud target for DNS credentials.
-
#email ⇒ Object
Email address for ACME account registration.
-
#gcp_project ⇒ Object
GCP Cloud DNS: Project ID.
-
#hosted_zone ⇒ Object
AWS Route53 hosted zone ID.
-
#json ⇒ Object
Set output format to JSON.
-
#keep_prev_version ⇒ Object
Whether to keep previous version [true/false].
-
#key ⇒ Object
The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used).
-
#lets_encrypt_url ⇒ Object
Returns the value of attribute lets_encrypt_url.
-
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
-
#name ⇒ Object
Target name.
-
#new_name ⇒ Object
New target name.
-
#resource_group ⇒ Object
Azure resource group name.
-
#timeout ⇒ Object
Returns the value of attribute timeout.
-
#token ⇒ Object
Authentication token (see
/authand/configure). -
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TargetUpdateLetsEncrypt
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TargetUpdateLetsEncrypt
Initializes the object
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 126 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::TargetUpdateLetsEncrypt` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::TargetUpdateLetsEncrypt`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'acme_challenge') self.acme_challenge = attributes[:'acme_challenge'] else self.acme_challenge = 'http' end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'dns_target_creds') self.dns_target_creds = attributes[:'dns_target_creds'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'gcp_project') self.gcp_project = attributes[:'gcp_project'] end if attributes.key?(:'hosted_zone') self.hosted_zone = attributes[:'hosted_zone'] end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'keep_prev_version') self.keep_prev_version = attributes[:'keep_prev_version'] end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'lets_encrypt_url') self.lets_encrypt_url = attributes[:'lets_encrypt_url'] else self.lets_encrypt_url = 'production' end if attributes.key?(:'max_versions') self.max_versions = attributes[:'max_versions'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'new_name') self.new_name = attributes[:'new_name'] end if attributes.key?(:'resource_group') self.resource_group = attributes[:'resource_group'] end if attributes.key?(:'timeout') self.timeout = attributes[:'timeout'] else self.timeout = '5m' end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end end |
Instance Attribute Details
#acme_challenge ⇒ Object
Returns the value of attribute acme_challenge.
19 20 21 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 19 def acme_challenge @acme_challenge end |
#description ⇒ Object
Description of the object
22 23 24 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 22 def description @description end |
#dns_target_creds ⇒ Object
Name of existing cloud target for DNS credentials. Required when acme-challenge=dns. Supported: AWS, Azure, GCP targets
25 26 27 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 25 def dns_target_creds @dns_target_creds end |
#email ⇒ Object
Email address for ACME account registration
28 29 30 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 28 def email @email end |
#gcp_project ⇒ Object
GCP Cloud DNS: Project ID. Optional - can be derived from service account
31 32 33 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 31 def gcp_project @gcp_project end |
#hosted_zone ⇒ Object
AWS Route53 hosted zone ID. Required when dns-target-creds points to AWS target
34 35 36 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 34 def hosted_zone @hosted_zone end |
#json ⇒ Object
Set output format to JSON
37 38 39 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 37 def json @json end |
#keep_prev_version ⇒ Object
Whether to keep previous version [true/false]. If not set, use default according to account settings
40 41 42 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 40 def keep_prev_version @keep_prev_version end |
#key ⇒ Object
The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)
43 44 45 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 43 def key @key end |
#lets_encrypt_url ⇒ Object
Returns the value of attribute lets_encrypt_url.
45 46 47 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 45 def lets_encrypt_url @lets_encrypt_url end |
#max_versions ⇒ Object
Set the maximum number of versions, limited by the account settings defaults.
48 49 50 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 48 def max_versions @max_versions end |
#name ⇒ Object
Target name
51 52 53 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 51 def name @name end |
#new_name ⇒ Object
New target name
54 55 56 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 54 def new_name @new_name end |
#resource_group ⇒ Object
Azure resource group name. Required when dns-target-creds points to Azure target
57 58 59 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 57 def resource_group @resource_group end |
#timeout ⇒ Object
Returns the value of attribute timeout.
59 60 61 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 59 def timeout @timeout end |
#token ⇒ Object
Authentication token (see /auth and /configure)
62 63 64 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 62 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
65 66 67 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 65 def uid_token @uid_token end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 301 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
91 92 93 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 91 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 68 def self.attribute_map { :'acme_challenge' => :'acme-challenge', :'description' => :'description', :'dns_target_creds' => :'dns-target-creds', :'email' => :'email', :'gcp_project' => :'gcp-project', :'hosted_zone' => :'hosted-zone', :'json' => :'json', :'keep_prev_version' => :'keep-prev-version', :'key' => :'key', :'lets_encrypt_url' => :'lets-encrypt-url', :'max_versions' => :'max-versions', :'name' => :'name', :'new_name' => :'new-name', :'resource_group' => :'resource-group', :'timeout' => :'timeout', :'token' => :'token', :'uid_token' => :'uid-token' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 277 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
119 120 121 122 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 119 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 96 def self.openapi_types { :'acme_challenge' => :'String', :'description' => :'String', :'dns_target_creds' => :'String', :'email' => :'String', :'gcp_project' => :'String', :'hosted_zone' => :'String', :'json' => :'Boolean', :'keep_prev_version' => :'String', :'key' => :'String', :'lets_encrypt_url' => :'String', :'max_versions' => :'String', :'name' => :'String', :'new_name' => :'String', :'resource_group' => :'String', :'timeout' => :'String', :'token' => :'String', :'uid_token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 240 def ==(o) return true if self.equal?(o) self.class == o.class && acme_challenge == o.acme_challenge && description == o.description && dns_target_creds == o.dns_target_creds && email == o.email && gcp_project == o.gcp_project && hosted_zone == o.hosted_zone && json == o.json && keep_prev_version == o.keep_prev_version && key == o.key && lets_encrypt_url == o.lets_encrypt_url && max_versions == o.max_versions && name == o.name && new_name == o.new_name && resource_group == o.resource_group && timeout == o.timeout && token == o.token && uid_token == o.uid_token end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 372 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
264 265 266 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 264 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
270 271 272 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 270 def hash [acme_challenge, description, dns_target_creds, email, gcp_project, hosted_zone, json, keep_prev_version, key, lets_encrypt_url, max_versions, name, new_name, resource_group, timeout, token, uid_token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
220 221 222 223 224 225 226 227 228 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 220 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
348 349 350 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 348 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 354 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
342 343 344 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 342 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
232 233 234 235 236 |
# File 'lib/akeyless/models/target_update_lets_encrypt.rb', line 232 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |