Class: Akeyless::UpdateAccountSettings
- Inherits:
-
Object
- Object
- Akeyless::UpdateAccountSettings
- Defined in:
- lib/akeyless/models/update_account_settings.rb
Instance Attribute Summary collapse
-
#address ⇒ Object
Address.
-
#city ⇒ Object
City.
-
#company_name ⇒ Object
Company name.
-
#country ⇒ Object
Country.
-
#default_share_link_ttl_minutes ⇒ Object
Set the default ttl in minutes for sharing item number between 60 and 43200.
-
#default_versioning ⇒ Object
If set to true, new item version will be created on each update [true/false].
-
#dp_enable_classic_key_protection ⇒ Object
Set to update protection with classic keys state [true/false].
-
#item_type ⇒ Object
VersionSettingsObjectType defines object types for account version settings.
-
#items_deletion_protection ⇒ Object
Set or unset the default behaviour of items deletion protection [true/false].
-
#json ⇒ Object
Set output format to JSON.
-
#jwt_ttl_default ⇒ Object
Default ttl.
-
#jwt_ttl_max ⇒ Object
Maximum ttl.
-
#jwt_ttl_min ⇒ Object
Minimum ttl.
-
#max_versions ⇒ Object
Max versions.
-
#password_length ⇒ Object
Password length between 5 - to 50 characters.
-
#phone ⇒ Object
Phone number.
-
#postal_code ⇒ Object
Postal code.
-
#token ⇒ Object
Authentication token (see
/authand/configure). -
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication.
-
#use_capital_letters ⇒ Object
Password must contain capital letters [true/false].
-
#use_lower_letters ⇒ Object
Password must contain lower case letters [true/false].
-
#use_numbers ⇒ Object
Password must contain numbers [true/false].
-
#use_special_characters ⇒ Object
Password must contain special characters [true/false].
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAccountSettings
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAccountSettings
Initializes the object
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/akeyless/models/update_account_settings.rb', line 158 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::UpdateAccountSettings` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::UpdateAccountSettings`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'company_name') self.company_name = attributes[:'company_name'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'default_share_link_ttl_minutes') self.default_share_link_ttl_minutes = attributes[:'default_share_link_ttl_minutes'] end if attributes.key?(:'default_versioning') self.default_versioning = attributes[:'default_versioning'] end if attributes.key?(:'dp_enable_classic_key_protection') self.dp_enable_classic_key_protection = attributes[:'dp_enable_classic_key_protection'] end if attributes.key?(:'item_type') self.item_type = attributes[:'item_type'] end if attributes.key?(:'items_deletion_protection') self.items_deletion_protection = attributes[:'items_deletion_protection'] end if attributes.key?(:'json') self.json = attributes[:'json'] else self.json = false end if attributes.key?(:'jwt_ttl_default') self.jwt_ttl_default = attributes[:'jwt_ttl_default'] end if attributes.key?(:'jwt_ttl_max') self.jwt_ttl_max = attributes[:'jwt_ttl_max'] end if attributes.key?(:'jwt_ttl_min') self.jwt_ttl_min = attributes[:'jwt_ttl_min'] end if attributes.key?(:'max_versions') self.max_versions = attributes[:'max_versions'] end if attributes.key?(:'password_length') self.password_length = attributes[:'password_length'] end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'uid_token') self.uid_token = attributes[:'uid_token'] end if attributes.key?(:'use_lower_letters') self.use_lower_letters = attributes[:'use_lower_letters'] end if attributes.key?(:'use_numbers') self.use_numbers = attributes[:'use_numbers'] end if attributes.key?(:'use_special_characters') self.use_special_characters = attributes[:'use_special_characters'] end if attributes.key?(:'use_capital_letters') self.use_capital_letters = attributes[:'use_capital_letters'] end end |
Instance Attribute Details
#address ⇒ Object
Address
19 20 21 |
# File 'lib/akeyless/models/update_account_settings.rb', line 19 def address @address end |
#city ⇒ Object
City
22 23 24 |
# File 'lib/akeyless/models/update_account_settings.rb', line 22 def city @city end |
#company_name ⇒ Object
Company name
25 26 27 |
# File 'lib/akeyless/models/update_account_settings.rb', line 25 def company_name @company_name end |
#country ⇒ Object
Country
28 29 30 |
# File 'lib/akeyless/models/update_account_settings.rb', line 28 def country @country end |
#default_share_link_ttl_minutes ⇒ Object
Set the default ttl in minutes for sharing item number between 60 and 43200
31 32 33 |
# File 'lib/akeyless/models/update_account_settings.rb', line 31 def default_share_link_ttl_minutes @default_share_link_ttl_minutes end |
#default_versioning ⇒ Object
If set to true, new item version will be created on each update [true/false]
34 35 36 |
# File 'lib/akeyless/models/update_account_settings.rb', line 34 def default_versioning @default_versioning end |
#dp_enable_classic_key_protection ⇒ Object
Set to update protection with classic keys state [true/false]
37 38 39 |
# File 'lib/akeyless/models/update_account_settings.rb', line 37 def dp_enable_classic_key_protection @dp_enable_classic_key_protection end |
#item_type ⇒ Object
VersionSettingsObjectType defines object types for account version settings
40 41 42 |
# File 'lib/akeyless/models/update_account_settings.rb', line 40 def item_type @item_type end |
#items_deletion_protection ⇒ Object
Set or unset the default behaviour of items deletion protection [true/false]
43 44 45 |
# File 'lib/akeyless/models/update_account_settings.rb', line 43 def items_deletion_protection @items_deletion_protection end |
#json ⇒ Object
Set output format to JSON
46 47 48 |
# File 'lib/akeyless/models/update_account_settings.rb', line 46 def json @json end |
#jwt_ttl_default ⇒ Object
Default ttl
49 50 51 |
# File 'lib/akeyless/models/update_account_settings.rb', line 49 def jwt_ttl_default @jwt_ttl_default end |
#jwt_ttl_max ⇒ Object
Maximum ttl
52 53 54 |
# File 'lib/akeyless/models/update_account_settings.rb', line 52 def jwt_ttl_max @jwt_ttl_max end |
#jwt_ttl_min ⇒ Object
Minimum ttl
55 56 57 |
# File 'lib/akeyless/models/update_account_settings.rb', line 55 def jwt_ttl_min @jwt_ttl_min end |
#max_versions ⇒ Object
Max versions
58 59 60 |
# File 'lib/akeyless/models/update_account_settings.rb', line 58 def max_versions @max_versions end |
#password_length ⇒ Object
Password length between 5 - to 50 characters
61 62 63 |
# File 'lib/akeyless/models/update_account_settings.rb', line 61 def password_length @password_length end |
#phone ⇒ Object
Phone number
64 65 66 |
# File 'lib/akeyless/models/update_account_settings.rb', line 64 def phone @phone end |
#postal_code ⇒ Object
Postal code
67 68 69 |
# File 'lib/akeyless/models/update_account_settings.rb', line 67 def postal_code @postal_code end |
#token ⇒ Object
Authentication token (see /auth and /configure)
70 71 72 |
# File 'lib/akeyless/models/update_account_settings.rb', line 70 def token @token end |
#uid_token ⇒ Object
The universal identity token, Required only for universal_identity authentication
73 74 75 |
# File 'lib/akeyless/models/update_account_settings.rb', line 73 def uid_token @uid_token end |
#use_capital_letters ⇒ Object
Password must contain capital letters [true/false]
85 86 87 |
# File 'lib/akeyless/models/update_account_settings.rb', line 85 def use_capital_letters @use_capital_letters end |
#use_lower_letters ⇒ Object
Password must contain lower case letters [true/false]
76 77 78 |
# File 'lib/akeyless/models/update_account_settings.rb', line 76 def use_lower_letters @use_lower_letters end |
#use_numbers ⇒ Object
Password must contain numbers [true/false]
79 80 81 |
# File 'lib/akeyless/models/update_account_settings.rb', line 79 def use_numbers @use_numbers end |
#use_special_characters ⇒ Object
Password must contain special characters [true/false]
82 83 84 |
# File 'lib/akeyless/models/update_account_settings.rb', line 82 def use_special_characters @use_special_characters end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
117 118 119 |
# File 'lib/akeyless/models/update_account_settings.rb', line 117 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/akeyless/models/update_account_settings.rb', line 88 def self.attribute_map { :'address' => :'address', :'city' => :'city', :'company_name' => :'company-name', :'country' => :'country', :'default_share_link_ttl_minutes' => :'default-share-link-ttl-minutes', :'default_versioning' => :'default-versioning', :'dp_enable_classic_key_protection' => :'dp-enable-classic-key-protection', :'item_type' => :'item-type', :'items_deletion_protection' => :'items-deletion-protection', :'json' => :'json', :'jwt_ttl_default' => :'jwt-ttl-default', :'jwt_ttl_max' => :'jwt-ttl-max', :'jwt_ttl_min' => :'jwt-ttl-min', :'max_versions' => :'max-versions', :'password_length' => :'password-length', :'phone' => :'phone', :'postal_code' => :'postal-code', :'token' => :'token', :'uid_token' => :'uid-token', :'use_lower_letters' => :'use-lower-letters', :'use_numbers' => :'use-numbers', :'use_special_characters' => :'use-special-characters', :'use_capital_letters' => :'use_capital-letters' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
324 325 326 |
# File 'lib/akeyless/models/update_account_settings.rb', line 324 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
151 152 153 154 |
# File 'lib/akeyless/models/update_account_settings.rb', line 151 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/akeyless/models/update_account_settings.rb', line 122 def self.openapi_types { :'address' => :'String', :'city' => :'String', :'company_name' => :'String', :'country' => :'String', :'default_share_link_ttl_minutes' => :'String', :'default_versioning' => :'String', :'dp_enable_classic_key_protection' => :'String', :'item_type' => :'String', :'items_deletion_protection' => :'String', :'json' => :'Boolean', :'jwt_ttl_default' => :'Integer', :'jwt_ttl_max' => :'Integer', :'jwt_ttl_min' => :'Integer', :'max_versions' => :'String', :'password_length' => :'Integer', :'phone' => :'String', :'postal_code' => :'String', :'token' => :'String', :'uid_token' => :'String', :'use_lower_letters' => :'String', :'use_numbers' => :'String', :'use_special_characters' => :'String', :'use_capital_letters' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/akeyless/models/update_account_settings.rb', line 281 def ==(o) return true if self.equal?(o) self.class == o.class && address == o.address && city == o.city && company_name == o.company_name && country == o.country && default_share_link_ttl_minutes == o.default_share_link_ttl_minutes && default_versioning == o.default_versioning && dp_enable_classic_key_protection == o.dp_enable_classic_key_protection && item_type == o.item_type && items_deletion_protection == o.items_deletion_protection && json == o.json && jwt_ttl_default == o.jwt_ttl_default && jwt_ttl_max == o.jwt_ttl_max && jwt_ttl_min == o.jwt_ttl_min && max_versions == o.max_versions && password_length == o.password_length && phone == o.phone && postal_code == o.postal_code && token == o.token && uid_token == o.uid_token && use_lower_letters == o.use_lower_letters && use_numbers == o.use_numbers && use_special_characters == o.use_special_characters && use_capital_letters == o.use_capital_letters end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/akeyless/models/update_account_settings.rb', line 355 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Akeyless.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/akeyless/models/update_account_settings.rb', line 426 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/akeyless/models/update_account_settings.rb', line 331 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
311 312 313 |
# File 'lib/akeyless/models/update_account_settings.rb', line 311 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
317 318 319 |
# File 'lib/akeyless/models/update_account_settings.rb', line 317 def hash [address, city, company_name, country, default_share_link_ttl_minutes, default_versioning, dp_enable_classic_key_protection, item_type, items_deletion_protection, json, jwt_ttl_default, jwt_ttl_max, jwt_ttl_min, max_versions, password_length, phone, postal_code, token, uid_token, use_lower_letters, use_numbers, use_special_characters, use_capital_letters].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
268 269 270 271 |
# File 'lib/akeyless/models/update_account_settings.rb', line 268 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
402 403 404 |
# File 'lib/akeyless/models/update_account_settings.rb', line 402 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/akeyless/models/update_account_settings.rb', line 408 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
396 397 398 |
# File 'lib/akeyless/models/update_account_settings.rb', line 396 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
275 276 277 |
# File 'lib/akeyless/models/update_account_settings.rb', line 275 def valid? true end |