Class: Akeyless::UpdateDBTarget

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/update_db_target.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateDBTarget

Initializes the object



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/akeyless/models/update_db_target.rb', line 163

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::UpdateDBTarget` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::UpdateDBTarget`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'db_name')
    self.db_name = attributes[:'db_name']
  end

  if attributes.key?(:'db_server_certificates')
    self.db_server_certificates = attributes[:'db_server_certificates']
  end

  if attributes.key?(:'db_server_name')
    self.db_server_name = attributes[:'db_server_name']
  end

  if attributes.key?(:'db_type')
    self.db_type = attributes[:'db_type']
  end

  if attributes.key?(:'host')
    self.host = attributes[:'host']
  end

  if attributes.key?(:'keep_prev_version')
    self.keep_prev_version = attributes[:'keep_prev_version']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'mongodb_atlas')
    self.mongodb_atlas = attributes[:'mongodb_atlas']
  end

  if attributes.key?(:'mongodb_atlas_api_private_key')
    self.mongodb_atlas_api_private_key = attributes[:'mongodb_atlas_api_private_key']
  end

  if attributes.key?(:'mongodb_atlas_api_public_key')
    self.mongodb_atlas_api_public_key = attributes[:'mongodb_atlas_api_public_key']
  end

  if attributes.key?(:'mongodb_atlas_project_id')
    self.mongodb_atlas_project_id = attributes[:'mongodb_atlas_project_id']
  end

  if attributes.key?(:'mongodb_default_auth_db')
    self.mongodb_default_auth_db = attributes[:'mongodb_default_auth_db']
  end

  if attributes.key?(:'mongodb_uri_options')
    self.mongodb_uri_options = attributes[:'mongodb_uri_options']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'oracle_service_name')
    self.oracle_service_name = attributes[:'oracle_service_name']
  end

  if attributes.key?(:'port')
    self.port = attributes[:'port']
  end

  if attributes.key?(:'pwd')
    self.pwd = attributes[:'pwd']
  end

  if attributes.key?(:'snowflake_account')
    self. = attributes[:'snowflake_account']
  end

  if attributes.key?(:'ssl')
    self.ssl = attributes[:'ssl']
  end

  if attributes.key?(:'ssl_certificate')
    self.ssl_certificate = attributes[:'ssl_certificate']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end

  if attributes.key?(:'update_version')
    self.update_version = attributes[:'update_version']
  end

  if attributes.key?(:'user_name')
    self.user_name = attributes[:'user_name']
  end
end

Instance Attribute Details

#commentObject

Comment about the target



19
20
21
# File 'lib/akeyless/models/update_db_target.rb', line 19

def comment
  @comment
end

#db_nameObject

Returns the value of attribute db_name.



21
22
23
# File 'lib/akeyless/models/update_db_target.rb', line 21

def db_name
  @db_name
end

#db_server_certificatesObject

(Optional) DB server certificates



24
25
26
# File 'lib/akeyless/models/update_db_target.rb', line 24

def db_server_certificates
  @db_server_certificates
end

#db_server_nameObject

(Optional) Server name for certificate verification



27
28
29
# File 'lib/akeyless/models/update_db_target.rb', line 27

def db_server_name
  @db_server_name
end

#db_typeObject

Returns the value of attribute db_type.



29
30
31
# File 'lib/akeyless/models/update_db_target.rb', line 29

def db_type
  @db_type
end

#hostObject

Returns the value of attribute host.



31
32
33
# File 'lib/akeyless/models/update_db_target.rb', line 31

def host
  @host
end

#keep_prev_versionObject

Returns the value of attribute keep_prev_version.



33
34
35
# File 'lib/akeyless/models/update_db_target.rb', line 33

def keep_prev_version
  @keep_prev_version
end

#keyObject

The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)



36
37
38
# File 'lib/akeyless/models/update_db_target.rb', line 36

def key
  @key
end

#mongodb_atlasObject

Returns the value of attribute mongodb_atlas.



38
39
40
# File 'lib/akeyless/models/update_db_target.rb', line 38

def mongodb_atlas
  @mongodb_atlas
end

#mongodb_atlas_api_private_keyObject

MongoDB Atlas private key



41
42
43
# File 'lib/akeyless/models/update_db_target.rb', line 41

def mongodb_atlas_api_private_key
  @mongodb_atlas_api_private_key
end

#mongodb_atlas_api_public_keyObject

MongoDB Atlas public key



44
45
46
# File 'lib/akeyless/models/update_db_target.rb', line 44

def mongodb_atlas_api_public_key
  @mongodb_atlas_api_public_key
end

#mongodb_atlas_project_idObject

MongoDB Atlas project ID



47
48
49
# File 'lib/akeyless/models/update_db_target.rb', line 47

def mongodb_atlas_project_id
  @mongodb_atlas_project_id
end

#mongodb_default_auth_dbObject

MongoDB server default authentication database



50
51
52
# File 'lib/akeyless/models/update_db_target.rb', line 50

def mongodb_default_auth_db
  @mongodb_default_auth_db
end

#mongodb_uri_optionsObject

MongoDB server URI options



53
54
55
# File 'lib/akeyless/models/update_db_target.rb', line 53

def mongodb_uri_options
  @mongodb_uri_options
end

#nameObject

Target name



56
57
58
# File 'lib/akeyless/models/update_db_target.rb', line 56

def name
  @name
end

#new_nameObject

New target name



59
60
61
# File 'lib/akeyless/models/update_db_target.rb', line 59

def new_name
  @new_name
end

#oracle_service_nameObject

Returns the value of attribute oracle_service_name.



61
62
63
# File 'lib/akeyless/models/update_db_target.rb', line 61

def oracle_service_name
  @oracle_service_name
end

#portObject

Returns the value of attribute port.



63
64
65
# File 'lib/akeyless/models/update_db_target.rb', line 63

def port
  @port
end

#pwdObject

Returns the value of attribute pwd.



65
66
67
# File 'lib/akeyless/models/update_db_target.rb', line 65

def pwd
  @pwd
end

#snowflake_accountObject

Returns the value of attribute snowflake_account.



67
68
69
# File 'lib/akeyless/models/update_db_target.rb', line 67

def 
  @snowflake_account
end

#sslObject

SSL connection mode



70
71
72
# File 'lib/akeyless/models/update_db_target.rb', line 70

def ssl
  @ssl
end

#ssl_certificateObject

SSL connection certificate



73
74
75
# File 'lib/akeyless/models/update_db_target.rb', line 73

def ssl_certificate
  @ssl_certificate
end

#tokenObject

Authentication token (see /auth and /configure)



76
77
78
# File 'lib/akeyless/models/update_db_target.rb', line 76

def token
  @token
end

#uid_tokenObject

The universal identity token, Required only for universal_identity authentication



79
80
81
# File 'lib/akeyless/models/update_db_target.rb', line 79

def uid_token
  @uid_token
end

#update_versionObject

Deprecated



82
83
84
# File 'lib/akeyless/models/update_db_target.rb', line 82

def update_version
  @update_version
end

#user_nameObject

Returns the value of attribute user_name.



84
85
86
# File 'lib/akeyless/models/update_db_target.rb', line 84

def user_name
  @user_name
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



119
120
121
# File 'lib/akeyless/models/update_db_target.rb', line 119

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/akeyless/models/update_db_target.rb', line 87

def self.attribute_map
  {
    :'comment' => :'comment',
    :'db_name' => :'db-name',
    :'db_server_certificates' => :'db-server-certificates',
    :'db_server_name' => :'db-server-name',
    :'db_type' => :'db-type',
    :'host' => :'host',
    :'keep_prev_version' => :'keep-prev-version',
    :'key' => :'key',
    :'mongodb_atlas' => :'mongodb-atlas',
    :'mongodb_atlas_api_private_key' => :'mongodb-atlas-api-private-key',
    :'mongodb_atlas_api_public_key' => :'mongodb-atlas-api-public-key',
    :'mongodb_atlas_project_id' => :'mongodb-atlas-project-id',
    :'mongodb_default_auth_db' => :'mongodb-default-auth-db',
    :'mongodb_uri_options' => :'mongodb-uri-options',
    :'name' => :'name',
    :'new_name' => :'new-name',
    :'oracle_service_name' => :'oracle-service-name',
    :'port' => :'port',
    :'pwd' => :'pwd',
    :'snowflake_account' => :'snowflake-account',
    :'ssl' => :'ssl',
    :'ssl_certificate' => :'ssl-certificate',
    :'token' => :'token',
    :'uid_token' => :'uid-token',
    :'update_version' => :'update-version',
    :'user_name' => :'user-name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



352
353
354
# File 'lib/akeyless/models/update_db_target.rb', line 352

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



156
157
158
159
# File 'lib/akeyless/models/update_db_target.rb', line 156

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/akeyless/models/update_db_target.rb', line 124

def self.openapi_types
  {
    :'comment' => :'String',
    :'db_name' => :'String',
    :'db_server_certificates' => :'String',
    :'db_server_name' => :'String',
    :'db_type' => :'String',
    :'host' => :'String',
    :'keep_prev_version' => :'String',
    :'key' => :'String',
    :'mongodb_atlas' => :'Boolean',
    :'mongodb_atlas_api_private_key' => :'String',
    :'mongodb_atlas_api_public_key' => :'String',
    :'mongodb_atlas_project_id' => :'String',
    :'mongodb_default_auth_db' => :'String',
    :'mongodb_uri_options' => :'String',
    :'name' => :'String',
    :'new_name' => :'String',
    :'oracle_service_name' => :'String',
    :'port' => :'String',
    :'pwd' => :'String',
    :'snowflake_account' => :'String',
    :'ssl' => :'Boolean',
    :'ssl_certificate' => :'String',
    :'token' => :'String',
    :'uid_token' => :'String',
    :'update_version' => :'Boolean',
    :'user_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/akeyless/models/update_db_target.rb', line 306

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      comment == o.comment &&
      db_name == o.db_name &&
      db_server_certificates == o.db_server_certificates &&
      db_server_name == o.db_server_name &&
      db_type == o.db_type &&
      host == o.host &&
      keep_prev_version == o.keep_prev_version &&
      key == o.key &&
      mongodb_atlas == o.mongodb_atlas &&
      mongodb_atlas_api_private_key == o.mongodb_atlas_api_private_key &&
      mongodb_atlas_api_public_key == o.mongodb_atlas_api_public_key &&
      mongodb_atlas_project_id == o.mongodb_atlas_project_id &&
      mongodb_default_auth_db == o.mongodb_default_auth_db &&
      mongodb_uri_options == o.mongodb_uri_options &&
      name == o.name &&
      new_name == o.new_name &&
      oracle_service_name == o.oracle_service_name &&
      port == o.port &&
      pwd == o.pwd &&
       == o. &&
      ssl == o.ssl &&
      ssl_certificate == o.ssl_certificate &&
      token == o.token &&
      uid_token == o.uid_token &&
      update_version == o.update_version &&
      user_name == o.user_name
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/akeyless/models/update_db_target.rb', line 383

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



454
455
456
457
458
459
460
461
462
463
464
465
466
# File 'lib/akeyless/models/update_db_target.rb', line 454

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/akeyless/models/update_db_target.rb', line 359

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


339
340
341
# File 'lib/akeyless/models/update_db_target.rb', line 339

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



345
346
347
# File 'lib/akeyless/models/update_db_target.rb', line 345

def hash
  [comment, db_name, db_server_certificates, db_server_name, db_type, host, keep_prev_version, key, mongodb_atlas, mongodb_atlas_api_private_key, mongodb_atlas_api_public_key, mongodb_atlas_project_id, mongodb_default_auth_db, mongodb_uri_options, name, new_name, oracle_service_name, port, pwd, , ssl, ssl_certificate, token, uid_token, update_version, user_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/akeyless/models/update_db_target.rb', line 283

def list_invalid_properties
  invalid_properties = Array.new
  if @db_type.nil?
    invalid_properties.push('invalid value for "db_type", db_type cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



430
431
432
# File 'lib/akeyless/models/update_db_target.rb', line 430

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'lib/akeyless/models/update_db_target.rb', line 436

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



424
425
426
# File 'lib/akeyless/models/update_db_target.rb', line 424

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



298
299
300
301
302
# File 'lib/akeyless/models/update_db_target.rb', line 298

def valid?
  return false if @db_type.nil?
  return false if @name.nil?
  true
end