Class: Akeyless::UpdateItem

Inherits:
Object
  • Object
show all
Defined in:
lib/akeyless/models/update_item.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/akeyless/models/update_item.rb', line 188

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Akeyless::UpdateItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Akeyless::UpdateItem`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'accessibility')
    self.accessibility = attributes[:'accessibility']
  end

  if attributes.key?(:'add_tag')
    if (value = attributes[:'add_tag']).is_a?(Array)
      self.add_tag = value
    end
  end

  if attributes.key?(:'cert_file_data')
    self.cert_file_data = attributes[:'cert_file_data']
  end

  if attributes.key?(:'delete_protection')
    self.delete_protection = attributes[:'delete_protection']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'new_metadata')
    self. = attributes[:'new_metadata']
  else
    self. = 'default_metadata'
  end

  if attributes.key?(:'new_name')
    self.new_name = attributes[:'new_name']
  end

  if attributes.key?(:'rm_tag')
    if (value = attributes[:'rm_tag']).is_a?(Array)
      self.rm_tag = value
    end
  end

  if attributes.key?(:'secure_access_add_host')
    if (value = attributes[:'secure_access_add_host']).is_a?(Array)
      self.secure_access_add_host = value
    end
  end

  if attributes.key?(:'secure_access_allow_external_user')
    self.secure_access_allow_external_user = attributes[:'secure_access_allow_external_user']
  end

  if attributes.key?(:'secure_access_allow_port_forwading')
    self.secure_access_allow_port_forwading = attributes[:'secure_access_allow_port_forwading']
  end

  if attributes.key?(:'secure_access_aws_account_id')
    self. = attributes[:'secure_access_aws_account_id']
  end

  if attributes.key?(:'secure_access_aws_native_cli')
    self.secure_access_aws_native_cli = attributes[:'secure_access_aws_native_cli']
  end

  if attributes.key?(:'secure_access_aws_region')
    self.secure_access_aws_region = attributes[:'secure_access_aws_region']
  end

  if attributes.key?(:'secure_access_bastion_api')
    self.secure_access_bastion_api = attributes[:'secure_access_bastion_api']
  end

  if attributes.key?(:'secure_access_bastion_issuer')
    self.secure_access_bastion_issuer = attributes[:'secure_access_bastion_issuer']
  end

  if attributes.key?(:'secure_access_bastion_ssh')
    self.secure_access_bastion_ssh = attributes[:'secure_access_bastion_ssh']
  end

  if attributes.key?(:'secure_access_cluster_endpoint')
    self.secure_access_cluster_endpoint = attributes[:'secure_access_cluster_endpoint']
  end

  if attributes.key?(:'secure_access_dashboard_url')
    self.secure_access_dashboard_url = attributes[:'secure_access_dashboard_url']
  end

  if attributes.key?(:'secure_access_db_name')
    self.secure_access_db_name = attributes[:'secure_access_db_name']
  end

  if attributes.key?(:'secure_access_db_schema')
    self.secure_access_db_schema = attributes[:'secure_access_db_schema']
  end

  if attributes.key?(:'secure_access_enable')
    self.secure_access_enable = attributes[:'secure_access_enable']
  end

  if attributes.key?(:'secure_access_host')
    if (value = attributes[:'secure_access_host']).is_a?(Array)
      self.secure_access_host = value
    end
  end

  if attributes.key?(:'secure_access_rdp_domain')
    self.secure_access_rdp_domain = attributes[:'secure_access_rdp_domain']
  end

  if attributes.key?(:'secure_access_rdp_user')
    self.secure_access_rdp_user = attributes[:'secure_access_rdp_user']
  end

  if attributes.key?(:'secure_access_rm_host')
    if (value = attributes[:'secure_access_rm_host']).is_a?(Array)
      self.secure_access_rm_host = value
    end
  end

  if attributes.key?(:'secure_access_ssh_creds')
    self.secure_access_ssh_creds = attributes[:'secure_access_ssh_creds']
  end

  if attributes.key?(:'secure_access_ssh_creds_user')
    self.secure_access_ssh_creds_user = attributes[:'secure_access_ssh_creds_user']
  end

  if attributes.key?(:'secure_access_url')
    self.secure_access_url = attributes[:'secure_access_url']
  end

  if attributes.key?(:'secure_access_use_internal_bastion')
    self.secure_access_use_internal_bastion = attributes[:'secure_access_use_internal_bastion']
  end

  if attributes.key?(:'secure_access_web_browsing')
    self.secure_access_web_browsing = attributes[:'secure_access_web_browsing']
  end

  if attributes.key?(:'secure_access_web_proxy')
    self.secure_access_web_proxy = attributes[:'secure_access_web_proxy']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'uid_token')
    self.uid_token = attributes[:'uid_token']
  end
end

Instance Attribute Details

#accessibility ⇒ Object

for personal password manager



19
20
21
# File 'lib/akeyless/models/update_item.rb', line 19

def accessibility
  @accessibility
end

#add_tag ⇒ Object

List of the new tags that will be attached to this item



22
23
24
# File 'lib/akeyless/models/update_item.rb', line 22

def add_tag
  @add_tag
end

#cert_file_data ⇒ Object

PEM Certificate in a Base64 format. Used for updating RSA keys' certificates.



25
26
27
# File 'lib/akeyless/models/update_item.rb', line 25

def cert_file_data
  @cert_file_data
end

#delete_protection ⇒ Object

Returns the value of attribute delete_protection.



27
28
29
# File 'lib/akeyless/models/update_item.rb', line 27

def delete_protection
  @delete_protection
end

#name ⇒ Object

Current item name



30
31
32
# File 'lib/akeyless/models/update_item.rb', line 30

def name
  @name
end

#new_metadata ⇒ Object

New item metadata



33
34
35
# File 'lib/akeyless/models/update_item.rb', line 33

def 
  @new_metadata
end

#new_name ⇒ Object

New item name



36
37
38
# File 'lib/akeyless/models/update_item.rb', line 36

def new_name
  @new_name
end

#rm_tag ⇒ Object

List of the existent tags that will be removed from this item



39
40
41
# File 'lib/akeyless/models/update_item.rb', line 39

def rm_tag
  @rm_tag
end

#secure_access_add_host ⇒ Object

Returns the value of attribute secure_access_add_host.



41
42
43
# File 'lib/akeyless/models/update_item.rb', line 41

def secure_access_add_host
  @secure_access_add_host
end

#secure_access_allow_external_user ⇒ Object

Returns the value of attribute secure_access_allow_external_user.



43
44
45
# File 'lib/akeyless/models/update_item.rb', line 43

def secure_access_allow_external_user
  @secure_access_allow_external_user
end

#secure_access_allow_port_forwading ⇒ Object

Returns the value of attribute secure_access_allow_port_forwading.



45
46
47
# File 'lib/akeyless/models/update_item.rb', line 45

def secure_access_allow_port_forwading
  @secure_access_allow_port_forwading
end

#secure_access_aws_account_id ⇒ Object

Returns the value of attribute secure_access_aws_account_id.



47
48
49
# File 'lib/akeyless/models/update_item.rb', line 47

def 
  @secure_access_aws_account_id
end

#secure_access_aws_native_cli ⇒ Object

Returns the value of attribute secure_access_aws_native_cli.



49
50
51
# File 'lib/akeyless/models/update_item.rb', line 49

def secure_access_aws_native_cli
  @secure_access_aws_native_cli
end

#secure_access_aws_region ⇒ Object

Returns the value of attribute secure_access_aws_region.



51
52
53
# File 'lib/akeyless/models/update_item.rb', line 51

def secure_access_aws_region
  @secure_access_aws_region
end

#secure_access_bastion_api ⇒ Object

Returns the value of attribute secure_access_bastion_api.



53
54
55
# File 'lib/akeyless/models/update_item.rb', line 53

def secure_access_bastion_api
  @secure_access_bastion_api
end

#secure_access_bastion_issuer ⇒ Object

Returns the value of attribute secure_access_bastion_issuer.



55
56
57
# File 'lib/akeyless/models/update_item.rb', line 55

def secure_access_bastion_issuer
  @secure_access_bastion_issuer
end

#secure_access_bastion_ssh ⇒ Object

Returns the value of attribute secure_access_bastion_ssh.



57
58
59
# File 'lib/akeyless/models/update_item.rb', line 57

def secure_access_bastion_ssh
  @secure_access_bastion_ssh
end

#secure_access_cluster_endpoint ⇒ Object

Returns the value of attribute secure_access_cluster_endpoint.



59
60
61
# File 'lib/akeyless/models/update_item.rb', line 59

def secure_access_cluster_endpoint
  @secure_access_cluster_endpoint
end

#secure_access_dashboard_url ⇒ Object

Returns the value of attribute secure_access_dashboard_url.



61
62
63
# File 'lib/akeyless/models/update_item.rb', line 61

def secure_access_dashboard_url
  @secure_access_dashboard_url
end

#secure_access_db_name ⇒ Object

Returns the value of attribute secure_access_db_name.



63
64
65
# File 'lib/akeyless/models/update_item.rb', line 63

def secure_access_db_name
  @secure_access_db_name
end

#secure_access_db_schema ⇒ Object

Returns the value of attribute secure_access_db_schema.



65
66
67
# File 'lib/akeyless/models/update_item.rb', line 65

def secure_access_db_schema
  @secure_access_db_schema
end

#secure_access_enable ⇒ Object

Returns the value of attribute secure_access_enable.



67
68
69
# File 'lib/akeyless/models/update_item.rb', line 67

def secure_access_enable
  @secure_access_enable
end

#secure_access_host ⇒ Object

Returns the value of attribute secure_access_host.



69
70
71
# File 'lib/akeyless/models/update_item.rb', line 69

def secure_access_host
  @secure_access_host
end

#secure_access_rdp_domain ⇒ Object

Returns the value of attribute secure_access_rdp_domain.



71
72
73
# File 'lib/akeyless/models/update_item.rb', line 71

def secure_access_rdp_domain
  @secure_access_rdp_domain
end

#secure_access_rdp_user ⇒ Object

Returns the value of attribute secure_access_rdp_user.



73
74
75
# File 'lib/akeyless/models/update_item.rb', line 73

def secure_access_rdp_user
  @secure_access_rdp_user
end

#secure_access_rm_host ⇒ Object

Returns the value of attribute secure_access_rm_host.



75
76
77
# File 'lib/akeyless/models/update_item.rb', line 75

def secure_access_rm_host
  @secure_access_rm_host
end

#secure_access_ssh_creds ⇒ Object

Returns the value of attribute secure_access_ssh_creds.



77
78
79
# File 'lib/akeyless/models/update_item.rb', line 77

def secure_access_ssh_creds
  @secure_access_ssh_creds
end

#secure_access_ssh_creds_user ⇒ Object

Returns the value of attribute secure_access_ssh_creds_user.



79
80
81
# File 'lib/akeyless/models/update_item.rb', line 79

def secure_access_ssh_creds_user
  @secure_access_ssh_creds_user
end

#secure_access_url ⇒ Object

Returns the value of attribute secure_access_url.



81
82
83
# File 'lib/akeyless/models/update_item.rb', line 81

def secure_access_url
  @secure_access_url
end

#secure_access_use_internal_bastion ⇒ Object

Returns the value of attribute secure_access_use_internal_bastion.



83
84
85
# File 'lib/akeyless/models/update_item.rb', line 83

def secure_access_use_internal_bastion
  @secure_access_use_internal_bastion
end

#secure_access_web_browsing ⇒ Object

Returns the value of attribute secure_access_web_browsing.



85
86
87
# File 'lib/akeyless/models/update_item.rb', line 85

def secure_access_web_browsing
  @secure_access_web_browsing
end

#secure_access_web_proxy ⇒ Object

Returns the value of attribute secure_access_web_proxy.



87
88
89
# File 'lib/akeyless/models/update_item.rb', line 87

def secure_access_web_proxy
  @secure_access_web_proxy
end

#token ⇒ Object

Authentication token (see /auth and /configure)



90
91
92
# File 'lib/akeyless/models/update_item.rb', line 90

def token
  @token
end

#uid_token ⇒ Object

The universal identity token, Required only for universal_identity authentication



93
94
95
# File 'lib/akeyless/models/update_item.rb', line 93

def uid_token
  @uid_token
end

Class Method Details

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



136
137
138
# File 'lib/akeyless/models/update_item.rb', line 136

def self.acceptable_attributes
  attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/akeyless/models/update_item.rb', line 96

def self.attribute_map
  {
    :'accessibility' => :'accessibility',
    :'add_tag' => :'add-tag',
    :'cert_file_data' => :'cert-file-data',
    :'delete_protection' => :'delete_protection',
    :'name' => :'name',
    :'new_metadata' => :'new-metadata',
    :'new_name' => :'new-name',
    :'rm_tag' => :'rm-tag',
    :'secure_access_add_host' => :'secure-access-add-host',
    :'secure_access_allow_external_user' => :'secure-access-allow-external-user',
    :'secure_access_allow_port_forwading' => :'secure-access-allow-port-forwading',
    :'secure_access_aws_account_id' => :'secure-access-aws-account-id',
    :'secure_access_aws_native_cli' => :'secure-access-aws-native-cli',
    :'secure_access_aws_region' => :'secure-access-aws-region',
    :'secure_access_bastion_api' => :'secure-access-bastion-api',
    :'secure_access_bastion_issuer' => :'secure-access-bastion-issuer',
    :'secure_access_bastion_ssh' => :'secure-access-bastion-ssh',
    :'secure_access_cluster_endpoint' => :'secure-access-cluster-endpoint',
    :'secure_access_dashboard_url' => :'secure-access-dashboard-url',
    :'secure_access_db_name' => :'secure-access-db-name',
    :'secure_access_db_schema' => :'secure-access-db-schema',
    :'secure_access_enable' => :'secure-access-enable',
    :'secure_access_host' => :'secure-access-host',
    :'secure_access_rdp_domain' => :'secure-access-rdp-domain',
    :'secure_access_rdp_user' => :'secure-access-rdp-user',
    :'secure_access_rm_host' => :'secure-access-rm-host',
    :'secure_access_ssh_creds' => :'secure-access-ssh-creds',
    :'secure_access_ssh_creds_user' => :'secure-access-ssh-creds-user',
    :'secure_access_url' => :'secure-access-url',
    :'secure_access_use_internal_bastion' => :'secure-access-use-internal-bastion',
    :'secure_access_web_browsing' => :'secure-access-web-browsing',
    :'secure_access_web_proxy' => :'secure-access-web-proxy',
    :'token' => :'token',
    :'uid_token' => :'uid-token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



424
425
426
# File 'lib/akeyless/models/update_item.rb', line 424

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



181
182
183
184
# File 'lib/akeyless/models/update_item.rb', line 181

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/akeyless/models/update_item.rb', line 141

def self.openapi_types
  {
    :'accessibility' => :'String',
    :'add_tag' => :'Array<String>',
    :'cert_file_data' => :'String',
    :'delete_protection' => :'String',
    :'name' => :'String',
    :'new_metadata' => :'String',
    :'new_name' => :'String',
    :'rm_tag' => :'Array<String>',
    :'secure_access_add_host' => :'Array<String>',
    :'secure_access_allow_external_user' => :'String',
    :'secure_access_allow_port_forwading' => :'Boolean',
    :'secure_access_aws_account_id' => :'String',
    :'secure_access_aws_native_cli' => :'Boolean',
    :'secure_access_aws_region' => :'String',
    :'secure_access_bastion_api' => :'String',
    :'secure_access_bastion_issuer' => :'String',
    :'secure_access_bastion_ssh' => :'String',
    :'secure_access_cluster_endpoint' => :'String',
    :'secure_access_dashboard_url' => :'String',
    :'secure_access_db_name' => :'String',
    :'secure_access_db_schema' => :'String',
    :'secure_access_enable' => :'String',
    :'secure_access_host' => :'Array<String>',
    :'secure_access_rdp_domain' => :'String',
    :'secure_access_rdp_user' => :'String',
    :'secure_access_rm_host' => :'Array<String>',
    :'secure_access_ssh_creds' => :'String',
    :'secure_access_ssh_creds_user' => :'String',
    :'secure_access_url' => :'String',
    :'secure_access_use_internal_bastion' => :'Boolean',
    :'secure_access_web_browsing' => :'Boolean',
    :'secure_access_web_proxy' => :'Boolean',
    :'token' => :'String',
    :'uid_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/akeyless/models/update_item.rb', line 370

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      accessibility == o.accessibility &&
      add_tag == o.add_tag &&
      cert_file_data == o.cert_file_data &&
      delete_protection == o.delete_protection &&
      name == o.name &&
       == o. &&
      new_name == o.new_name &&
      rm_tag == o.rm_tag &&
      secure_access_add_host == o.secure_access_add_host &&
      secure_access_allow_external_user == o.secure_access_allow_external_user &&
      secure_access_allow_port_forwading == o.secure_access_allow_port_forwading &&
       == o. &&
      secure_access_aws_native_cli == o.secure_access_aws_native_cli &&
      secure_access_aws_region == o.secure_access_aws_region &&
      secure_access_bastion_api == o.secure_access_bastion_api &&
      secure_access_bastion_issuer == o.secure_access_bastion_issuer &&
      secure_access_bastion_ssh == o.secure_access_bastion_ssh &&
      secure_access_cluster_endpoint == o.secure_access_cluster_endpoint &&
      secure_access_dashboard_url == o.secure_access_dashboard_url &&
      secure_access_db_name == o.secure_access_db_name &&
      secure_access_db_schema == o.secure_access_db_schema &&
      secure_access_enable == o.secure_access_enable &&
      secure_access_host == o.secure_access_host &&
      secure_access_rdp_domain == o.secure_access_rdp_domain &&
      secure_access_rdp_user == o.secure_access_rdp_user &&
      secure_access_rm_host == o.secure_access_rm_host &&
      secure_access_ssh_creds == o.secure_access_ssh_creds &&
      secure_access_ssh_creds_user == o.secure_access_ssh_creds_user &&
      secure_access_url == o.secure_access_url &&
      secure_access_use_internal_bastion == o.secure_access_use_internal_bastion &&
      secure_access_web_browsing == o.secure_access_web_browsing &&
      secure_access_web_proxy == o.secure_access_web_proxy &&
      token == o.token &&
      uid_token == o.uid_token
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/akeyless/models/update_item.rb', line 455

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Akeyless.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



526
527
528
529
530
531
532
533
534
535
536
537
538
# File 'lib/akeyless/models/update_item.rb', line 526

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/akeyless/models/update_item.rb', line 431

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


411
412
413
# File 'lib/akeyless/models/update_item.rb', line 411

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



417
418
419
# File 'lib/akeyless/models/update_item.rb', line 417

def hash
  [accessibility, add_tag, cert_file_data, delete_protection, name, , new_name, rm_tag, secure_access_add_host, secure_access_allow_external_user, secure_access_allow_port_forwading, , secure_access_aws_native_cli, secure_access_aws_region, secure_access_bastion_api, secure_access_bastion_issuer, secure_access_bastion_ssh, secure_access_cluster_endpoint, secure_access_dashboard_url, secure_access_db_name, secure_access_db_schema, secure_access_enable, secure_access_host, secure_access_rdp_domain, secure_access_rdp_user, secure_access_rm_host, secure_access_ssh_creds, secure_access_ssh_creds_user, secure_access_url, secure_access_use_internal_bastion, secure_access_web_browsing, secure_access_web_proxy, token, uid_token].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



352
353
354
355
356
357
358
359
# File 'lib/akeyless/models/update_item.rb', line 352

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



502
503
504
# File 'lib/akeyless/models/update_item.rb', line 502

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



508
509
510
511
512
513
514
515
516
517
518
519
520
# File 'lib/akeyless/models/update_item.rb', line 508

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



496
497
498
# File 'lib/akeyless/models/update_item.rb', line 496

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



363
364
365
366
# File 'lib/akeyless/models/update_item.rb', line 363

def valid?
  return false if @name.nil?
  true
end